#pragma rtGlobals=3		// Use modern global access method and strict wave access.
#pragma version=2.2
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//EBAS Export Tool for Q-ACSM (EETA)
//written by Jay Slowik (Paul Scherrer Institute, Switzerland)

//Toolkit to export Aerodyne aerosol mass spectrometer (ToF-AMS, Q-AMS, TOF-ACSM, Q-ACSM) data to the EBAS database
//Provides data at Level 0 (measurement time resolution) or Level 2 (re-averaged to hourly data, missing points filled in)
//Requires fully processed ACSM data

//Thanks to:
//Roman Frhlich (Paul Scherrer Institute) - beta testing
//Ann Mari Fjaeraa, Paul Eckhardt, Wenche Aas, Markus Fiebig (Norwegian Institute for Air Research) - EBAS file format and validation
//Howard Rodstein (Wavemetrics, Inc.) - UTF-8 encoding
//Aerodyne AMS/ACSM community
//ACTRIS project
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
strconstant EBAS_version = "2.4a"
constant EBAS_rec2panel= 0
constant EBAS_panel2Rec = 1
constant EBAS_recKill = 2
constant EBAS_STP_hPa = 1013.25
constant EBAS_STP_K = 273.15
strconstant EBAS_regionWMO = "(1) Africa;(2) Asia;(3) South America;(4) North and Central America;(5) South-West Pacific;(6) Europe;(7) Antarctica;"
strconstant EBAS_landUse = "Agricultural;Airport;Blighted area;Commercial;Desert;Forest;Industrial;Military reservation;Mobile;Remote park;Residential;Single point source area;Snowfield;Urban park;Other;Not available;"
strconstant EBAS_landSetting = "Mountain;Polar;Coastal;Rural;Suburban;Urban and center city;Other;Not available;"
strconstant EBAS_inletType = "Cyclone;Diffuser cone;Elutriator;Hat or hood;Impactor--direct;Impactor--virtual/concentrator;Impactor--elutriator combination;Isokinetic;None--open-face filter;Open conductive tubing;Selective filtration;"
strconstant EBAS_inletCut = "None;PM1;PM2.5;PM10;Other;"
strconstant EBAS_instDryer = "Nafion dryer;Diffusion dryer;None;Other (see metadata);"
strconstant EBAS_stationGAW = "G;R;C;"
strconstant EBAS_defSppList = "Org;SO4;NO3;NH4;Chl;Org_43;Org_44;Org_60;"
strconstant EBAS_instType = "Q-ACSM;ToF-ACSM;HR-ToF-AMS;C-ToF-AMS;Q-AMS;"
strconstant EBAS_instID = "qACSM;tACSM;hrAMS;cAMS;qAMS;" //internal codes corresponding to EBAS_instType, <= 5 chars to allow funcRefs
strconstant EBAS_sppList = "Org;SO4;NO3;NH4;Chl;Org_44;Org_43;Org_60;NO3_30;NO3_46;"
strconstant EBAS_metaList = "CE;airbeam;lensPressure;inletPressure;inletRH;inletT;RIE_Org;RIE_SO4;RIE_NO3;RIE_NH4;RIE_Chl;" //list of all possible metadata; inletRH and inletT may be removed if not measured 
strconstant EBAS_instLens = "Standard (PM1);PM2.5;"
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
menu "EBAS"
	"EETA: EBAS Export Tool", ebas_getWindow("EETA", "ebas_main()")
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_getWindow(win_name,proc_name)
	//fetch or create panel
	string win_name,proc_name
	if (itemsinlist(winlist(win_name,";","WIN:64"))>0)
		dowindow /f $win_name
	elseif (!(itemsinlist(winlist(win_name,";","WIN:64"))))
		execute proc_name
	endif
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_main()	
	//if EBAS DF doesn't exist, create & initialize
	if (dataFolderRefStatus(root:EBAS:output) != 1)
		ebas_initialize()
	endif
	
	ebas_winGen_main()
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_initialize()
	//initializes EETA
	newdatafolder/o root:EBAS
	newdatafolder/o root:EBAS:output
	
	dfref oldDF = getdatafolderDFR()
	setdatafolder root:EBAS
	
	variable i, num
	string thisType

	//***** reference info *****\\
	//initialize variables
	
	//records
	string/G info_itxPath, info_itxName
	string typeList1D = "instRec;siteRec;"
	num=itemsinlist(typeList1D)
	for (i=0; i<num; i+=1)
		thisType = stringfromlist(i, typeList1D)	
		ebas_initRecord(thisType)		
	endfor
	//2D records
	string typeList2D = "persRec;orgRec;"
	num=itemsinlist(typeList2D)
	for (i=0; i<num; i+=1)
		thisType = stringfromlist(i, typeList2D)
		wave/t/z/SDFR=root:ebas thisRec = $(thisType+"Rec")
		if (waveexists(thisRec))
			ebas_initRecord(thisType)
		else
			make/O/T/N=0 $("root:ebas:"+thisType+"Rec")
		endif
	endfor
	
	//
	string/G main_sStatus = "Ready"
	variable/G main_vStatus
	
	//project
	string/G proj_acrList = "ACTRIS"
	variable/G proj_versionNum = 1
	string/G proj_versionTxt = "Initial version, manually inspected."
	string/G proj_acknowledge = "Request acknowledgement details from data originator. The EETA export tool was developed with support from ACTRIS."
	string/G proj_comment = ""
	
	//data handling & reporting
//	wave ts = root:ACSM_incoming:acsm_utc_time
	string/G data_currentInst
	string/G data_sppList = EBAS_sppList
	string/G data_CEwave, data_inletT, data_inletP, data_inletRH
	variable/G data_vTimeStart //= ts[0]
	variable/G data_vTimeStop //= ts[numpnts(ts)-1]
	string/G data_sTimeStart = secs2date(data_vTimeStart, -2) + " " + secs2time(data_vTimeStart, 3)
	string/G data_sTimeStop = secs2date(data_vTimeStop, -2) + " " + secs2time(data_vTimeStop, 3)
	
	string/G ref_dataLevel
	string/G ref_timeWave
	string/G ref_detLimMethod = "1 min detection limit; filter measurement"
	
	string/G data_exp_wTS
	string/G data_exp_instructions 
	svar gStr = root:ebas:data_exp_instructions
	gStr = "\f01Enter name of data to export and\rassociated waves (full path).\f00"
	gStr +="\r\f04Quick method:\f00"
	gStr += "\r   1. Locate wave in data browser"
	gStr += "\r   2. Right-click and choose <Copy Full Path>"
	gStr += "\r   3. Paste into export table"
	
	string/G data_report //used to store miscellaneous info about the last "Preview data" calculation; can later be read for header
		//origTimeRes = original time resolution of measurements
	string/G out_lastFile //last file generated by EETA
	
	//data & metadata info waves
	wave/t/z expData_name
	if (!waveexists(expData_name))
		make/O/T/N=0 expData_name, expData_wDat, expData_wErr, expMeta_Name, expMeta_units, expMeta_wVal
	endif
	
	//color reference waves for preview
	make/O/T/N=20 root:ebas:colorTxt /WAVE=colorTxt
	make/O/N=(20,3) root:ebas:colorVal /WAVE=colorVal
	colorTxt[0] = "Org";	colorVal[0][] = {{0},{65280},{0}}
	colorTxt[1] = "SO4";	colorVal[1][] = {{65280},{0},{0}}
	colorTxt[2] = "NO3";	colorVal[2][] = {{0},{0},{65280}} 
	colorTxt[3] = "NH4";	colorVal[3][] = {{65280},{43520},{0}} 
	colorTxt[4] = "Chl";	colorVal[4][] = {{65280},{0},{52224}}
	colorTxt[5] = "Org_43";	colorVal[5] = {{44032},{29440},{58880}}
	colorTxt[6] = "Org_44";	colorVal[6][] = {{65280},{0},{52224}}
	colorTxt[7] = "Org_60";	colorVal[7][] = {{39168},{26112},{0}}
	colorTxt[8] = "NO3_30";	colorVal[8][] = {{16384},{65280},{65280}}
	colorTxt[9] = "NO3_46";	colorVal[9][] = {{0},{39168},{39168}}
	colorTxt[10] = "CE";		colorVal[10][] = {{0},{0},{0}}
	colorTxt[11] = "airbeam";	colorVal[11][] = {{34816},{34816},{34816}}
	colorTxt[12] = "inletPressure";	colorVal[12][] = {{26112},{0},{20736}}
	colorTxt[13] = "RIE_Org";		colorVal[13][] = {{0},{65280},{0}}
	colorTxt[14] = "RIE_SO4";		colorVal[14][] = {{65280},{0},{0}}
	colorTxt[15] = "RIE_NO3";		colorVal[15][] = {{0},{0},{65280}} 
	colorTxt[16] = "RIE_NH4";		colorVal[16][] = {{65280},{43520},{0}} 
	colorTxt[17] = "RIE_Chl";		colorVal[17][] = {{65280},{0},{52224}}
	colorTxt[18] = "inletT";		colorVal[18][] = {{26112},{26112},{0}}
	colorTxt[19] = "inletRH";	colorVal[19][] = {{0},{52224},{52224}}	
	
	//EBAS flags
	string/G ref_userFlagVal
	string/G ref_flagTargetList
	string/G ref_flagList = ""
	ref_flagList += "000: (V) Valid measurement;"
	ref_flagList += "120: (V) Sample reanalysed with similar result;"
	ref_flagList += "185: (V) Possible local contamination indicated by wind direction or velocity;"
	ref_flagList += "420: (V) Preliminary data;"
	ref_flagList += "457: (V) Extremely low value, outside four times standard deviation in a lognormal distribution;"
	ref_flagList += "458: (V) Extremely high value, outside four times standard deviation in a lognormal distribution;"
	ref_flagList += "459: (I) Extreme value, unspecified error;"
	ref_flagList += "460: (I) Contamination suspected;"
	ref_flagList += "651: (V) Agricultural activity nearby;"
	ref_flagList += "652: (V) Construction activity nearby;"
	ref_flagList += "659: (I) Unspecified instrument/sampling anomaly;"
	ref_flagList += "660: (V) Unspecified instrument/sampling anomaly;"
	ref_flagList += "780: (V) Value below detection or quantification limit, data element contains estimated or measured value;"
	ref_flagList += "781: (V) Value below detection limit, data element contains detection limit;"
	ref_flagList += "899: (I) Measurement undefined, unspecified reason;"
	ref_flagList += "980: (I) Missing due to calibration or zero/span check;"
	ref_flagList += "999: (I) Missing measurement, unspecified reason;"
	ref_flagList += "-1: (?) Other flag - see EBAS website and enter at right;"
	
	//detection limits
	wave/z/t detLimTxt
	if (!waveexists(detLimTxt))
		make/O/T/N=0 detLimTxt
		make/O/N=0 detLimVal
	endif
	
	//cleanup
	setdatafolder oldDF
end

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_initRecord(type, [df])
	//initializes the "instRec" wave containing description of data
	string type //instRec, siteRec, persRec, orgRec
	dfref df // datafolder in which to create waves; defaults to root:ebas
	
	if (paramisdefault(df))
		dfref df = root:ebas
	endif
	
	variable numCols
	
	dfref oldDF = getdatafolderDFR()
	setdatafolder df
	
	strswitch (type)
		case "instRec":
		case "inst":
			make/O/T/N=9 instRec
			setdimlabel 0, 0, instID, instRec //user-specified
			setdimlabel 0, 1, serial, instRec
			setdimlabel 0, 2, method, instRec //user-specified
			setdimlabel 0, 3, daqInfo, instRec
			setdimlabel 0, 4, type, instRec
			setdimlabel 0, 5, dryer, instRec
			setdimlabel 0, 6, dryerInfo, instRec
			setdimlabel 0, 7, orifice, instRec
			setdimlabel 0, 8, lens, instRec
			break
			
		case "siteRec":
		case "site":
			make/O/T/N=22 siteRec
			setdimlabel 0, 0, stationCode, siteRec
			setdimlabel 0, 1, platformCode, siteRec
			setdimlabel 0, 2, labCode, siteRec
			setdimlabel 0, 3, stationID_WDCA, siteRec
			setdimlabel 0, 4, stationName_GAW, siteRec
			setdimlabel 0, 5, stationID_GAW, siteRec
			setdimlabel 0, 6, stationID_AIRS, siteRec
			setdimlabel 0, 7, stationID_listOther, siteRec
			setdimlabel 0, 8, stationState, siteRec
			setdimlabel 0, 9, latitude, siteRec
			setdimlabel 0, 10, longitude, siteRec
			setdimlabel 0, 11, altitude, siteRec
			setdimlabel 0, 12, landUse, siteRec
			setdimlabel 0, 13, landSetting, siteRec
			setdimlabel 0, 14, type_GAW, siteRec
			setdimlabel 0, 15, region_WMO, siteRec
			setdimlabel 0, 16, inletHt, siteRec
			setdimlabel 0, 17, inletType, siteRec
			setdimlabel 0, 18, inletDescription, siteRec
			setdimlabel 0, 19, stationName, siteRec
			setdimlabel 0, 20, registered, siteRec
			setdimlabel 0, 21, inletCut, siteRec
			break
			
		case "persRec":
		case "pers":
			wave/t/z persRec_info
//			if (!waveexists(persRec_info))
//				make/O/T/N=7 persRec_info = {"Last name", "First name", "Organization", "Organization code", "Data originator/PI", "Data submitter"}
//			endif
			wave/t/z persRec
			if (waveexists(persRec))
				numCols = dimsize(persRec,1)
			else
				numCols = 1
			endif
			make/O/T/N=(7,numCols) persRec
			setdimlabel 0, 0, lastName, persRec
			setdimlabel 0, 1, firstName, persRec
			setdimlabel 0, 2, email, persRec
			setdimlabel 0, 3, orgName, persRec
			setdimlabel 0, 4, orgCode, persRec
			setdimlabel 0, 5, dataOrigin, persRec
			setdimlabel 0, 6, dataSubmit, persRec
			break
			
		case "orgRec":
		case "org":
			wave/t/z orgRec_info
//			if (!waveexists(orgRec_info))
//				make/O/T/N=9 orgRec_info = {"Name", "Acronym", "Department/Unit", "Address line 1", "Address line 2", "Postal code", "Town", "Country", "EBAS lab code"}
//			endif
			wave/t/z orgRec
			if (waveexists(orgRec))
				numCols = dimsize(orgRec,1)
			else
				numCols = 1		
			endif
			make/O/T/N=(9,numCols) orgRec
			setdimlabel 0, 0, name, orgRec
			setdimlabel 0, 1, acronym, orgRec
			setdimlabel 0, 2, dept, orgRec
			setdimlabel 0, 3, address1, orgRec
			setdimlabel 0, 4, address2, orgRec
			setdimlabel 0, 5, postCode, orgRec
			setdimlabel 0, 6, town, orgRec
			setdimlabel 0, 7, country, orgRec
			setdimlabel 0, 8, labCode, orgRec
			break
			
	endswitch

	//cleanup
	setdatafolder oldDF
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/t ebas_commentSpace(str)
	//for general comments in output file, inserts blank space between comment title and data, so data is approximately aligned
	//...this didn't work very well; for now just add 5 spaces to everything
	string str
	
	string output

//	variable charStart = 45
//	
//	string title = stringfromlist(0, str, ":")
//	string value = stringfromlist(1, str, ":")
//	variable titleLen = strlen(title)
//	
//	string spaces = ":"
//	variable i
//	for (i=0; i<charStart-titleLen; i+=1)
//		spaces += " "
//	endfor
//	
//	output = replacestring(":", str, spaces)

	output = replacestring(":", str, ":     ")
	return output
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_file_genHeader(header, dataLevel)
	wave/t header
	string dataLevel
	
	//generates header data for exported file
	dfref ebas = root:EBAS
	variable refNum
	string fileName
	
	//***** initialize file *****\\
	//globals
	nvar/SDFR=ebas proj_versionNum
	svar/SDFR=ebas proj_acrList, ref_dataLevel, proj_versionTxt, proj_acknowledge, proj_comment, ref_detLimMethod
	svar/SDFR=ebas data_report
	wave/t/SDFR=root:ebas detLimSpp
	wave/SDFR=root:ebas detLimVal
	wave/SDFR=root:ebas:output tsStart=$("tsLev"+dataLevel+"_start"), tsStop=$("tsLev"+dataLevel+"_stop")
	wave/t/SDFR=ebas siteRec, instRec, orgRec, persRec
	wave/t/SDFR=ebas instInfo
	string instID = instRec[%type]
	//utilities
	string str, thisSpp, sppInfo
	variable i, j, num, pos
	
	//data & metadata lists
	string dataList = ebas_panel_outputList("data", dataLevel)
	string metaList = ebas_panel_outputList("meta", dataLevel)
	
	//parse personnel list
	make/O/FREE/N=(dimsize(persRec, 1)) col_key_orig=str2num(persRec[%dataOrigin][p]), col_key_sub=str2num(persRec[%dataSubmit][p])
	extract/FREE/INDX col_key_orig, col_index_orig, col_key_orig==1
	extract/FREE/INDX col_key_sub, col_index_sub, col_key_sub==1
	make/T/O/FREE/N=(dimsize(persRec,0), numpnts(col_index_orig)) info_persOrigin = persRec[p][col_index_orig[q]]
	make/T/O/FREE/N=(dimsize(persRec,0), numpnts(col_index_sub)) info_persSubmit = persRec[p][col_index_sub[q]]
	make/T/O/FREE/N=(dimsize(orgRec,1)) key_org_labCode = orgRec[%labCode][p]
	setdimlabel 0, finddimlabel(persRec,0,"orgCode"), orgCode, info_persOrigin, info_persSubmit
	//code for host institute
	controlinfo ebas_pop_hostInstitute
	string hostCode = stringfromlist(0, s_value, ",")
	
	//time
	string revisionStr = ebas_file_time2ebas(datetime, "14dig")
	
	//header dimensions & navigation
	string funcParStr = ""
	funcParStr += "numOrigin=" + num2str(dimsize(info_persOrigin,1)) + "&"
	funcParStr += "numSubmit=" + num2str(dimsize(info_persSubmit,1)) + "&"
	funcParStr += "dataList=" + dataList + "&"
	funcParStr += "metaList=" + metaList + "&"
	variable numHdrLines = ebas_file_numLinesInHdr(funcParStr, dataLevel)
	variable firstGenComment, lastGenComment
	variable numDepVars = 1 + 3*itemsinlist(dataList) + 2*itemsinlist(metaList)
	
	//***** write data *****\\
	redimension /N=(numHdrLines) header
	i = 0
	
	//line 1 - number of header lines + obsolete parameter
	header[i] = num2str(numHdrLines) + " " + "1001"
	i+=1
	
	//line 2 - names of data originators/PIs
	header[i] = ebas_file_recToListEBAS(info_persOrigin, ", ", "; ", numRows=2)
	i+=1
	
	//line 3 - 
	findvalue/TXOP=4/TEXT=hostCode key_org_labCode
	if (v_value == -1)
		abort "Error: no organization record found for lab code " + siteRec[%labCode] + ". Perhaps you need to update the Personnel panel? Aborting from ebas_file_genHeader."
	endif
	header[i] = hostCode + ", " + ebas_file_recToListEBAS(orgRec, ", ", "; ", numRows=8, startCol=v_value, numCols=1)
	i+=1
	
	//line 4 - names of data submitter(s)
	header[i] = ebas_file_recToListEBAS(info_persSubmit, ", ", "; ", numRows=2)
	i+=1
	
	//line 5 - project acronyms
	header[i] = proj_acrList
	i+=1
	
	//line 6 - obsolete parameters
	header[i] = "1 1"
	i +=1
	
	//line 7 - reference and revision dates
	header[i] = ebas_file_time2ebas(tsStart[0], "date_space") + " " + ebas_file_time2ebas(datetime, "date_space")
	i+=1
	
	//line 8 - time interval between measurement start points (fraction of data)
	//only applies to Level 2+ data b/c time series must be uniform
	header[i] = selectstring(stringmatch(dataLevel, "2"), "0", "0.041667")
	i+=1
	
	//line 9 - end time of averaging period
	header[i] = "Days from the file reference point (start_time)"
	i+=1
	
	//line 10 - number of dependent columns (data & flags)
	header[i] = num2str(numDepVars)
	i+=1
	
	//line 11 - scaling for dependent variables (obsolete)
	header[i] = "1"
	for (j=1; j<str2num(header[i-1]); j+=1)
		header[i] += " 1"
	endfor
	i+=1
	
	//line 12 - missing values for dependent variables
	header[i] = "9999.999999 "
	for (j=0; j<itemsinlist(dataList); j+=1)
		header[i] += " 9999.999 9999.999 9.999 "
	endfor
	for (j=0; j<itemsinlist(metaList); j+=1)
		header[i] += " 9999.999 9.999"
	endfor
	i+=1
	
	//line 13
	header[i] = "end_time of measurement, days from the file reference point"
	i+=1
	
	//...now the line numbers depend on file contents...
	
	//names and units of the dependent variable columns
	variable unitConv, detLim
	string thisSppType
	//data
	for (j=0; j<itemsinlist(dataList); j+=1)
		thisSpp = stringfromlist(j, dataList)
		sppInfo = ebas_data_unitInfo(thisSpp)
		if (stringmatch(stringbykey("sppName",sppInfo,"=",";"), stringbykey("sppCat",sppInfo,"=",";")))
			//*****spp is sum of a frag wave (e.g. Org, SO4)
			//spp
			header[i] = stringbykey("sppCat", sppInfo, "=", ";")
			header[i] += ", " + stringbykey("unitTxt", sppInfo, "=", ";")
			header[i] += ", " + "Statistics=arithmetic mean"
			findvalue/TXOP=4/TEXT=thisSpp detLimSpp
			if (v_value != -1 && numtype(detLimVal[v_value]) == 0)
				thisSppType = stringfromlist(0,thisSpp,"_")
				unitConv = str2num(stringbykey("unitConv", ebas_data_unitInfo(thisSppType), "=", ";"))
				detLim = detLimVal[v_value]*unitConv
				header[i] += ", " + "Detection limit=" + ebas_file_formatData(detLim, "float_3") + " " + stringbykey("unitTxt", sppInfo, "=", ";")
				header[i] += ", " + "Detection limit expl.=" + ref_detLimMethod
			endif
			//uncertainties
			header[i+1] = stringbykey("sppCat", sppInfo, "=", ";")
			header[i+1] += ", " + stringbykey("unitTxt", sppInfo, "=", ";")
			header[i+1] += ", " + "Statistics=uncertainty"
		else
			//*****spp is an individual mz/ion (e.g. Org_44, SO4_48)
			//spp
			header[i] = stringbykey("sppCat", sppInfo, "=", ";")
			header[i] += ", " + stringbykey("unitTxt", sppInfo, "=", ";")
			header[i] += ", " + "Fraction=" + stringbykey("sppName", sppInfo, "=", ";")
			header[i] += ", " + "Statistics=arithmetic mean"
			//uncertainties
			header[i+1] = stringbykey("sppCat", sppInfo, "=", ";")
			header[i+1] += ", " + stringbykey("unitTxt", sppInfo, "=", ";")
			header[i+1] += ", " + "Fraction=" + stringbykey("sppName", sppInfo, "=", ";")
			header[i+1] += ", " + "Statistics=uncertainty"
		endif
		header[i+2] = "numflag"
		header[i+2] += ", " + "no unit"
		i +=3
	endfor
	if (stringmatch(dataLevel, "0")) //EETA v2.2 - only save metadata in level 0 file
		//metadata
		string thisMeta
		num = itemsinlist(metaList)
		for (j=0; j<num; j+=1)
			thisMeta = stringfromlist(j, metaList)
			header[i] = ebas_rec_instStr(thisMeta+"_nameFin",instID) + ", " + ebas_rec_instStr(thisMeta+"_unitsFin",instID)
			str = ebas_rec_instStr(thisMeta+"_extraInfo",instID)
			header[i] += selectstring(strlen(str) > 0, "", ", "+str)
			header[i+1] = "numflag " + ebas_rec_InstStr(thisMeta+"_nameFin", instID) + ", no unit"
			i+=2
		endfor
	endif
	
	//special comments - used by internal data centre
	header[i] = "0"
	i+=1
	
	//***** normal comments *****\\
	
	//number of normal comment lines
	header[i] = num2str(numHdrLines - (i+1))
	i+=1
	
	firstGenComment = i
	
	header[i] = "Data definition:" + "EBAS_1.1"
	i+=1
	
	header[i] = "Set type code:"  + selectstring(stringmatch(dataLevel, "2"), "TI", "TU")
	i+=1
	
	header[i] = "Timezone:" + "UTC"
	i+=1
	
	header[i] = "Timeref: " + "00_00"
	i+=1
		
	header[i] = "File name:" + ebas_file_getFileName(dataLevel)
	i+=1
	
	header[i] = "Startdate:" + ebas_file_time2ebas(tsStart[0], "14dig")
	i+=1
	
	header[i] = "Revision date: " + revisionStr
	i+=1
	
	header[i] = "Version:" + num2str(proj_versionNum)
	i+=1
	
	header[i] = "Version description:" + "File generated with EETA v" + EBAS_version + ". " + proj_versionTxt
	i+=1
	
	header[i] = "Data level:" + dataLevel
	i+=1
	
	header[i] = "Period code:"  + ebas_file_getPeriodCode(tsStart, tsStop)
	i+=1
	
	header[i] = "Resolution code:" + ebas_file_getResolutionCode(tsStart, tsStop,dataLevel)
	i+=1
	
	header[i] = "Orig. time res.:"  + stringbykey("origTimeRes", data_report, "=", ";") 
	i+=1
	
	header[i] = "Station code:" + siteRec[%stationCode]
	i+=1
	
	header[i] = "Platform code:" + siteRec[%platformCode]
	i+=1

	header[i] = "Station name:" + siteRec[%stationName]
	i+=1
	
	header[i] = "Station WDCA-ID:" + siteRec[%stationID_WDCA]
	i+=1
	
	header[i] = "Station GAW-Name:" + siteRec[%stationName_GAW]
	i+=1
	
	header[i] = "Station GAW-ID:" + siteRec[%stationID_GAW]
	i+=1
	
	if (strlen(siteRec[%stationID_Airs]) > 0)
		header[i] = "Station AIRS-ID:" + siteRec[%stationID_AIRS]
		i+=1
	endif
	
	if (strlen(siteRec[%stationID_listOther]) > 0)
		header[i] = "Station other IDs:"
		str = siteRec[%stationID_listOther]
		num = itemsinlist(str)
		for (j=0; j<num; j+=1)
			header[i] += stringfromlist(0, stringfromlist(j,str), ",") + "(" + stringfromlist(1, stringfromlist(j,str), ",") + ")" + " "
		endfor
		i+=1
	endif
	
	if (strlen(siteRec[%stationState]) > 0)
		header[i] = "Station state/province:" + siteRec[%stationState]
		i+=1
	endif
	
	header[i] = "Station land use:" + siteRec[%landUse]
	i+=1
	
	header[i] = "Station setting:" + siteRec[%landSetting]
	i+=1
	
	header[i] = "Station GAW type:" + selectstring(strlen(siteRec[%stationID_GAW]) > 0, "", siteRec[%type_GAW])
	i+=1
	
	header[i] = "Station WMO region:" + siteRec[%region_WMO]
	i+=1
	
	header[i] = "Station latitude:" + siteRec[%latitude]
	i+=1
	
	header[i] = "Station longitude:" + siteRec[%longitude]
	i+=1
	
	header[i] = "Station altitude:" + siteRec[%altitude] + "m"
	i+=1
	
	header[i] = "Measurement height:" + siteRec[%inletHt] + "m"
	i+=1
		
	header[i] = "Component: " + "chemistry_ACSM"
	i+=1
	
	header[i] = "Unit:" + "ug/m3"
	i+=1

	if (stringmatch(instRec[%lens], "Standard*"))
		str = "1"
	elseif (stringmatch(instRec[%lens], "PM2.5"))
		str = "25"
	endif
	header[i] = "Matrix:" + "pm" + str +  "_non_refractory"
	i+=1
	
	header[i] = "Instrument type:" + "aerosol_mass_spectrometer"
	i+=1
		
	header[i] = "Laboratory code:" + siteRec[%labCode]
	i+=1	

	header[i] = "Instrument name:" + "Aerodyne_"+instRec[%type]+"_"+instRec[%serial]+selectstring(strlen(instRec[%instID])>0, "", "_"+instRec[%instID])
	i+=1
	
	header[i] = "Instrument manufacturer:" + "Aerodyne"
	i+=1
	
	header[i] = "Instrument model:" + instRec[%type]
	i+=1	
	
	header[i] = "Instrument serial number:" + instRec[%serial]
	i+=1
	
	header[i] = "Method ref:" + siteRec[%labCode] + "_" + instRec[%method]
	i+=1

	header[i] = "Standard method:" + "None"
	i+=1

	header[i] = "Inlet type:" + siteRec[%inletType]
	i+=1
	
	header[i] = "Inlet description:" 
	header[i] += "Inlet cutpoint=" + stringfromlist(stringmatch(stringfromlist(0,siteRec[%inletCut]),"Other") ? 1:0, siteRec[%inletCut])
	header[i] += "; Comment=" + siteRec[%inletDescription]
	i+=1
	
	header[i] = "Humidity/temperature control:" + instRec[%dryer]
	i+=1
	
	header[i] = "Humidity/temperature control description:" + instRec[%dryerInfo]
	i+=1
	
	header[i] = "Volume std. temperature:" + "273.15K"
	i+=1
	
	header[i] = "Volume std. pressure:" + "1013.25hPa"
	i+=1
			
	//EETA 2.0 - detection limits & explanations now included with species definitions
	header[i] = "Detection limit:"
	i+=1

	header[i] = "Detection limit expl.:"
	i+=1
	
	header[i] = "Measurement uncertainty expl.: "
	header[i] += "Uncertainties calculated using " + instRec[%daqInfo] + " based on the method of Allan et al. (2003), DOI 10.1029/2002JD002358."
	i+=1

	header[i] = "Zero/negative values code:" + "Zero/negative possible"
	i+=1
	
	header[i] = "Zero/negative values:" + "Zero and neg. values may appear due to statistical variations at very low concentrations"
	i+=1
	
	num = dimsize(info_persOrigin, 1)
	for (j=0; j<num; j+=1)
		header[i] = "Originator:"
		header[i] += ebas_file_recToListEBAS(info_persOrigin, ", ", "; ", numRows=3, startCol=j, numCols=1) + ", "
		header[i] += ebas_file_recToListEBAS(orgRec, ", ", "; ", startCol=str2num(info_persOrigin[%orgCode][j]), numCols=1, startRow=0, numRows=8)
		i+=1
	endfor
	
	num = dimsize(info_persSubmit, 1)
	for (j=0; j<num; j+=1)
		header[i] = "Submitter:"
		header[i] += ebas_file_recToListEBAS(info_persSubmit, ", ", "; ", numRows=3, startCol=j, numCols=1) + ", "
		header[i] += ebas_file_recToListEBAS(orgRec, ", ", "; ", startCol=str2num(info_persSubmit[%orgCode][j]), numCols=1, startRow=0, numRows=8)
		i+=1
	endfor
		
	header[i] = "Acknowledgement:" + "EETA (EBAS Export Tool for AMS/ACSM) development was supported by ACTRIS. "
	header[i] += proj_acknowledge
	i+=1		
		
	header[i] = "Comment:"  + proj_comment
	i+=1

	lastGenComment = i-1	
		
//EETA v2.0 = obsolete fields		
//	header[i] = "Sample duration:" + header[i-1]
//	i+=1
	
//	header[i] = "Measurement uncertainty:" + "Species-dependent"
//	i+=1	

	header[i] = "start_time end_time "
	num = itemsinlist(dataList)
	//data
	for (j=0; j<num; j+=1)
		str = stringfromlist(j, dataList)
		header[i] += str + " "
		header[i] += "err_" + str + " "
		header[i] += "numFlag_" + str + " "
	endfor
	num = itemsinlist(metaList)
	for (j=0; j<num; j+=1)
		str = stringfromlist(j,metaList)
		header[i] += str + " "
		header[i] += "numFlag_" + str + " "
	endfor
	//insert blank space to make it easier to read general comments
	header[firstGenComment,lastGenComment] = ebas_commentSpace(header[p])
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_rec_instFromEnvt()
	//attempts to automatically set various instrument parameters on inst panel
	//method depends on the "instrument type" popupmenu
	
	//destination
	svar/SDFR=root:ebas inst_serial, inst_analysisProgram
	//instrument
	controlinfo ebas_pop_instType
	string instType = s_value
	
	//serial #
	inst_serial = ebas_rec_instStr("serial", instType)
	
	//DAQ info
	inst_analysisProgram = ebas_rec_instStr("analysisProgram",instType) + " " + ebas_rec_instStr("analysisVersion",instType)
	
	//
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/t ebas_rec_instStr(strID, inst)
	//returns various instrument-specific strings
	//note: default cases indicate an appropriate response was not found and the user must provide
	string strID //type of string requested
	string inst //instrument (can be instType or instID)
	
	variable pos
	string instID, str
	
	//if the passed instID was actually and instType, do conversion
	pos = whichlistitem(inst, EBAS_instType)
	if (pos != -1)
		instID = stringfromlist(pos, EBAS_instID)
	else
		instID = inst
	endif
	
	
	strswitch(strID)
		case "instID":
			return instID
		case "instType":
			pos =  whichlistitem(instID, EBAS_instID)
			return stringfromlist(pos, EBAS_instType)
			
		case "analysisProgram":
			strswitch(instID)
				case "qACSM":
					return "ACSM Local"
				case "hrAMS":
				case "cAMS":
				case "spAMS":
					return "SQUIRREL"
				case "tACSM":
					return "TofWare"
			endswitch
			break
			
		case "analysisVersion":
			strswitch(instID)
				case "qACSM":
					return stringfromlist(0, ebas_getConst_wrapper("ebas_getConst_version_acsm"), " ")
				case "hrAMS":
				case "cAMS":
				case "spAMS":
					//squirrel doesn't have a version global (just pragma), so we have to improvise...
					str = listmatch(winlist("*", ";", "WIN:128"), "SQ_backbone_*")
					str = replacestring("SQ_backbone_", stringfromlist(0,str,"."), "")
					return replacestring("_", str, ".")
				case "tACSM":
					nvar/SDFR=root:tw_globals tofware_version, tofware_subversion
					return num2str(tofware_version) + "." + num2str(tofware_subversion)
			endswitch
			break
		
		case "serial":
			strswitch(instID)
				case "qACSM":
					//attempt to read serial number from DAQ; corrupt in some datasets
					wave DAQ_val = root:DAQ_val
					str = num2istr(DAQ_val[74])
					return str[0,2] + "-" + str[3,5]	
				//JAY - FOR AMS & TOF-ACSM, HAVE TO LOOK IN HDFS FOR THIS...
			endswitch
			break
	
	//***** metadata information *****\\
	//these are of the form <dataType_value>
	//each dataType must have results for value = units, unitsFin, nameFin, extraInfo	
		case "airbeam_units":
			strswitch(instID)
				case "qACSM":
					return "A"
				default:	
					return "1/s"
			endswitch
		case "airbeam_unitsFin":
			return ebas_rec_instStr("airbeam_units", inst)
		case "airbeam_nameFin":
			strswitch(instID)
				case "qACSM":
					return "nitrogen_ion_flow_signal"	
				default:
					return "nitrogen_ion_flow"
			endswitch
		case "airbeam_extraInfo":
			return ""
		
		case "lensPressure_units":
			return "torr"
		case "lensPressure_unitsFin":
			return "hPa"
		case "lensPressure_nameFin":
			return "pressure"
		case "lensPressure_extraInfo":
			wave/t/SDFR=root:ebas instRec
			return "Matrix=instrument, Location=instrument inlet, Orifice diameter=" + instRec[%orifice] + " um"
			
		case "inletPressure_units":
			return "torr"
		case "inletPressure_unitsFin":
			return "hPa"
		case "inletPressure_nameFin":
			return "pressure"
		case "inletPressure_extraInfo":
			return "Matrix=instrument, Location=instrument internal"
			
		case "inletRH_units":
			return "%"
		case "inletRH_unitsFin":
			return "%"
		case "inletRH_nameFin":
			return "relative_humidity"
		case "inletRH_extraInfo":
			return "Matrix=instrument, Location=instrument inlet"
			
		case "inletT_units":
			return "deg C"
		case "inletT_unitsFin":
			return "K"
		case "inletT_nameFin":
			return "temperature"
		case "inletT_extraInfo":
			return "Matrix=instrument, Location=inlet"
			
		case "RIE_Org_units":
		case "RIE_SO4_units":
		case "RIE_NO3_units":
		case "RIE_NH4_units":
		case "RIE_Chl_units":
		case "RIE_Org_unitsFin":
		case "RIE_SO4_unitsFin":
		case "RIE_NO3_unitsFin":
		case "RIE_NH4_unitsFin":
		case "RIE_Chl_unitsFin":
			return "no unit"
		case "RIE_Org_nameFin":
		case "RIE_SO4_nameFin":
		case "RIE_NO3_nameFin":
		case "RIE_NH4_nameFin":
		case "RIE_Chl_nameFin":
			return "relative_ionization_efficiency"
		case "RIE_Org_extraInfo":
			return "Reference component=organic_mass"
		case "RIE_SO4_extraInfo":
			return "Reference component=sulphate_total"
		case "RIE_NO3_extraInfo":
			return "Reference component=nitrate"
		case "RIE_NH4_extraInfo":
			return "Reference component=ammonium"
		case "RIE_Chl_extraInfo":
			return "Reference component=chloride"
			
		case "ce_units":
		case "ce_unitsFin":
			return "no unit"
		case "ce_nameFin":
			return "collection_efficiency"
		case "ce_extraInfo":
			return ""
	
//		case "NO3_30_units":
//		case "NO3_46_units":
//			return "ug N/m3"
//		case "ce_unitsFin":
////			return "ug/m3 N":
//		case "ce_nameFin":
//			return "collection_efficiency"
//		case "ce_extraInfo":
//			return
	
	//***** functions *****\\
	//note that the default case is the protofunc
	case "fn_data_dataLev0":
		strswitch(instID)
			case "qACSM":
				return "ebas_data_dataLev0_qACSM" 
			default:
				return "ebas_data_dataLev0"
		endswitch
		
	case "fn_data_metaLev0":
		strswitch(instID)
			case "qACSM":
				return "ebas_data_metaLev0_qACSM"
			default:
				return "ebas_data_metaLev0"
		endswitch
		
	case "fn_data_tsLev0":
		strswitch(instID)
			case "qACSM":
				return "ebas_data_tsRaw_qACSM"
			default:
				return "ebas_data_tsRaw"
		endswitch
		
		
	endswitch	
	return "" //couldn't find anything...
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/t ebas_getConst_wrapper(exCall)
	//wrapper function for retrieving constants that may not exist (depending on which ipfs are present)
	string exCall //name of retrieval macro
	
	execute exCall+"()"
	svar tempStr = root:ebas:tempStr
	string destStr = tempStr
	killstrings tempStr
	return destStr
end

//the getConst macros dump a single constant (in string form) to the global string root:ebas:tempStr
macro ebas_getConst_version_acsm()
	string/G root:ebas:tempStr = versionStr
endmacro
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/t ebas_file_getFileName(dataLevel)
	//returns the file name for exported data
	string dataLevel //"0", "2"
	string destStr
		
	wave/SDFR=root:ebas:output tsStart=$("tsLev"+dataLevel+"_start"), tsStop=$("tsLev"+dataLevel+"_stop")
	wave/t/SDFR=root:ebas siteRec, instRec
	
	destStr = siteRec[%stationCode] + "."
	destStr += ebas_file_time2ebas(tsStart[0],"14dig") + "."
	destStr += ebas_file_time2ebas(datetime, "14dig") + "."
	destStr+= "aerosol_mass_spectrometer" + "."
	destStr += "chemistry_ACSM" + "."
	destStr += "pm1_non_refractory" + "."
	destStr += ebas_file_getPeriodCode(tsStart, tsStop) + "."
	destStr += ebas_file_getResolutionCode(tsStart, tsStop, dataLevel) + "."
	destStr += "Aerodyne_"+instRec[%type]+"_"+instRec[%serial]+selectstring(strlen(instRec[%instID])>0, "", "_"+instRec[%instID]) + "."
	destStr+= siteRec[%labCode] + "_" + instRec[%method] + "."
	destStr += "lev" + dataLevel + "."
	destStr += "nas"
	
	return destStr
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/t ebas_file_getPeriodCode(tsStart, tsStop)
	//returns period code (dataset duration) in EBAS format
	//if we're less than <tolerance> away from a "nice" period, return that
	wave tsStart, tsStop
	variable tolerance = 0.1
	
	variable first = tsStart[0]
	variable last = tsStop[numpnts(tsStop)-1]
	variable timeVal, timeValRnd
	variable i
	
	variable secsInDay = 24*60*60
	variable secsInYr = 365.25 * secsInDay
	
	
	//years
	timeVal = (last-first)/secsInYr
	timeValRnd = round(timeVal)
	if (timeValRnd - timeVal < tolerance && timeValRnd != 0)
		return num2str(timeValRnd) + "y"
	endif
	
	//months
	string firstDate = secs2date(first,-2)
	variable firstYear = str2num(stringfromlist(0, firstDate, "-"))
	variable firstMonth = str2num(stringfromlist(1, firstDate, "-"))
	variable firstDay= str2num(stringfromlist(2, firstDate, "-"))
	variable testYear, testMonth, testDay
	variable testLast
	for (i=1; i<=11; i+=1)
		testMonth = firstMonth + i
		if (testMonth > 12)
			testMonth -= 12
			testYear = firstYear + 1
		endif
		if (firstDay>30 && (testMonth==4 || testMonth==6 || testMonth==9 || testMonth==11))
			testDay = 30
		elseif (firstDay > 28 && testMonth==2)
			testDay = 28
		else
			testDay = firstDay
		endif
		
		testLast = date2secs(testYear, testMonth, testDay)
		if (abs(last-testLast) <= tolerance*(testLast-date2secs(firstYear,firstMonth,firstDay)))
			return num2str(i) + "m"
		endif
	endfor
	
	//days
	return num2str(round((last-first)/secsInDay)) + "d"
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/t ebas_file_getResolutionCode(tsStart, tsStop,dataLevel)
	//returns period code (dataset duration) in EBAS format//returns period code (dataset duration) in EBAS format
	wave tsStart, tsStop
	string dataLevel
	
	string code
	if (stringmatch(dataLevel, "2"))
		code = "1h"
	else //Level 0 - estimate from time series
		wave/SDFR=root:ebas ts=$("tsLev"+dataLevel)
		code = num2str(round((tsStop[0] - tsStart[0])/60)) + "mn"
	endif
		
	return code
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/t ebas_file_time2ebas(ts, mode)
	//converts an IGOR time stamp to various EBAS time formats (returns string)
	variable ts
	string mode
	string dest
	
	strswitch(mode)
		case "14dig":
			//yyyymmddhhmmss
			dest = replacestring("-", secs2date(ts,-2), "") + replacestring(":", secs2time(ts,3), "")	
			break
			
		case "date_space":
			//yyyy mm dd
			dest = replacestring("-", secs2date(ts,-2), " ")
			break
		
		case "6dig":
			//yyyymmdd
			dest = replacestring("-", secs2date(ts,-2), "")
			break
	endswitch
	
	return dest
end	
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_file_writeITX()
	//called through ebas_panel_doOps from "Save output as itx" button
	//writes header & data/metadata waves to itx file
	
	variable i, num
	string thisSpp, thisMeta
	
	string dfStr = "root:ebas:output:"
	string saveStr = ""
	
	//generate headers
	make/O/T/N=0 root:ebas:output:header_Lev0/WAVE=header_Lev0, root:ebas:output:header_Lev2/WAVE=header_Lev2
	ebas_file_genHeader(header_Lev0, "0")
	ebas_file_genHeader(header_Lev2, "2")
	saveStr += dfStr+"header_Lev0;"
	saveStr += dfStr+"header_Lev2;"
	
	//get time series
	saveStr += dfStr+"tsLev0_start;"
	saveStr += dfStr+"tsLev0_stop;"
	saveStr += dfStr+"tsLev2_start;"
	saveStr += dfStr+"tsLev2_stop;"
	
	//get data & metadata lists
	string sppList, metaList
	wave/SDFR=root:ebas expData_name, expMeta_name
	sppList = ebas_util_txtWaveToList(expData_name)
	metaList =ebas_util_txtWaveToList(expMeta_name)
	num = itemsinlist(sppList)
	for (i=0; i<num; i+=1)
		thisSpp = stringfromlist(i,sppList)
		saveStr += dfStr+"ug0_"+thisSpp+";"
		saveStr += dfStr+"err0_"+thisSpp+";"
		saveStr += dfStr+"flag0_"+thisSpp+";"
		if (!stringmatch(thisSpp, "NO3_*"))
			saveStr += dfStr+"ug2_"+thisSpp+";"
			saveStr += dfStr+"err2_"+thisSpp+";"
			saveStr += dfStr+"flag2_"+thisSpp+";"
		endif
	endfor
	num=itemsinlist(metaList)
	for (i=0; i<num; i+=1)
		thisMeta = stringfromlist(i,metaList)
		saveStr += dfStr+"meta0_"+thisMeta+";"
		savestr += dfStr+"flag0_"+thisMeta+";"
	endfor
	
	//save file
	string fileName = ebas_file_getFileName("2") + ".itx"
	
	string str
	for (i=0; i<itemsinlist(saveStr); i+=1)
		str = stringfromlist(i,saveStr)
		if (!waveexists($str))
			print str
		endif
	endfor
	
	save/B/t/O/P=EBAS_PATH_EXPORT saveStr as fileName
	print "<<---------- EBAS data and headers saved as itx ---------->>"		
		print "File name: " + fileName
		pathinfo EBAS_PATH_EXPORT
		print "Location: " + s_path
	print "<<---------- End report ---------->>"	
	doalert 0, "File saved to reference directory; see history window for details."
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_file_mergeITX()
	//called through ebas_panel_doOps from "Merge itx files"
	//merges data from external (previously saved) itx into current experiment
	
	dfref oldDF = getdatafolderDFR()
	dfref tempDF = newfreedatafolder()
	variable wDex, numW, i, num
	string wList, thisW
	
	//load
	setdatafolder tempDF
	loadwave/Q/T ""
	setdatafolder oldDF
	
	//check TS waves, get number of pts to insert
	wave/z/SDFR=tempDF src_tsLev0_start = tsLev0_start
	wave/z/SDFR=tempDF src_tsLev0_stop = tsLev0_stop
	wave/z/SDFR=tempDF src_tsLev2_start = tsLev2_start
	wave/z/SDFR=tempDF src_tsLev2_stop = tsLev2_stop
	if (!waveexists(src_tsLev0_start) || !waveexists(src_tsLev0_stop) || !waveexists(src_tsLev2_start) || !waveexists(src_tsLev2_stop))
		setdatafolder oldDF
		abort "Error: missing time stamp waves in selected itx. Aborting from ebas_file_mergeITX."
	endif
	variable numToAdd_lev0 = numpnts(src_tsLev0_start)
	variable numToAdd_lev2 = numpnts(src_tsLev2_start)
	variable startAdd, numToAdd
	
	//get species list (data outputs) from current expt
	svar/SDFR=root:ebas data_sppList, data_metaList
	wave/SDFR=root:ebas expData_name, expMeta_name
	//data: spp --> waves
	string wList_spp = ""
	data_sppList = ebas_util_txtWaveToList(expData_name)
	num = itemsinlist(data_sppList)	
	for (i=0; i<num; i+=1)
		wList_spp += "ug0_"+stringfromlist(i,data_sppList)+";" + "err0_"+stringfromlist(i,data_sppList)+";" + "flag0_"+stringfromlist(i,data_sppList)+";"
		if (!stringmatch(stringfromlist(i,data_sppList),"NO3_*"))
			wList_spp += "ug2_"+stringfromlist(i,data_sppList)+";" + "err2_"+stringfromlist(i,data_sppList)+";" + "flag2_"+stringfromlist(i,data_sppList)+";"
		endif
	endfor
	//metadata: spp --> waves
	string wList_meta = ""
	data_metaList = ebas_util_txtWaveToList(expMeta_name)
	num = itemsinlist(data_metaList)
	for (i=0; i<num; i+=1)
		wList_meta += "meta0_"+stringfromlist(i,data_metaList)+";" + "flag0_"+stringfromlist(i,data_metaList)+";"
	endfor
	//time waves
	string wList_ts = "tsLev0_start;tsLev0_stop;tsLev2_start;tsLev2_stop;"
	
	print "<<---------- Start itx merge ---------->>"
	
	//eventually check for header agreement?
	
	//missing time values for level 2 data (gap between files)
	variable numMissTS, firstMissTS
	wave/SDFR=root:ebas:output dest_tsLev2_start = tsLev2_start, dest_tsLev2_stop=tsLev2_stop
	if (src_tsLev2_start[0] < dest_tsLev2_start[0])  //src precedes dest
		firstMissTS = src_tsLev2_stop[numpnts(src_tsLev2_stop)-1]
		numMissTS = (dest_tsLev2_start[0] - firstMissTS) / (60*60)
	else //dest precedes src
		firstMissTS = dest_tsLev2_stop[numpnts(dest_tsLev2_stop)-1]
		numMissTS = (src_tsLev2_start[0] - firstMissTS) / (60*60)
	endif
	if (numMissTS < 0)  //check that src ends before dest starts
		abort "Cannot merge files: incompatible time stamps. Aborting from ebas_file_mergeITX."
	else
		make/O/FREE/D/N=(numMissTS) miss_tsLev2_start, miss_tsLev2_stop
		miss_tsLev2_start = firstMissTS + p*(60*60)
		miss_tsLev2_stop = miss_tsLev2_start + 60*60	
	endif
	
	//continue with load 
	wList = wList_ts + wList_spp + wList_meta
	numW = itemsinlist(wList)
	variable level
	variable missCtr = 0
	for (wDex=0; wDex<numW; wDex+=1)
		thisW = stringfromlist(wDex, wList)
		level = stringmatch(thisW, "ug0*") || stringmatch(thisW, "meta0*") || stringmatch(thisW,"flag0*") || stringmatch(thisW,"tsLev0*") || stringmatch(thisW, "err0*") ? 0 : 2
		wave/SDFR=root:ebas:output wDest = $thisW
		wave/z/SDFR=tempDF wSource = $thisW
		//redimension
		startAdd = numpnts(wDest)
		numToAdd = (level==0) ? numToAdd_lev0 : numToAdd_lev2
		insertpoints startAdd, numToAdd, wDest
		//add values
		if (!waveexists(wSource))
			wDest[startAdd,startAdd+numToAdd-1] = stringmatch(thisW,"flag0*") ? 0.999 : nan
			missCtr += 1
			print "Warning: " + thisW +"not found in current experiment; blank values added."
		else
			wDest[startAdd, startAdd+numToAdd-1] = wSource[p-startAdd]
			if (level==2 & numMissTS > 0) //need to add blank entries in TS for gap between files
				startAdd = numpnts(wDest)
				insertpoints startAdd, numMissTS, wDest
				if (stringmatch(thisW,"flag2*"))
					wDest[startAdd, startAdd+numMissTS-1] = 0.999
				elseif (stringmatch(thisW, "tsLev2_start"))
					wDest[startAdd, startAdd+numMissTS-1] = miss_tsLev2_start[p-startAdd]
				elseif (stringmatch(thisW, "tsLev2_stop"))
					wDest[startAdd, startAdd+numMissTS-1] = miss_tsLev2_stop[p-startAdd]
				else
					wDest[startAdd, startAdd+numMissTS-1] = nan
				endif
			endif
			print thisW + " merged successfully."
		endif
	endfor
	
	//sort
	wList = "tsLev0_stop;tsLev2_stop;" + wList_spp + wList_meta
	numW = itemsinlist(wList)
	wave/SDFR=root:ebas:output tRef_lev0=tsLev0_start, tRef_lev2=tsLev2_start
	for (wDex=0; wDex<numW; wDex+=1)
		thisW = stringfromlist(wDex, wList)
		wave/SDFR=root:ebas:output wDest=$thisW
		if (stringmatch(thisW, "ug0*") || stringmatch(thisW, "meta0*") || stringmatch(thisW, "flag0*") || stringmatch(thisW,"tsLev0*"))
			sort tRef_lev0 wDest
		elseif (stringmatch(thisW, "ug2*") || stringmatch(thisW, "meta2*") || stringmatch(thisW, "flag2*") || stringmatch(thisW,"tsLev2*"))
			sort tRef_lev2 wDest
		endif
		sort tRef_lev0 tRef_lev0
		sort tRef_lev2 tRef_lev2
	endfor
	
	//cleanup
	print "<<---------- Merge complete ---------->>"
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function	ebas_file_write()
	//called through ebas_panel_doOps from "Write EBAS file"
	//writes data to EBAS-compatible file
	//header & data processing called internally
	string dest //"ebas", or "itx"
	string str, fileName

	dfref oldDF = getdatafolderDFR()
	dfref tempDF = newfreedatafolder()
	string levelList = "0;2;"
	variable levDex, numLev = itemsinlist(levelList)
	string thisLevel
	string reportStr = ""
	
	//get file location
	variable changePath = 0
	pathinfo EBAS_PATH_EXPORT
	if (!V_flag) //path doesn't exist
		changePath = 1
	else
		str = "File will be exported to "+S_path+".  Accept destination?"
		doalert 2, str
		if (v_flag==2)
			changePath = 1
		elseif (V_flag==3)
			abort "Export cancelled by user."
		endif
	endif
	if (changePath)
		newpath /O/Q/M="Select folder for exported data." EBAS_PATH_EXPORT
	endif
	
	for (levDex=0; levDex<numLev; levDex+=1)
		thisLevel = stringfromlist(levDex, levelList)
		//get file name
		fileName = ebas_file_getFileName(thisLevel)
		
		//write header
		make/O/T/FREE/N=0 header_raw
		ebas_file_genHeader(header_raw, thisLevel)
		make/O/T/FREE/N=(numpnts(header_raw)) header_UTC8
		strswitch(igorInfo(2))
			case "Macintosh":
				header_UTC8 = ebas_util_macRomanToUTF8(header_raw)
				break
			case "Windows":
				header_UTC8 = ebas_util_win1252ToUTF8(header_raw)
				break
		endswitch
	
		//write data
		make/O/FREE/T/N=0 data
		reportStr += "wavesWithNaNs=" + stringbykey("alertList_nan", ebas_file_genData(data, thisLevel), "=", "&") + "&"
	
		//combine header and data
		setdatafolder tempDF
		concatenate /O/KILL {header_UTC8, data}, fileContents
		setdatafolder oldDF
		
		//create file
		save/J/O/M="\r\n"/P=EBAS_PATH_EXPORT fileContents as fileName
		
		//report
		pathInfo EBAS_PATH_EXPORT
		if (levDex==0)
			print "<<---------- File information ---------->>"
		endif
		print "Saved Level " + thisLevel + " file at: " + secs2date(dateTime,-2) + " " + secs2time(datetime,3)
		print "Name: " + fileName
		print "Location: " + s_path
	endfor
	
	if (strlen(stringbykey("wavesWithNaNs", reportStr, "=", "&")) > 0)
		doalert 0, "Warning: unexpected NaNs found in output waves and treated as missing data (see history window for details). Inspect waves in root:EBAS:output folder."
		print "Unexpected NaNs found in: " + stringbykey("wavesWithNaNs", reportStr, "=", "&")
	endif 
	
	svar/SDFR=root:ebas out_lastFile
	out_lastFile = fileName
	doalert 0, "File saved. See history window for details.\r\rThe file may be reviewed in WordPad or MS Excel, and is then ready for upload to the EBAS FTP site using the <Upload to EBAS database> button."
	print "<<---------- End report ---------->>"
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_file_upload()
	//uploads file to EBAS database
	
	//increment version number
	nvar/SDFR=root:ebas proj_versionNum

	string ftpStr = "ftp://ebas-submissions.nilu.no/incoming/"
	svar/SDFR=root:ebas out_lastFile 
	string fileStr_lev2 = out_lastFile
	string fileStr_lev0 = replacestring(".lev2.", fileStr_lev2, ".lev0.")
	
	print "<<---------- Uploading files to EBAS ---------->>"
	ftpUpload/P=EBAS_PATH_EXPORT ftpStr+fileStr_lev0, fileStr_lev0
	if (V_flag==0)
		print "Level 0 file (" + fileStr_lev0 +") was uploaded successfully."
	else
		print "Level 0 file (" + fileStr_lev0 + ") failed!"
		print "<<---------- End report ---------->>"
		abort "Warning: failed to upload Level 0 file. Aborting from ebas_file_upload."	
	endif
	
	ftpUpload/P=EBAS_PATH_EXPORT ftpStr+fileStr_lev2, fileStr_lev2
	if (V_flag==0)
		print "Level 2 file (" + fileStr_lev2 +") was uploaded successfully."
	else
		print "Level 2 file (" + fileStr_lev2 + ") failed!"
		print "<<---------- End report ---------->>"
		abort "Warning: failed to upload Level 2 file. Aborting from ebas_file_upload."	
	endif
	
	proj_versionNum +=1
	//jay = incomplete; print some report to command line & window
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/t ebas_file_genData(dest, dataLevel)
	//generates text wave holding all data in EBAS format
	//returns key-list info about operation
	wave/t dest
	string dataLevel // "0", "2"
	
	variable missingVal_data = 9999.999
	variable missingVal_flag = 9.999
	variable flagVal_miss = 0.999
	variable secsInDay = 60*60*24
	
	//data and metadata lists
	string dataList = ebas_panel_outputList("data", dataLevel)
	string metaList = ebas_panel_outputList("meta", dataLevel)
	
	//other initialization
	wave/SDFR=root:ebas:output tsStart = $("tsLev"+dataLevel+"_start"), tsStop = $("tsLev"+dataLevel+"_stop")
	variable i, num
	string thisSpp, thisMeta
	variable alertFlag_nan = 1
	string alertList_nan = ""
	
	//redimension output
	redimension /N=(numpnts(tsStart)) dest
	
	//time series
	string refdate = ebas_file_time2ebas(tsStart[0], "date_space")
	variable refDateSecs = date2secs(str2num(stringfromlist(0,refDate," ")), str2num(stringfromlist(1,refDate," ")), str2num(stringfromlist(2,refDate," ")))
	wavestats/Q tsStart
	alertList_nan += selectstring(v_numNaNs > 0, "", nameofwave(tsStart)+";")
	wavestats/Q tsStop
	alertList_nan += selectstring(v_numNaNs > 0, "", nameofwave(tsStop)+";")
	dest = ebas_file_formatData((tsStart-refDateSecs)/secsInDay, "float_6")
	dest += " " + ebas_file_formatData((tsStop-refDateSecs)/secsInDay, "float_6")
	
	//data
	variable chkFin=0
	string alertList = ""
	num = itemsinlist(dataList)
	for (i=0; i<num; i+=1)
		thisSpp = stringfromlist(i,dataList)
		wave/SDFR=root:ebas:output wData=$("ug"+dataLevel+"_"+thisSpp), wErr=$("err"+dataLevel+"_"+thisSpp), wFlag=$("flag"+dataLevel+"_"+thisSpp)
		//handle unexpected NaNs
		wavestats/Q wData
		alertList_nan += selectstring(v_numNaNs > 0, "", nameofwave(wData)+";")
		wavestats/Q wErr
		alertList_nan += selectstring(v_numNaNs > 0, "", nameofwave(wErr)+";")
		dest += " " + ebas_file_formatData(wFlag != flagVal_miss && numtype(wData)==0 ? wData : missingVal_data, "float_3") //data
		dest += " " + ebas_file_formatData(wFlag != flagVal_miss && numtype(wErr) == 0 ? wErr : missingVal_data, "float_3") //err
		dest += " " + ebas_file_formatData(numtype(wData)==0 && numtype(wErr)==0 ? wFlag : missingVal_flag, "float_3") //flag
	endfor
	
	//metadata
	if (stringmatch(dataLevel, "0"))
		num = itemsinlist(metaList)
		for (i=0; i<num; i+=1)
			thisMeta = stringfromlist(i, metaList)
			wave/SDFR=root:ebas:output wMeta=$("meta"+dataLevel+"_"+thisMeta), wFlag=$("flag"+dataLevel+"_"+thisMeta)
			wavestats/Q wMeta
			alertList_nan += selectstring(v_numNaNs > 0, "", nameofwave(wMeta)+";")
			dest += " " + ebas_file_formatData(wFlag != flagVal_miss && numtype(wMeta)==0 ? wMeta : missingVal_data, "float_3") //metadata
			dest += " " + ebas_file_formatData(numtype(wMeta)==0 ? wFlag : missingVal_flag, "float_3") //flag 
		endfor
	endif
	
	//build results string
	string resultStr = ""
	resultStr += "alertList_nan=" + alertList_nan + "&"
	return resultStr
end	
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/T ebas_file_formatData(data, type)
	//returns an EBAS-formatted textual representation of a data point
	variable/D data
	string type //float_# or int. (# specifies number of digits after decimal)
	
	string compStr = stringfromlist(0, type, "_")
	variable var
	string destStr
	
	strswitch (compStr)
		case "float":
			var = str2num(stringfromlist(1,type,"_"))
			sprintf destStr, "%.*f", var, data
			break
		case "int":
			sprintf destStr, "%03u", data
			break
	endswitch	
	return destStr
end	
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_file_numLinesInHdr(paramStr, dataLevel)
	//returns the number of header lines in the exported file
	//most lines are mandatory, so just need to check whether optional lines exist
	string paramStr
	string dataLevel
	
	//parse paramStr
	variable numOrigin = str2num(stringbykey("numOrigin", paramStr, "=", "&"))
	variable numSubmit = str2num(stringbykey("numSubmit", paramStr, "=", "&"))
	string dataList = stringbykey("dataList", paramStr, "=", "&")
	string metaList = stringbykey("metaList", paramStr, "=", "&")
	
	dfref ebas = root:ebas
	wave/t/SDFR=ebas siteRec
	
	variable numLines = 0
	numLines += 13 //mandatory block
	numLines += 3*itemsinlist(dataList)//names and units of the dependent variable columns (note each spp has data, err, and flag) 
	numLines += 2*itemsinlist(metaList)
	numLines += 21 //mandatory block
	numLines += strlen(siteRec[%stationID_Airs]) > 0 ? 1 : 0
	numLines += strlen(siteRec[%stationID_listOther]) > 0 ? 1 : 0
	numLines += strlen(siteRec[%stationState]) > 0 ? 1 : 0
	numLines += 30 //mandatory block
	numLines += numOrigin
	numLines += numSubmit
	numLines += 3 //mandatory block //JAY -  RECOUNT AT END!! (A FEW LINES MAY EXPAND/VANISH)
	
	return numLines
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/t ebas_file_recToListEBAS(mat, rowSepStr, colSepStr, [startRow, numRows, startCol, numCols])
	//converts a record matrix to a EBAS-formatted list
	//columns comprise external list; each column entry contains a nested row-based list
	wave/t mat
	string rowSepStr, colSepStr
	variable startRow, numRows, startcol, numCols
	
	//initialize optional params
	startRow = paramisdefault(startRow) ? 0 : startRow
	numRows = paramisdefault(numRows) ? dimsize(mat,0)-startRow : numRows
	startCol = paramisdefault(startcol) ? 0 : startCol
	numCols = paramisdefault(numCols) ? dimsize(mat,1)-startCol : numCols
	
	string destStr = ""
	variable colDex, rowDex
	for (colDex=startCol; colDex<startCol+numCols; colDex+=1)
		for (rowDex=startRow; rowDex<startRow+numRows; rowDex+=1)	
			destStr += mat[rowDex][colDex]
			destStr += selectstring(rowDex==numRows-1, rowSepStr, "") //don't add rowSepStr if we're at end of column
		endfor
		destStr += selectstring(colDex==numCols-1, colSepStr, "") //don't add colSepStr if we're at end of entry
	endfor

	return destStr
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/t ebas_recList(type)
	//returns summary list of primary info from record
	string type //inst, org, pers, site
	dfref ebas = root:ebas
	string destList = ""
	variable start, stop
	
	destList = ""
	
	strswitch (type)
		case "pers":
			wave/t/SDFR=ebas persRec
			if (dimsize(persRec,0) > 0)
				make/T/O/FREE/N=(dimsize(persRec,1)) temp 
				temp = persRec[%lastName][p] + ", " + persRec[%firstName][p]
				destList += ebas_util_txtWaveToList(temp)
			endif
			break
			
		case "org":
			wave/t/SDFR=ebas orgRec
			if (dimsize(orgRec,0) > 0)
				make/T/O/FREE/N=(dimsize(orgRec, 1)) temp 
				temp = orgRec[%labCode][p] + ", " + orgRec[%name][p] + selectstring(strlen(orgRec[%acronym][p])>0, "", " ("+orgRec[%acronym][p] + ")")
				destList += ebas_util_txtWaveToList(temp)
			endif		
			break
	endswitch
	
	return destList
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_winGen_main()
	//main panel
	
//	dowindow/K EETA
	
	//build panel	
	dowindow/K EETA
	PauseUpdate; Silent 1		// building window...
	NewPanel /W=(49,63,590,753) /N=EETA
	SetDrawLayer UserBack
	DrawPICT 21,12,0.4,0.4,ProcGlobal#ebas_jpg_PSI
	DrawPICT 430,12,0.35,0.27,ProcGlobal#ebas_jpg_LAC
	
	string titleStr = "          EETA v" + EBAS_version + "\r\\Z16(EBAS Export Tool for ACSM/AMS)"
	TitleBox ebas_tit_main,pos={146,8},size={241,48},title=titleStr
	TitleBox ebas_tit_main,font="Arial",fSize=24,frame=0,fStyle=1,fColor=(0,0,65280)
	
	ValDisplay ebas_vd_status,pos={12,659},size={223,19},limits={0,1,0},barmisc={0,0},highColor= (0,0,65280),value= #"root:ebas:main_vStatus"
	TitleBox ebas_tit_status,pos={15,633},size={36,13},frame=0,fStyle=1,variable= root:EBAS:main_sStatus
	
	//background information
	GroupBox ebas_grp_info,pos={10,63},size={520,96},title="Background information",labelBack=(56576,56576,56576),fStyle=1
	PopupMenu ebas_pop_hostInstitute,pos={19,82},title="Host institute:",mode=1,popvalue="<Select>",value= #"selectstring(strlen(ebas_recList(\"org\"))>0, \"None available - edit personnel records.\", ebas_recList(\"org\"))"
	Button ebas_butt_recEdit,pos={470,111},size={50,42},disable=1,proc=ebas_panel_doOps,title="Edit",fColor=(0,65280,65280)
	PopupMenu ebas_pop_info,pos={413,82},proc=ebas_panel_popCtrl,title="Type:",mode=1,value= #"\"All;Site;Instrument;Personnel;\""
	Button ebas_butt_recLoad,pos={398,110},size={70,22},proc=ebas_panel_doOps,title="Load from itx",fColor=(13056,13056,0)
	Button ebas_butt_recSave,pos={398,133},size={70,22},proc=ebas_panel_doOps,title="Save to itx",fColor=(13056,13056,0)
	
	GroupBox ebas_grp_itx,pos={17,108},size={374,44},title="Reference .itx file",labelBack=(56576,56576,56576)
	SetVariable ebas_sv_itxPath,pos={25,130},size={189,16},title="Path:",value= root:EBAS:info_itxPath
	SetVariable ebas_sv_itxName,pos={222,130},size={159,16},title="File name:",value= root:EBAS:info_itxName
	
	//data management
	GroupBox ebas_grp_export,pos={11,166},size={517,216},title="Generate data for export",labelBack=(56576,56576,56576),fStyle=1
	TitleBox ebas_tit_dataSourceTxt pos={25,189}, title="Instrument:",frame=0
	TitleBox ebas_tit_dataSource pos={80,185}, variable=root:EBAS:data_currentInst,labelBack=(0,65280,65280)
	popupmenu ebas_pop_dataMethod,pos={173,185},title="Method:",value="Automatic;Manual",mode=1,proc=ebas_panel_popCtrl
	Button ebas_butt_previewTS,pos={394,185},size={125,36},proc=ebas_panel_doOps,title="\\Z14Preview & set flags",fColor=(0,13056,0)
	
	GroupBox ebas_grp_data,pos={22,213},size={498,79},title="Data selection"
	SetVariable ebas_sv_sppList,pos={31,236},size={428,16},title="Species:",value= root:EBAS:data_sppList
	setvariable ebas_sv_sppList noedit=1,valueBackColor=(0,65280,65280) //currently fixed
	Button ebas_butt_defSppList,pos={461,234},size={50,20},proc=ebas_panel_doOps,title="Default", disable=1 //currently disabled
	
	PopupMenu ebas_pop_metadata,pos={31,261}, title="Metadata:",value="Detection limits;Inlet pressure (ambient);Inlet temperature;Inlet RH;",proc=ebas_panel_popCtrl
	Button ebas_butt_detLims,pos={188,260},size={70,25},proc=ebas_panel_doOps,title="Edit values"
	SetVariable ebas_sv_detLims,pos={263,264},size={250,16},title="Method:",value= root:EBAS:ref_detLimMethod
	
	checkbox ebas_chk_metaInletP, pos={229,269}, size={97,14}, title="Inlet P measured", value=1, proc=ebas_panel_chkCtrl
	setvariable ebas_sv_metaInletP, pos={338,269}, size={175,16}, title="Wave (torr):", value=root:EBAS:data_inletP
	checkbox ebas_chk_metaInletT, pos={206,269}, size={97,14}, title="Inlet T measured", value=1, proc=ebas_panel_chkCtrl
	setvariable ebas_sv_metaInletT, pos={326,269}, size={185,16}, title="Estimated T (deg C):", value=root:EBAS:data_inletT
	checkbox ebas_chk_metaInletRH, pos={163,269}, size={106,14}, title="Inlet RH measured", value=0, proc=ebas_panel_chkCtrl
	setvariable ebas_sv_metaInletRH, pos={289,269}, size={220,14}, title="Wave (%):", value=root:EBAS:data_inletRH
	
	groupbox ebas_grp_ce,pos={276,298},size={241,77},title="Collection efficiency"
	PopupMenu ebas_pop_ceSource,pos={286,322},proc=ebas_panel_popCtrl,title="CE method:",mode=1,value= #"\"Batch table;Time-dependent;\""
	SetVariable ebas_sv_ceSourceW,pos={286,352},size={212,16},title="Wave",value= root:EBAS:data_CEwave
	
	GroupBox ebas_grp_time,pos={20,298},size={250,77},title="Select time period"
	SetVariable ebas_sv_timeStart,pos={27,323},size={139,16},proc=ebas_panel_svCtrl,title="Start:",value= root:EBAS:data_sTimeStart
	SetVariable ebas_sv_timeStop,pos={27,350},size={139,16},proc=ebas_panel_svCtrl,title="Stop:",value= root:EBAS:data_sTimeStop
	PopupMenu ebas_pop_timeStart,pos={173,321},proc=ebas_panel_popCtrl,mode=1,value= #"\"Auto;User set;Start of year;\""
	PopupMenu ebas_pop_timeStop,pos={173,348},proc=ebas_panel_popCtrl,mode=1,value= #"\"Auto;User set;1 year;6 months;3 months;2 months;1 month\""
		
	//finalize file and write
	GroupBox ebas_grp_finalize,pos={12,387},size={518,147},title="Finalize",labelBack=(56576,56576,56576),fStyle=1	
	SetVariable ebas_sv_exportNum,pos={22,407},size={114,16},title="File version #:",value= root:EBAS:proj_versionNum
	SetVariable ebas_sv_exportTxt,pos={146,408},size={373,16},title="Version description:",value= root:EBAS:proj_versionTxt
	SetVariable ebas_sv_projAcrList,pos={22,428},size={501,16},title="List of project acronyms:",value= root:EBAS:proj_acrList
	SetVariable ebas_sv_exportAck,pos={22,448},size={501,16},title="Acknowledgement instructions:",value= root:EBAS:proj_acknowledge
	SetVariable ebas_sv_exportcomment,pos={22,468},size={501,16},title="Additional comments:",value= root:EBAS:proj_comment
	Button ebas_butt_write,pos={20,491},size={121,35},proc=ebas_panel_doOps,title="\\Z14Write EBAS file",fColor=(0,13056,0)
	button ebas_butt_saveITX,pos={149,491},size={121,35},title="Save output as itx", proc=ebas_panel_doOps, fColor=(13056,13056,0)
	button ebas_butt_mergeITX,pos={274,491},size={121,35},title="Merge itx outputs",proc=ebas_panel_doOps,fColor=(13056,13056,0)
	Button ebas_butt_end,pos={399,491},size={121,35},proc=ebas_panel_doOps,title="Close",fColor=(13056,0,0)
	
	groupbox ebas_grp_upload,pos={13,544},size={516,66},title="Upload to EBAS",fStyle=1,labelBack=(56576,56576,56576)
	setvariable ebas_sv_lastFile,pos={25,563},size={497,16},title="Last file saved:", value=root:EBAS:out_lastFile
	button ebas_butt_upload,pos={23,583},size={498,20},title="Upload to EBAS database",proc=ebas_panel_doOps,fColor=(0,13056,0)
	
	//support
	GroupBox ebas_grp_reference,pos={258,616},size={273,64},title="Help and support",fStyle=1
	Button ebas_butt_helpEmail,pos={267,655},size={119,20},proc=ebas_panel_doOps,title="EETA support"
	Button ebas_butt_helpEBAS,pos={403,634},size={119,20},proc=ebas_panel_doOps,title="EBAS home and FTP"
	Button ebas_butt_helpACSM,pos={403,655},size={119,20},proc=ebas_panel_doOps,title="EBAS ACSM template"
	Button ebas_butt_helpManual,pos={266,634},size={121,20},proc=ebas_panel_doOps,title="View EETA docs"
	
	//control updates
	controlinfo ebas_pop_dataMethod
	ebas_panel_popCtrl("ebas_pop_dataMethod", v_value, s_value)
	controlinfo ebas_pop_ceSource
	ebas_panel_popCtrl("ebas_pop_ceSource", v_value, s_value)
	controlinfo ebas_pop_metadata
	ebas_panel_popCtrl("ebas_pop_metadata", v_value, s_value)
End
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_panel_doOps(ctrlName) : buttoncontrol
	//operation controls from buttons
	string ctrlName
	
	dfref oldDF = getdatafolderDFR()
	dfref ebas = root:EBAS
	string str, type, mailStr
	variable var, i, num
	
	strswitch (ctrlName)
		case "ebas_butt_recLoad":
		case "ebas_butt_recSave":
			//get type list
			str = winName(0,64)
			if (stringmatch(str, "EETA"))
				controlinfo ebas_pop_info
				str = s_value
			endif
			strswitch (str)
				case "All":
					type = "All"
					break
				case "ebas_inst":
				case "Instrument":
					type = "Instrument"
					break
				case "ebas_site":
				case "Site":
					type = "Site"
					break
				case "ebas_personnel":
				case "Personnel":
					type = "Personnel"
					break
			endswitch
			if (stringmatch(ctrlName, "ebas_butt_recLoad"))
				ebas_info_itxOps("load", type)
			elseif (stringmatch(ctrlName, "ebas_butt_recSave"))
				ebas_info_itxOps("save", type)
			endif
			doalert 0, "Operation complete."
			break
			
		case "ebas_butt_recEdit":
			controlinfo ebas_pop_info
			type = s_value 
			strswitch (type)
				case "Site":
					ebas_winGen_site()
				break
				case "Instrument":
					ebas_winGen_inst()
				break
				case "Personnel":
					ebas_winGen_pers()
				break
			endswitch
			break
			
		case "ebas_butt_recDelete":
		case "ebas_butt_recUpdate":
			if (stringmatch(ctrlName, "ebas_butt_recDelete"))
				var = EBAS_recKill
			elseif (stringmatch(ctrlName, "ebas_butt_recUpdate"))
				var = EBAS_panel2rec
			endif
			controlinfo ebas_pop_recList
			type = s_value
			controlinfo ebas_tab_pers
			str = s_value
			if (stringmatch(str, "Personnel"))
				ebas_recData2D("pers", type, var)
			elseif (stringmatch(str, "Organization"))
				ebas_recData2D("org", type, var)				
			endif
			break
			
		case "ebas_butt_recUpdate1D":
			string panelName = winName(0,64)
			if (stringmatch(panelName, "ebas_inst"))
				type = "inst"	
			elseif (stringmatch(panelName, "ebas_site"))
				type = "site"
			endif
			ebas_recData1D(type, EBAS_panel2rec)
			break
			
		case "ebas_butt_codeOther":
			string titleStr
			controlinfo ebas_pop_codeOtherOp
			ebas_rec_otherID(s_value)
			svar/SDFR=root:ebas code_otherID
			titleStr = replacestring(";", code_otherID, "\r")
			titlebox ebas_tit_otherID, title=titleStr
			break
		
		case "ebas_butt_end":
			dowindow/K $winName(0,64)
			break
			
		case "ebas_butt_write":
			ebas_file_write()
			break
			
		case "ebas_butt_webGAWSIS":
			browseurl /z "http://gaw.empa.ch/gawsis/login.asp"
			break
		case "ebas_butt_helpEBAS":
			browseurl /z "http://ebas-submit.nilu.no/Default.aspx?TabName=NO%3csub%3ex%3c%2fsub%3e+%28regular%29"
			break
		case "ebas_butt_helpACSM":
			browseurl /z "http://ebas-submit.nilu.no/SubmitData/RegularAnnualDataReporting/ACSMregular.aspx"
			break
			
		case "ebas_butt_email":
			mailStr = "mailto:ebas@nilu.no"
			mailStr += "&subject=EBAS: station ID request"
			mailStr += "&body=This is an automatic message."
			browseurl /z mailStr
			break
		case "ebas_butt_helpEmail":
			wave/t/SDFR=root:ebas instRec
			mailStr = "mailto:jay.slowik@psi.ch"
			mailStr += "&subject=EETA: <Your topic here>"
			mailStr += "&body=EETA version " + EBAS_version + "%0A" + instRec[%daqInfo] + "%0A%0A" + "<DESCRIBE ISSUE HERE>"
			browseurl/z mailStr
			break
			
		case "ebas_butt_helpManual":
			ebas_help_docs()
			break		

		case "ebas_butt_previewTS":
			ebas_data_previewTS()
			break
		
		case "ebas_butt_defSppList":
			svar/SDFR=root:ebas data_sppList
			data_sppList = EBAS_defSppList
			break	
			
		case "ebas_butt_closePreview":
			dowindow/K ebas_preview
			break
		
		case "ebas_butt_flagTable":
			controlinfo ebas_pop_prevList
			string level, src, list, pref
			strswitch(s_value)
				case "Data (Level 0)":
					src = "data"
					level = "0"
					pref = "ug"
					break
				case "Data (Level 2)":
					src = "data"
					level = "2"
					pref = "ug"
					break
				case "Metadata (Level 0)":
					src = "meta"
					level = "2"
					pref = "meta"
					break
			endswitch
			list = ebas_panel_outputList(src, level)
			num = itemsinlist(list)
			wave/SDFR=root:ebas:output tsStart=$("tsLev"+level+"_start"), tsStop=$("tsLev"+level+"_stop")
			edit/N=ebas_flags tsStart, tsStop
			modifytable format(tsStart)=8, format(tsStop)=8
			for (i=0; i<num; i+=1)
				wave/SDFR=root:ebas wItem=$(pref+level+"_"+stringfromlist(i,list)), wFlag=$("flag"+level+"_"+stringfromlist(i,list))
				appendtotable wItem, wFlag
			endfor
			break
			
		case "ebas_butt_persReport":
			wave/t/SDFR=root:ebas persRec
			num = dimsize(persRec,1)
			print "<<---------- Personnel associated with active dataset ---------->>"
			print "Data originator(s):"
			for (i=0; i<num; i+=1)
				if (stringmatch("1", persRec[%dataOrigin][i]))
					print persRec[%lastName][i] + ", "+ persRec[%firstName][i] + " (" + persRec[%orgName][i]+ ")"
				endif
			endfor
			print "Data submitter(s):"
			for (i=0; i<num; i+=1)
				if (stringmatch("1", persRec[%dataSubmit][i]))
					print persRec[%lastName][i] + ", "+ persRec[%firstName][i] + " (" + persRec[%orgName][i]+ ")"
				endif
			endfor
			print "<<---------- End report ---------->>"
			doalert 0, "The report has been printed to the history window."
			break
			
		case "ebas_butt_detLims":
			ebas_data_detLims()
			break
		
		case "ebas_butt_openDB":
			execute "createbrowser"
			break
			
		case "ebas_butt_recReadIGOR":
			ebas_rec_instFromEnvt()
			break
			
		case "ebas_butt_saveITX":
			ebas_file_writeITX()
			break
		
		case "ebas_butt_mergeITX":
			ebas_file_mergeITX()
			break
			
		case "ebas_butt_upload":
			ebas_file_upload()
			break
			
	endswitch
	
	//cleanup
	setdatafolder oldDF
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_rec_otherID(mode)
	//updates list of "Other" station IDs based on instructions from site description panel (ebas_site)
	string mode //Add, Rem
	
	string network, ID
	svar/SDFR=root:ebas code_otherID
	
	strswitch(mode)
		case "Add":
			controlinfo ebas_sv_otherNetwork
			network = s_value
			controlinfo ebas_sv_otherID
			ID = s_value
			code_otherID = replacestringbykey(network, code_otherID, ID, ",", ";",1)
			break
			
		case "Rem":
			controlinfo ebas_pop_otherRem
			network = s_value
			code_otherID = removebykey(network, code_otherID, ",", ";", 1)
			popupmenu ebas_pop_otherRem, mode=1
			break
	endswitch
	
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/t ebas_util_keyList(keyList, keySepStr, listSepStr)
	//returns list of all keys in key-list
	string keyList, keySepStr, listSepStr
	
	variable i, num = itemsinlist(keyList, listSepStr)
	string dest = ""
	for (i=0; i<num; i+=1)
		dest += stringfromlist(0, stringfromlist(i,keyList,listSepStr), keySepStr) + ";"
	endfor
	
	return dest
end	
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/t ebas_panel_scrollList(masterList, dispList, direction)
	//"scrolls" masterList for display in dispList
	string masterList, dispList
	string direction //L or R

	variable newPos, i, num, oldPos, compPos
	string newDispList
	
	//get current position
	compPos = stringmatch(stringfromlist(0,dispList),"...") ? 1 : 0
	oldPos = whichlistitem(stringfromlist(compPos,dispList), masterList)
	
	//new position
	if (stringmatch(direction,"L"))
		newPos = max(0, oldPos-1)
	elseif (stringmatch(direction, "R"))
		newPos = min(itemsinlist(masterList)-1, oldPos+1)
	endif
		
	//write new dispList
	newDispList = selectstring(newPos==0, "...;", "")
	num = itemsinlist(masterList)
	for (i=newPos; i<num; i+=1)
		newDispList += stringfromlist(i,masterList) + ";"
	endfor
	
	return newDispList
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_data_expSanity()
	//checks whether data/metadata reference waves are set up properly; aborts with error message if not
	//returns 0 if success
	
	//globals from export panel
	svar/SDFR=root:ebas tsName = data_exp_wTS
	wave/T/SDFR=root:ebas expData_name, expData_wDat, expData_wErr
	wave/T/SDFR=root:ebas expMeta_name, expMeta_wVal, expMeta_units
	
	//other initialization
	variable wLen, i, chkVal
	variable reportFlag = 0
	string thisName, thisSppType, thisSppVal
	
	controlinfo ebas_pop_dataMethod
	if (stringmatch(s_value, "Manual"))
	
		//********** Checks for "Manual" calculation mode **********\\
		//time axis
		wave/z wTS = $tsName
		if (!waveexists(wTS))
			abort "Error: time axis wave does not exist."
		endif
		if (wavetype(wTS) !=4)
			abort "Error: time axis must be a double precision wave."
		endif
		wLen = numpnts(wTS)
		
		//data waves
		for (i=0; i<numpnts(expData_name); i+=1)
			wave/z wDat=$expData_wDat[i], wErr=$expData_wErr[i]
			if (!waveexists(wDat))
				abort "Error: data wave for <" + expData_name[i] + "> does not exist."
			elseif (!waveexists(wErr))
				abort "Error: uncertainty wave for <" + expData_name[i] + "> does not exist."
			elseif (wavetype(wDat,1) != 1)
				abort "Error: data wave for <" + expData_name[i] + "> must be numeric."
			elseif (wavetype(wErr,1) != 1)
				abort "Error: uncertainty wave for <" + expData_name[i] + "> must be numeric."
			elseif (numpnts(wDat) != wLen)
				abort "Error: data wave for <" + expData_name[i]  + "> does not have the same number of points as time axis."
			elseif (numpnts(wErr) != wLen)
				abort "Error: uncertainty wave for <" + expData_name[i]  + "> does not have the same number of points as time axis."
			endif
		endfor
		//enforce nice names
//		expData_name = replacestring(" ", expData_name, "_")
		
		//metadata
		for (i=0; i<numpnts(expMeta_name); i+=1)
			if (strlen(expMeta_units[i]) == 0)
				abort "Error: units missing for metadata <" + expMeta_name[i] + "."
			endif
			if (numtype(str2num(expMeta_wVal[i])) == 0) // constant
				print "Created metadata wave: metaW_"+expMeta_name[i]+" = " + expMeta_wVal[i]
				make/O/N=(numpnts(wTS)) $("metaW_"+expMeta_name[i]) /WAVE=thisMeta
				thisMeta = str2num(expMeta_wVal[i])
				expMeta_wVal[i] = getwavesdatafolder(thisMeta,2)
				reportFlag = 1	
			else //wave
				wave/z wVal = $expMeta_wVal[i]
				if (!waveexists(wVal))
					abort "Error: metadata wave for <" + expMeta_name[i] + "> does not exist."
				elseif (wavetype(wVal,1) != 1)
					abort "Error: metadata wave for <" + expMeta_name[i]  + "> must be numeric."
				elseif (numpnts(wVal) != wLen)
					abort "Error: metadata wave for <" + expMeta_name[i] + "> does not have the same number of points as time axis."
				endif
			endif
		endfor
	
	else 
		//********** Checks for "Automatic" calculation mode **********\\
	endif
	
	//********** General checks **********\\
	//verify CE is present - v2.2 should never be triggered b/c all fields forced
	findvalue/TXOP=4/TEXT="CE" expMeta_name
	if (v_value == -1)
		insertpoints numpnts(expMeta_name), 1, expMeta_name, expMeta_wVal, expMeta_units
		v_value = numpnts(expMeta_name)-1
		expMeta_name[v_value] = "CE"
		expMeta_wVal[v_value] = ""
		expMeta_units[v_value] = "no unit"
		abort "Error: metadata entry for <collection_efficiency> was missing and has been added to table. Please define a metadata wave or value."
	endif
	//enforce nice names
//	expMeta_name = replacestring(" ", expMeta_name, "_")

	//ambient pressure and temperature
	wave/t/SDFR=root:ebas expMeta_name, expMeta_wVal
	//pressure
	findvalue/TXOP=4/TEXT="inletPressure" expMeta_name
	if (stringmatch(expMeta_name[v_value], "Auto"))
		controlinfo ebas_chk_metaInletP
		svar/SDFR=root:ebas data_inletP
		if (v_value)
			if (!waveexists($data_inletP))
				abort "Error: wave for inlet (ambient) pressure does not exist."
			endif
		else
			if (numtype(str2num(data_inletP)) != 0)
				abort "Error: invalid value for inlet (ambient) pressure."
			endif
		endif
	endif
	//temperature
	findvalue/TXOP=4/TEXT="inletT" expMeta_name
	if (stringmatch(expMeta_name[v_value], "Auto"))	
		controlinfo ebas_chk_metaInletT
		if (!v_value)
			svar/SDFR=root:ebas data_inletT
			if (!numtype(str2num(data_inletT)) != 0)
				abort "Error: invalid value for inlet (ambient) temperature."
			endif
		endif
	endif
	
	if (reportFlag==1)
		doalert 0, "Metadata waves were created.  See history window for details."
	endif
	
	return 0
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_winGen_export(instStr)
	//generates panel for manual export of data
	string instStr
	dfref oldDF = getdatafolderDFR()
	
	//convert instStr to instID if needed
	string instID = ebas_rec_instStr("instID", instStr)
	
//	//initialize
//	if (!waveexists(root:ebas:expData_name))
//		setdatafolder root:ebas
//		make/O/T/N=5 expData_name = {"Org","SO4","NO3","NH4","Chl"}, expData_wDat, expData_wErr
//		make/O/T/N=1 expMeta_name = {"collection_efficiency"}
//		make/O/T/N=1 expMeta_wVal
//		make/O/T/N=1 expMeta_units = {"no unit"}
//	endif
	
	wave/t/SDFR=root:ebas expData_name, expData_wData, expData_wErr, expMeta_name, expMeta_wVal, expMeta_units
	
	//***** generate export panel *****\\
	dowindow/K eeta_export
	//make panel
	pauseupdate; silent 1
	NewPanel  /N=eeta_export /HOST=EETA /EXT=0 /W=(0,600,470,50) /K=2 ///FG=(FL,FT,FR,FB) ///W=(606,69,1071,665)
	TitleBox ebas_tit_export,pos={100,6},size={223,24},title="Select waves for export",font="Arial",fSize=20,frame=0,fStyle=1
	TitleBox ebas_tit_export,fColor=(0,0,65280)
	TitleBox ebas_tit_expDataTxt,pos={14,106},size={67,13},title="Data waves",frame=0,fStyle=1
	SetVariable ebas_sv_expTS,pos={13,72},size={201,16},title="Time axis:",fStyle=1,value= root:EBAS:data_exp_wTS
	TitleBox ebas_tit_expInstructions,pos={231,34},size={211,86},variable= root:EBAS:data_exp_instructions
	TitleBox ebas_tit_expMetaTxt,pos={14,355},size={93,13},title="Metadata waves",frame=0,fStyle=1
	button ebas_butt_openDB, pos={13,34}, size={211,21}, title="Open data browser", proc=ebas_panel_doOps
	
	//data table
	wave/t/SDFR=root:ebas expData_name,expData_wDat,expData_wErr
	Edit/W=(11,127,451,343)/HOST=#/N=ebas_winGen_expData  expData_name,expData_wDat,expData_wErr
	ModifyTable format(Point)=1,width(Point)=0,title(expData_name)="Name",width(expData_wDat)=132
	ModifyTable title(expData_wDat)="Data wave",width(expData_wErr)=152,title(expData_wErr)="Uncertainty wave"
	SetActiveSubwindow ##
	
	//metadata table
	wave/t/SDFR=root:ebas expMeta_name,expMeta_wVal,expMeta_units
	String fldrSav1= GetDataFolder(1)
	SetDataFolder root:EBAS:
	Edit/W=(12,375,449,546)/HOST=#/N=ebas_winGen_metaData  expMeta_name,expMeta_wVal,expMeta_units
	ModifyTable format(Point)=1,width(Point)=0,width(expMeta_name)=113,title(expMeta_name)="Name"
	ModifyTable width(expMeta_wVal)=154,title(expMeta_wVal)="Wave OR constant",width(expMeta_units)=61
	ModifyTable title(expMeta_units)="Units"
	SetActiveSubwindow ##
	
	//cleanup
	setdatafolder oldDF
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_data_detLims()
	//generates window in which user can declare or edit detection limits for chosen species
	dfref ebas = root:ebas
	wave/z/T/SDFR=ebas detLimSpp
	wave/z/SDFR=ebas detLimVal
	svar/SDFR=ebas data_sppList
	
	string thisSpp
	variable i, pos, num
	
	if (!waveexists(detLimSpp))
		make/O/T/N=0 root:ebas:detLimSpp /wave=detLimSpp
		make/O/N=0 root:ebas:detLimVal /wave=detLimVal
	endif
	
	//in case we're coming from an older version of EETA, compress lists
	num = numpnts(detLimSpp)-1
	for (i=num; i>=0; i-=1)
		if (stringmatch(detLimSpp[i], "*_*"))
			deletepoints i, 1, detLimSpp, detLimVal
		endif
	endfor
	
	//compress list
	data_sppList = replacestring(",", data_sppList, ";")
	string destList = ebas_util_uniqueList(stringfromlist(0,data_sppList,"_"))
	
	num = itemsinlist(destList)
	for (i=0; i<num; i+=1)
		thisSpp = stringfromlist(i, destList)
		findvalue/TEXT=thisSpp detLimSpp
		if (v_value == -1)
			pos = numpnts(detLimSpp)
			insertpoints pos, 1, detLimSpp, detLimVal
			detLimSpp[pos] = thisSpp
			detLimVal[pos] = nan
		endif
	endfor
	
	edit /N=ebas_detLims /K=1 detLimSpp, detLimVal
	modifytable title(detLimSpp)="Spp", title(detLimVal)="DetLim (ug/m3)"
end	
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/t ebas_info_getFile(op, type, df)
	//gets path & file information for "general info" read/write operation
	//performs sanity checks on file & gives user opportunity to abort if problems found
	//returns key-separated list (key=data/) 
		//fileFullPath = file name (including full path)
		//wvList = list of waves for operation
	string op //load, save
	string type //All, Site, Personnel, Instrument
	dfref df //datafolder into which file data is loaded for reading/evaluation; normally a temporary or free DF
	
	dfref oldDF = getdatafolderDFR()
	dfref ebas=root:ebas
	svar/SDFR=ebas info_itxPath, info_itxName
	string alertStr
	variable i, num
	string wvList
	
	//initialize df with blank waves; this gives us a complete (blank) virtual file to work with, so we don't end up with missing waves
	wvList = "instRec;siteRec;persRec;orgRec;"
	num = itemsinlist(wvList)
	for (i=0; i<num; i+=1)
		ebas_initRecord(stringfromlist(i,wvList), df=df)
	endfor
	
	//waves for operation
	strswitch(type)
		case "All":
			wvList = "instRec;siteRec;persRec;orgRec;"
			break
		case "Site":
			wvList = "siteRec;"
			break
		case "Personnel":
			wvList = "persRec;orgRec;"
			break
		case "Instrument":
			wvList = "instRec;"
			break
	endswitch
	
	//verify path
	if (strlen(info_itxPath)==0)
		newpath/O/Q/M="Select folder for reference .itx file." EBAS_PATH_ITX
	else
		newpath/O/Q EBAS_PATH_ITX, info_itxPath
	endif
	if (v_flag != 0)
		newPath/O/Q/M="Select folder containing reference itx:" EBAS_PATH_ITX
	endif
	pathinfo EBAS_PATH_ITX
	info_itxPath = s_path
	
	//verify file
	if (strlen(info_itxName)==0)
		info_itxName = "EBAS_reference.itx"
	elseif (!stringmatch(info_itxName, "*.itx"))
		info_itxName += ".itx"
	endif
	string fileList = indexedfile(EBAS_PATH_ITX, -1, ".itx")
	if (whichlistitem(info_itxName, fileList) == -1) //file doesn't exist
		if (stringmatch(op, "load"))
			alertStr = "Warning: cannot find specified itx file. Info type <" + type + "> will be reinitialized with blank data.  Continue?"
			doalert 1, alertStr
			if (v_flag == 2)
				abort "Operation cancelled by user."
			endif
		endif
	else
		setdatafolder df
		loadwave/T/O/Q info_itxPath+info_itxName
		setdatafolder oldDF
		num = itemsinlist(wvList)
		alertStr = ""
		for (i=0; i<num; i+=1)
			wave/z/t/SDFR=df thisWv=$stringfromlist(i,wvList)
			if (!waveexists(thisWv))
				alertStr += stringfromlist(i,wvList)+";"
			endif
		endfor
		if (itemsinlist(alertStr)>0)
			alertStr = "Warning: required waves <" + alertStr + "> were not found in itx and the corresponding IGOR records will be reinitialized with blank data.  Continue?"
			doalert 1, alertStr
			if (v_flag == 2)
				abort "Operation cancelled by user."
			endif
		endif
	endif
	
	//compare instrument ID
	wave/z/t/SDFR=df instRec_itx=instRec
	if (waveexists(instRec_itx))
		wave DAQ_val=root:DAQ_val
		if (!stringmatch(num2istr(DAQ_val[74]), replacestring("-", instRec_itx[%serial], "")) && whichlistitem(info_itxName, fileList) != -1)
			doalert 1, "Warning: instrument serial number in itx does not match that in IGOR.  Continue?"
			if (v_flag == 2)
				abort "Operation cancelled by user."
			endif
			string str = num2istr(DAQ_val[74])
			instRec_itx[%serial] = str[0,2] + "-" + str[3,5]
		endif
	endif
	
	//return full path to file
	string resultStr = ""
	resultStr += "fileFullPath=" + info_itxPath + info_itxName + "/"
	resultStr += "wvList=" + wvList + "/"
	return resultStr
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_info_itxOps(op, type)
	//loads or saves one or more "general info" records between itx and IGOR
	string op //load, save
	string type //All, Site, Personnel, Instrument
	
	variable i, num
	string thisWv
	
	dfref tempDF = newfreedatafolder()
	string infoStr = ebas_info_getFile(op, type, tempDF)
	string wvList = stringbykey("wvList", infoStr, "=", "/")
	string fileFullPath = stringbykey("fileFullPath", infoStr, "=", "/")
	
	strswitch (op)
		case "load":
			dfref sourceDF = tempDF
			dfref destDF = root:ebas
			break
		case "save":
			dfref sourceDF = root:ebas
			dfref destDF = tempDF
			break
	endswitch
	
	//proceed with data transfer
	setdatafolder destDF
	num = itemsinlist(wvList)
	variable dexDL, numDL
	string thisDL
	for (i=0; i<num; i+=1)
		thisWv = stringfromlist(i, wvList)
		wave/T/SDFR=sourceDF source = $thisWv
		if (waveexists(source))
			duplicate/o source $nameofwave(source)
		else
			ebas_initRecord(thisWv, df=sourceDF)
		endif
		ebas_initRecord(thisWv, df=destDF) //ALWAYS do this in case source was obsolete!
	endfor
	
	if (stringmatch(op, "save"))
		//write to file
		wave/t/SDFR=tempDF persRec, orgRec, instRec, siteRec
		Save/O/T persRec,orgRec,instRec,siteRec as fileFullPath
	elseif (stringmatch(op, "load"))
		strswitch(type)
			case "Instrument":
				ebas_recData1D("inst", EBAS_rec2panel)
				break
			case "Site":
				ebas_recData1D("site", EBAS_rec2panel)
				break
			case "Personnel":
				controlinfo ebas_tab_pers
				ebas_persTabCtrl("ebas_tab_pers", v_value)
				break
		endswitch
	endif
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_winGen_site()
	//edit site record
	dfref oldDF = getdatafolderDFR()
	dfref ebas = root:ebas
	setdatafolder ebas
	
	// initialize data
	wave/t siteRec
	string/G code_ebasStationName, code_ebasStation, code_ebasPlatform, code_ebasLab
	string/G code_wdcaID, code_gawName, code_gawID, code_airsID, code_otherID
	string/G stat_state
	variable/G stat_latitude, stat_longitude, stat_altitude
	string/G in_cutPt, in_description
	variable/G in_height
	
	dowindow/K ebas_site
	
	PauseUpdate; Silent 1		// building window...
	NewPanel /W=(491,63,951,446) /N=ebas_site
	TitleBox ebas_tit_site,pos={110,5},size={150,24},title="Site Description"
	TitleBox ebas_tit_site,font="Arial",fSize=20,frame=0,fStyle=1,fColor=(0,0,65280)
	Button ebas_butt_recLoad,pos={14,31},size={95,20},proc=ebas_panel_doOps,title="Load from file"
	Button ebas_butt_recLoad,fColor=(13056,13056,0)
	Button ebas_butt_recSave,pos={111,32},size={123,19},proc=ebas_panel_doOps,title="Save to file"
	Button ebas_butt_recSave,fColor=(13056,13056,0)
	Button ebas_butt_recUpdate1D,pos={243,30},size={116,21},proc=ebas_panel_doOps,title="Update in IGOR",fColor=(0,65280,65280)
	Button ebas_butt_end,pos={362,31},size={91,20},proc=ebas_panel_doOps,title="End"
	Button ebas_butt_end,fColor=(13056,0,0)
	
	//station IDs
	GroupBox ebas_grp_ID,pos={13,54},size={222,333},title="Station IDs",fSize=14,fStyle=1
	setvariable ebas_sv_stationName,pos={21,77},size={198,16},title="Station name",value=root:ebas:code_ebasStationName
	PopupMenu ebas_pop_stStatus,pos={20,99},proc=ebas_panel_popCtrl,title="Station status:",mode=2,value= #"\"Registered;Unregistered;\""
	
	GroupBox ebas_grp_ebas,pos={20,127},size={204,92},title="EBAS codes",fStyle=1
	SetVariable ebas_sv_ebasCodeSt,pos={29,149},size={187,16},title="Station:",value= root:ebas:code_ebasStation
	SetVariable ebas_sv_ebasCodePlat,pos={29,170},size={188,16},title="Platform:",value= root:ebas:code_ebasPlatform
	SetVariable ebas_sv_ebasCodeLab,pos={29,189},size={187,16},title="Lab:",value= root:ebas:code_ebasLab
	
	GroupBox ebas_grp_codeOther,pos={21,223},size={203,157},title="Other codes",fStyle=1
	popupmenu ebas_pop_code,pos={28,244},title="Network",value=#"\"WDCA;GAW;AIRS;Other;\"",mode=1,proc=ebas_panel_popCtrl
	SetVariable ebas_sv_codeWDCA,pos={29,270},size={187,16},title="WDCA (ID)",value= root:ebas:code_wdcaID
	SetVariable ebas_sv_nameGAW,pos={29,290},size={187,16},title="GAW (name)",value= root:ebas:code_gawName
	SetVariable ebas_sv_gawID,pos={29,270},size={187,16},title="GAW (ID)",value= root:ebas:code_gawID,proc=ebas_panel_svCtrl
	PopupMenu ebas_pop_gawType,pos={29,310},size={148,21},title="GAW station type:"
	PopupMenu ebas_pop_gawType,mode=1,value= #"EBAS_stationGAW", help={"G=global; R=regional; C=contribution"}
	SetVariable ebas_sv_airsID,pos={29,270},size={185,16},title="AIRS (ID)",value= root:ebas:code_airsID
	titlebox ebas_tit_otherIDtxt,pos={138,287},frame=0,title="(Network,ID)"
	popupmenu ebas_pop_codeOtherOp,pos={25,269},mode=1,value=#"\"Add;Rem\"",proc=ebas_panel_popCtrl
	setvariable ebas_sv_otherNetwork,pos={24,294},size={84,16},title="Network",value= _STR:""
	setvariable ebas_sv_otherID,pos={30,314},size={78,16},title="ID",value=_STR:""
	titlebox ebas_tit_otherID,pos={111,269},frame=1,title="" //fill in title after loading record
	popupmenu ebas_pop_otherRem,pos={24,301},mode=1,value= #"selectstring(strlen(ebas_util_keyList(root:ebas:code_otherID,\",\",\";\"))>0,\"None\",ebas_util_keyList(root:ebas:code_otherID,\",\",\";\"))"
	button ebas_butt_codeOther,pos={25,337},size={84,17},title="Execute",proc=ebas_panel_doOps
	
	GroupBox ebas_grp_register,pos={16,178},size={214,183},title="Registration instructions",fStyle=1
	TitleBox ebas_tit_regInstructions,pos={20,132},size={209,34},title="Each site must be registered with GAWSIS\rprior to submission."
	Button ebas_butt_webGAWSIS,pos={55,210},size={87,20},proc=ebas_panel_doOps,title="Go to website"
	Button ebas_butt_email,pos={152,210},size={50,20},proc=ebas_panel_doOps,title="Email"
	
	//station description
	GroupBox ebas_grp_site,pos={241,54},size={212,333},title="Station description",fSize=14,fStyle=1
	
	GroupBox ebas_grp_location,pos={249,79},size={195,186},title="Location",fStyle=1
	SetVariable ebas_sv_latitude,pos={257,98},size={180,16},title="Latitude",value= root:ebas:stat_latitude
	SetVariable ebas_sv_longitude,pos={256,119},size={181,16},title="Longitude",value= root:ebas:stat_longitude
	SetVariable ebas_sv_altitude,pos={258,144},size={178,16},title="Altitude (m)",value= root:ebas:stat_altitude
	PopupMenu ebas_pop_landSetting,pos={256,164},size={126,21},title="Land type:",mode=1,value= #"EBAS_landSetting"
	PopupMenu ebas_pop_landUse,pos={257,188},size={131,21},title="Land use:",mode=1,value= #"EBAS_landUse"
	PopupMenu ebas_pop_wmoRegion,pos={255,213},size={108,21},title="Region",mode=1,value= #"EBAS_regionWMO",proc=ebas_panel_popCtrl
	SetVariable ebas_sv_state,pos={254,240},size={180,16},title="State (USA/Canada only)",value= root:ebas:stat_state
	
	GroupBox ebas_grp_inlet,pos={250,266},size={195,114},title="Inlet",fStyle=1
	popupmenu ebas_pop_inletType,pos={258,283},title="Type",mode=1,value=EBAS_inletType,proc=ebas_panel_popCtrl
	popupmenu ebas_pop_inletCut,pos={259,309},title="Cutpoint",mode=1,value=EBAS_inletCut,proc=ebas_panel_popCtrl
	setvariable ebas_sv_inletCut,pos={361,311},size={74,16},title="Specify",value=root:ebas:in_cutPt
	SetVariable ebas_sv_inletHt,pos={259,336},size={178,16},title="Height (m)",value= root:ebas:in_height
	SetVariable ebas_sv_description,pos={259,357},size={176,16},title="Description",value= root:ebas:in_description
	
	//***** update panel *****\\
	string ctrlList, thisCtrl
	variable ctrlDex, numCtrls
	
	ebas_recData1D("site", EBAS_rec2panel)
	
	svar/SDFR=root:ebas code_otherID
	string titleStr = replacestring(";", code_otherID, "\r")
	titlebox ebas_tit_otherID, title=titleStr
	
	//popup controls
	ctrlList = "ebas_pop_stStatus;ebas_pop_wmoRegion;ebas_pop_inletCut;"
	numCtrls = itemsinlist(ctrlList)
	for (ctrlDex=0; ctrlDex<numCtrls; ctrlDex+=1)
		thisCtrl = stringfromlist(ctrlDex, ctrlList)
		controlinfo $thisCtrl
		ebas_panel_popCtrl(thisCtrl, v_value, s_value)
	endfor
	
	//cleanup
	setdatafolder oldDF
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_winGen_inst()
	//edit instrument record
	dfref oldDF = getdatafolderDFR()
	dfref ebas = root:ebas
	setdatafolder ebas
	
	//initialize data
	wave/t instRec
	string/G inst_instID, inst_serial, inst_method, inst_daqInfo, inst_analysisProgram, inst_dryer
	variable/G inst_orifice
	string str
	
	dowindow/K ebas_inst
	
	//create panel
	PauseUpdate; Silent 1		// building window...
	NewPanel /W=(116,138,569,379) /N=ebas_inst
	TitleBox ebas_tit_main,pos={120,4},size={214,24},title="Instrument description",font="Arial",fSize=20,frame=0,fStyle=1,fColor=(0,0,65280)
	Button ebas_butt_recLoad,pos={7,31},size={107,22},proc=ebas_panel_doOps,title="Load from itx",fColor=(13056,13056,0)
	Button ebas_butt_recSave,pos={118,31},size={107,22},proc=ebas_panel_doOps,title="Save to itx",fColor=(13056,13056,0)
	Button ebas_butt_recUpdate1D,pos={228,31},size={107,22},proc=ebas_panel_doOps,title="Update in IGOR",fColor=(0,13056,13056)
	Button ebas_butt_end,pos={341,31},size={107,22},proc=ebas_panel_doOps,title="Close window",fColor=(13056,0,0)
	
	groupbox ebas_grp_instID,pos={7,60},size={441,97},title="Identification"
	PopupMenu ebas_pop_instType,pos={15,79},title="Instrument type:",mode=1,value= #"EBAS_instType",proc=ebas_panel_popCtrl
	SetVariable ebas_sv_serial,pos={15,105},size={171,16},title="Serial #:",value= root:EBAS:inst_serial
	SetVariable ebas_sv_instID,pos={15,129},size={171,16},title="Additional ID",value= root:EBAS:inst_instID
	Button ebas_butt_recReadIGOR,pos={214,79},size={225,22},proc=ebas_panel_doOps,title="Get ID values from" //complete title in control updates
	setvariable ebas_sv_instAnalysis,pos={214,107},size={225,16},title="Analysis program",value=root:EBAS:inst_analysisProgram
	SetVariable ebas_sv_method,pos={214,129},size={225,16},title="Analysis method",value= root:EBAS:inst_method
	
	groupbox ebas_grp_instConfig,pos={7,166},size={441,68},title="Configuration"
	setvariable ebas_sv_instOrifice,pos={15,185},size={157,18},title="Orifice diameter (\\F'Symbol'm\\F'MS sans serif'm)",value=root:EBAS:inst_orifice
	popupmenu ebas_pop_instLens,pos={15,208},title="Aerodynamic lens",mode=1,value=#"EBAS_instLens"
	popupmenu ebas_pop_instDryer,pos={253,184},title="Dryer",mode=1,value=#"EBAS_instDryer", proc=ebas_panel_popCtrl
	setvariable ebas_sv_instDryer,pos={253,210},size={167,15},title="Specify",value=root:EBAS:inst_dryer
	
	//load data
	ebas_recData1D("inst", EBAS_rec2panel)
	
	//control updates
	controlinfo ebas_pop_instType
	ebas_panel_popCtrl("ebas_pop_instType", v_value, s_value)
	controlinfo ebas_pop_instDryer
	ebas_panel_popCtrl("ebas_pop_instDryer", v_value, s_value)
	
	//cleanup
	setdatafolder oldDF
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_winGen_pers()
	//edit personnel record
	dfref oldDF = getdatafolderDFR()
	dfref ebas = root:ebas
	setdatafolder ebas
	
	//initialize
	wave/t persRec, orgRec
	string/G pers_lastName, pers_firstName, pers_email
	string/G org_name, org_acronym, org_dept, org_add1, org_add2, org_postCode, org_town, org_country, org_labCode
	
	dowindow/K ebas_personnel
	//create panel	
	PauseUpdate; Silent 1		// building window...
	NewPanel /W=(661,77,952,422) /N=ebas_personnel
	TitleBox ebas_tit_pers,pos={73,3},size={137,24},title="Personnel Info"
	TitleBox ebas_tit_pers,font="Arial",fSize=20,frame=0,fStyle=1,fColor=(0,0,65280)
	Button ebas_butt_recLoad,pos={12,33},size={85,20},proc=ebas_panel_doOps,title="Load from itx"
	Button ebas_butt_recLoad,fColor=(13056,13056,0)
	Button ebas_butt_recSave,pos={99,33},size={90,20},proc=ebas_panel_doOps,title="Save to itx"
	Button ebas_butt_recSave,fColor=(13056,13056,0)
	Button ebas_butt_end,pos={193,33},size={83,20},proc=ebas_panel_doOps,title="Close window"
	Button ebas_butt_end,fColor=(13056,0,0)
	TabControl ebas_tab_pers,pos={8,59},size={269,279},proc=ebas_persTabCtrl
	TabControl ebas_tab_pers,tabLabel(0)="Organization",tabLabel(1)="Personnel"
	TabControl ebas_tab_pers,value= 0
	PopupMenu ebas_pop_recList,pos={19,82},size={75,21},title="Edit:"
	PopupMenu ebas_pop_recList,mode=1,popvalue="New",value= #"\"New;\" + ebas_recList(\"org\")", proc=ebas_panel_popCtrl
	SetVariable ebas_sv_persLastName,pos={21,112},size={242,16},disable=1,title="Last name:"
	SetVariable ebas_sv_persLastName,value= root:ebas:pers_lastName
	SetVariable ebas_sv_persFirstName,pos={22,136},size={241,16},disable=1,title="First name:"
	SetVariable ebas_sv_persFirstName,value= root:ebas:pers_firstName
	PopupMenu ebas_pop_persOrg,pos={20,182},size={221,21},disable=1,title="Organization:"
	PopupMenu ebas_pop_persOrg,mode=1,popvalue="PSI, Paul Scherrer Institute",value= #"ebas_recList(\"org\")"
	CheckBox ebas_chk_persOrigin,pos={22,210},size={87,14},disable=1,title="Data originator"
	CheckBox ebas_chk_persOrigin,value= 0
	CheckBox ebas_chk_persSubmit,pos={22,232},size={86,14},disable=1,title="Data submitter"
	CheckBox ebas_chk_persSubmit,value= 0
	Button ebas_butt_recUpdate,pos={16,299},size={86,30},proc=ebas_panel_doOps,title="Update in IGOR"
	Button ebas_butt_recUpdate,fColor=(0,13056,13056)
	SetVariable ebas_sv_orgName,pos={18,106},size={248,16},title="Name:"
	SetVariable ebas_sv_orgName,value= root:ebas:org_name
	SetVariable ebas_sv_orgAcro,pos={19,126},size={247,16},title="Acronym:"
	SetVariable ebas_sv_orgAcro,value= root:ebas:org_acronym
	SetVariable ebas_sv_orgDept,pos={17,147},size={249,16},title="Department:"
	SetVariable ebas_sv_orgDept,value= root:ebas:org_dept
	SetVariable ebas_sv_orgAdd1,pos={18,166},size={249,16},title="Address line 1:"
	SetVariable ebas_sv_orgAdd1,value= root:ebas:org_add1
	SetVariable ebas_sv_orgAdd2,pos={17,187},size={251,16},title="Address line 2:"
	SetVariable ebas_sv_orgAdd2,value= root:ebas:org_add2
	SetVariable ebas_sv_orgPost,pos={17,207},size={251,16},title="Postal code:"
	SetVariable ebas_sv_orgPost,value= root:ebas:org_postCode
	SetVariable ebas_sv_orgTown,pos={17,228},size={252,16},title="Town:"
	SetVariable ebas_sv_orgTown,value= root:ebas:org_town
	SetVariable ebas_sv_orgCountry,pos={20,249},size={249,16},title="Country:"
	SetVariable ebas_sv_orgCountry,value= root:ebas:org_country
	Button ebas_butt_recDelete,pos={108,299},size={98,30},proc=ebas_panel_doOps,title="Delete from IGOR"
	Button ebas_butt_recDelete,fColor=(0,13056,13056)
	Button ebas_butt_persReport,pos={210,299},size={61,30},proc=ebas_panel_doOps,title="Report"
	SetVariable ebas_sv_orgLabCode,pos={21,272},size={249,16},title="EBAS lab code:"
	SetVariable ebas_sv_orgLabCode,value= root:ebas:org_labCode
	setvariable ebas_sv_persEmail title="Email:", pos={21,159}, size={241,16}, value=root:ebas:pers_Email
	
	//update tabs
	ebas_persTabCtrl("ebas_tab_pers", 0)
	
	//cleanup
	setdatafolder oldDF
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_panel_updateStatus(vStatus, sStatus)
	//updates the status bar on the main panel
	variable vStatus
	string sStatus
	
	dfref ebas = root:ebas
	nvar/sdfr=ebas main_vStatus
	svar/SDFR=ebas main_sStatus
	
	main_vStatus = vStatus
	main_sStatus = sStatus
	
	controlupdate/W=EETA ebas_vd_status
	controlupdate/W=EETA ebas_tit_status
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/t ebas_util_txtWaveToList(txtWave, [listSepStr])
	//converts a text wave to a list
	wave/t txtWave
	string listSepStr
	string list
	variable numItems,itemDex
	if (paramisdefault(listSepStr))
		listSepStr = ";"
	endif
	
	numItems = numpnts(txtWave)
	list = ""
	for (itemDex=0; itemDex<numItems; itemDex+=1)
		list += (txtWave[itemDex]+listSepStr)
	endfor

	return list
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/t ebas_util_uniqueList(list,[listSepStr])
	//given a list with possible duplicates, return the list with duplicates removed
	string list
	string listSepStr
	if (paramIsDefault(listSepStr))
		listSepStr = ";"
	endif
	variable itemDex, numListItems = itemsinlist(list,listSepStr)
	string resultStr = "", thisItem
	for (itemDex=0; itemDex<numListItems; itemDex+=1)
		thisItem = stringfromlist(itemDex,list,listSepStr)
		if (whichlistitem(thisItem, resultStr, listSepStr) == -1)
			resultStr += thisItem + listSepStr
		endif
	endfor
	return resultStr
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_persTabCtrl(ctrlName, tabNum) : tabcontrol
	//tab control for personnel panel
	string ctrlName
	variable tabNum
	
	variable hideState
	variable tab_pers = 1
	variable tab_org = 0
	
	//personnel tab
	hideState = tabNum == tab_pers ? 0 : 1
	setvariable ebas_sv_persLastName, disable = hideState
	setvariable ebas_sv_persFirstName, disable = hideState
	popupmenu ebas_pop_persOrg, disable = hideState
	checkbox ebas_chk_persOrigin, disable = hideState
	checkbox ebas_chk_persSubmit, disable = hideState
	setvariable ebas_sv_persEmail, disable=hideState
	if (tabNum == tab_pers)
		PopupMenu ebas_pop_recList,mode=1,popvalue="New",value= #"\"New;\" + ebas_recList(\"pers\")"
		ebas_recData2D("pers", "New", EBAS_rec2panel)
	endif
	
	//organization
	hideState = tabNum == tab_org ? 0 : 1
	setvariable ebas_sv_orgName, disable = hideState
	setvariable ebas_sv_orgAcro, disable = hideState
	setvariable ebas_sv_orgDept, disable = hideState
	setvariable ebas_sv_orgAdd1, disable = hideState
	setvariable ebas_sv_orgAdd2, disable = hideState
	setvariable ebas_sv_orgPost, disable = hideState
	setvariable ebas_sv_orgTown, disable = hideState
	setvariable ebas_sv_orgCountry, disable = hideState
	setvariable ebas_sv_orgLabCode, disable = hideState
	if (tabNum == tab_org)
		PopupMenu ebas_pop_recList,mode=1,popvalue="New",value= #"\"New;\" + ebas_recList(\"org\")"
		ebas_recData2D("org", "New", EBAS_rec2panel)
	endif
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_panel_popCtrl(ctrlName, popNum, popStr) : popupmenucontrol
	//popup menu controls
	string ctrlName, popStr
	variable popNum
	
	variable hide, noEditVal
	string str
	variable i, num
	string sDate, sTime, checkStr
	
	strswitch (ctrlName)
		case "ebas_pop_persList":
			ebas_recData2D("pers", popStr, EBAS_rec2panel)
			break
		
		case "ebas_pop_orgList":
			ebas_recData2D("org", popStr, EBAS_rec2panel)
			break
			
		case "ebas_pop_stStatus":
			hide = stringmatch(popStr, "Registered") ? 0 : 1
				groupbox ebas_grp_ebas, disable=hide
					setvariable ebas_sv_ebasCodeSt, disable=hide
					setvariable ebas_sv_ebasCodePlat, disable=hide
					setvariable ebas_sv_ebasCodeLab, disable=hide
				groupbox ebas_grp_codeOther, disable=hide
					setvariable ebas_sv_codeWDCA, disable=hide
					setvariable ebas_sv_nameGAW, disable=hide
					setvariable ebas_sv_gawID, disable=hide
					popupmenu ebas_pop_gawType, disable=hide
					setvariable ebas_sv_airsID, disable=hide
					popupmenu ebas_pop_code, disable=hide
					popupmenu ebas_pop_codeOtherOp, disable=hide
					setvariable ebas_sv_otherNetwork, disable=hide
					setvariable ebas_sv_otherID, disable=hide
					button ebas_butt_codeOther, disable=hide
					titlebox ebas_tit_otherIDtxt, disable=hide
					titlebox ebas_tit_otherID, disable=hide
					popupmenu ebas_pop_otherRem, disable=hide
				if (hide==0)
					controlinfo ebas_pop_code
					ebas_panel_popCtrl("ebas_pop_code",v_value,s_value)
				endif
			hide = stringmatch(popStr, "Unregistered") ? 0 : 1
				titlebox ebas_tit_regInstructions, disable=hide
				groupbox ebas_grp_register, disable=hide
					button ebas_butt_webGAWSIS, disable=hide
					button ebas_butt_email, disable=hide
			break
				
		case "ebas_pop_flagList":
			hide = !stringmatch(stringfromlist(0,popStr,":"), "-1")
			setvariable ebas_sv_flagUser, disable=hide
			break
		
		case "ebas_pop_code":
			hide = stringmatch(popStr,"WDCA") ? 0 : 1
				setvariable ebas_sv_codeWDCA, disable=hide
			hide = stringmatch(popStr,"GAW") ? 0 : 1
				setvariable ebas_sv_gawID, disable=hide
				popupmenu ebas_pop_gawType, disable=hide
				setvariable ebas_sv_nameGAW, disable=hide
			hide = stringmatch(popStr, "AIRS") ? 0 : 1
				setvariable ebas_sv_airsID, disable=hide
			hide = stringmatch(popStr, "Other") ? 0 : 1
				titlebox ebas_tit_otherID, disable=hide
				titlebox ebas_tit_otherIDtxt, disable=hide
				button ebas_butt_codeOther, disable=hide
				popupmenu ebas_pop_codeOtherOp, disable=hide
				setvariable ebas_sv_otherNetwork, disable=hide
				setvariable ebas_sv_otherID disable=hide
				popupmenu ebas_pop_otherRem, disable=hide
				controlinfo ebas_pop_codeOtherOp
				if (hide==0)
					ebas_panel_popCtrl("ebas_pop_codeOtherOp", v_value, s_value)
				endif
			break
			
		case "ebas_pop_codeOtherOp":
			hide = stringmatch(popStr, "Add") ? 0 : 1
				setvariable ebas_sv_otherNetwork, disable=hide
				setvariable ebas_sv_otherID, disable=hide
			hide = stringmatch(popStr, "Rem") ? 0 : 1
				popupmenu ebas_pop_otherRem, disable=hide, mode=1
			break
			
		case "ebas_pop_flagMethod":
			//traces on current graph
			string sppList, prefix
			controlinfo ebas_pop_prevList
			strswitch(s_value)
				case "Data (Level 0)":
					sppList = ebas_panel_outputList("data", "0")
					prefix = "ug0_"
					break
				case "Data (Level 2)":
					sppList = ebas_panel_outputList("data", "2")
					prefix = "ug2_"
					break
				case "Metadata (Level 0)":
					sppList = ebas_panel_outputList("meta", "0")
					prefix = "meta0_"
					break
			endswitch
			//contents  & status of target popup
			svar/SDFR=root:ebas ref_flagTargetList
			strswitch(popStr)
				case "All":
				case "All: this plot":
				case "All: this level":
					hide = 1
					break
				case "Group: all levels":
				case "Group: this level":
					hide = 0
					ref_flagTargetList = ""
					for (i=0; i<itemsinlist(sppList); i+=1)
						str = stringfromlist(0, stringfromlist(i,sppList), "_")
						if (whichlistitem(str, ref_flagTargetList) == -1)
							ref_flagTargetList += str + ";"
						endif
					endfor
					break
				case "Single item: all levels":
				case "Single item: this level":
					hide = 0
					ref_flagTargetList = replacestring(prefix, sppList, "")
					break
			endswitch
			
			//status of dependent controls
			popupmenu ebas_pop_flagTarget, mode=1, disable=hide
			break
			
		case "ebas_pop_recList":
			string recType
			controlinfo ebas_tab_pers
			if (stringmatch(s_value,"Personnel"))
				recType = "pers"
			elseif (stringmatch(s_value, "Organization"))
				recType = "org"
			endif
			ebas_recData2D(recType, popStr, EBAS_REC2PANEL)	
			break
			
		case "ebas_pop_info":
			hide = stringmatch("All", popStr)
			button ebas_butt_recEdit, disable=hide	
			break
			
		case "ebas_pop_ceSource":
			hide = stringmatch(popStr, "Batch table")
			setvariable ebas_sv_ceSourceW, disable=hide
			break	
			
		case "ebas_pop_timeStart":			
		case "ebas_pop_timeStop":
			ebas_panel_updateTimePeriod(ctrlName, popStr)
			break 
		
		case "ebas_pop_dataMethod":
			setactivesubwindow EETA 
			strswitch(popStr)
				case "Automatic":
					if (whichlistitem("eeta_export", childwindowlist("EETA")) != -1)
						killwindow EETA#eeta_export
					endif
					break
				case "Manual":
					ebas_winGen_export(popStr)
					break
			endswitch
			ebas_panel_updateData(popStr)
			ebas_panel_updateMeta(popStr)
			controlinfo ebas_pop_timeStart
			ebas_panel_popCtrl("ebas_pop_timeStart", v_value, s_value)
			controlinfo ebas_pop_timeStop
			ebas_panel_popCtrl("ebas_pop_timeStop", v_value, s_value)
			break
			
		case "ebas_pop_instType":
			//to avoid weird behavior, disable "read inst data from IGOR" button if we can't find instrument infrastructure
			string procList = winlist("*", ";", "WIN:128")
			strswitch(popStr)	
				case "Q-ACSM":
					checkStr = listmatch(procList, "acsm_local_*")
					hide = strlen(checkStr) > 0 ? 0 : 2
					break
				case "ToF-ACSM":
					checkStr = listmatch(procList, "tw*_SQ_backbone")
					hide = strlen(checkStr) > 0 ? 0 : 2
					break
				case "HR-ToF-AMS":
				case "C-ToF-AMS":
				case "SP-AMS":
					checkStr = listmatch(procList, "SQ_AMSPanel*")
					hide = strlen(checkStr) > 0 ? 0 : 2
					break
				case "Q-AMS":
					hide = 2
			endswitch
			button ebas_butt_recReadIGOR, disable = hide
			if (!hide)
				str = "Get ID values from " + ebas_rec_instStr("analysisProgram", popStr)
				button ebas_butt_recReadIGOR, title = str
			endif
			break
			
		case "ebas_pop_wmoRegion":
			setvariable ebas_sv_state, disable = stringmatch(popStr, "(4) North and Central America") ? 0 : 1
			break
			
		case "ebas_pop_inletCut":
			setvariable ebas_sv_inletCut, disable= stringmatch(popStr,"Other") ? 0 : 1
			break
		
		case "ebas_pop_instDryer":
			setvariable ebas_sv_instDryer, disable=stringmatch(popStr,"Other*") ? 0 : 1
			break
			
		case "ebas_pop_metadata":
			setactivesubwindow EETA
			hide = stringmatch(popStr, "Detection limits") ? 0 : 1
			button ebas_butt_detLims, disable = hide
			setvariable ebas_sv_detLims, disable = hide
			hide = stringmatch(popStr, "Inlet pressure*") ? 0 : 1
			checkbox ebas_chk_metaInletP, disable=hide
			setvariable ebas_sv_metaInletP, disable=hide
			hide = stringmatch(popStr, "Inlet temperature") ? 0 : 1
			checkbox ebas_chk_metaInletT, disable=hide
			setvariable ebas_sv_metaInletT, disable=hide
			hide = stringmatch(popStr, "Inlet RH") ? 0 : 1
			checkbox ebas_chk_metaInletRH, disable=hide
			setvariable ebas_sv_metaInletRH, disable=hide
			strswitch(popStr)
				case "Inlet pressure (ambient)":
				case "Inlet temperature":
				case "Inlet RH":
					strswitch(popStr)
						case "Inlet pressure (ambient)":
							str = "InletP"
							break
						case "Inlet temperature":
							str = "InletT"
							break
						case "Inlet RH":
							str = "InletRH"
							break
					endswitch
					controlinfo $("ebas_chk_meta"+str)
					ebas_panel_chkCtrl("ebas_chk_meta"+str, v_value)	
					break
			endswitch	
			break
			
		case "ebas_pop_prevList":
			setwindow ebas_preview#prev_data_0, hide=!stringmatch(popStr, "Data (Level 0)")
			setwindow ebas_preview#prev_data_2, hide=!stringmatch(popStr, "Data (Level 2)")
			setwindow ebas_preview#prev_meta_0, hide=!stringmatch(popStr, "Metadata (Level 0)")	
			svar/SDFR=root:ebas ref_timeWave
			ref_TimeWave = "Waves in root:ebas:output\rTime wave:  "
			strswitch(popStr)
				case "Data (Level 0)":
				case "Metadata (Level 0)":
					ref_TimeWave += "tsLev0_stop"
					break
				case "Metadata (Level 0)":
					ref_timeWave += "tsLev2_stop"
			endswitch	
			//dependent controls
			controlinfo ebas_pop_flagMethod
			ebas_panel_popCtrl("ebas_pop_flagMethod", v_value, s_value)	
			break
	endswitch
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_panel_updateTimePeriod(ctrlName, popStr)
	//updates displayed start & stop times of raw time series
	string ctrlName,popStr
	//outputs
	svar/SDFR=root:ebas data_sTimeStart, data_sTimeStop
	nvar/SDFR=root:ebas data_vTimeStart, data_vTimeStop
	//other initialization
	variable numYears, numMonths, stopYear, stopMonth, noEditVal
	string sDate, sTime, suffix
	
	//get raw time series
	make/O/D/FREE/N=0 tsRaw
	controlinfo ebas_pop_dataMethod
	if (stringmatch(s_value, "Manual"))
		suffix = ""
	else
		svar/SDFR=root:ebas data_currentInst
		suffix = "_" + ebas_rec_instStr("instID", data_currentInst)
	endif
	funcref ebas_data_tsRaw func_data_tsRaw = $("ebas_data_tsRaw"+suffix)
	func_data_tsRaw(tsRaw)
	
	if (stringmatch(ctrlName, "ebas_pop_timeStop"))
		sDate = stringfromlist(0,data_sTimeStart, " ")
		sTime = stringfromlist(1, data_sTimeStart, " ")
		if (stringmatch(popStr, "Auto"))
			data_vTimeStop = tsRaw[numpnts(tsRaw)-1]
			noEditVal = 1
		elseif (stringmatch(popStr, "User set"))
			noEditVal = 0
		elseif (stringmatch(popStr, "*year"))		
			numYears = str2num(stringfromlist(0,popStr," "))
			data_vTimeStop = date2secs(str2num(stringfromlist(0,sDate,"-"))+numYears, str2num(stringfromlist(1,sDate,"-")), str2num(stringfromlist(2,sDate,"-")))
			data_vTimeStop += 60*60*str2num(stringfromlist(0,sTime,":")) + 60*str2num(stringfromlist(1,sTime,":")) + str2num(stringfromlist(2,sTime,":"))
			noEditVal = 1
		elseif (stringmatch(popStr, "*month*"))
			numMonths = str2num(stringfromlist(0, popStr, " "))
			stopYear = str2num(stringfromlist(1,sDate,"-"))+numMonths <= 12 ? str2num(stringfromlist(0,sDate,"-")) : 1+str2num(stringfromlist(0,sDate,"_"))
			stopMonth = str2num(stringfromlist(1,sDate,"-"))+numMonths <= 12 ? numMonths+str2num(stringfromlist(1,sDate,"-")) : str2num(stringfromlist(1,sDate,"-"))+numMonths-12
			data_vTimeStop = date2secs(stopYear, stopMonth, str2num(stringfromlist(2,sDate,"-")))
			data_vTimeStop += 60*60*str2num(stringfromlist(0,sTime,":")) + 60*str2num(stringfromlist(1,sTime,":")) + str2num(stringfromlist(2,sTime,":"))
			noEditVal = 1
		endif
		data_sTimeStop =  secs2date(data_vTimeStop, -2) + " " + secs2time(data_vTimeStop, 3)
		setvariable ebas_sv_timeStop, noedit = noEditVal
	
	elseif (stringmatch(ctrlName, "ebas_pop_timeStart"))
		strswitch (popStr)
			case "Auto":
				data_vTimeStart = tsRaw[0]
				noEditVal = 1
				break
			case "User set":
				noEditVal = 0
				break
			case "Start of year":
				sDate = stringfromlist(0, data_sTimeStart, " ")
				data_vTimeStart = date2secs(str2num(stringfromlist(0,sDate,"-")), 1, 1)
				noEditVal = 1
				break
		endswitch
		data_sTimeStart =  secs2date(data_vTimeStart, -2) + " " + secs2time(data_vTimeStart, 3)
		controlinfo ebas_pop_timeStop
		ebas_panel_popCtrl("ebas_pop_timeStop", v_value, s_value)
		setvariable ebas_sv_timeStart, noedit = noEditVal
	endif
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_util_isSpp(str, spp)
	//returns 1 if str is another form of spp; 0 otherwise
	string str, spp
	
	string compStr = ""
	strswitch (str)
		case "sulfate":
		case "sulphate":
		case "SO4":
			compStr = "SO4"
			break
		case "nitrate":
		case "NO3":
			compStr = "NO3"
			break
		case "ammonium":
		case "NH4":
			compStr = "NH4"
			break
		case "Cl":
		case "Chl":
		case "chloride":
			compStr = "Chl"
			break
		case "Org":
		case "organic":
		case "organics":
			compStr = "Org"
			break
	endswitch
	return stringmatch(compStr, spp)
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_panel_svCtrl(ctrlName,varNum,varStr,varName) :setvariablecontrol
	//setvariable controls
	string ctrlName
	variable varNum
	string varStr
	string varName
	
	strswitch(ctrlName)
		case "ebas_sv_timeStart":
		case "ebas_sv_timeStop":
			svar/SDFR=root:ebas str = $varName
			nvar/SDFR=root:ebas var = $(replacestring("data_s", varName, "data_v"))
			string sDate = stringfromlist(0, str, " ")
			string sTime = stringfromlist(1, str, " ")
			var = date2secs(str2num(stringfromlist(0,sDate,"-")), str2num(stringfromlist(1,sDate,"-")), str2num(stringfromlist(2,sDate,"-")))
			var +=60*60*str2num(stringfromlist(0,sTime,":")) + 60*str2num(stringfromlist(1,sTime,":")) + str2num(stringfromlist(2,sTime,":"))			
			
			controlinfo ebas_pop_timeStop
			ebas_panel_popCtrl("ebas_pop_timeStop", v_value, s_value)
			
			//check
			str = secs2date(var, -2) + " " + secs2time(var, 3)
			break
			
		case "ebas_sv_gawID":
			svar/SDFR=root:ebas code_gawID
			popupmenu ebas_pop_gawType, disable = strlen(code_gawID)>0 ? 0 : 1
			break
			
		case "ebas_sv_sppList":
			controlinfo ebas_pop_dataMethod
			ebas_panel_updateData(s_value)
			break
	endswitch
	
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_panel_updateData(method)
	//updates spp export waves based on main panel
	string method //Automatic or Manual
	
	//initialize
	svar/SDFR=root:ebas data_sppList
	data_sppList = replacestring(",", data_sppList, ";")
	wave/t/SDFR=root:ebas expData_name, expData_wDat, expData_wErr
	setwavelock 0, expData_name, expData_wDat, expData_wErr
	
	strswitch (method)
		case "Automatic":
			//overwrite everything
			redimension /N=(itemsinlist(data_sppList)) expData_name, expData_wDat, expData_wErr
			expData_name = stringfromlist(p, data_sppList)
			expData_wDat = "Auto"
			expData_wErr = "Auto"
			setwavelock 1, expData_name, expData_wDat, expData_wErr
			break
		case "Manual":
			variable i, num
			//remove spp in data wave not found in sppList
			num = numpnts(expData_name)
			for (i=num-1; i>-0; i-=1)
				if (whichlistitem(expData_name[i], data_sppList) == -1)
					deletepoints i, 1, expData_name, expData_wDat, expData_wErr
				endif
			endfor
			//add sppList items not already in wave
			num = itemsinlist(data_sppList)
			for (i=0; i<num; i+=1)
				findvalue/TXOP=4/TEXT=stringfromlist(i,data_sppList) expData_name
				if (v_value==-1)
					insertpoints numpnts(expData_name), 1, expData_name, expData_wDat, expData_wErr
					expData_name[numpnts(expData_name)-1] = stringfromlist(i,data_sppList)
				endif	
			endfor
			setwavelock 1, expData_name
			break
	endswitch
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_panel_updateMeta(method)
	//updates metadata export waves based on main panel
	string method //Automatic or Manual
	
	wave/t/SDFR=root:ebas expMeta_name, expMeta_units, expMeta_wVal
	svar/SDFR=root:ebas data_currentInst, data_sppList
	variable i, num
	
	//common metadata
	setactivesubwindow EETA
	string metaList = EBAS_metaList
	controlinfo ebas_chk_includeRH
	if (!v_value)
		metaList = removefromlist("inletRH", metaList)
	endif
	num = itemsinlist(data_sppList)

	setwavelock 0, expMeta_name, expMeta_units, expMeta_wVal
	strswitch(method)
		case "Automatic":
			//overwrite everything
			redimension/N=(itemsinlist(metaList)) expMeta_name, expMeta_units, expMeta_wVal
			expMeta_name = stringfromlist(p,metaList)
			expMeta_wVal = "Auto"
			expMeta_units = ebas_rec_instStr(data_currentInst, stringfromlist(p,metaList)+"_units")
			setwavelock 1, expMeta_name, expMeta_units, expMeta_wVal
			break
		case "Manual":
			//remove spp in data wave not found in sppList
			num = numpnts(expMeta_name)
			for (i=num-1; i>=0; i-=1)
				if (whichlistitem(expMeta_name[i], metaList) == -1)
					deletepoints i, 1, expMeta_name, expMeta_units, expMeta_wVal
				endif
			endfor
			//add sppList items not already in wave
			num = itemsinlist(metaList)
			for (i=0; i<num; i+=1)
				findvalue/TXOP=4/TEXT=stringfromlist(i,metaList) expMeta_name
				if (v_value==-1)
					insertpoints numpnts(expMeta_name), 1, expMeta_name, expMeta_units, expMeta_wVal
					expMeta_name[numpnts(expMeta_name)-1] = stringfromlist(i,metaList)
				endif	
			endfor
			expMeta_units = ebas_rec_instStr(expMeta_name+"_units", data_currentInst)
			setwavelock 1, expMeta_name, expMeta_units
			break
	endswitch		
end	
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_recData1D(type, direction)
	//converts record <--> panel for 1D records (site and inst info)
	string type //site, inst
	variable direction
	
	//make sure dimlabels are updated & record exists
	ebas_initRecord(type)
	
	dfref ebas = root:ebas
	wave/t/SDFR=ebas recWave = $(type+"Rec")
	variable panelExists = whichlistitem("ebas_"+type, winlist("*", ";", "Win:64")) != -1
	
	strswitch (type)
		case "inst":
			svar/SDFR=root:ebas inst_instID, inst_serial, inst_method, inst_daqInfo, data_currentInst, inst_dryer
			nvar/SDFR=root:ebas inst_orifice
			if (direction == EBAS_panel2rec)
				recWave[%instID] = inst_instID
				recWave[%serial] = inst_serial
				recWave[%method] = inst_method
				recWave[%daqInfo] = inst_daqInfo
				controlinfo ebas_pop_instType
				recWave[%type] = s_value
				controlinfo ebas_pop_instDryer
				recWave[%dryer] = s_value
				recWave[%dryerInfo] = selectstring(stringmatch(recWave[%dryer],"Other*"), "", inst_dryer)
				recWave[%orifice] = num2str(inst_orifice)
				controlinfo ebas_pop_instLens
				recWave[%lens] = s_value
			elseif (direction == EBAS_rec2panel)
				inst_instID = recWave[%instID]
				inst_serial = recWave[%serial] 
				inst_method = recWave[%method]
				inst_daqInfo = recWave[%daqInfo]
				inst_dryer = recWave[%dryerInfo] //note this is extra info if recWave[%dryer]="Other"
				inst_orifice = str2num(recWave[%orifice])
				if (panelExists)
					doWindow/F ebas_inst			
					popupmenu ebas_pop_instType, mode = max(1,1+whichlistitem(recWave[%type], EBAS_instType))
					controlinfo ebas_pop_instType
					ebas_panel_popCtrl("ebas_pop_instType", v_value, s_value)
					popupmenu ebas_pop_instDryer, mode = max(1,1+whichlistitem(recWave[%dryer], EBAS_instDryer))
					controlinfo ebas_pop_instDryer
					ebas_panel_popCtrl("ebas_pop_instDryer", v_value, s_value)
					popupmenu ebas_pop_instDryer, mode = max(1,1+whichlistitem(recWave[%lens], EBAS_instLens))
				endif
			endif
			//update instType on main panel
			data_currentInst = recWave[%type]
			dowindow/F EETA
			strswitch(data_currentInst)
				case "Q-ACSM":
					popupmenu ebas_pop_dataMethod value = "Automatic;Manual;"
					break
				default:
					popupmenu ebas_pop_dataMethod value = "Manual;",mode=1
			endswitch
			controlupdate ebas_pop_dataMethod
			controlinfo ebas_pop_dataMethod
			ebas_panel_popCtrl("ebas_pop_dataMethod", v_value, s_value)
			dowindow/F ebas_inst
			break
		
		case "site":
			svar/SDFR=ebas code_ebasStationName, code_ebasStation, code_ebasPlatform, code_ebasLab
			svar/SDFR=ebas code_wdcaID, code_gawName, code_gawID, code_airsID, code_otherID
			nvar/SDFR=ebas stat_latitude, stat_longitude, stat_altitude
			svar/SDFR=ebas stat_state
			svar/SDFR=ebas in_type, in_cutPt, in_description
			nvar/SDFR=ebas in_height
			if (direction == EBAS_panel2rec)
				//simple panel read
				recWave[%stationName] = code_ebasStationName
				recWave[%stationCode] = code_ebasStation
				recWave[%platformCode] = code_ebasPlatform
				recWave[%labCode] = code_ebasLab
				recWave[%stationID_WDCA] = code_wdcaID
				recWave[%stationName_GAW] = code_gawName
				recWave[%stationID_GAW] = code_gawID
				recWave[%stationID_AIRS] = code_airsID
				recWave[%stationID_listOther] = code_otherID
				recWave[%stationState] = stat_state
				recWave[%latitude] = num2str(stat_latitude)
				recWave[%longitude] = num2str(stat_longitude)
				recWave[%altitude] = num2str(stat_altitude)
				controlinfo ebas_pop_landUse
				recWave[%landUse] = s_value
				controlinfo ebas_pop_landSetting
				recWave[%landSetting] = s_value
				controlinfo ebas_pop_gawType
				recWave[%type_GAW] = s_value
				controlinfo ebas_pop_wmoRegion
				recWave[%region_WMO] = num2str(v_value)
				recWave[%inletHt] = num2str(in_height)
				controlinfo ebas_pop_inletType
				recWave[%inletType] = s_value
				recWave[%inletDescription] = in_description	
				controlinfo ebas_pop_inletCut
				recWave[%inletCut] = s_value + ";" + in_cutPt + ";"
				controlinfo ebas_pop_stStatus
				recWave[%registered] = selectstring(stringmatch(s_value,"Registered"), "No", "Yes")			
			elseif (direction == EBAS_rec2panel)
				//EBAS codes
				code_ebasStationName = recWave[%stationName]
				code_ebasStation = recWave[%stationCode]
				code_ebasPlatform = recWave[%platformCode]
				code_ebasLab = recWave[%labCode]
				//other codes
				code_wdcaID = recWave[%stationID_WDCA]
				code_gawName = recWave[%stationName_GAW]
				code_gawID = recWave[%stationID_GAW]
				
				code_airsID = recWave[%stationID_AIRS]
				code_otherID = recWave[%stationID_listOther]
				//location
				stat_latitude = str2num(recWave[%latitude])
				stat_longitude = str2num(recWave[%longitude])
				stat_altitude = str2num(recWave[%altitude])
				stat_state = recWave[%stationState]
				//inlet
				in_height = str2num(recWave[%inletHt])			
				in_description = recWave[%inletDescription]	
				in_cutPt = stringfromlist(1, recWave[%inletCut])
				//panel controls
				if (panelExists)
					popupmenu ebas_pop_gawType, mode = max(1,1+whichlistitem(recWave[%type_GAW], EBAS_stationGAW))
					popupmenu ebas_pop_landSetting, mode = max(1, 1+whichlistitem(recWave[%landSetting], EBAS_landSetting))
					popupmenu ebas_pop_landUse, mode = max(1, 1+whichlistitem(recWave[%landUse], EBAS_landUse))
					popupmenu ebas_pop_wmoRegion,mode=str2num(recWave[%region_WMO])
					popupmenu ebas_pop_inletType, mode = max(1, 1+whichlistitem(recWave[%inletType], EBAS_inletType))
					popupmenu ebas_pop_inletCut, mode = max(1, 1+whichlistitem(stringfromlist(0,recWave[%inletCut]), EBAS_inletCut))
					//registration status
					popupmenu ebas_pop_stStatus, mode = stringmatch(recWave[%registered],"Yes") ? 1 : 2
					controlinfo ebas_pop_stStatus
					ebas_panel_popCtrl("ebas_pop_stStatus", v_value, s_value)
				endif
			endif
			break
			
	endswitch		
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_recData2D(type, recKey,direction)
	//converts record <--> panel for 2D records (personnel & organization)
	string type
	string recKey //identifier for record entry or "New"
	variable direction
	
	dfref ebas = root:ebas
	wave/t/SDFR=ebas recWave = $(type+"Rec")
	controlinfo ebas_pop_recList
	variable recPos = v_value == 1 ? -1 : v_value-2
	string recStr = s_value
	variable pos
	variable panelExists = whichlistitem("ebas_"+type, winlist("*", ";", "Win:64")) != -1
	
	//didn't find existing record (panel2rec) OR popup set to New (panel2Rec or rec2Panel)
	if (direction == EBAS_PANEL2REC)
		if (stringmatch(recKey, "New")) //new entry: need to expand wave & adjust recPos
			if (dimsize(recWave,1)==0) //starting from 0D wave - have to initialize
				ebas_initRecord(type+"Rec")
				recPos = 0
			else //wave & dimlabels exist; just add a column
				recPos = dimsize(recWave,1)
				insertpoints/M=1 recPos, 1, recWave
			endif
		endif
	elseif (direction==EBAS_recKill && !stringmatch(recKey, "New"))
		deletepoints/M=1 recPos, 1, recWave
	endif	

	strswitch (type)
		case "pers":
			svar/SDFR=ebas pers_firstName, pers_lastName, pers_email
			if (direction == EBAS_PANEL2REC) //saving panel data to record
				recWave[%lastName][recPos] = pers_lastName
				recWave[%firstName][recPos] = pers_firstName
				recWave[%email][recPos] = pers_email
				controlinfo ebas_pop_persOrg
				recWave[%orgName][recPos] = s_value
				recWave[%orgCode][recPos] = num2str(v_value - 1)
				controlinfo ebas_chk_persOrigin
				recWave[%dataOrigin][recPos] = selectstring(v_value, "0", "1")
				controlinfo ebas_chk_persSubmit
				recWave[%dataSubmit][recPos] = selectString(v_value, "0", "1")
			elseif (direction == EBAS_REC2PANEL || direction==EBAS_recKill) //record wave to panel
				if (stringmatch(recKey, "New") || direction == EBAS_recKill)
					pers_lastName = ""
					pers_firstName = ""
					pers_email = ""
					if (panelExists)
						popupmenu ebas_pop_persOrg, mode=1
						checkbox ebas_chk_persOrigin, value=0
						checkbox ebas_chk_persSubmit, value=0
					endif
				else	
					pers_lastName = recWave[%lastName][recPos]
					pers_firstName = recWave[%firstName][recPos]
					pers_email = recWave[%email][recPos]			
					if (panelExists)
						pos = whichlistitem(recWave[%orgName][recPos], ebas_recList("org"))
						popupmenu ebas_pop_persOrg, mode=max(1,1+str2num(recWave[%orgCode][recPos]))
						checkbox ebas_chk_persOrigin, value=str2num(recWave[%dataOrigin][recPos])
						checkbox ebas_chk_persSubmit, value = str2num(recWave[%dataSubmit][recPos])
					endif
				endif
			endif
			break
			
		case "org":
			svar/SDFR=ebas org_name, org_acronym, org_dept, org_add1, org_add2, org_postCode, org_town, org_country, org_labCode
			if (direction == EBAS_PANEL2REC) //saving panel data to record
				recWave[%name][recPos] = org_name
				recWave[%acronym][recPos] = org_acronym
				recWave[%dept][recPos] = org_dept
				recWave[%address1][recPos] = org_add1
				recWave[%address2][recPos] = org_add2
				recWave[%postCode][recPos] = org_postCode
				recWave[%town][recPos] = org_town
				recWave[%country][recPos] = org_country
				recWave[%labCode][recPos] = org_labCode
			elseif (direction == EBAS_REC2PANEL || direction == EBAS_recKill) //record to panel
				if (stringmatch(recKey,"New"))
					org_name = ""
					org_acronym = ""
					org_dept = ""
					org_add1 = ""
					org_add2 = ""
					org_postCode = ""
					org_town = ""
					org_country = ""
					org_labCode = ""
				else
					org_name = recWave[%name][recPos]
					org_acronym = recWave[%acronym][recPos]
					org_dept = recWave[%dept][recPos]
					org_add1 = recWave[%address1][recPos]
					org_add2 = recWave[%address1][recPos]
					org_postCode = recWave[%postCode][recPos]
					org_town = recWave[%town][recPos]
					org_country = recWave[%country][recPos]
					org_labCode = recWave[%labCode][recPos]
				endif
				//update affected personnel records
				wave/T/SDFR=ebas persRec
				if (direction==EBAS_recKill)
					//have to update persRec orgCodes; subtract 1 from any that are >= recPos (which was deleted)
					persRec[%orgCode][] = num2str(	str2num(persRec[%orgCode][q])>=recPos ? str2num(persRec[%orgCode][q])-1 : str2num(persRec[%orgCode][q])	)
				elseif (direction==EBAS_PANEL2REC)
					wave/t/SDFR=ebas orgRec
					persRec[%orgName][] = orgRec[%labCode][str2num(persRec[%orgCode][q])]      + ", " +      orgRec[%name][str2num(persRec[%orgCode][q])]      +      selectstring(strlen(orgRec[%acronym][str2num(persRec[%orgCode][q])])>0, "", " ("+orgRec[%acronym][str2num(persRec[%orgCode][q])]+")") 
				endif
			endif
			break
	endswitch
	
	//report
	if (direction==EBAS_panel2rec)
		if (stringmatch(recKey,"New"))
			popupmenu ebas_pop_recList, mode= 2 + recPos
			doalert 0, "Entry added."
		else
			doalert 0, "Entry modified."
		endif
	elseif (direction==EBAS_recKill)
		popupmenu ebas_pop_recList, mode=1
		doalert 0, "Entry deleted."
	endif
end	
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//function/t ebas_data_CE(sppList, wTS, wCE)
	//calculates collection efficiency wave(s), redimensioning if necessary
	//returns info (key/list) on calculation method
	string sppList
	wave wTS, wCE

	variable i, num, val
	string thisSpp, abortStr
	
	//redimension dest wave
	redimension/N=(numpnts(wTS)) wCE
	
	//determine CE declaration method
	controlinfo ebas_pop_ceSource
	string method = s_value
	
	string destStr = ""
	strswitch (method)
		case "Batch table":
			destStr += "method=batch&"
			wave/t specName = root:specName
			wave facCE = root:CE
			extract/O facCE, facCE_spp, whichlistitem(specName[p],sppList,";",0,0)!=-1
			wavestats/Q facCE_spp
			if (v_min==v_max)
				destStr += "numOut=1&"
				wCE = facCE_spp[0]
			else
				abortStr = "Error: all species must have the same CE in batch table. Aborting from ebas_data_CE."
				abort abortStr
			endif		
			break
			
		case "Time-dependent":
			destStr += "method=wave&"
			svar/SDFR=root:ebas data_CEwave
			destStr += "wName=" + data_CEwave + "&"
			
			wave source_CE = $data_CEwave
			if (!waveexists(source_CE))
				abortStr = "Error: CE source wave <" + data_CEwave + "> does not exist. Aborting from ebas_data_CE."
				abort abortStr
			endif
			
			if (numpnts(source_CE) != numpnts(wTS))
				abortStr = "Error: waves acsm_utc_time and " + data_CEwave + " have different lengths. Aborting from ebas_data_CE."
				abort abortStr 
			endif
			wCE = source_CE
			break			
	endswitch
	
	return destStr
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_data_calcTS(paramStr)
	//calculates time series and associated (PMF-style) uncertainties
	//also calculates & saves collection efficiency as a metadata output
	//this function contains only general-purpose calculations
		//instrument-specific routines are called via funcref - see "//instrument selection"
	//fills the "origTimeRes" field in data_report
	string paramStr
	
	//parse paramStr
	string dataList_lev0 = stringbykey("dataList_lev0", paramStr, "=", "&")
	string metaList_lev0 = stringbykey("metaList_lev0", paramStr, "=", "&")
	string dataList_lev2 = stringbykey("dataList_lev2", paramStr, "=", "&")
	string instID = stringbykey("instID", paramStr, "=", "&")  //e.g. "_AMS", "_qACSM"
	string instSuffix = selectstring(stringmatch(instID, "general"), "_"+instID, "")
	//reporting
	svar/SDFR=root:ebas data_report
	
	//other initialization
	variable pos, i, num, unitConv
	string thisDest, thisItem
	
	//instrument selection
	funcref ebas_data_tsRaw ebas_data_tsRaw = $ebas_rec_instStr("fn_data_tsLev0", instID)
	funcref ebas_data_dataLev0 fn_data_dataLev0 = $ebas_rec_instStr("fn_data_dataLev0", instID)
	funcref ebas_data_metaLev0 fn_data_metaLev0 = $ebas_rec_instStr("fn_data_metaLev0", instID)
	
	//split destList & metaList into calc/read classes (calc=calculate via instrument function; read=read from pregenerated wave or constant)
	string dataList_calc="", dataList_read="", metaList_calc="", metaList_read=""
	wave/t/SDFR=root:ebas expData_name, expData_wDat, expData_wErr, expMeta_name, expMeta_wVal
	num = numpnts(expData_name)
	for (i=0; i<num; i+=1)
		if (stringmatch(expData_wDat[i],"Auto") || stringmatch(expData_wErr[i],"Auto"))
			dataList_calc += expData_name[i] + ";"
		endif
		if (!stringmatch(expData_wDat[i],"Auto") || !stringmatch(expData_wErr[i],"Auto"))
			dataList_read += expData_name[i] + ";"
		endif
	endfor
	num = numpnts(expMeta_name)
	for (i=0; i<num; i+=1)
		if (stringmatch(expMeta_wVal[i],"Auto"))
			metaList_calc += expMeta_name[i] + ";"
		else
			metaList_read += expMeta_name[i] + ";"
		endif
	endfor
	
	//instrument type & level 0 data (time axis, data, and metadata)
	make/O/FREE/D/N=0 tsRaw
	ebas_data_tsRaw(tsRaw)
	
	make/O/D/FREE/N=(numpnts(tsRaw), itemsinlist(dataList_lev0)) mDatLev0, mErrLev0
	make/O/D/FREE/N=(numpnts(tsRaw), itemsinlist(metaList_lev0)) mMetaLev0
	
	make/O/D/N=0/FREE mDat_calc, mErr_calc, mMeta_calc
	make/O/D/N=0/FREE mDat_read, mErr_read, mMeta_read
	
	//get metadata (level 0)
	fn_data_metaLev0(metaList_calc, tsRaw, mMeta_calc)
	ebas_data_metaLev0(metaList_read, tsRaw, mMeta_read)
	
	//extract CE
	make/O/D/N=(numpnts(tsRaw))/FREE wCE
	if (whichlistitem("CE", metaList_calc) != -1)
		wCE = mMeta_calc[p][whichlistitem("CE", metaList_calc)]
	elseif (whichlistitem("CE", metaList_read) != -1)
		wCE = mMeta_read[p][whichlistitem("CE", metaList_read)]
	else
		abort "Error: invalid collection efficiency wave. Aborting from ebas_data_calcTS."
	endif
	
	//get data (level 0)
	fn_data_dataLev0(dataList_calc, tsRaw, wCE,mDat_calc, mErr_calc)
	ebas_data_dataLev0(dataList_read, tsRaw, wCE, mDat_read, mErr_read)
	
	//merge auto/read matrices into single matrix
	//metadata
	make/O/FREE/N=(numpnts(tsRaw)) wTemp
	variable pos_calc, pos_read, pos_ref
	num = itemsinlist(metaList_lev0)
	for (i=0; i<num; i+=1)
		thisItem = stringfromlist(i, metaList_lev0)
		pos_calc = whichlistitem(thisItem, metaList_calc)
		pos_read = whichlistitem(thisItem, metaList_read)
		findvalue/TXOP=4/TEXT=thisItem expMeta_name
		pos_ref = v_value
		wTemp = stringmatch(expMeta_wVal[pos_ref], "Auto") ? mMeta_calc[p][pos_calc] : mMeta_read[p][pos_read]
		ebas_data_metaUnitsToFin(thisItem, wTemp)
		mMetaLev0[][i] = wTemp[p]
	endfor
	//data
	variable pos_P, pos_T
	num = itemsinlist(dataList_lev0)
	findvalue/TXOP=4/TEXT="inletPressure" expMeta_name
	pos_P = v_value
	findvalue/TXOP=4/TEXT="inletT" expMeta_name
	pos_T = v_value
	for (i=0; i<num; i+=1)
		thisItem = stringfromlist(i,dataList_lev0)
		pos_calc = whichlistitem(thisItem, dataList_calc)
		pos_read = whichlistitem(thisItem, dataList_read)
		findvalue/TXOP=4/TEXT=thisItem expData_name
		pos_ref = v_value
		unitConv = str2num(stringbykey("unitConv", ebas_data_unitInfo(thisItem), "=", ";"))	
		mDatLev0[][i] = unitConv * stringmatch(expData_wDat[pos_ref], "Auto") ? mDat_calc[p][pos_calc] : mDat_read[p][pos_read]
		mErrLev0[][i] = unitConv * stringmatch(expData_wErr[pos_ref], "Auto") ? mErr_calc[p][pos_calc] : mErr_read[p][pos_read]
		//convert to STP
		mDatLev0[][i] = mDatLev0[p][i] * (mMetaLev0[p][pos_T]/EBAS_STP_K) / (mMetaLev0[p][pos_P]/EBAS_STP_hPa)
	endfor
	
	//report raw time resolution
	make/O/FREE/N=1 tempStart=tsRaw[0], tempStop=tsRaw[1]
	data_report += "origTimeRes=" + ebas_file_getResolutionCode(tempStart, tempStop, "1") + ";"
	
	//generate level 0 time waves
	make/O/D/N=0 root:ebas:output:tsLev0_start/WAVE=tsLev0_start, root:ebas:output:tsLev0_stop/WAVE=tsLev0_stop
	setscale d,0,0,"dat" tsLev0_start, tsLev0_stop
	ebas_data_timeWaveLev0(tsRaw, tsLev0_start, tsLev0_stop)
	
	//trim dataset to selected interval
	nvar/SDFR=root:ebas data_vTimeStart, data_vTimeStop
	//last point to delete (before dataset)
	pos = binarysearch(tsLev0_stop, data_vTimeStart) -1 
	if (pos >=0 && pos <=numpnts(tsLev0_stop)-1)
		deletepoints/M=0 0, pos+1, tsLev0_start, tsLev0_stop, mDatLev0, mErrLev0, mMetaLev0
	endif
	//first point to delete (after dataset)
	pos = binarysearch(tsLev0_start, data_vTimeStop) + 1
	if (pos >=0 && pos <=numpnts(tsLev0_start)-1)
		deletepoints/M=0 pos, numpnts(tsLev0_start)-pos, tsLev0_start, tsLev0_stop, mDatLev0, mErrLev0, mMetaLev0
	endif
		
	//generate level 2 matrices
	make/O/FREE/D/N=(0) mDatLev2, mErrLev2, mMetaLev2 //mMetaLev2 not currently needed for EBAS, but generate just in case
	make/O/D/N=0 root:ebas:output:tsLev2_start/WAVE=tsLev2_start, root:ebas:output:tsLev2_stop/WAVE=tsLev2_stop
	ebas_data_changeToLev2(mDatLev0, mErrLev0, mMetaLev0, tsLev0_start, tsLev0_Stop, mDatLev2, mErrLev2, mMetaLev2, tsLev2_start, tsLev2_stop) //data trimming handled internally (via rebinning)
	
	//unpack matrices & set flags
	variable numLev0 = dimsize(mDatLev0,0)
	variable numLev2 = dimsize(mDatLev2, 0)
	variable missFlag = 0.999
	string dfStr = "root:ebas:output:"
	for (i=0; i<itemsinlist(dataList_lev0); i+=1)
		thisDest = stringfromlist(i,dataList_lev0)		
		make/O/D/N=(numLev0) $(dfStr+"ug0_"+thisDest)/WAVE=ug0, $(dfStr+"err0_"+thisDest)/WAVE=err0, $(dfStr+"flag0_"+thisDest)/WAVE=flag0
		ug0 = mDatLev0[p][i]
		err0 = mErrLev0[p][i]
		flag0 = numtype(ug0[p])==0 ? 0 : missFlag
	endfor
	for (i=0; i<itemsinlist(dataList_lev2); i+=1)
		thisDest = stringfromlist(i,dataList_lev2)	
		make/O/D/N=(numLev2) $(dfStr+"ug2_"+thisDest)/WAVE=ug2, $(dfStr+"err2_"+thisDest)/WAVE=err2, $(dfStr+"flag2_"+thisDest)/WAVE=flag2
		ug2 = mDatLev2[p][i]
		err2 = mErrLev2[p][i]
		flag2 = numtype(ug2[p])==0 ? 0 : missFlag
	endfor
	for (i=0; i<itemsinlist(metaList_lev0); i+=1)
		thisDest = stringfromlist(i,metaList_lev0)
		make/O/D/N=(numLev0) $(dfStr+"meta0_"+thisDest)/WAVE=meta0, $(dfStr+"flag0_"+thisDest)/WAVE=flag0
		meta0 = mMetaLev0[p][i]
		flag0 = numtype(meta0[p])==0 ? 0 : missFlag
	endfor
//	make/O/D/N=(numLev0) $("root:ebas:meta0_CE") = wCE
	
	//report - obsolete v2.2
//	svar/SDFR=root:ebas ref_dataLevel, ref_timeWave
//	ref_dataLevel = "Level " + level + " data"
//	ref_timeWave = "Time wave is:\rroot:ebas:tsLev"+level+"_stop"
	
	//cleanup
	killwaves/z mDat, mErr, mMeta
	ebas_panel_updateStatus(0, "Ready")
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_data_metaUnitsToFin(strMeta, wMeta)
	//converts metadata from initial to final units
	string strMeta
	wave wMeta
	
	strswitch(strMeta)
		case "lensPressure":
		case "inletPressure":
			//torr --> hPa
			wMeta *= 1.333
			break
		case "inletT":
			//degrees C --> K
			wMeta += 273
			break
	endswitch
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_data_tsRaw(tsRaw)
	//generates raw level 0 time axis
	wave tsRaw

	svar/SDFR=root:ebas tsName = data_exp_wTS
	wave tempTS = $tsName
	redimension /N=(numpnts(tempTS)) tsRaw
	tsRaw = tempTS
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_data_metaLev0(metaList, tsRaw, mMetaLev0)
	//PROTOFUNC
	//handles generation of level 0 metadata
		//two methods: (1) wave declaration in EETA metadata table; (2) constant set in EETA metadata table
	string metaList
	wave tsRaw, mMetaLev0
	
	//metadata
	string thisMeta
	wave/t/SDFR=root:ebas expMeta_wVal, expMeta_name
	variable i, num = itemsinlist(metaList)
	redimension /N=(numpnts(tsRaw), num) mMetaLev0
	for (i=0; i<num; i+=1)
		thisMeta = stringfromlist(i,metaList)
		findvalue/TXOP=4/TEXT=thisMeta expMeta_name
		if (numtype(str2num(expMeta_wVal[v_value])) == 0) //constant
			mMetaLev0[][i] = str2num(expMeta_wVal[v_value])
		else //wave declaration
			wave wMeta = $expMeta_wVal[v_value]
			mMetaLev0[][i] = wMeta[p]
		endif
	endfor
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_data_dataLev0(dataList, tsRaw, wCE, mDatLev0, mErrLev0)
	//PROTOFUNC
	//handles generation of raw level 0 ts, data, and error matrices (note data and error are NOT individual 1-D waves)
	//defaults to loading from EETA tables
	string dataList
	wave tsRaw, wCE, mDatLev0, mErrLev0

	//declare globals
	wave/T/SDFR=root:ebas expData_wDat, expData_wErr
	//other initialization
	variable i, num
	
	//data
	num = itemsinlist(dataList)
	redimension /N=(numpnts(tsRaw), num) mDatLev0, mErrLev0
	for (i=0; i<num; i+=1)
		wave wDat = $expData_wDat[i]
		wave wErr = $expData_wErr[i]
		mDatLev0[][i] = wDat[p]
		mErrLev0[][i] = wErr[p]
	endfor
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_data_tsRaw_qACSM(tsRaw)
	//based on protofunc ebas_data_tsRaw
	//generates raw time axis for Q-ACSM
	wave tsRaw
	
	//time axis
	wave/SDFR=root:ACSM_incoming acsm_utc_time
	redimension /N=(numpnts(acsm_utc_time)) tsRaw
	fastop tsRaw = acsm_utc_time
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_data_dataLev0_qACSM(dataList, tsRaw, wCE, mDatLev0, mErrLev0)
	//based on protofunc ebas_data_dataLev0
	//get raw data (mDat) and uncertainties (mErr) for Q-ACSM auto-calc
	//data and uncertainties are in matrix form (columns corresponding to dataList), NOT individual 1-D waves
	//PROTOFUNC - defaults to loading from EETA tables
	string dataList
	wave tsRaw, wCE, mDatLev0, mErrLev0
	
	//ACSM functions - declare as funcrefs so ipf compiles if ACSM software not present
	funcref ebas_protoACSM_respeciate ACSM_PMF_RespeciateWholeTS = $"ACSM_PMF_RespeciateWholeTS"
	//globals
	wave/t RIE_sppName = root:specname
	wave RIE_sppVal = root:RIE
	wave massCalib_nitrate = root:massCalib_nitrate
	//other initialization	
	variable taskDex, numTasks, destDex, numDests
	variable colDex, numCols, mz, pos
	string calcInfo
	string thisTask, thisMatType, thisdataList, thisSpp, thisDest
	
	//redimension output waves
	redimension/N=(numpnts(tsRaw), itemsinlist(dataList)) mDatLev0, mErrLev0

	//create raw (unspeciated) matrices - note CE is NOT applied
	make/O/N=0 mDatRaw, mErrRaw
	wave/z corrW = root:TimeSeries_corrections:smCorr_w
	if (!waveExists(corrW))
		Abort "You need to create a corrections wave first using the Corrections Workplot. Aborting from ebas_data_tsCorrs."
	endif
	string info_data = ebas_acsmMats(mDatRaw, mErrRaw)
	variable gain = str2num(stringbykey("gain", info_data, "=", "&"))
	variable dwellTime = str2num(stringbykey("dwellTime", info_data, "=", "&"))
	variable minError = str2num(stringbykey("minError", info_data, "=", "&"))
	//apply time series corrections (see ACSM_applyCorrectionForPMF in ACSM_local)
	mDatRaw *= corrW[p]
	mErrRaw *= corrW[p]
	
	//reorganize dataList to group individual ions with their respective parents
	string dataList_toProc = dataList
	string dest_taskList = ""
	string dataList_thisSpp
	do
		thisSpp = stringfromlist(0, stringfromlist(0, dataList_toProc), "_")
		dataList_thisSpp = listmatch(dataList, thisSpp+"*")
		dest_taskList += thisSpp + "=" + dataList_thisSpp + "&"
		dataList_toProc = removefromlist(dataList_thisSpp, dataList_toProc)
	while (itemsinlist(dataList_toProc) > 0)
		
	//calculate data products
	variable numToDel = dimsize(mDatRaw,1) - 125 //chop bad m/z's
	numTasks = itemsinlist(dest_taskList, "&")
	for (taskDex=0; taskDex<numTasks; taskDex+=1)
		ebas_panel_updateStatus(taskDex/numTasks, "Generating data products")
		thisTask = stringfromlist(taskDex, dest_taskList, "&")
		thisMatType = stringfromlist(0, thisTask, "=")
		thisdataList = stringfromlist(1, thisTask, "=")
		
		//matrix speciation
		ACSM_PMF_RespeciateWholeTS(mDatRaw, thisMatType, "mDat"+thisMatType)
		ACSM_PMF_RespeciateWholeTS(mErrRaw, thisMatType, "mErr"+thisMatType)
		wave mDatSpp = $("mDat"+thisMatType)
		wave mErrSpp = $("mErr"+thisMatType)
		deletepoints/M=1 125, numToDel, mDatSpp, mErrSpp
	
		//*****copied from ACSM_PMF_initialize in acsm_local_1532.ipf*****\\
		//unit conversion, minimum errors, and CE application
		mDatSpp *= (Gain/(6.24e18*DwellTime))
		mErrSpp *= (Gain/(6.24e18*DwellTime))
		mErrSpp = mErrSpp[p][q] == 0 ? minError : mErrSpp[p][q]
		findvalue/TXOP=4/TEXT=thisMatType RIE_sppName
		mDatSpp *= 1 / (wCE[p] * RIE_sppVal[v_value] * massCalib_nitrate[0])
		mErrSpp *= 1 / (wCE[p] * RIE_sppVal[v_value] * massCalib_nitrate[0])
		//***** end copied code *****\\
		
		duplicate/o mDatSpp root:ebas:testMat
		
		//sum matrix to time series
		numDests = itemsinlist(thisdataList)
		for (destDex=0; destDex<numDests; destDex+=1)
			thisDest = stringfromlist(destDex, thisdataList)
			pos = whichlistitem(thisDest, dataList) //for bookkeeping, position in destination matrices corresponds to *original* dataList
			if (itemsinlist(thisDest, "_") > 1) //individual mz
				mz = str2num(stringfromlist(1, thisDest, "_"))
				mDatLev0[][pos] = mDatSpp[p][mz-1]
				mErrLev0[][pos] = mErrSpp[p][mz-1]
			else //sum of species	
				matrixop/o/FREE tempDest = sumRows(mDatSpp)
				mDatLev0[][pos] = tempDest[p]
				//error propagation
				fastop tempDest = 0	
				numCols = dimsize(mErrSpp,1)
				for (colDex=0; colDex<numCols; colDex+=1)
					tempDest += mErrSpp[p][colDex]^2
				endfor
				mErrLev0[][pos] = sqrt(tempDest[p])
			endif	
		endfor
	endfor
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_data_metaLev0_qACSM(metaList, tsRaw, mMetaLev0)
	////based on protofunc ebas_data_metaLev0
	//get raw metadata time series (mMetaLev0) using "Auto" calculation for Q-ACSM
	string metaList
	wave tsRaw, mMetaLev0
	
	//initialize output
	redimension/N=(numpnts(tsRaw), itemsinlist(metaList)) mMetaLev0
	
	//handle non-CE metadata
	variable calcType //1 == find direct; 2=location in reference wave; 3=user constant
	variable metaDex, metaVal, numMeta, pos, abortFlag = 0
	string thisMeta
	numMeta = itemsinlist(metaList)
	for (metaDex=0; metaDex<numMeta; metaDex+=1)
		thisMeta = stringfromlist(metaDex, metaList)

		strswitch(stringfromlist(0, thisMeta, "_"))
			case "lensPressure":
				calcType = 1
				wave/z thisMetaW = root:diagnostics:inletP
			case "inletPressure":		
				svar/SDFR=root:ebas data_inletP
				controlinfo ebas_chk_metaInletP
				if (v_value)
					calcType = 1
					wave/z thisMetaW = $data_inletP
				else
					calcType = 3
					metaVal = str2num(data_inletP)
				endif				
				break
			case "airbeam":
				calcType = 1
				wave/z thisMetaW = root:diagnostics:airbeam
				break
			case "inletRH":
				calcType = 1
				controlinfo ebas_chk_metaInletRH
				if (v_value)
					svar/SDFR=root:ebas data_inletRH
					wave/z thisMetaW = $data_inletRH
				else			
					abort "Automatic calculation of inlet RH for Q-ACSM is not currently supported. Aborting from ebas_data_dataLev0_qACSM."
				endif
				break			
			case "inletT":
				svar/SDFR=root:ebas data_inletT		
				controlinfo ebas_chk_metaInletT
				if (v_value)
					calcType = 1
					wave/z thisMetaW = $data_inletT
				else
					calcType = 3
					metaVal = str2num(data_inletT)
				endif
				break
			case "RIE":
				calcType = 3
				wave/t/z/SDFR=root: metaSourceTxt = Specname
				wave/z/SDFR=root: metaSourceVal = RIE
				if (!waveexists(metaSourceTxt) || !waveexists(metaSourceVal))	
					abortFlag = 1
				else
					findvalue/TXOP=4/TEXT=stringfromlist(1,thisMeta,"_") metaSourceTxt
					metaVal = metaSourceVal[v_value]
				endif
				break
			case "ce":
				calcType = 3
				wave/t specName = root:specName
				wave facCE = root:CE
				string sppList = "Org;NO3;SO4;NH4;Chl;"
				extract/O facCE, facCE_spp, whichlistitem(specName[p],sppList,";",0,0)!=-1
				wavestats/Q facCE_spp
				if (v_min==v_max)
					metaVal = facCE_spp[0]
				else
					abort "Error: all species must have the same CE in batch table. Aborting from ebas_data_metaLev0_qACSM."
				endif
		endswitch
		//general checks for abort
		if (calcType == 1)
			if (!waveexists(thisMetaW))
				abortFlag = 1
			elseif (numpnts(thisMetaW) != dimsize(mMetaLev0,0))
				abortFlag = 2
			endif
		endif
		
		//report errors or assign data
		if (abortFlag==1)
			abort "Error: metadata <" + thisMeta + "> source wave does not exist. Aborting from ebas_data_dataLev0_qACSM."
		elseif (abortFlag==2)
			abort "Error: metadata <" + thisMeta + "> does not have the correct wave length. Aborting from ebas_data_dataLev0_qACSM."
		elseif (calcType==1)
			mMetaLev0[][metaDex] = thisMetaW[p]
		elseif (calcType==2)
			mMetaLev0[][metaDex] = metaSourceVal[pos]
		elseif (calcType==3)
			mMetaLev0[][metaDex] = metaVal
		endif
	endfor
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/t ebas_file_metaUnits(meta, [instID])
	//returns units for specified metadata
	string meta, instID
	
	strswitch(meta)
		case "collection_efficiency":
			return "no unit"
		
		case "inlet_pressure":
			return "torr"
	
	endswitch
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_data_timeWaveLev0(tsRaw, tsStart, tsStop)
	//calculates measurement start and stop times (for Lev0 time series) from raw acsm time series
	wave tsRaw, tsStart, tsStop
	
	variable badThresh = 0.05 // allowed deviation from apparent averaging time before avg time is assumed to be bad and is replaced
	
	redimension /N=(numpnts(tsRaw)) tsStart, tsStop
	
	//stop times are easy - directly recorded by ACSM
	fastop tsStop = tsRaw
	
	make/O/FREE/D/N=(numpnts(tsRaw)) rawAvgTime = p > 0 ? tsStop[p] - tsStop[p-1] : tsStop[1] - tsStop[0]
	//1. check if rawAvgTime violates threshold by comparing to (previously checked) rawAvgTime[p-1]
	//2. if violation, rawAvgTime[p] gets rawAvgTime[p+/-1] depending on which of tsStop[p+/-1] is closer to tsStop[p]
	rawAvgTime[1, numpnts(rawAvgTime)-2] = abs(rawAvgTime[p]-rawAvgTime[p-1])/rawAvgTime[p-1] < badThresh ? rawAvgTime[p] : (abs(tsStop[p-1]-tsStop[p])<abs(tsStop[p+1]-tsStop[p]) ? rawAvgTime[p-1] : rawAvgTime[p+1])
	
	//calculate start times from stop times & cleaned integration wave
	fastop tsStart = tsStop - rawAvgTime
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_data_changeToLev2(mDatLev0, mErrLev0, mMetaLev0, tsLev0_start, tsLev0_stop, mDatLev2, mErrLev2, mMetaLev2, tsLev2_start, tsLev2_stop)
	//converts ACSM data and error matrices from native time resolution (Lev0) to hourly data (lev2)
	//Lev2 waves will be redimensioned internally
	//ts waves should be double precision
	wave mDatLev0, mErrLev0, mMetaLev0, tsLev0_start, tsLev0_stop, mDatLev2, mErrLev2, mMetaLev2, tsLev2_start, tsLev2_stop
	
	//time parameters
	variable secsInHr = 60*60
	nvar/SDFR=root:ebas data_vTimeStart, data_vTimeStop
	
	//misc initialization
	variable numMZ = dimsize(mDatLev0,1)
	variable i, numRaw = dimsize(mDatLev0,0)
	variable startLev0, stopLev0, posStartLev2, posStopLev2
	variable weight
	string timeStr
	variable year, month, day
	
	//get nice start/stop points
	//start = first day, truncate time
	variable firstT, lastT
	timeStr = secs2date(data_vTimeStart,-2)
	year = str2num(stringfromlist(0,timeStr,"-"))
	month = str2num(stringfromlist(1,timeStr,"-"))
	day = str2num(stringfromlist(2,timeStr,"-"))
	firstT = date2secs(year,month,day)
	//stop = last day + 1, truncate time
	timeStr = secs2date(data_vTimeStop,-2)
	year = str2num(stringfromlist(0,timeStr,"-"))
	month = str2num(stringfromlist(1,timeStr,"-"))
	day = str2num(stringfromlist(2,timeStr,"-"))
	lastT = date2secs(year,month,day) + 24*secsInHr
	
	variable numTS = (lastT-firstT)/secsInHr
	make/O/FREE/N=(numTS) fracGood = 0
	redimension /N=(numTS, dimsize(mDatLev0,1)) mDatLev2, mErrLev2
	redimension /N=(numTS, dimsize(mMetaLev0,1)) mMetaLev2
	redimension /N=(numTS) tsLev2_start, tsLev2_stop
	fastop mDatLev2 = 0
	fastop mErrLev2 = 0
	
	tsLev2_start = firstT + p*secsInHr
	tsLev2_stop = firstT + (p+1)*secsInHr
	setscale d,0,0,"dat" tsLev2_start, tsLev2_stop

	for (i=0; i<numRaw; i+=1)
		ebas_panel_updateStatus(i/numRaw, "Averaging data")
		if (numtype(mDatLev0[i][0])!= 0) //bad point
			continue
		endif
		
		if (tsLev0_stop[i] > tsLev2_start[0] && tsLev0_stop[i] < tsLev2_stop[numTS-1]) //make sure point falls within requested time interval
					
			posStartLev2 = ebas_util_findVar(tsLev2_start, tsLev0_start[i], 0, 2)
			posStopLev2 = tsLev0_stop[i] <= tsLev2_stop[posStartLev2] ? posStartLev2 : min(numTS, posStartLev2 + 1) //check if we jump a Lev2 bin edge
			
			if (posStartLev2 == posStopLev2) //entire measurement falls in a single bin
				weight = (tsLev0_stop[i]-tsLev0_start[i])/secsInHr
				fracGood[posStartLev2][] += weight
				mDatLev2[posStartLev2][] += mDatLev0[i][q] * weight
				mErrLev2[posStartLev2][] += mErrLev0[i][q] * weight
				mMetaLev2[posStartLev2][] += mMetaLev0[i][q]*weight
			else //measurement spans a bin edge
				//lower bin (Lev0 start to Lev2 start) goes into bin_Lev2start
				if (tsLev0_stop[i] > tsLev2_start[0])
					weight = (tsLev2_stop[posStartLev2] - tsLev0_start[i]) / secsInHr
					fracGood[posStartLev2] += weight
					mDatLev2[posStartLev2][] += mDatLev0[i][q] * weight
					mErrLev2[posStartLev2][] += mErrLev0[i][q] * weight
					mMetaLev2[posStartLev2][] += mMetaLev0[i][q]*weight
				endif
				//upper bin (Lev2 start to Lev0 stop) goes into bin_Lev2stop
				if (tsLev0_stop[i] < tsLev2_stop[numTS-1])
					weight = (tsLev0_stop[i] - tsLev2_start[posStopLev2]) / secsInHr
					fracGood[posStopLev2] += weight
					mDatLev2[posStopLev2][] += mDatLev0[i][q] * weight
					mErrLev2[posStopLev2][] += mErrLev0[i][q] * weight
					mMetaLev2[posStopLev2][] += mMetaLev0[i][q]*weight
				endif
			endif
		endif
	endfor	
	//account for missing/bad data points
	mDatLev2 /= fracGood[p]
	mErrLev2 /= fracGood[p]
	mMetaLev2 /= fracGood[p]
		
	//complete error calculation
	mErrLev2 *= sqrt((tsLev0_stop[0]-tsLev0_start[0])/secsInHr)	
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_util_findVar(w,val,wType,mode)
	//returns index number of val in wave w; in case of an inexact match, the output is determined by the mode parameter
	wave w 
	variable val //value to find in wave w
	variable wType//wave description: 0=monotonically increasing, 1=monotonically decreasing
	variable mode //determines output type as follows
		//mode = 0: returns exact value only; return -1 if no exact match
		//mode = 1: if no exact match, returns point with value closest to val (i.e. if val=7, w[3]=6.9, w[4]=7.5, returns 3)
		//mode = 2: if no exact match, returns closest point with lower index value (in above example, returns 3)
		//mode = 3: if no exact match, returns closest point with higher index value (in above example, returns 4)
		//mode = 4: if no exact match, linearly interpolates between values of bracketing points to find a non-integer point number (in above example, returns ~3.17)
	variable low,high,comp
	
	//handle values beyond wave edge 
	if (val<w[0])
		switch (mode)
			case 0:
			case 2:
			case 4:
				return -1
			case 1:
			case 3:
				return 0
		endswitch
	elseif (val>w[numpnts(w)-1])
		switch (mode)
			case 0:
			case 3:
			case 4:
				return -1
			case 1:
			case 2:
				return numpnts(w)-1
		endswitch
	endif
	
	//searching...
	if (wType == 0)
		low = 0
		high = numpnts(w)-1
		do
			comp = floor((high+low)/2)
			if (val < w[comp])
				high = comp
			elseif (val>= w[comp])
				low = comp
			endif
		while (high - low > 1)
	elseif (wType == 1)
		low = 0
		high = numpnts(w)-1
		do
			comp = floor((high+low)/2)
			if (val < w[comp])
				low = comp
			elseif (val>= w[comp])
				high = comp
			endif
		while (high-low > 1)
	endif
	
	//calculating output...		
	if (w[high] == val)
		return high
	elseif (w[low] == val)
		return low
	elseif (mode == 0)
		return -1
	elseif (mode==1)
		if (abs(w[high]-val) < abs(w[low]-val))
			return high
		else
			return low
		endif
	elseif (mode == 2)
		return low
	elseif (mode == 3)
		return high
	elseif (mode == 4)
		return low+(val-w[low])/(w[high]-w[low])
	endif
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////	

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/t ebas_acsmMats(mDat, mErr)
	//calculates ts vs. m/z matrices in <units?> ug/m3
	//returns parameters used in calculation needed for external calcs
	//mostly copied from ACSM_PMF_initialize in acsm_local_1532.ipf
		//resulting function is a bit ugly, but leaves base procedure as unchanged as possible to facilitate compatibility with future analysis software upgrades
		//modified so that intermediate calculations take place in free datafolder to avoid conflicts with ACSM
		//inserted modifications to abort calculation if user cancels any of the prompts
	wave mDat, mErr
	
	dfref oldDF = getdatafolderDFR()
	dfref freeDF = newfreedatafolder()
	
	//ACSM funcrefs
	funcref ebas_protoACSM_calcMinErr Calc_minError = $"Calc_minError"
	funcref ebas_protoACSM_enforceMin Replace_lessThan_withVal = $"Replace_lessThan_withVal"
	funcref ebas_protoACSM_nanToZero deluxe_Nan2Zero = $"deluxe_Nan2Zero"
	
	//***** begin copied code *****\\
	variable a = 1.2
	
	//**modified for EBAS (all intermediates stored in free df)
//	string sf = getDatafolder(1); MakeAndOrSetDF( "root:PMFMats" )
	setdatafolder freeDF
	
	//Get Gain
	variable Gain = 2e4
	Prompt Gain "What was the gain for these measurements?"
	DoPrompt "What was the gain for these measurements" Gain
	if (v_flag==1)
		setdatafolder oldDF
		abort "Operation cancelled by user."
	endif
	variable DwellTime = 1
	// The Dwell Time we want is the total number of sets of open and closed for each point * the dwell time setting from ACSM DAQ * 2*ka_amu_window
	// e.g. 10sets*0.5s/amu*0.1amu = 0.5s. ka_amu_window is the fraction of an amu which is used to calculate the stick height.
	Prompt DwellTime "What was the Dwell Time (s/amu)?"
	DoPrompt "Dwell Time", DwellTime
	if (v_flag==1)
		setdatafolder oldDF
		abort "Operation cancelled by user."
	endif
	//Get m/z for electronic noise
	variable massForElectronicNoise = 140
	Prompt massForElectronicNoise, "What mass should be used to determine electronic noise? Enter zero to skip"
	DoPrompt "Electonic Noise", massForElectronicNoise
	if (v_flag==1)
		setdatafolder oldDF
		abort "Operation cancelled by user."
	endif
	variable electronicNoise = 0
	// Open and closed haven't been RIT (Tm/z) corrected.
	wave OpenMat = root:acsm_incoming:mssopen_mzcorr
	wave ClosedMat = root:acsm_incoming:mssClosed_mzcorr
	// calculate electronic noise based on closed data for a m/z with no real signal
	if (massForElectronicNoise != 0)
		make /O/N=(dimsize(closedMat,0)) eNoiseWave = closedMat[p][massForElectronicNoise]
		wavestats /Q eNoiseWave
		// factors here are to convert to counts...
		electronicNoise=6.24e18*DwellTime*V_Sdev/Gain
	endif
	// Convert open and closed to counts
	make/O/N=(dimsize(OpenMat,0), dimsize(OpenMat,1)) openMatCts = OpenMat*6.24e18*DwellTime/Gain
	make/O/N=(dimsize(ClosedMat,0), dimsize(ClosedMat,1)) ClosedMatCts = ClosedMat*6.24e18*DwellTime/Gain
	//Apply RIT Correction to open and closed (in counts)
	MatrixOp/O openMatCts = openMatCts^t
	MatrixOp/O closedMatCts = closedMatCts^t
	//***** End copied code *****\\
	
	//Here we modify the ion transmission correction to fix a bug in ACSM_local
//	ACSM_correctIonTransmission(openMatCts)
//	ACSM_correctIonTransmission(closedMatCts)
	wave avRITFit = root:RIT:averageRITFit
	openMatCts /= avRITFit[p]
	closedMatCts/= avRITFit[p]
	
	//***** Begin copied code *****\\
	MatrixOp/O openMatCts = openMatCts^t
	MatrixOp/O closedMatCts = closedMatCts^t
	//Calculate difference and its error in cts
	MatrixOp/O diffMatCts = OpenMatCts - ClosedMatCts 
	MatrixOp/O eOpenMatCts = a*powr(OpenMatCts,0.5)
	MatrixOp/O eClosedMatCts = a*powr(ClosedMatCts,0.5)
	MatrixOp/O eDiffMatCts = powr((powr(eOpenMatCts,2) + powr(eClosedMatCts,2)),0.5)
	//Trim the first column from the matrices (this is a dummy column so p = amu typically)
	deletepoints /M=1 0,1,eDiffMatCts, diffMatCts
	// Replace low errors with min error really tiny errors can cause problems in PMF 
	variable minError = Calc_minError(Gain,DwellTime)
	eDiffMatCts = Replace_lessThan_withVal(eDiffMatCts,minError,minError)
	// add electronic Noise
	MatrixOp/O eDiffMatCts = powr((powr(eDiffMatCts,2) + electronicNoise*electronicNoise),0.5)
	//Remove NaNs
	eDiffMatCts = deluxe_Nan2Zero(eDiffMatCts)
	DiffMatCts = deluxe_NaN2Zero(diffMatCts)
	
	//***** end copied code *****\\
	//store outputs
	redimension /N=(dimsize(diffMatCts,0), dimsize(diffMatCts,1)) mDat, mErr
	mDat = diffMatCts
	mErr = eDiffMatCts
	string destStr = ""
	destStr += "gain=" + num2str(gain) +"&"
	destStr += "dwellTime=" + num2str(dwellTime) + "&"
	destStr += "minError=" + num2str(minError) + "&"
	
	//cleanup
	setdatafolder oldDF
	return destStr
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/t ebas_data_unitInfo(spp)
	//given a species spp, returns key-list with information about spp units
	string spp
	//list elements (variable name is list key)
	string unitTxt = "ug/m3"	//unit string
	variable unitConv = 1 		//conversion from ug/m3 to EBAS units (EBAS = ug/m3 * unitConv)
	string sppName = spp		//name of species for EBAS (e.g. NO3 --> nitrate)
	string sppCat = spp		//species category (e.g. organic_mass for org_43)
	
	//other initialization
	string resultStr = ""
	string thisType
	
	thisType = stringfromlist(0, spp, "_")
	strswitch(thisType)
		case "NH4":
		case "NO3":
			unitTxt = "ug N/m3"
			unitConv = ebas_data_sppMass("N") / ebas_data_sppMass(spp)
			if (stringmatch(thisType, "NH4"))
				sppCat = "ammonium"
			elseif (stringmatch(thisType, "NO3"))
				sppCat = "nitrate"
			endif
			break
		case "SO4":
			unitTxt = "ug S/m3"
			unitConv = ebas_data_sppMass("S") / ebas_data_sppMass(spp)
			sppCat = "sulphate_total"
			break
		case "Org":
			sppCat = "organic_mass"
			break
		case "Chl":
			sppCat = "chloride"
			break
	endswitch
	
	if (itemsinlist(spp, "_") == 1) //spp is sum of frag wave (e.g Org)
		sppName = sppCat //otherwise, retain spp name
	endif
	
	resultStr += "unitTxt=" + unitTxt + ";"
	resultStr += "unitConv=" + num2str(unitConv) + ";"
	resultStr += "sppName=" + sppName + ";"
	resultStr += "sppCat=" + sppCat + ";"
	
	return resultStr
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_data_sppMass(spp)
	//calculate molecular weight of spp (from formula)
	string spp
	//constants
	variable mass_H = 1.007 // JAY - GET VALUE
	variable mass_N = 14.0057
	variable mass_O = 15.9994
	variable mass_S = 32.066
	variable mass_C = 12.000
	
	variable result = 0
	string thisItem
	variable massElem, i
	
	string transList = ""
	//this is very crude for now: elements must be single letter & # must be < 9
	
	//step 1: change spp name to something easier to work with
	for (i=0; i<strlen(spp); i+=1)
		if (numtype(str2num(spp[i])) != 0)	
			transList += spp[i] + "="
			if (numtype(str2num(spp[i+1])) != 0 || i+1 >= strlen(spp))
				transList += "1;"
			else
				transList += spp[i+1] + ";"
			endif
		endif
	endfor
	
	//step 2: do calculations		
	for (i=0; i<itemsinlist(transList); i+=1)
		thisItem = stringfromlist(i, transList)
		strswitch(stringfromlist(0, thisItem, "="))
			case "H":
				massElem = mass_H
				break
			case "N":
				massElem = mass_N
				break
			case "O":
				massElem = mass_O
				break
			case "S":
				massElem = mass_S
				break
		endswitch
		result += massElem * str2num(stringfromlist(1,thisItem,"="))
	endfor
	
	return result
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_data_previewTS()
	//calculates requested data products and generates panel for data preview in which EBAS flags can be set
	
	//initialize
	wave/t/SDFR=root:ebas expMeta_name, expMeta_wVal, expData_name, expData_wDat, expData_wErr
	
	//save CE status
	controlinfo ebas_pop_dataMethod
	if (stringmatch(s_value, "Manual"))
		expData_wDat = selectstring(stringmatch(expData_wDat,"Auto"), expData_wDat, "")
		expData_wErr = selectstring(stringmatch(expData_wErr,"Auto"), expData_wErr, "")
		expMeta_wVal = selectstring(stringmatch(expMeta_wVal,"Auto"), expmeta_wVal, "")
	else
		setwavelock 0, expData_wDat, expData_wErr, expMeta_wVal
		expData_wDat = "Auto"
		expData_wErr = "Auto"
		expMeta_wVal = "Auto"
		findvalue/TXOP=4/TEXT="ce" expMeta_Name
		variable pos = v_value
		controlinfo ebas_pop_ceSource
		if (stringmatch(s_value, "Batch table"))
			expMeta_wVal[pos] = "Auto"
		elseif (stringmatch(s_value, "Time-dependent") || stringmatch(s_value, "Middlebrook"))
			svar/SDFR=root:ebas data_ceWave
			expMeta_wVal[pos] = data_ceWave
		endif
		setwavelock 1, expData_wDat, expData_wErr
	endif
	
	//pre-checks
	ebas_data_expSanity()
	
	//initialize report string
	svar/SDFR=root:ebas data_report
	data_report = ""
	
	//********** prepare parameter string for calculation ***********\\
	string funcParStr = ""
	
	//data & metadata lists
	funcParStr += "dataList_lev0=" + ebas_panel_outputList("data", "0") + "&"
	funcParStr += "metaList_lev0=" + ebas_panel_outputList("meta", "0") + "&"
	funcParStr += "dataList_lev2=" + ebas_panel_outputList("data", "2") + "&"
	
	//prepare paramStr from panel info - will pass to calculation and panel
	svar/SDFR=root:ebas data_currentInst
	funcParStr += "instID=" + ebas_rec_instStr("instID", data_currentInst) + "&"
	
	//calculate time series
	ebas_data_calcTS(funcParStr)
	//generate panel
	ebas_winGen_previewTS(funcParStr)
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/T ebas_panel_outputList(type, level)
	//returns list of outputs
	string type //data or meta
	string level //0 or 2
	
	strswitch(type)
		case "data":
			wave/T/SDFR=root:ebas expData_name
			string dataList_lev0 = ebas_util_txtWaveToList(expData_name)
			if (stringmatch(level, "0"))
				return dataList_lev0
			elseif (stringmatch(level, "2"))
				string dataList_lev2 = removefromlist("NO3_30", dataList_lev0)
				dataList_lev2 = removefromlist("NO3_46", dataList_lev2)
				return dataList_lev2
			endif
			break
		
		case "meta":
			wave/T/SDFR=root:ebas expMeta_name
			if (stringmatch(level, "0"))
				string metaList_lev0 = ebas_util_txtWaveToList(expMeta_name)
				return metaList_lev0
			elseif (stringmatch(level, "2"))
				return ""
			endif
			break
			
		default:
			return ""		
	endswitch
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_winGen_previewTS(paramStr)
	//panel generation for previewing data and setting EBAS flags
	string paramStr
	
	//parse paramStr
	string dataList_lev2 = stringbykey("dataList_lev2", paramStr, "=", "&")
	string dataList_lev0 = stringbykey("dataList_lev0", paramStr, "=", "&")
	string metaList_lev0 = stringbykey("metaList_lev0", paramStr, "=", "&")
	
	//reference waves & globals
	wave/t/SDFR=root:ebas colorTxt
	wave/SDFR=root:ebas colorVal
	wave/t/SDFR=root:ebas expMeta_name, expMeta_units
	svar/SDFR=root:ebas data_currentInst
	
	//other initialization	
	variable itemDex, numItems
	variable plotDex, numPlots
	string thisItem, thisItemList, thisLevel, thisType, thisTitle, thisPlotName, thisSpp
	string legendStr, unitStr

	//create panel
	dowindow/K ebas_preview
	newpanel /W=(238,67,1171,608) /N=ebas_preview
	//controls
	GroupBox ebas_grp_display,pos={8,7},size={312,89},title="Display options"
	popupmenu ebas_pop_prevList, pos={16,25},fstyle=1,fColor=(0,0,0), proc=ebas_panel_popCtrl, popColor=(13056,13056,0)
	popupmenu ebas_pop_prevList, title="Show:", value="Data (Level 2);Data (Level 0);Metadata (Level 0);"
	TitleBox ebas_tit_timeWave,pos={15,55},size={87,34},variable= root:ebas:ref_timeWave
	CheckBox ebas_chk_errorBars,pos={245,29},size={63,14},proc=ebas_panel_chkCtrl,title="Error bars",value= 1
	Button ebas_butt_closePreview,pos={226,69},size={88,21},proc=ebas_panel_doOps,title="Close preview", fColor=(65280,0,0)
	
	GroupBox ebas_grp_flags,pos={323,7},size={600,90},title="EBAS flags"
	PopupMenu ebas_pop_flagList,pos={330,26},size={314,21},proc=ebas_panel_popCtrl,title="Active flag (apply with marquee):"
	PopupMenu ebas_pop_flagList,mode=1,value= #"root:ebas:ref_flagList"
	PopupMenu ebas_pop_flagMethod,pos={330,52},size={84,21},proc=ebas_panel_popCtrl,title="Apply to:",mode=1,value= #"\"All;All: this level;All: this plot;Group: all levels;Group: this level;Single item: all levels;Single item: this level;\""
	PopupMenu ebas_pop_flagTarget,pos={506,52},size={60,21},disable=1,mode=1,value= #"root:ebas:ref_flagTargetList"
	SetVariable ebas_sv_flagUser,pos={779,28},size={81,16},disable=1,title="Flag:",value= root:ebas:ref_userFlagVal
	Button ebas_butt_flagTable,pos={820,69},size={96,20},proc=ebas_panel_doOps,title="View current flags"
	
	//generate plots
	numPlots = 3
	for (plotDex=0; plotDex<numPlots; plotDex+=1)
		//initialize
		switch (plotDex)
			case 0:
				thisItemList = dataList_lev0
				thisLevel = "0"
				thisType = "data"
				break
			case 1:
				thisItemList = metaList_lev0
				thisLevel = "0"
				thisType = "meta"
				break
			case 2:	
				thisItemList = dataList_lev2
				thisLevel = "2"
				thisType = "data"
				break
		endswitch
		thisTitle = upperStr(thisType + ": Level " + thisLevel)
		thisPlotName = "prev_" + thisType + "_" + thisLevel
		wave/SDFR=root:ebas:output wTS = $("tsLev" + thisLevel + "_stop")
		numItems = itemsinlist(thisItemList)
		//initialize legend
		legendStr = thisTitle
		
		//draw
		display /W=(13,102,920,533) /HOST=ebas_preview /N=$thisPlotName
		for (itemDex=0; itemDex<numItems; itemDex+=1)
			thisItem = stringfromlist(itemDex, thisItemList)
			if (stringmatch(thisType, "data"))
				wave/SDFR=root:ebas:output tsItem=$("ug"+thisLevel+"_"+thisItem), tsErr=$("err"+thisLevel+"_"+thisItem), tsFlag=$("flag"+thisLevel+"_"+thisItem)
			elseif (stringmatch(thisType, "meta"))
				wave/SDFR=root:ebas:output tsItem=$("meta"+thisLevel+"_"+thisItem), tsFlag=$("flag"+thisLevel+"_"+thisItem)
			endif
			
			appendtograph tsItem vs wTS
			appendtograph/L=flag tsFlag vs wTS
			if (stringmatch(thisType, "data"))
				errorbars $nameofwave(tsItem) Y, wave=(tsErr, tsErr)
			endif
			
			//color & style
			findValue/TXOP=4/TEXT=thisItem colorTxt
			if (v_value != -1)
				modifygraph rgb($nameofwave(tsItem))=(colorVal[v_value][0], colorVal[v_value][1], colorVal[v_value][2])
				modifygraph lsize($nameofwave(tsItem))=2
				modifygraph rgb($nameofwave(tsFlag))=(colorVal[v_value][0], colorVal[v_value][1], colorVal[v_value][2])
				modifygraph lsize($nameofwave(tsFlag))=2
			endif
			
			//legend contents
			legendStr += "\r\s(" +nameofwave(tsItem) + ") " + thisItem
			if (stringmatch(thisType, "meta"))
				unitStr = ebas_rec_instStr(thisItem+"_unitsFin", data_currentInst)
			elseif (stringmatch(thisType, "data"))
				thisSpp = stringfromlist(0,thisItem,"_")
				unitStr = stringbykey("unitTxt", ebas_data_unitInfo(thisSpp), "=", ";")
			endif
			legendStr += " (" + unitStr + ")"
		endfor
			
		//axis labels & legend
		textbox legendStr
		label bottom "Date and Time"
		label left selectstring(stringmatch(thisType,"data"), "Units in legend", "\F'Symbol'm\F'Arial'g m\S-3\M at STP")
		ModifyGraph axisEnab(left)={0,0.7},axisEnab(flag)={0.75,1},freePos(flag)=0
		Label flag "NumFlag"
		ModifyGraph lblPos(flag)=62
			
		//cleanup
		setactivesubwindow ##
		dowindow /HIDE=1 $thisPlotName
	endfor
	
	//execute control functions
	controlinfo ebas_pop_prevList
	ebas_panel_popCtrl("ebas_pop_prevList", v_value, s_value)
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function ebas_panel_chkCtrl(ctrlName, checked) : checkboxcontrol
	//checkbox operations
	string ctrlName
	variable checked
	
	variable i, num, pos
	
	strswitch(ctrlName)
		case "ebas_chk_errorBars":
			string thisTrace, errTrace
			string traceList = traceNameList("ebas_preview", ";", 1)
			num = itemsinlist(traceList)
			for (i=0; i<num; i+=1)
				thisTrace = stringfromlist(i, traceList)
				if (checked)
					errTrace = "root:ebas:"+replacestring("ug_", thisTrace, "err_")
					errorbars $thisTrace Y, wave=($errTrace, $errTrace)
				else
					errorbars $thisTrace OFF
				endif
			endfor
			break
			
		
		case "ebas_chk_metaInletP":
			setvariable ebas_sv_metaInletP, title=selectstring(checked, "Estimated P (torr):", "Wave (torr):")
			break
			
		case "ebas_chk_metaInletT":
			setvariable ebas_sv_metaInletT, title=selectstring(checked, "Estimated T (deg C);", "Wave (deg C):")
			break
		
		case "ebas_chk_metaInletRH":
			wave/T/SDFR=root:ebas expMeta_name, expMeta_wVal, expMeta_units
			svar/SDFR=root:ebas data_currentInst
			string units = ebas_rec_instStr("inletRH_units", data_currentInst)
			string meta = "inletRH"
			setvariable ebas_sv_metaInletRH, disable=!checked, title=selectstring(checked, "", "Wave ("+units+"):")
			setwavelock 0, expMeta_name, expMeta_units
			if (checked)
				svar/SDFR=root:ebas data_currentInst
				pos = numpnts(expMeta_name)		
				insertpoints pos, 1, expMeta_name, expMeta_wVal, expMeta_units
				expMeta_name[pos] = meta					
				expMeta_wVal[pos] = ""
				expMeta_units[pos] = units
			else
				findvalue/TXOP=4/TEXT=meta expMeta_name
				deletepoints v_value, 1, expMeta_name, expMeta_wVal, expMeta_units
			endif
			setwavelock 1, expMeta_name, expMeta_units
			break
	endswitch
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
menu "GraphMarquee" //JAY - NEED TO EDIT THIS
	"-"
	"EBAS: Apply active flag", ebas_marq_setFlags()
end

function ebas_marq_setFlags()
	//set EBAS flags from user marquee	
	
	//read panel
	string plot_type, plot_level
	controlinfo ebas_pop_prevList
	strswitch(s_value)
		case "Data (Level 0)":
			plot_type = "data"
			plot_level = "0"
			break
		case "Data (Level 2)":
			plot_type = "data"
			plot_level = "2"
			break
		case "Metadata (Level 0)":
			plot_type = "meta"
			plot_level = "0"
			break
	endswitch
	//other panel reads
	controlinfo ebas_pop_flagMethod
	string target_method = s_value
	controlinfo ebas_pop_flagTarget
	string target_val = s_value
	
	//determine target waves
	string destList_item, destList_level, tempList
	strswitch(target_method)
		case "All":
			destList_item = ebas_util_uniqueList(ebas_panel_outputList("data","0") + ebas_panel_outputList("data", "2") + ebas_panel_outputList("meta", "0"))
			destList_level = "0;2;"
			break
		case "All: this level":
			destList_item = ebas_panel_outputList("data", plot_level) + ebas_panel_outputList("meta",plot_level)
			destList_level = plot_level
			break
		case "All: this plot":
			destList_item = ebas_panel_outputList(plot_type, plot_level)
			destList_level = plot_level
			break
		case "Group: all levels":
			tempList = ebas_util_uniqueList(ebas_panel_outputList("data","0") + ebas_panel_outputList("data", "2") + ebas_panel_outputList("meta", "0"))
			destList_item = listMatch(tempList, target_val+"*")
			destList_level = "0;2;"
			break
		case "Group: this level":
			tempList = ebas_panel_outputList(plot_type, plot_level)
			destList_item = listMatch(tempList, target_val+"*")
			destList_level = plot_level
			break
		case "Single item: all levels":
			destList_item = target_val
			destList_level = "0;2;"
			break
		case "Single item: this level":
			destList_item = target_val
			destList_level = plot_level
			break
	endswitch	
	
	//get (raw) marquee range
	wave/SDFR=root:ebas:output tsPlot = $("tsLev"+plot_level+"_stop")
	variable edgeL_time, edgeR_time
	getMarquee/K/Z bottom
	edgeL_time = V_left
	edgeR_time = V_right
//	tsPlot[edgeL_time] = binarysearch(tsPlot,V_left)+1 
//	tsPlot[edgeR_time] = binarysearch(tsPlot,V_right)
	
	//apply flags
	wave/T/SDFR=root:ebas refData=expData_name, refMeta=expMeta_name
	variable levelDex, numLevels = itemsinlist(destList_level)
	variable itemDex, numItems = itemsinlist(destList_item)
	string thisLevel, thisItem, thisPrefix
	variable edgeL, edgeR
	for (levelDex=0; levelDex<numLevels; levelDex+=1)
		//marquee coordinates for this level
		wave/SDFR=root:ebas:output tsRef = $("tsLev"+stringfromlist(levelDex,destList_level)+"_stop")
		edgeL = binarySearch(tsRef, edgeL_time)+1
		edgeR = binarySearch(tsRef, edgeR_time)
		//get flag value
		controlinfo ebas_pop_flagList
		variable flagVal = str2num(stringfromlist(0, s_value, ":"))
		if (flagVal == -1)
			nvar/SDFR=root:ebas ref_userFlagVal
			flagVal = ref_userFlagVal
		endif
	
		//step through target waves & set flags
		thisLevel = stringfromlist(levelDex, destList_level)
		for (itemDex=0; itemDex<numItems; itemDex+=1)
			thisItem = stringfromlist(itemDex, destList_item)
			findvalue/TXOP=4/TEXT=thisItem refData
			wave/SDFR=root:ebas:output wTarget = $("flag" + thisLevel + "_" + thisItem)
			if (waveexists(wTarget)) //catch NO3_30 & no3_46
				wTarget[edgeL, edgeR] = flagVal/1000
			endif
		endfor
	endfor
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/t ebas_panel_listFlagTarget(itemList, level)
	//returns a list of all traces targeted by set flag operation
	string itemList, level
	
	wave/T/SDFR=root:ebas expData_name, expMeta_name
	variable i, num = itemsinlist(itemList)
	
	controlinfo ebas_pop_flagMethod
	string flagMethod = s_value
	controlinfo ebas_pop_flagTarget
	string flagTarget = s_value
	string traceList = traceNameList("ebas_preview", ";", 1)
	strswitch(flagMethod)
		case "All":
			return listmatch(traceList, "ug_*")
		case "All group":
			return listmatch(traceList, "ug_"+flagTarget+"*")
		case "Single":
			return listMatch(traceList, "ug_"+flagTarget)
	endswitch
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//********************* ACSM protofuncs ************************\\
function ebas_protoACSM_respeciate(diffMat, specName, destStr)
	//ACSM protofunc
	//from ACSM_PMF_ReSpeciateWholeTS
	wave diffMat
	string SpecName,destStr
end
function ebas_protoACSM_calcMinErr(gain, dwell_time)
	//ACSM protofunc
	//from Calc_MinError
	variable gain
	variable dwell_time
end
function ebas_protoACSM_enforceMin(num, val, lessThanVal)
	//ACSM protofunc
	//from Replace_lessThan_withVal
	variable num
	variable val
	variable lessThanVal
end
function ebas_protoACSM_nanToZero(num)
	//ACSM protofunc
	//from Deluxe_nan2zero
	variable num
end
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/S ebas_util_win1252ToUTF8(windows1252String)
	//renamed from "ConvertWindows1252StringToUTF8" in "Convert Windows1252 to UTF8.ipf", written by Howard Rodstein (Wavemetrics, Inc.)

// ConvertWindows1252StringToUTF8(windows1252String)
// windows1252String is a string in the Windows-1252 (also called Windows Latin1 and Windows Western) text encoding.
// The function result is the corresponding string in the UTF-8 text encoding.
// This will be very slow for very large text waves.
// Do not use this in Igor7. Use the Igor7 ConvertTextEncoding function or SetWaveTextEncoding operation instead.
// Example:
//	Wave windows1252TextWave = <some text wave containing Windows-1252 text>
//	Duplicate/O windows1252TextWave, tempUTF88TextWave
//	tempUTF88TextWave = ConvertWindows1252StringToUTF8(windows1252TextWave)
//	// Do something with tempUTF88TextWave
//	KillWaves tempUTF88TextWave
	String windows1252String
	
	String utf8Text = ""
	
	Variable numwindows1252Chars = strlen(windows1252String)
	Variable i
	for(i=0; i<numwindows1252Chars; i+=1)
		String windows1252Char = windows1252String[i]
		Variable windows1252Code = char2num(windows1252Char) & 0xFF
		if (windows1252Code < 128)
			utf8Text += windows1252Char
		else
			switch(windows1252Code)
				case 128:
					utf8Text += "€"
					break
				case 129:
					utf8Text += ""
					break
				case 130:
					utf8Text += "‚"
					break
				case 131:
					utf8Text += "ƒ"
					break
				case 132:
					utf8Text += "„"
					break
				case 133:
					utf8Text += "…"
					break
				case 134:
					utf8Text += "†"
					break
				case 135:
					utf8Text += "‡"
					break
				case 136:
					utf8Text += "ˆ"
					break
				case 137:
					utf8Text += "‰"
					break
				case 138:
					utf8Text += "Š"
					break
				case 139:
					utf8Text += "‹"
					break
				case 140:
					utf8Text += "Œ"
					break
				case 141:
					utf8Text += ""
					break
				case 142:
					utf8Text += "Ž"
					break
				case 143:
					utf8Text += ""
					break
				case 144:
					utf8Text += ""
					break
				case 145:
					utf8Text += "‘"
					break
				case 146:
					utf8Text += "’"
					break
				case 147:
					utf8Text += "“"
					break
				case 148:
					utf8Text += "”"
					break
				case 149:
					utf8Text += "•"
					break
				case 150:
					utf8Text += "–"
					break
				case 151:
					utf8Text += "—"
					break
				case 152:
					utf8Text += "˜"
					break
				case 153:
					utf8Text += "™"
					break
				case 154:
					utf8Text += "š"
					break
				case 155:
					utf8Text += "›"
					break
				case 156:
					utf8Text += "œ"
					break
				case 157:
					utf8Text += ""
					break
				case 158:
					utf8Text += "ž"
					break
				case 159:
					utf8Text += "Ÿ"
					break
				case 160:
					utf8Text += " "
					break
				case 161:
					utf8Text += "¡"
					break
				case 162:
					utf8Text += "¢"
					break
				case 163:
					utf8Text += "£"
					break
				case 164:
					utf8Text += "¤"
					break
				case 165:
					utf8Text += "¥"
					break
				case 166:
					utf8Text += "¦"
					break
				case 167:
					utf8Text += "§"
					break
				case 168:
					utf8Text += "¨"
					break
				case 169:
					utf8Text += "©"
					break
				case 170:
					utf8Text += "ª"
					break
				case 171:
					utf8Text += "«"
					break
				case 172:
					utf8Text += "¬"
					break
				case 173:
					utf8Text += "­"
					break
				case 174:
					utf8Text += "®"
					break
				case 175:
					utf8Text += "¯"
					break
				case 176:
					utf8Text += "°"
					break
				case 177:
					utf8Text += "±"
					break
				case 178:
					utf8Text += "²"
					break
				case 179:
					utf8Text += "³"
					break
				case 180:
					utf8Text += "´"
					break
				case 181:
					utf8Text += "µ"
					break
				case 182:
					utf8Text += "¶"
					break
				case 183:
					utf8Text += "·"
					break
				case 184:
					utf8Text += "¸"
					break
				case 185:
					utf8Text += "¹"
					break
				case 186:
					utf8Text += "º"
					break
				case 187:
					utf8Text += "»"
					break
				case 188:
					utf8Text += "¼"
					break
				case 189:
					utf8Text += "½"
					break
				case 190:
					utf8Text += "¾"
					break
				case 191:
					utf8Text += "¿"
					break
				case 192:
					utf8Text += "À"
					break
				case 193:
					utf8Text += "Á"
					break
				case 194:
					utf8Text += "Â"
					break
				case 195:
					utf8Text += "Ã"
					break
				case 196:
					utf8Text += "Ä"
					break
				case 197:
					utf8Text += "Å"
					break
				case 198:
					utf8Text += "Æ"
					break
				case 199:
					utf8Text += "Ç"
					break
				case 200:
					utf8Text += "È"
					break
				case 201:
					utf8Text += "É"
					break
				case 202:
					utf8Text += "Ê"
					break
				case 203:
					utf8Text += "Ë"
					break
				case 204:
					utf8Text += "Ì"
					break
				case 205:
					utf8Text += "Í"
					break
				case 206:
					utf8Text += "Î"
					break
				case 207:
					utf8Text += "Ï"
					break
				case 208:
					utf8Text += "Ð"
					break
				case 209:
					utf8Text += "Ñ"
					break
				case 210:
					utf8Text += "Ò"
					break
				case 211:
					utf8Text += "Ó"
					break
				case 212:
					utf8Text += "Ô"
					break
				case 213:
					utf8Text += "Õ"
					break
				case 214:
					utf8Text += "Ö"
					break
				case 215:
					utf8Text += "×"
					break
				case 216:
					utf8Text += "Ø"
					break
				case 217:
					utf8Text += "Ù"
					break
				case 218:
					utf8Text += "Ú"
					break
				case 219:
					utf8Text += "Û"
					break
				case 220:
					utf8Text += "Ü"
					break
				case 221:
					utf8Text += "Ý"
					break
				case 222:
					utf8Text += "Þ"
					break
				case 223:
					utf8Text += "ß"
					break
				case 224:
					utf8Text += "à"
					break
				case 225:
					utf8Text += "á"
					break
				case 226:
					utf8Text += "â"
					break
				case 227:
					utf8Text += "ã"
					break
				case 228:
					utf8Text += "ä"
					break
				case 229:
					utf8Text += "å"
					break
				case 230:
					utf8Text += "æ"
					break
				case 231:
					utf8Text += "ç"
					break
				case 232:
					utf8Text += "è"
					break
				case 233:
					utf8Text += "é"
					break
				case 234:
					utf8Text += "ê"
					break
				case 235:
					utf8Text += "ë"
					break
				case 236:
					utf8Text += "ì"
					break
				case 237:
					utf8Text += "í"
					break
				case 238:
					utf8Text += "î"
					break
				case 239:
					utf8Text += "ï"
					break
				case 240:
					utf8Text += "ð"
					break
				case 241:
					utf8Text += "ñ"
					break
				case 242:
					utf8Text += "ò"
					break
				case 243:
					utf8Text += "ó"
					break
				case 244:
					utf8Text += "ô"
					break
				case 245:
					utf8Text += "õ"
					break
				case 246:
					utf8Text += "ö"
					break
				case 247:
					utf8Text += "÷"
					break
				case 248:
					utf8Text += "ø"
					break
				case 249:
					utf8Text += "ù"
					break
				case 250:
					utf8Text += "ú"
					break
				case 251:
					utf8Text += "û"
					break
				case 252:
					utf8Text += "ü"
					break
				case 253:
					utf8Text += "ý"
					break
				case 254:
					utf8Text += "þ"
					break
				case 255:
					utf8Text += "ÿ"
					break
			endswitch
		endif
	endfor
	
	return utf8Text
End
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function/S ebas_util_macRomanToUTF8(macRomanString)
	//renamed from "ConvertMacRomanStringToUTF8" from "Convert MacRoman To UTF8.ipf" by Howard Rodstein (Wavemetrics, Inc.)

// ConvertMacRomanStringToUTF8(macRomanString)
// macRomanString is a string in the MacRoman text encoding.
// The function result is the corresponding string in the UTF-8 text encoding.
// This will be very slow for very large text waves.
// Do not use this in Igor7. Use the Igor7 ConvertTextEncoding function or SetWaveTextEncoding operation instead.
// Example:
//	Wave macRomanTextWave = <some text wave containing MacRoman text>
//	Duplicate/O macRomanTextWave, tempUTF88TextWave
//	tempUTF88TextWave = ConvertMacRomanStringToUTF8(macRomanTextWave)
//	// Do something with tempUTF88TextWave
//	KillWaves tempUTF88TextWave
	String macRomanString
	
	String utf8Text = ""
	
	Variable numMacRomanChars = strlen(macRomanString)
	Variable i
	for(i=0; i<numMacRomanChars; i+=1)
		String macRomanChar = macRomanString[i]
		Variable macRomanCode = char2num(macRomanChar) & 0xFF
		if (macRomanCode < 128)
			utf8Text += macRomanChar
		else
			switch(macRomanCode)
				case 128:
					utf8Text += "Ä"
					break
				case 129:
					utf8Text += "Å"
					break
				case 130:
					utf8Text += "Ç"
					break
				case 131:
					utf8Text += "É"
					break
				case 132:
					utf8Text += "Ñ"
					break
				case 133:
					utf8Text += "Ö"
					break
				case 134:
					utf8Text += "Ü"
					break
				case 135:
					utf8Text += "á"
					break
				case 136:
					utf8Text += "à"
					break
				case 137:
					utf8Text += "â"
					break
				case 138:
					utf8Text += "ä"
					break
				case 139:
					utf8Text += "ã"
					break
				case 140:
					utf8Text += "å"
					break
				case 141:
					utf8Text += "ç"
					break
				case 142:
					utf8Text += "é"
					break
				case 143:
					utf8Text += "è"
					break
				case 144:
					utf8Text += "ê"
					break
				case 145:
					utf8Text += "ë"
					break
				case 146:
					utf8Text += "í"
					break
				case 147:
					utf8Text += "ì"
					break
				case 148:
					utf8Text += "î"
					break
				case 149:
					utf8Text += "ï"
					break
				case 150:
					utf8Text += "ñ"
					break
				case 151:
					utf8Text += "ó"
					break
				case 152:
					utf8Text += "ò"
					break
				case 153:
					utf8Text += "ô"
					break
				case 154:
					utf8Text += "ö"
					break
				case 155:
					utf8Text += "õ"
					break
				case 156:
					utf8Text += "ú"
					break
				case 157:
					utf8Text += "ù"
					break
				case 158:
					utf8Text += "û"
					break
				case 159:
					utf8Text += "ü"
					break
				case 160:
					utf8Text += "†"
					break
				case 161:
					utf8Text += "°"
					break
				case 162:
					utf8Text += "¢"
					break
				case 163:
					utf8Text += "£"
					break
				case 164:
					utf8Text += "§"
					break
				case 165:
					utf8Text += "•"
					break
				case 166:
					utf8Text += "¶"
					break
				case 167:
					utf8Text += "ß"
					break
				case 168:
					utf8Text += "®"
					break
				case 169:
					utf8Text += "©"
					break
				case 170:
					utf8Text += "™"
					break
				case 171:
					utf8Text += "´"
					break
				case 172:
					utf8Text += "¨"
					break
				case 173:
					utf8Text += "≠"
					break
				case 174:
					utf8Text += "Æ"
					break
				case 175:
					utf8Text += "Ø"
					break
				case 176:
					utf8Text += "∞"
					break
				case 177:
					utf8Text += "±"
					break
				case 178:
					utf8Text += "≤"
					break
				case 179:
					utf8Text += "≥"
					break
				case 180:
					utf8Text += "¥"
					break
				case 181:
					utf8Text += "µ"
					break
				case 182:
					utf8Text += "∂"
					break
				case 183:
					utf8Text += "∑"
					break
				case 184:
					utf8Text += "∏"
					break
				case 185:
					utf8Text += "π"
					break
				case 186:
					utf8Text += "∫"
					break
				case 187:
					utf8Text += "ª"
					break
				case 188:
					utf8Text += "º"
					break
				case 189:
					utf8Text += "Ω"
					break
				case 190:
					utf8Text += "æ"
					break
				case 191:
					utf8Text += "ø"
					break
				case 192:
					utf8Text += "¿"
					break
				case 193:
					utf8Text += "¡"
					break
				case 194:
					utf8Text += "¬"
					break
				case 195:
					utf8Text += "√"
					break
				case 196:
					utf8Text += "ƒ"
					break
				case 197:
					utf8Text += "≈"
					break
				case 198:
					utf8Text += "∆"
					break
				case 199:
					utf8Text += "«"
					break
				case 200:
					utf8Text += "»"
					break
				case 201:
					utf8Text += "…"
					break
				case 202:
					utf8Text += " "
					break
				case 203:
					utf8Text += "À"
					break
				case 204:
					utf8Text += "Ã"
					break
				case 205:
					utf8Text += "Õ"
					break
				case 206:
					utf8Text += "Œ"
					break
				case 207:
					utf8Text += "œ"
					break
				case 208:
					utf8Text += "–"
					break
				case 209:
					utf8Text += "—"
					break
				case 210:
					utf8Text += "“"
					break
				case 211:
					utf8Text += "”"
					break
				case 212:
					utf8Text += "‘"
					break
				case 213:
					utf8Text += "’"
					break
				case 214:
					utf8Text += "÷"
					break
				case 215:
					utf8Text += "◊"
					break
				case 216:
					utf8Text += "ÿ"
					break
				case 217:
					utf8Text += "Ÿ"
					break
				case 218:
					utf8Text += "⁄"
					break
				case 219:
					utf8Text += "€"
					break
				case 220:
					utf8Text += "‹"
					break
				case 221:
					utf8Text += "›"
					break
				case 222:
					utf8Text += "ﬁ"
					break
				case 223:
					utf8Text += "ﬂ"
					break
				case 224:
					utf8Text += "‡"
					break
				case 225:
					utf8Text += "·"
					break
				case 226:
					utf8Text += "‚"
					break
				case 227:
					utf8Text += "„"
					break
				case 228:
					utf8Text += "‰"
					break
				case 229:
					utf8Text += "Â"
					break
				case 230:
					utf8Text += "Ê"
					break
				case 231:
					utf8Text += "Á"
					break
				case 232:
					utf8Text += "Ë"
					break
				case 233:
					utf8Text += "È"
					break
				case 234:
					utf8Text += "Í"
					break
				case 235:
					utf8Text += "Î"
					break
				case 236:
					utf8Text += "Ï"
					break
				case 237:
					utf8Text += "Ì"
					break
				case 238:
					utf8Text += "Ó"
					break
				case 239:
					utf8Text += "Ô"
					break
				case 240:
					utf8Text += ""
					break
				case 241:
					utf8Text += "Ò"
					break
				case 242:
					utf8Text += "Ú"
					break
				case 243:
					utf8Text += "Û"
					break
				case 244:
					utf8Text += "Ù"
					break
				case 245:
					utf8Text += "ı"
					break
				case 246:
					utf8Text += "ˆ"
					break
				case 247:
					utf8Text += "˜"
					break
				case 248:
					utf8Text += "¯"
					break
				case 249:
					utf8Text += "˘"
					break
				case 250:
					utf8Text += "˙"
					break
				case 251:
					utf8Text += "˚"
					break
				case 252:
					utf8Text += "¸"
					break
				case 253:
					utf8Text += "˝"
					break
				case 254:
					utf8Text += "˛"
					break
				case 255:
					utf8Text += "ˇ"
					break
			endswitch
		endif
	endfor
	
	return utf8Text
End
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Logos
Picture ebas_jpg_PSI
	ASCII85Begin
	s4IA0!"_al8O`[\!<E3P!A"3Ns5=JU7<iNY!!#S^.KB_S!!!6(&ci(7!<<*"!<<*")?C!A!<<*"@K6
	B.)Z^*B!<<*"C&e56-ijDM!<<*"!W_ID0`_=U*WQ0?EW?(>1'%FV'EA+5O8o7\Bnlfk!<<*"U]:Apc
	2[hE^r@r+&17GX^r@r+&17GX6"FnCAKXf_Dffo=BQ%i46W5fa9jqOGDKKf<BE0eA0ebXB2**HH+>Gc
	81,M$K2?3gZ!MBMp!<<*"s8Tet!h]Yr!<<*"&-Mt5"/#bs!<<*"KE2&Qz"on`+!rr?%!!!3'!!!o<"
	TSQ'!!!u>!!!r="TSQ'!!"8F!!"DJ!rr?%!!!'#!!!$$"98H&!!"PN!!!'%"98H&!!!N>z!!#Oi!!!
	$"!!#Oi!!!$"!!*&Os53kg8k)BA!!*-$!([)\!!*&d!";/(Ddm9b6VRO]s6]js6"FnCAH67k!!!!"s
	4[O,!"9,=#RLbF#mh"P$OR7R'b:]]%i#op',;/o(_I/b$k*OQ&I]'V$k*OQ$k*OQ$k*OQ$k*OQ$k*O
	Q$k*OQ$ipeF$OmRT&.T0]'FkT_'GM#e%Ls0b$k*OQ$kX'[$k*OQ$kWmV$k*OQ$k*OQ$k*OQ$k*OQ$k
	*OQ$k*OQ$k30O!"fJ:492#V!?qLF&HMtG!WUsU"98f/_uW(&!!*6(!<E3%!<<*"z!rr?'"9eu7#RLh
	G!<<-(!<E3%!<E0#z!!*'$!sAc3#7(VC$P3:="9AT+"9J`3"pbA7$o7na!YGM;+VHL55uD&(,&r/h"
	r*2nYsKZ\'iMkW1Gj-(d6e-bP#Ll/nRHVt(8A*e-:F%sA4=A1F>ar`<T7T\Z\66FFlW'_-^:E\[$AS
	ZjRf:V`RX)C<b?N0QDV+1f&lZb7os>ILR4pJa4KMK&HDk6!<NB,!sAc3#6tG:2$![Y&Ha12&d1Kt@<
	!J)"YtXk'VVcu,Jd:*n1u>!iGsO56W4_0F#<D5"r<r=K*N_\_U:i9<217?79)6fA`E9eKYu8]j7>a)
	UkQ1@`73l?V7":mjn2YdG(u<[[`6n\p*Vdh=(c`4Q`%=5s4RG]!s&B'&H`UF561,#\Q3S2At`-Y4\W
	L(qA,I$c.SJdoPSiqG1CNXZh.;u!6)*blQ=l1YPh/ZSML,Yr9E-U2?;os_e&dQMJD$,\r*euE:DOtT
	AY2j@d^CnS(\a$)e27(nCIY*F`)'(5@;^=ehY5ngPLi2XLd+gA[Sr4XmTjKXg;rI`jks_gTd?E8pK6
	sGmq7^3r3[k(#:sO]oE9t#7l/%rbo>OPP1WJ>+Jl.q>R(&kV@H;8B\rL#:g:BnM0b6'NnXF`d2-3I[
	t?q>HsdGpqP4UBCr?peE^sW7hV?'lT:KgR+I(a-+h"IP++j1,%>nZhg4=%XSnFW=6g)dUMW.mUJZ$P
	b+oX8>3p17@s'^jgV6t6X3uGdkIplqBP70+8TmLP,a\[s<D3fRPLCs?rB?Z).<CK/Y)q3k\_g!?XH.
	S7C.`d.]n_/moc,c_18`Ls0J''Y_^ol7E;!X][I/I7^U)J*oTm8fc[*dVFl2uNrFC'?bKb!LWnQ65d
	,U:5ZF@>Ek>hJ8J&SS5Ng7t2nK!6O/i@m7Zdj4\=M\-bF)5]bT?uBFf3ZeuZq"PHQXej/l=b?)9:]Y
	dQE[[8]^N9%Zfp'=+7=U=Pk'<0n_8ilCSk&-15@d#c-GQ5c6e<t:1__F\$h_Grr<T.(]!OsE=_B)G(
	!-Lc"ig!K0Yrr#m.p!SX`JR-hN_mV5*aBG5e+^?_asYr?CRkl(&uboO?4-5beef[QR>pG1C-:hQ9HR
	oN$F(c[1.i9C.']PuEWUUfE>L'bK3/K#^_'Zh$CID3]Ui=H]7glP:;=Sb61k`mrUol^I@.kcX<?a*(
	1[D0[`+5Ju+L(]Kd"+7kB!ejr#4qIjj%4ZkDRjF`JAd?S=`[@d83kl/c3h<Fp1^Ji\^D07j%-_P&2;
	i-crNIF&>%EGKg1!Qd"(tR3g%qi/ZIAjV`oW3t1pXM^!(9rV7#+'2/rr?`/S'S]`=WaNEpFZ=f8o?6
	cds1_UogeBFhCl`o9p.G!\h1U[TB+noH6;h!h>5Y#qgS$bm[qrI7QiBEUeum/^D2H^gJc`_eG<AgC4
	0rCZXQOOls'oRrrC%$9778Q._Hr]+,,m;g9R]Vh#@A[hYGm]b]@eSp"O@Kg8Le6(&CQrXOYaFYkkVk
	p3'`&Q'B0fWk_E*AgUPW.sQ:#qNU#El2La[VR<[I9'A4lf@-k@`dSXt%^-_SL8L&*JRq]`^IcT.W5Z
	BsF/rl(LMriI%`\S7\(CM;o^&ljPi^E7=nShof4.2#rgeeq2!P?*FYI"WYmq6b+4MsF!u@2$]Cr:2Y
	Q6>Um*'2`VrlHh<HQjiQ*GK6MFHsS$u!3=D/Z]ail2eG[Q36Ta'3H=pr+>[idIEB?UhA_GH'lU=plG
	;QTl_EYNWaQI?lqOoUF9-cK!qpj^W^RUFN.u9=%r1?%[2nge8Y)m6A2U[Hg3FI8s;?=/62U(a"N%NX
	Yt]m&cT0A#&Y_[I:EArd32^5*sa&E=Na*2,n%QRVQSP%e$=+UZl\eVOFdSY)4(MWMuSVf"_Aker?b@
	)Es'_e<Kt5s3UF<Q8X6D>^TbH726eteoo^5_5n+g8Xn],F5-Nf=K;B$cKd^_)#jTFJ+X/5@*1oon)=
	EUk&CJm>Bi]P)G?V#!1h\jgbJg/DZ9_%'YigRTD&bDgV<T=+1l+_ho7/CefWcK!1PY"kB3AcO7eS"b
	BcBR0>"(=o^S8S(iu(b?Me"uX_F`>a)%g?Hb]2kX)n:@)]u$9q,ZDMG5hR@/?*_ro:Q"9no$D^8+oY
	eBQik6qnABIIe)h\Y;l<dA.%4>V2hcY:u,XTK'uI3qfc6=gKKJ"`/o'aQ80'S6XoYZpt5O7rrC3Mrr
	Cf_rrD:o^[\T*NW0!DD>sUFDuTgcb!5Lg_uB_<hd$0]fKoN;V3\k`lV?a<>@Y6nB28)h)m_T/8^<I1
	F\UZibX!m"p"SbU62J4dG9a84)Q`2:9*NkWS;Jr+3\7P'[asnFa86l_meT0@)qNh0ikObW.Ut$F2qZ
	]3qlIBbmrWoYZXp4Mq]5*J`b\<GB`A(l'<2!3ej&lg*HaXo4NIFZ5>f2dXhXSsrrDmu0DoX8UOVB0J
	*l"j!;*S'eUFp@VWV*:3\OIW'o&?f@Uk<FG2^'dB;j^]oH(#^cb"]&gZs@d#X@se8mhSu)]u$9q,ZD
	MG5hR@/?h/Oe@pjj3qleAh+Q>E_!&4.:JJg:lS_Yag2_"HHRrsIG..DN+cC^HIG+W#cJMn,!8'U;!2
	Z!*pp]OSokpi'PGh\]fq3FV1I7SUg<1u<m+ib[B$\p*!5bP09E+u2+/n)m<o<dtrrE!KW&(2VrDrd\
	d4r3O?]0clX37\.(OP%<N\t;jMjiCjpGW!=ftVb&J+8kOS\jE9\7HXUXrgYa6Tme=l6g-0RA..g.!L
	Ok&jRD,&4cebYSLQe--h"clTaeSrrBNXoa5't]$L8.5OIA,6DaRf?etWh`V6Gu^&J'j?btsS>j)%QZ
	i8pEqfi&?:od\?=`O#8D&:]AhdP8D[g+Usr>'=+3NmYhDINhT:b9Y*&6(Z[7*q8!&eG#ie)Z[;3hM7
	#+$U8%$f=tO/RWSjm3C9Wc`t`EdG;:reuJSSIf"T`[76n1TXa/O6-t@#.!i:MqgS%$X&nc!mg.<0Np
	49XJ)^&Mrr>berrCB]GO'eUVVppHGt"M@q^Itppu&bjWGRmlbe'lubA3imZ/Q'"CE2KKh7:8O/DT..
	9?ku&r7!iu8M;[[rE&;s?Ve\bJ(@7CG"#-0fCj$%[%GUuG,,#BlVIN\4SF9k/i%D-ZB8TXpk>W7_?g
	ENBsaIar+Q*1iY/<k!7jC.iuN88aSrI!e84@E(A49(G>uQ%BR%B&Y8r\.\[>B%^DHO.<F(Z&^7Xs4=
	4=m_rH#uoa2`DTQe(HfCJ+j`<ed"@D7AAMCRWSBgFQ$i3C&-=7-_mT,]WroC^hu_P$GKog\U%3!7,5
	KqZW"N^K3V/LB;q4fK^RAp+1V[l4XuI6KLD2J3LAhCOcZU(u/iM/#upYeSk@crG2E5_\h;,jX!&fiP
	*&+!90L5cbl]2kF.`X\8SRh&$3NH8MDBfC4G5X:W<7m5J8/`AoHhprRl\JCF#V=ebeb2_Hs?O^>HRT
	3\F-em*agD3?!s7;"\T%pANrR^r*cJp/OIQQs;dI5kZq=mrP,nGA[0kTQCrk!@(JBe<g3`oi0[Mi"M
	oLQJ13rQIbg6kp30dc0?-O)uO0(Su6@CnT29DV]-u?AOai12HrhWFB6GjZb,,p!!iLd[<Jg&EVce=7
	F#l;\@4HF@p)eJ=)Et=RTRR2<DR\,\^(3TafUT,q\SU3p>=Q;`OJ^u4[2S`k'or#*rc5r=]do`hYja
	Pg&D&Wrn4f-*f&F^?2jnokk\Y^hu,s-gA7M$IP96#Q&h,3Wqu7#(09r8C"a';[GL%/^RiEJ"2R#i.H
	\Cb2BGV3e?5]=.h/rRY/&'J>?/(<Ck#KcSuq%$FS_o!O'V,;piX$rLB^t2FhCN4fi=)MQ,!1=BldEA
	ptU:lcaA5@qaTW3HG=%K^4$!Xrr@NHhn5,ArrDZ"lEC1li.()f5Pe51q:kRDrr=Zj5P?Frr@#!:p"0
	3Dk)96>AJ5"Cf3eOXRP4W(8PYoUmJ<m`!1,Yeq\)d)P[(-:DloX5a4>112r0kF=u5NFloVLDVRrn.Y
	/RilD7=:$qIY5\l$Y^UrH8,?q4dlhfgVae^ZLm8nUG<QcheE*V=pNOdYK!mI;dO5!&sn8o+Ft$!;!\
	bYPqebJ*]loqGCY_FZ^/Cp%RbHkr5q/SMIk4ZYcDQb3NX32]dt10Uge[g,A;5Q,!9?rrDkhrrC_@Z-
	e'`rrA_l!8'MGq`aJsI>?;)^-=jKhTbpq;k^V5!A1GC$.;C<D/Xr"P"@,&g&L%55Y4=1?VjWr7S-9B
	!!**#!!4i?6pa<D&-)]IDKKns7m\>#=]upQcN".L!rr<$!!!"-@rlTT:f'gc!!!":Df0+dzzz!!!$"
	!;=tD!<<*"!7NMc6pa<Bzzzzzzzzzzz!!!@9E,p%#!!)os!!"cbATM>]!!+bR!!$eYFDu=%!!/Si!!
	!^BCN+@q!!0;(!!!^R<)Q'`!!1"<!!!LA<)Q'`!!1RL!!!L<<)Q'`!!2-\!!!LL=BSf-!!2]l!!!^G
	=BSf-!!3E+!!!^B=BSf-!!4,?!!!^TAU&:s!!!!dDfBuBBkM+$+>Gl:3?UUuDdm9#;gEG+ASlK28T&
	$VEc>r;@<?'k!!!"0ATM>]z!!!TsA8bpg+At]r+=Js)3B/Gfzzzzzzzzzzzzzzzzzzz!!!"$=]upJz
	!:s%f!<<*"!>`m]=]upJzzz!!!"/F`MX*z!!!$$1B7DbF`MX*z!!!$$1B7DbF`MX*z!!!$$1B7DW=]
	upJz!1Xl+!)KEk!!N4%=]upJz!&TZ8!2(kC!"Y>s=]upJz!%'E#!"^d`!5>!'gAjS@!<E3%!<E3%!<
	E3%!<E3%!<E3%!<E3%!<E3%!<E3%!<E3%!<E3%!<E3%!<E3%!<E3%!<E3%!<E3%!<E3%s4[N@!<E3%
	!<E3%!<E3%!<E3%!<E3%!<E3%!<E3%!<E3%!<E3%!<E3%!<E3%!<E3%!<E3%!<E3%!<E3%!<E3%!WT
	q8&I8Dj":tY9+ohZV!<Wo7s24mZ!!!$'!<E3%!<E0#z!!!$$!sAc3#7(VC$ie-F[1E<>!<WE*"9Sf2
	"9\])!IXtM!rrH9"VMt55mA!"@0[ur'Jb6%Ta2l0Z,%/QdI8D;@WI&,$5OEp)&aeJ-R^Dn1c70M3&s
	#e6q'R884cEP<)lt#=BSg;A7]@cBPD4&FEMbNG^4UfKS>/9Ll%"PPE_>uQ^F20U8+N\VPgAlWj8t<[
	C3QS\[oYq`5Ta:aN;TQe'uq!f@\d1iSrnYjlYail0@g0oCV_Lp\=R\s24mZ!<<3&!<E3%!<E3%z!!!
	$$!sAc3#7(VC$ie-F[1NB?!<NB,!sAi4"9\]*!d=VF!Ws#;"X,T)&j]A"@;ur)14]]F6BRtH_$M>B;
	XbE1EmY40,W+I+nJ<#[)C?g[.4R252`NfY6UX@47n?3D;cHat='/U/@q9._B4u!oF*)PJGBeCZJqJ`
	1L51SAMNX0fQ'Rc(R@9kFUnsrdW2Zf&Za@-K\%&u[_Sa=2`lH0Bb0nbge^i@)g"PHGjQ5OekiqC'oC
	V_Lp\=R\s4RG]!s&B'&H`UF561]^.&)S!.&)S!r+uB5K7NlBj'RPUn4;Hjf>bQ8]OTs)!;Ol/rr@`^
	rK#t,"aGf'n?7\UTC!`SCZ*3rW./FFg(i_(WF>N!.fT<>]_a;95AJ[90.c8CD0%OPrbVQRrNH5$Dsn
	P/<dl%XO6oC5@/-e@3fi!EZh,=LHu/T,Y3T0h!+`I.rp/os?CBegX6ZNr@r$44ETGlq@C<S5k'`?.m
	_@uErr<9DJ'&YDCk&YToD\fm=7A,_LnFH$)u`blq],Q!BKuH,:Q@<[8Yl_T?JNm,!!,r?rjDph:C$n
	"_+6fKUd#!0=Z,>oqdk6,rYP)OQ$F?qSr;SmMuNbhFaG?Y@+'=D^*E,SN4"XD6I_IOVO:K.?I:CV+$
	+*5Pk1MspGMsN":>).K&$.!rX'qVMZ3Zh5MB[24(\:bHopi?GfN2AL4NiMiU&;Y5CkC=XRrW9;ObRi
	W>:boGjiNgL&RK[Y#tIJ4$=ZidWL,@kaijCmBdmB&eFatkOp%n=n.:@&+P_JAS^7!+&D\!q_`+P$e9
	)VCLLpkA$:-PiQmAYB:sJc`4cW2n%jYRB1gUei?ko$Nf:Q5>hs*1=q0SZJG.miOQtDCQgppP!!GO]M
	lh@^rr@YRrkr"6LFe9G\abj'iRRj>j^PaIIO]$ba2<mK.F<[17in5\Mi4OoO]uD9]JC[%Tn[)p7\gt
	rQ)jlJIOV;urj($N7<8H1q;)&N_91ZEO2oKmrX)l2r$;%jn`Soh_X@p2&bnBUa2+5$M=AFBLQ)-IV.
	s<knKk?9nP<'6oij'XCO0j"f!]ZrL`RM_At!:o88Ro[3.=@hKDtqG-%D"hmB,DU&UrHkn5)@($fZA`
	>!6R^?h#rGNqf*:4I66$Hm\VUUNkD1G##LHgar#0rr<=R+0.ommC0Zi`=a9!><7$K;-/ruBU<#-g:-
	>PpYl,P#1WY$hCec'J)Hc!1k-*bET0cM*tWl0r+#Mkn@QVF-1S.QW-FZJg7>A%esZ%q5e>LRX_..u=
	k)i@oT+g4k^$OroutT"Y(ut@D'tOCq(VgK5]uuXJ&.`V!#l*>NdklkfuimP\_$a.nDE8=L9+(M'%hG
	%=4R3Xj*S;0_+$A]`r?#L@%'g;["$d!+VSe<5MZc;7;9khhsX-e;+23"Ijb6rn9*p6?]4pa#6+[9ce
	1BZpd=RQi^^kf93M&3j'*O6;#"thY7p[Lqc0o1n4Zmp=mB(;(tCIRn#^#gq=*.p8Mi0JqoI/)q3CKb
	r#1@f6%""RannC'eiIH_mu?3@IOaTn2o364?YK:c`/fa=1@`VLPC7H2Bs$R2dqq3CX_Nr"h9>rjAY.
	I4As+6uhe1"oK)Yh'_#FDqg]%7`chf<N49#<1%LVu`rXA](!0`WFYs7T2GSC)W;n8rNQa(G^hgbNK!
	WBf_d<F3r?gR[[gJcQS0!t"=:A?d<55S.*/8cfA^9PDZn4pN6BmF?8DXgM<F_a*Zc#7S1Oj+<^Uli`
	YMUh]&?aHZtZ28+tT<o]USMO4CXoAB8]h;)LIPQ:)Z.(W-muLfj0'mMXDZ"@FgYLQ>>$Q<P81q#^TT
	Vi`/`r'aAqf%]*?ESCe^*rXrrA7#rLj/jm"g$jrrCOZ?a'"frL#n2jF:h2q^p\3rrD^TnGQ>iR[)K$
	5M?0r.'?qbrr=d'pb"euC&:m-55tV7X8^b#%e("r1&F62,JlJ`N;OOtMrA"KHtN/3iNE`)f(8efn-.
	nBl$=D/i_(jZ:Prr2Ru=8@[C(^!]""2A!bn4drr>fOrr=Ktpb0,SV=4-0rrB=a^q]`EIN@"hIOG+2q
	4Kt!,Q7sgj"D5H62pq:;uXh/1%F^ir(5pu([JdDnXTI-MS*<!C47K!*jIgL(&WJm"T#"+XPI5uHA&N
	UgKWCL-.UMi*NTghKL6/]^T81Fp\t3r#lamh62nhFp*9@mrr?+2`*3+mXJNQ%J!^BR;+LbG.%gX!.%
	h*j?hc4.r"Vk"rr@XXIa*1V^YrH_9(=S%'Ch[k>O\9#h[F9DjO*<AdB%13nR'5,&mE<&af'H.^e(Tj
	.b[!D&DV&m+Ro\l[&/1e14<5%e%a,Uj0.i5qb;OkSiW(S?QT2#Hqa=ij#qTd7^7`eqX18`>J[7Eb4+
	-L^(Tq+ZR1=`lVfCjQF^CTiB7uMdqsQ\p=aqJ.6!T#^-D+1(W>-6`S^/_*sR*WQK%.N+,'XoZZgr,m
	6=?bU="+U(jMOi^+IqoMe2LV-@JB[^@:!GFX&KPp$hpe5A'l?g2;CCJ)Jf5fSAEsL[>!"rrCfC`P*&
	6r'U",`P3'K7I\LZQG'?Q>3]&]#J_Ajd^2<C?MIpNAND0QisuggqSo#-C'tGrTCs(UoW(&(aD<_n@L
	N1&g7:)_?+YFKZG*o"<Wi-.n3=iug@+_fnTKcKT*"eWj3R)@ioqgO[ZPcD5E3ApghQih@<c7PjjWX!
	9==:2S-q]"WEES2l5FNi]Ur]K[[Po_L&V/*f>=Si-\a`ESg)s;5e7Ge]'3h9Fume1p>]*,en(s(^=j
	qCeu[HhH&),u.tdWOn/pT7m3D,p>PM.ej5HV_^+9+DnH9IlWH_diROt\I@HK[-_&f;J8MY_#7Fs)VB
	dD."r>+\9>g_uJ?KkPbGA/&=lZJHTcYY5`n)o%CGlU]1'pp'iIbXl&[Pu'qfJE58pl5/Er*d.$r&<P
	L#bo`E3FP#]li'$:SujBm]IVoY%A`f&2/a%@CluhYdE-=%BeX;9,1Ml7I32:W+7fX6]>*:-T=5?urS
	p%Z<VW9XGJr>IpgnY3d<L#r0>gM6>O\Q-Nt:IRCH\5kTqU`Fco6tBR$=p^pnu.&CKeZ?9m$ntkup=)
	[!P$mDtlDLp9)sD;=XYdi&C"@U2&/\K74O0&O&&Hhb8W&90<.RM*DP(oo0?s1$WrMK?_+!O+?k<Mp3
	U.2L+8ipm%ksbhL]%&cVi`B><AjIh+b[Di0#Urr?ePg*=HQB9%EHHiV\Rh[9-?^g84jO&5>\`".g<V
	3H;]YMr8?@3qeWiSTDS*1K[QYIlfm6In3K[GpW^c$B$-01sc:S,S3l_@CTfH8XpQQ+YjuJc+DMA&<^
	8HmPZCHsuMWL;#25B1UFBmJ;=O0+;ON0@BFZ-:jXqp<,*.kuQBdeh8#Fjo(no;AP9gPCEB.!*AXa,^
	71F*dh/k!.o!8`ubo--[<8A*^0&fMS9P`fD[/fO,C=qSS,m4+k.aOe?$ElFhM8Wjh0,$.;eH\>HL6_
	Bs008;a&Y%>Y+HNk\O980NcAl_.RNnRglB"`M^[n%!F@-`sB/7c9"H\!a;B#@9[l56EmYZ&1>Y(IM_
	LOKtIqhl/!0E?\Z3Xi=??2.5Y40LHI5bl/!N/FNElfB"X]u5=a.=XYfo#T'kb#l;b=&NF]SkBqKLR4
	1940cBad&I;bnF\+SA`Jr1tX_#FBU^PLdUp[+emnI*C'f&*n(m6PT+D<!hp>MIoKnb_=Y&4$F[h=P\
	S$rQf),DIVA<K9&571lPee)WW@Y6Vt5mOl3pp^ZTSBl5P@4;m+7mOflLk+6k\d4AgsH)?\1P05D8dR
	b^CcQf]=40tRLJ,#`;!$s#P+8q6A/H5_!p$I78kJJD;-Jo>`lppQ;rg7g(kcU*0ZF@gQ!4IIVE;opS
	fj>g"3d_e>L&2QgHlr.2nRLNH[_LbHNYC`err<LW,5B'kY\R2%qVT1]lmL>Xn@l0(a/I0m*So4gEaC
	<cDRVP2(<)]Zq_.jcD=Osm0?/Ks^UD,-`Xe!"'>?!Ppj^;5"<c'o4sbIJ`EkTt7>"Fa4se=#%[A])2
	-j*S2ETSD/S)MSc(S@=[C1AT]IC2J+8@rsr^p8Y,Q@aQ2ojhS55["9DuTfi3ksaFIbk#(p,m^*rrCL
	Y`@;d4`qEK>f&,=LIqTNn7<=%U5Q:]ea75LSrZ?X+.K9Ba58a/'`I9*%7uR!m#'_nO(WB\lf/5c%G`
	P@dIu=4+Z^uRu>g]^UFZhokXR9sXAs1a1(6[6oTlOS16uVZCe,KDb?e_>V]Rru-^M?X!b>ZnC=k;<E
	:\aPOK(AKkPo<+o/ZlZc,gs!=)bB97D72<GcGV".!2[1&(Z53h#Q&<:!8*@jJ,NV:%]f@Drr@WRrrC
	2Jrr?Mhq]7kBrrB'Si[&]oZ@ndWDt$>Lo#LYba8?X$rf.N_hu<\oXmtHO!11+l["#omIh;TDHp[T1q
	c2L#Idtb(*uo&7GK(^/>BkV_it%!ZC#Wu)a%Vu=F3AWAUX.sngY8c5)(p]6E<V7jDV"u;VY^:kkcEl
	IRP$_%?J=:P>Kb4(hLH;;7:ZZ!^43u<?aVQS2t4`a$Es!3_;>\dB[;_=!"V1:Vt`(+V"PiEn2J>TL`
	R2uh3GtZ!5ad(hHrukU$*O@e+CgtDf6tklLJ%o@r%R5SnX.I42$)!&)+)`$6n=>D]^Y"+o>t<JPu+:
	3W*VU0RRk(&ktd>[c59=7Qa-<Njjae=FSEESp-^gRlAD(^I\A)i9"DB9@q5!q[pOFJ*N]rNIP$%n8)
	-`UNi"%#o030Hc0)_RBPfmho5TqN`oJkU$G_p\u(Ujl$A)\@r&#W\uqNN'_Y^aL$c7Q>M[ug6T)9i'
	"g#qUUjN62^LH+alsm!mH+:[#P+)U!.Vi'+1I<tQglH@$1Y@]^Q/<oC9N.Dhcj7Yn%_.&[Dq`tNo8;
	qO@O;mGR*58M&tj!efH0d+_I3>dWNkI?[,4G<IHf(Yd9d6/UL"f!)((]IhB=4nV?)LJGq*I44^(p++
	SeeGX')p4n)dmCm.9tZf,g<kk9>jKrIQO`,T&:rNAo0[[F8cTn_jch4V<5)5D:\nl>\iK!0XJ^)6g2
	J)I&N[=@QC!8rb?dQA-"^PS#Np`i7J0&6oO^CYJr'B3)I1`L%t<dAM'4Ti\BIZp\b9[c^U@:sFu29j
	=Vgs,hK^[Q*L`-k;<(]4n%p3X0sDJjB2IN3Tfioe45]=TWBaen;E'7<BRBK"$Y9.'OQ,=(c7RA&=$=
	B6A(2B-'<q'Kg^Wtieq`EMM5VN!*?Vr3XY]<kF(?jH4#rr<:8I!bYQn71GolqqWhJ)a&<O+eA'rr@[
	83)?^3r&+8-isu4-X\Yk\IgmX,T2pleqSnjCUFh^SG>[&8GdG)pgtX/Z(2"0USS0+Q5Pu3k`HkjuY'
	==INr??_8YYut39BZGZ(QJOpuSSkRKQP7Z9otHW+k*3\[Bk\Pp!T"2SPX9A<%Ou15PW%2LiR&TCPmp
	@3>@Y^-;Psl1a.RH[kr2ec,Upg\1+9!3tSB-iTK^.9BD^'U5\iP53s-YP"h9c*-K?rr<56rr@Y:rlT
	[@dC$_!rmX.F^+";-`r6@*>N(X`NtcAZ(OQn"C!+BMBYf(-J#Vc5(:Uj0dP]X-p!4%]&`#\*Ia\,];
	K)3CrIKH808Ep(:_25diK*@jnCl^jHOh&th:[%F_=q$YC-%u;I!MC@5*t9t#&8@%_.[^.9%;g6oY!^
	e.g)r!G4S/m$s".p]#D$*r"":ncp+gc_r'.^rX'+/ptObGL,@cnG\?`3pe.I];=OjIU1r!==q!V/FT
	2=Rpl!!q1qh>Eq^<T9m=2UH[%@d%Rp'#r=g'q^Y%r?ciX*"W3cEZ#pbUCY<iN-I(&bR)&C5\c\j(`E
	."!97Ml1:W*8B0(r)N6iN-mXcgq^mdH'cnU+4=Yj2-"3'0g#C8X@eqDN1nO^Sr`?GfCT1B,bg/HS.F
	derXO5KTCFGj0DlK17.F'iYD?LGpgrH/rM@4FBi92>iV/7QmfmRRV;:oJi`+NUC[1m=e25uIX=gBW[
	$p"!Y("\R[eA-3DXbYEr;C`0gFr9kfC"WYL&4o"f/hIGM<?dC:WG\YR[)6O15dEthTNkO9!KV_)RR+
	KX2pj'^V(`a3qN>JJ"V;EdsNPC!7XBqQ%(ien7jWSV$C?,!4,f&XoAC#GJ_MdVUD@k=Z\S-p3Z'0j6
	un&a8?X$rf.N_hu<\oXmtHO!11+mKjX=e+,iB8Gj#&4S)JdBj'R[-,C%,H143O*[;0c`r)2,D9B$Ht
	8Z(6Wp'[d&9rRimk3lDf(aEWs-tJh6nOCeH6qiL:jeAJl3L.-QoD?28V/F'_;+5"#q/_&%@t/:/g;C
	_`n5IZf6c*.:rMP-YIg>aI628L"f][c%n?9j8M*<$Np5NOM:6+ROV.dG9M6/W%3n7NsA[f"RL)"<Df
	nZb^00a4?paFaKZqUqK3f!)OqeTpe)qF&1Igl+hoA^q5>q8=mkD?k(B$e1V2i-Cr]p:R;b`5C]njZZ
	=3do0F5PQhFr2"K.kPkOfj/W+Zl'FiBoFh0(Jl$hDpiZ,MrWp.5,lAt`[G^uoa1i+sHi#k?iSPCF;o
	CRk?g2mFQ[c#NEQF;5+>%MSDT-M#rC5>2e25E:)f85B]!fA^\%,83,mZg-VV6pl[?H*'e,4aq7R,gr
	hsbX+m90<Nr*Aef_ggDsicg2CBKt1J`EMDpiVrljpnQg_rrCg2'n-ldWQu$*pub?@mE#;-KTF)u2N8
	s!W-FfLr[tkR"P5[t[H-0`\^IleGkE`^DRI'a^:(MaZFGMScL(t@XY0!PNoJdXg>XuU$]B;iB8U@LM
	:P40NLDjPA9<#skPSe=Bs333n.55TrLj,na)aE/HkuM7nR(61?<oZK>hu<qT,qeI&6kWl/V(<nH,bj
	+9dRB<>"3^kjOoUeD>sTf8pinT4t(os1Oiij)0ga9DKVG@fu)dOMl9rX+I_<hIg9Y+pcJ@Bk&%,/\^
	XPD>O.&\ZV>E9hFB3e'r)Me.&<'oU4#tE+/1Sh7:6-b'Mng!'Mo&)\c2X7Cj^=!g$i8H!5Uo"!9$]N
	@JHbiTDfI1phJ.M8AF+eHpR:@JNpXD!3s;tS%l6n[_Lc:ehjSt?gOu`>u9e#DY*kFrM+l9D^Xq=--u
	?CTAuQ`c]&2/$3C/,$]F$U`BT8&n;Vq8.K9Cb49#9g0B*M#I!>O?rNlM(%3thTrJU[U#u7b*rr?V[C
	B"9FBkL?@&!?SSm->1hq;5\j.HR2kGopDg-SPGSkPg240%'\!#&\S`!.p2[h4aiKk[1_4FBeJUleen
	c#PROR'N[79RQp:Dh\Gpa^u+WT5MJQE^'aB_^Yo+l'kff9[6*ad`829\2'3A(LIT!P>=_/pdWMZ=k0
	m5WY14QCDCk4LQn(3&q9=DYcg5`Q!!PUcX8W;%eR,ZO`NL>3dsn_8NI1idDi6deeik4$:W<>6)*TBl
	T>TM.n-RZ_XSd"6?g)g&M!s\KNR*;r[:Q]A7?-<]l2o]0/Z*bj(]OJ)O8(<1r1],Cjo5=d,H?7XlUA
	#J@S!><Q(s>p?pQ?fMTh1#AW@?JUaZnLSnMQfgK2U^2#H^+dmYVj-e;"@#S6XdZb3ZpD(Tl>53gku_
	YVsob8]b-ijuM0[(;*,[^rlWJY!g=CPZ:WTpci;.AC@92fs"Sr5aBG\GlQ:VsRFPqu-r+qdK7]^d#3
	Hm/u:-#j?^nn73FjKmY'6S)Q)U]K)`kcg[^F(R)b5k^"n=/@<Yc.Bb@A/uFZ[eeOA5ib=nhVK\7$IK
	';!)ue;\qc*Rq_(^@McPu-cc$eU/!r+U"&+Rh;E48od`*W`r4pn^2e>?J,l5h/=VOQP:(0i\kc@>U[
	&a%sqZa]E-rr<5rrrA:srn@APp,mR9rr?%0_n(^TdunK[]AM._"8gXK!/#b`FlQhc?gpVDfdk(W&U\
	*JY9/#8>5nSVoDPrRmi(tV<q07J[;YF#g2#_4PGeE\BkuGijo26/p'iLga%`o;<SZJCe*QGfiRr'b$
	u,Sd?\k?DDEn&mS+\i<rm9R!eUJR>p?o8Z`@paGc%&mdX8`/)%Y)<1r-A/PSK%8grKO_%*>A.#n]->
	lnP@*,M5tQ3WbNU\]F1jTh6)I-pf?,1B@EtH,^@!Rme$b6F\@(\]HcB"Z0Jo<S,KhUIh-dZ_r'!EJ!
	&Xd(+\BF[IIW'$Bb40Gai!L\[oE$5A<?=?O\Snl.t2:)rTkf2o88jg-,&_D76n#4;4X1C5XRA_Psg[
	A,_Gkd>F0r=%QcApKRV>Hs*XtO5kHO*TPh\?P;[s'YZX+:=n3FkJ,Sdr)`DAa#_%q8TSr':O+S#Y26
	61k"R5J,/Usa#b?HLrrCu6IhmNKItI\#n5E]I8)RsN`4q:=#lH:7IuAUWM=DPD4mo</I1O6P,k0X7X
	kp1&Uj/*^m^QcT-Atp5[9-kP\C&o)Z&[lA6V>#"\Obj)gLpEq/+t+\:&?@=!5Uf^!.7*%mtETJpfma
	u[(!ou#CLC`U%'#f/`uRe^M33g9==;nK7#?NW(bf$?5W1(Kf+8h:U9K_XO([rg<f+gp!&q@>.17hri
	l1t!8ofPT8J(Ipikc5LgLSg*TFgRHmJ5.YDYR]psW6jX^B'("kTjaQ+QP3M.0#`XY(!HP";uD2W"7O
	]j_4nD-G*Uf_KZ1XKLU,GjYG[D;/Fg60iVi7<=%XHiF)^fDbga5A;3p?gtlRnB[^<IQ.$8qd]UDQi7
	WdpeuVln`PWk[=>O_!9'IJ!3e]H,9@0+YntEtmFp1c5PCe7m%X)Oq]<RnH,'.7ec,Vb?hc$.L[C9!?
	i?l%!,S29c<8`L42#"]5K;M;g.Rcm=]4'g^%!@&4RWt?9!G@AN>rTqcRg3QfTO"8DtlD`r_^Au9E*7
	eiOAfbJ(df0V)qj#WSR%7^Ma$YIgk%$m?@EnG_5&DF:[*+p:Jp0,(Znm[*h,uHtCg1;V<=Q-b+CP]M
	UMb!_Y@)[*66faYYHZ]:c@`O8(Z/j)==Yj'VR2B>IpcHt<#cqbR!r^c-]Pps1RlU&7USrrC#THbpR8
	2STUs;fS[+J#<"=<k?[jT%d)%hJ3n:KqsIk3+fVP1*b<+n7]l?Uk@]?rL"27J,N_=ZZUblV,^[PnE!
	iUrHta/hspcAMCY&)i>;J'Y5P'o!,)mq^U>NVl_/\Oq!%=,iF\"JIa'T^\t4uPj5P!:Hk3(=3hq("n
	bnm*YI+<0%-r4FV<.N[[^W[AA]-?/I@f:4GPNs;-g>RI)PchHilB%lf^JNjf01g7:\]_8:Kl43Bkar
	V1KaF5j'NFDj&FL7Z1,B@(P>Gee3$I)lBc[[+)8?r]DEV]dG+VoibA>*2J773DuTfi]t`Y%5A#uR22
	FKiD>Zi+eDL$X0E+Y?p6kp\Z_j5l!*(DaMWni%)qeQFf<<,Crj4)JMWP$=P^d@rg->QD+_C3@j-?3q
	n`TVm[*e8)0`4VQd]IW;ME`('dquJEHtf`P@rJ9]CT\tb2DEj\1"sN_X)B#iU-P2+=3c,ImAp,+BfD
	7?g99mXqcRX%KsN8afP2KLIP=p]>I,NpX$*l:MPHUeB]N;.A;te&aSFKHO7kW<nsB@VK):&??N1"BJ
	,:9L$i^4,LZ.'3;lS(0b*A7\l"/Ot8Tk3sbs1p$rr@Y,lIKoh3`k\jqe58@IEJm#?YTN?(d9q9g"\'
	h7a2Ce[tpi7A6Dd)G)f$B,.rDR/,]pli7pO6Hs6'dr"D$+qY/"E'RWC?LQ5p?_sqKmj&u/RXn\7$*\
	<LL[aj^\::?WhnR]u%YgtKtbdL?i2qd2MS3Vmu($n0S5`b_/+7)l)!+J0Q5P9!n7Bb?9b,%NPj3!XY
	p[+kiciT(QXFU<N)h7X#J(n?0Nt:r]rrBuhpp^8'c%UYQ7=U-,J%%jg=8O*5p\rkOn0S)7#>kEJ+1+
	8KrrDgB2o4qkHmJL[nY>&]LG-DPDhm'6mt^l_HrBLTJoj*!DWg%um1!KFXBfO():ruR$]S3H_bANqB
	@J9;CWW[Mq\s19TsKJ1rK7*[K3,c;Hr9[Trr<2tpr262MdI*EIITtKG!EE2`#T3.`#fS=A)]-\lZS^
	C\%s`Nk5O+)[FKY!W9SU#g0MDkVl=#jVaYR5E8G=gpF-GBG;I"l5PuPJrr=Jjpa?(AAjc(Jrr?-Hm3
	>uIJ+.-tr1eW!DuH:-!5tN.;#^O%>nTf_`S4ZUq18K<d7"eq#Per/7/`q]!8sU`HpR;H2I@PUD0TmU
	nW/O$[#3JpVoLdaU:-+d^.9KXN\,?@O<d+m'o>sKNDjK21L<FsqeU`:g1B(5)NX9&qcIS,euiJmZG-
	,,nUApSg0LA=kI.#%EQnoB(&;C">irfRo"W:nrX3ZE!%D1O\c2Zr\E^j*A^P:nSPF@[.TTWcV3c,ca
	:AN\rMdQiU7.XK(]&(;)uF@7(,nc1[_8s@^%'81dcN."#p?d2`%j\:A;9oTOcXuAr>>P7i80M0r)3'
	gr"@K:VhdMlGa$2)/b/McN.*S%Wb\4?23/>bhCc@I[J6f^RscnP6W3GSc.99Z(>=.ZnCXSUboAW]_[
	X&q;%S(Ur"1IY;+:?kJ(YF^rrD]aX]Oe!ANH@'a-A/<rA<p?.k[9A72/cf'N%:!'N%:!'N%:!INj9X
	`ujl,DqcB"q`OlYlW*ilYMpr/%EADJPg'-I5>TuDrr?2#j,JP+hsbX+r1TVRa85e]5Pio[")Ihf^LP
	UD]AeV45PmqJ48l+,%,:P\lf)!`&,8f4i>R?g\kV=tiKsQEK[[`N-MVkfIqe.j)Q&F:FgjX+DQ),m:
	8Mael3h6Frd$p)ZZK)>dumqLAZqP`q#UJXhsbW(`'4_+#Q>#Cqb^P_f<JOer'G=Uh[_gq@e)'klTQW
	F^+/n:=DKE]^oW^OphrFf(Pj[gqou&&GIp%eRJm7Pi/CtZeN@.;!!Q:!K_2An5;qrYp4MjYM<.Qmf[
	@DDf3U5`jP(TZ%jsfm2$pa/o$g1Ch%P.e&c6^#_+t"1Cle?>^9ceArrCbkiadB/J`+S[S&)iM4>!;[
	GXLHYL2S`/bIl?l4?]MfFZjd)'%XheOEcr[>1Xt'B@C_*.!4&VFo=g[_6H5o8WSaY%K(!grr<33rM)
	IkWqZiaKCrRYrlmV7nQ)3'V0K<B*uD_/4BM'";:2RU[a[,c*p:E-Fl?[/Xn7'dMR8uiGa$&pB5O@jK
	lp[IP4hl/P?2VSHDIVIp:Wm/="#.8rnee:htCsdMEbjjNcs#]A(A:3Hj9A8i]dlJO?_a0Mo*&bYCb]
	f=a'bE`Ksa[Y2Dr+S[f?b"E3n:rr@\!5A$ekVE\fkg0_`q=KU\nRJR!`eTu$tP2]N+<qs#[>7Z:.RX
	MPd[^WS9H$uRf:"K6Pf%+apf%Tbj9lqPeS,1A/!/%*H2a>1Z!;Ikc[IF1DnR0j2BQ&k0!";%/4:"Ki
	QU:37mJ"Te?>,mQ]N33snCpL_n"a#bOr[M(9=c(a,CdnOpbT\DHQ/U3O5i[a/%.E$$@FPSD?4f%1J.
	*=`I9Cm_,ZIl6llYt4foum1JPPk</fUN%4P$O!-rMK+7ilh0E2$g\GlOJ=5_-s'pnWA[_9:W9afu&R
	ILC;QFA;^L"jTG'%AdG$!O@9Oef++nJfAP$a\L1nuV9KUt7%(0E.`sr]\%GeM"[H:\Z@tMD]5h(:M!
	VP5bN!c$ntS['M[VM1,[,FM):g,$812d@u_I?s3;Fa`1r=/`_sRg&?Koq9jD&4'g;,h/>irMZ3ZJeh
	m7e=%g8XQ@ej+e1IH-ZFbgY<K(!;dmZ*?Q!8$E4&W/fN5(d0?guued7"e++32_**XD]F-K"\AJ(\`0
	hu99f=2Z3MBA`WWTC%L8!+\I4TDG,'?Z5rE_;Kh6D>sU@kP^_8*WH-)#6fK@rr<7OrrC0_rn*k:6p(
	eU!3+c(])DiGJ+hq.p?h`OJ'#0Kd!taW4tHX5l3FNEq"K6]TCR"eZhOEamtC]@qO[J2^Xu'MRf<AOD
	Z-7.!:5Mh=8r9M%puO1merP<jQ(f'n,"]o$3("u4n/DM%Ai@)+@"Q]MC>W8$NC)TJ+t\+r2&lUfDbi
	Uj1rG+W.#c=qQs?"9E,".ID=ksJ%!,jNueK)!7aI+m^AhZ^[T"_!WDS=_#cj_&:^rTrJ:G4rrCTenJ
	8lJ/+N*-#SI(:."hJU5O:o1a8W4`Lpd*d=\Eu(rr=_[.&)e,'N%+!'N%+;kNi-J#BG:=g@p<9C@?Zp
	[-a`].sNT(kJ>X:a&(9[Kc1>+L`Zu:8$)!>6[q3HVVYT[_>ZF`rrDadGK8"C?OlCOA"%(QgR)gSrrD
	gOS,Nb1nFtl?V;fhr-ca5DB&CK[HsQN%Sj!%Dr(VKh/M?q[5.RG&Sf[Dl_bF?3`lebI'O,g'_n(n[>
	3j;9][n:XZo>W9`japm)ufp(fDZ*\q[NHQrr@Y*rldPgrL5u$/*ZP=d3c9Z:E*Kk7sh=b2>E<0>MTe
	sGiqW,H0n>\Bp7@KB<>l4Cp@=YG\9n)r&lA!P%q1I&,B+Pg)mSLm/d4e"T/.j4@/H]j1gB4nFqig4Z
	[?7(%G=fpQ+9_*dCuZ-=%#"h>u53)ckI19gu0gbEHeOX.nmff:"%qB;KCt<W.W\9H7e7Om(BRUL!f5
	rr?OI/,;d:!/#`Mi42\`e_36C5@VC]^Vk+rrmKX<d#uT2?c:3-;C0(k*tIM#T0A==?0W4:2#dOmoK>
	):]XjTWRSP#=[^V^^aS"pV=HcbaXfJ$jEG[iW!2>?"!WGoFn6PL=F8Sc4!.qWXg=kW:[.3@P'""itQ
	E0/\O]t-@]>1!NpiQ6!X$LR+W4DEB`7%3r4+>pAeD>?.bkIGggt2HC@IV.WiRdu?1\Q:JTn56]:Q#,
	upquV``#BI(k?ctl:[pAqoQf:a=o@M0n99J30=dn51cn-qU4&LGrd3Pl<%UH.;uZiLP^gM7DD.o'M5
	1$VIqd.j,\9eQb=MEUj#nnfK+Y+9bABGgecfp)@k9^u7t'h*!9n"n!!G]A$ZGed#OF;gZnXicHkirX
	Or2UmC$rW"Y?bDU;DhH0gg&#[`:@D[e&s#^?/=5G.Q?_YY3B<SO<:K%;+5PV;+20"r[E=25NJX<6iR
	.kj2IYeI_DrY&GU2@9)d+THopg31]2^s.1FSu0>c+2%)3N>$P]j=(5H@^74`A\#>#NF.jHOLZB]5<?
	fU&66iK\R`'=,?4B_[aVsE(8$F0U2Jh-j$_,Rg()a-hirJ3Wph,rqX[eJ?S;/(>:MWW@T'V=$'ajra
	49am0*^[/3G\a-3u.pbh+]ru9kD`-YNJbtT0!!dK@8GIE!'B1D+5sN9e!$?G=a&)#,$i&m#V_<\8;k
	`uX/NR+<F5`>:7=QYBI=.?$>bi%@]%f,Z.`4%hi/_5BJ&.[_nkHl:rrDp;4p$5uLZ4SK*T+6-lt-&l
	I`JqS'%;>E^OgnkpbR9W]3Sb?_A9j?[Bm<.?F8'kYd`12YZjcD_"$[\C:\e:*bUhIY+aJh^TemU1TU
	LH\*`)Q!+X'b:]3!F;Pc48(6c=$C:a;ce.:pJMC>W(59Bh)i4f3knq]Nb?iIun"9/AdiV7P&^u,&$-
	iR$<q\4P4n`-hO<'LsFqrIbWK)>QJarp]aD1DEpr"&f-X,#ZaJ!X6Q+-#.lrr?[RMLH*2fC2_XpRVH
	]UYmZGbsT?30%6ooSO2p:][Sd=r=\gK/G6Uq:J.1Ud^;a62I"?DLseA?F@;N/j6<>?,eLP]+@"RlMZ
	3Z*J,"N&r"\]"O'fpLpd4m%rrD5+?g&I/!!G[arUGC2U&P+E?iJ9!*BlU\gABkg`IAm-!5dt"!/.Pq
	>*Y,/VVZ)1n;R@nT,'O2U&!8C#+MFQ0`M,cpi"(H5*mAEFSgPG.jUR52Wa(i9W(V$-JEZee'n:<qI"
	cSd7"e;+6F%4!!b:Z!6SW^4oYN7NUS1m!*'8WC\lBW!/"N@jV2#6rrB@`nY?*a:Khmj-6M_u0Dq[4j
	59fkhZ?%8:j>ID;>:P!!!S/V]DhkB^Y)*Fp-ABRnL$s(=7F[;eU1B!8`FXupesp0'@KYngdKlekoMh
	6Ibf";q1dTrHTb<Fp3LVeV='Xd2c[<!88b-eEH@rj]1;EWFJ&&.Iu<)%psK*A"_dkB4E'1/gMKSO[J
	5O9c\I@(B-PT9EN/jVph/N7KGsKe9TLH?`VmR0>tJ(-OeJ1EcA2-HQ2TJ;!5Z2&$oK,]TC>D/fs4=Y
	`a(Z*pku(u;tunHXQqpig4+sn-MX=i_\^6c1o]SOh@J%^5H@tq\m*&&GL3mSmN-_Crr@bVpa.*\&bG
	^krr@Y>r'A\Ph%rB-r$D4u_rDnOnRqQMf&a>u:9_45\[9$><fc2&[0Mlh`h*hhYe4>Il1T:E>()F)I
	:mW\X8ONbDa&[D5593grrBo#$,.MV)rY^c1i%">p_Vo(KKM3O:BkJJ@D9pZpfkU=4e@;!Bf>(r4%3S
	S=B\n'8BiB\>M\,Y2.or]7PIU2Z@=0ucdV"]B13M8!.P=tn9Cl/Pcr_0rkr`9^\WBR>@-4e!![RqaY
	s+0rrDD1p^-s#VB:[qiZIZ7Vu2d_fLPqZDi_[0IJ@#RcTgbTrr<3orN^q2SK8%2XeGa;Rb*7@,H#p(
	eiYrWLjW4^08KC2N,S*+Ns"XXe\-W"*M:8AHf<UiK%IudFf=$OB_o%kIq:^;0Y=1E;N$eSQL-:&;Zl
	_TrXRf[Xl8.QIbar'"9')"\(8%bVnt[Ok/u`'_V'R`U[,Z+]Og(CC<o2\5&i=78)\kP_nI<+rLPlP5
	K(-Lhe9Rt;o<8E8,iPnI/G\5dJa1Gfq0-.Z]Zn)iXa#3L0kFlDe*(;9?Fm]GXo\Y,/'!`Gn$gNU%lN
	B\k?^;:GR,eRASXE>CRtaZ`i_hqf@8'><cen(Z#!Pd_&ZO]AcnK4@u>aIi:L*GgfdJiVrl_rrBo=F*
	hh@ih)%`0@X@Ode(WIoPIP(-UlL$mkmbO2aEj#n7RN[hSRT2YOrS/!.oWJ`SLh!!.o]Lae&n>!+kU#
	hOS[O")1gQShKVeQ:kY/j1gCV+hO(CnY_<5/HiO<>!].R=*$a&l*hJ?K\@N&D"LF)hqf]EQSL%M7[f
	&!m'#tohobCq51-*^/!pk0GQ&)brrA9jkTBM?h[0;_oapnp?d>SI)N4Uq.7)S#m++?NJ*L>/ZG3-Kp
	cA$G;1G6gg!b<rrrCP9ig#"cfBgi\<drD&Z-U@&r[n,o?P9b2KjPEEHoJ&"5&V,!3bO5UCT0EVXPE'
	L\t54)HqgC%H>nc0lU]K:BpR"]Q*"!,R2+O"U7-,!,e%XZk^`[5ApQ!*V>gPSrnm3H^\U*C*.QoTn;
	%#DS_\dlfBaU>rr<m`=8do(@m>iX&9YP]9B5Jt?a?$bn)OEJ*-dM3$ThRb&9tt0?O2$$i\(r1G8AnT
	Xd+UQqQ@6)hd9"[NLd2A10cqbf$Ha?$>2D;#r^8ICOu/$'N&"ar_)/<>CZH@kO$Uq!+j2NrrCM#MdP
	\Arr<0tQ7II[,k((]4OPK/6h!$/Q<@dA8E#Rl?X%e$P"-Zm&OS@d0NCu6N*#i,rrBlPrrD.2T=7&`Q
	Q90-!)0sU5?7^`K#`>t6hWV2\*P?5Hqi)h*IItYkCJiUrPk>bNsaNQ*]3CgJaSNBgq"S`]Q%rbcOkY
	=CG9KT*igB<m^*\[1jL08e@sV2hr!*nF\3-_VNnMc^&8Ka."9pc&\L3qO7ps!Y5U$J6KKj_-h1"+TD
	8<R)oD>h81'5[_nJ))XlA4OBU:Ht'c'c@:"8Q@=VXqI<o:;>?g='Z!!K4pBrcV)rr@Xfrks6efA`CV
	?.2#MmtKJe[:OFo>j7]dM``q2ir)A;\5bp)5*'um9r6(7]iIcarUf"5V#CY7i/HR_6][8B[su>GKte
	W,/U/o6_-aG_S$/`HFoMFYC\,ARGO_9B_V3f=f=h=]H_UmO=O\mEh.K?inG`KE]Nm+kNe*tiEU/,-\
	uku4LhuGMWP?ns.&+2.3+7diJeV=]MBuBaMC?t"EQ8stW>[/lLnH5r^q^["ReL4(b1H&Sr:K6H&lD(
	4J-?Wa5Qqj!5Tdp?r#SA[rX$dJ!-`_g!24kb["#o]SU]Rm?h\5`qA8Nf8,ODufDZ*"rr@7grrAaAbH
	uc8S"5&eUL3b/J,0uK79q#,&,gu;+5=1;;-`%.=oSK<D1CX]?ah]eOW@C#!)HcMJ!rmo-1D\"g/D2R
	VS3c/>'fHt.\$,rpri14_(`fg-EAMNrX.P-46&^IDLl].X*(IfRnWU,Wd$[DUlOJXQ\_j%'Sc94Y:[
	N;hu4"!rr=IArOIFEM!CW/HI6O'0E2$)DRCmp^Yl>gZPJ[C@g2h7MY%G5$cD^Ygm+$>m>(&onP`_Xa
	TKR/G=adA5/S\ZRq$,LSjj6sA+W]CV'jtuqmeujNrK*35sK(k[FThBYLr/C^/\H>cbob_Zu:IG>#-[
	g]f!1s!/DX1R8q?F(Dh7]IgT_@3-NOe^6=%&UsPc]Do4g73%%D4dQcZoJ$tWEoP5/hpnQf6VM_Z)JD
	'7<!koH93cpjRR6sQDhqH<%rrB-SV".e'dEm6Dm,)r*rr<1`rr@\&XF(>(4k>DH%g2g[qWG\c9MFTs
	hLC(u*F8;E"`(^!F3ONgm5)Rb3q,q`8Y^'ZLQ63eg1[)?BOQ+KrXO/A\,7KN!:X%HM`S>/OWPS@0DH
	^MT.qmVUKmb]iV&\tT0?EJrr<]j;;hHSZ]";JB-"QtRK!7P_76]*F**p)^[b2cZ>]Ls+9#*]q]($6B
	Q*ia^Q)=kG@-/un8:JgTpta8qYnk!qUL'8X7ktlVt%t.;Z,/NJ!DDZ(YAA(f=ts*paV'd7;JjdYA9e
	YA+=:3Tfa-j$Sc:.YNXj[6hlRG^9gn";K(pjLeZo*%GtH=c#]muGF(*I]\D?B<pT9?rX3H?!!J\9J)
	I5sZi-*_5&E*n?aTh5_4,:[=SOE+S+.N5S`2Ud#b[eopfHJPdLi5CpPS(]m,(Cbk%R'=&b.,Ig9Msf
	=.UV?eLHfJATtI]^MC6\i!7:En828)'\D=<m2c'SpcJ1#nXd"$U41KsZR:Hr5gXUWg!UK&/)[RmGNF
	'N`-rTq*#jl-^tO4eO+[@5UdsRlCMTj3IO'X0[asn!["%>s^W&IWn+MP8M192s48>T@^VF412rGL4D
	=6G=qTe+enTTT_=ea!$,Zg9JOVmM&DlmSN\?ic$pHe=.LNOu!BQ[Sc<HPeO!)2kV,=hYHkMcF@r"TU
	t`P`\M=tbHAC0u]2(3+_3pg7ZSa_@bX+1#,)r)NNA"k;"->^-cd^URKPbs#k12(o(,L&V/3*S+l7Zb
	5eJLjVuuC"qL)Z$Z:RoO*-q;+24U"b/)\n96hhUO1pcrLX#h_f,KMrrBF&IoA6&Z[]gHhsucqJm\4u
	rr<MCogA`,Q$!!bqLSEurr<7^J'(;G2LjDAr($beearYs=8FCJq:5KF_4r+COq3PEp1-B"rrD_>rls
	!mMNq2U2s>c?U5I#&oA]cMK>#%\p-3/Mq_a0ookjUqYLMJ)1b\i%U\:,U!4/Plrr?%H_i"Atrr@\b^
	Z>)QArlgHLd1QLr'dg=htT#]r_0*\RK!8nVORSc<@>\Al$pME8,iQ]5^urO;+5O+=8>Mh!5X)ujY)+
	l^\s37"oeSQ6h'NYeY9h$?iCH#rr=KprO)Y*m!/"Qri.&qFgVa>rr@cPBFjQqrWj,9!%<KuMEgGtn]
	1X3+,I?%$"&aCn3E'16m(bmrr?LmN^*2Ur'dgA9$1AQ=8@AD721:P!"jPW!,d\o!"jPW!,d\XYP(3J
	n,9U(o;hlkK=V!^jWkoNrrDE,IN3k&q>I+)p@%ti)?0]$DgZF%!41SXPQ(W_+80KR`)$.iTDh_Sn5'
	&-LZ-;QYFjN<^Ma&Oi6e1m7eap[q`XrZM*Lj1rr?ZB-2\VX^GZ>i1IW!Z3!Fepp\Yfar_g<(F8l6nE
	RfR2bG*Vbd+A(HJ&-"%!9G`'[m0hX*EW7@9Y)fm6fW[TJ!pK<'n>.u?h0(-fPCK-NgKbGVla^K;_.F
	brWneh!%=T?L;3)2l$rPUeuSI!ZBjt0ra6F;73DpcU4<S!U4<S!U4>H?5N(R_q*R+.O7iICJ+]i@#1
	r?[rr<0Xpa,F)p5K"OJu8Oj^BVD3GT0$FQ12E*5Oc8a!9#<p=,>k)I2?)e!/,^mFniN,XV^Ae>>K)l
	IqO"a6ddi-IBtQ\Wu,-c-M2fV/,g#<rrA9>Ib=Z#?eOWB!*ZSaD1<-^n8:2_VJ#T_qL6e@qT>EMCSI
	<sh#@BApN5e<7R-#?qB^M1rr@X^J&+<4!Gf,m.elU4)h-+>&Fj(rGoiZTppNDASfH=/=eaci6Uc'iG
	b;o4HG7(db)E%DkrONi(^Ks9fA-!q=>o%'^K5@].&)eF_B8[s#P#;#9B+:aGPaAQhJ?O(r&sh+nZ0S
	DENp_Q?\k9tYjal1k.+BC,O)K21\$(Mq/W5eHHjd-NeZ5BlDOOuPOQ500E)9IYB]&RF^*1N5I?3aT+
	s_;\W!k.Sf,nf(%CM2f*44^,.5ua,N:_Y<GR?\0;`?lqj,gja^=rc2t=HX2ZEcn=at.b+MB_&(W)*F
	#^d9SoO;5ifVcX%$>F[T/$`2\.W+s?IH,*tKmm]G\9MQ_niPIJrr<&6i3(u,;6SYoiBN%1#(-RPVu0
	E]kM\p_RpBq@GX"mkVo*@@cUi$fplAMHDRe*OCYfHL[<^M'nIE13C/QqWTlK0cHLT[72UKDO4^<upN
	+15KS%kPurWgLTEW6#jrr@EkQf.W9's%&>do+nEFMAgjVo(_81hl..=&=h7It@MVin\Y;h3p/P"<K8
	HHqgI8Tp@\qq4Z[B"5!AcrrBkU^,S(=%K?D2`Vk^D,i%4Xp8X_f]K>W[`#"/L4iQT?rXVYIn<71n^N
	O)(:t5/6"PmgZMSWB?]Q]2J#E$:>"88&ZW]iXrfO#7-ipZ7\nJb="U[]@P5Ge-Spnq'=Ho[tY2M%Vt
	I6O!qa_g!r)ai*9><+P[h3SaW[F7W,6M!;n_&@fJ?gqc*`n0aqllknOi2ut;ghM<@5!Nd`RUrEC2P8
	ogMS9tUp$Eq>;ik1$)<cP^Y.W:r<`t_1-!ghFF]L(mNU:s=Vq[qhlb0FqpHeaWd7"eo#P%Ec!!e)T!
	6M_La.N'0]QaAUW#QQB#Q,J6rr=DoqdP'.&F_(HVfPqp+7OLh;BOSqp->!7jr"(XGhOO0,ID/1h?$c
	92fLZ*b-9+;X#B2X)7F0ff>BiBBC,+8m4\?DgGI;0bhiLb(Hba\8At)8Dr^@.`6lM-c$5nElIn7o<@
	]$D5d.HT:&D-P9@s1DDEr\iT=!5JRs46)rr?RsikPJcHMr>SGO3HO!%0#g5C_@(peUniWUGW.rIY%L
	C)Ps<rL,raMjp-/[^NX>(\)BiMi$Lc@"JZs!TFD3RVAQJ*)T-C[$"',.RpF@aA>T\O2pV,V>gO05M>
	E9=l'':Hm_oo"dtdkH_:LA;3K/Am8[EZr+`0I03.fKrm-g+7<8H1q+L_f_0s)[07UFFrJr!'rrCS:n
	F"'AU;+iXrX8,n!%E9n[Jp6nGjmBcWZR"=[1A8s!/:Dc&+>_]#SI(:."hJU5O:o1a8W4`Lpd*d?]T^
	+5`b_/+7)l)!+J0Q5P9!n7Bb?9b$2V^q1)=2'S%U+M?#'!M?#0u^]"R=rr<2Yp`'55"YK\Foj<A:'m
	04-NuD]9C3mY2YD[Q^0h^MeKmkqi[92A:Cuif\lCJdAjgVS(n[F/5Si\#,BlHE'-Ca!81W.r?NVXee
	1tm.W1^Eg#Hs6;Tn[%p4rMI51nC,>Il9>fn3e#Ah',K7YN<8s'CTS\t?4tcTokt<7_ns!lCMu;ehP>
	HnMS(OB`>gITV;>ptOs20mQ2[l"n4UON)#iB!Yd_Cig/h)hHlb'5GD55,r[-n+C+[,qLW&WalBf3sn
	[Z-5<cb-?CAQ5:5D_4&3_,>"oGqjB;`)\+BDrf6i9MC6_7FR_'cP*`_[C@nhS&eAr$9gA,+&uHQ2G2
	'^[Vt)Z$XA!mj,Cb&%#[F`f5-?OnMe`7/m6VNnV7A^\BY&qc^W3!.nj26\A?0P/g8pYWaI;ph\%kU-
	=J__V]q@PjJQ-,$9VV[1.Cb8G8sQZG_3:h`V];l>`$F:W7&Ro_Coi="k`W/,oSQ?L[=\(B4AdRf;2J
	A\bhh>lN>>*rJF'lIkPNniU@N,K(WT[OW#W05PL5\:2J@pMVVd2i'@cK"o^NrWk%6Ge@>^!!J2XM02
	o=#"qaISgs6G2X<-<-1F^L59BSTF^[9?B1__%(?q'/064B^\,&2*?c-g[*1-.qn)43Gr"YjaVQ+InZ
	dCrpph/QX`ifgVJ3p_'RbrbaHl:p:aJ9bQl8t&_?3KenIA(.VZ>[1DcC3I$VZ)j1i6s@5CII^m!:3k
	Y8+pH-eSU)$rr?^#M]/4E[(R49L-(fP(joJq\(3Cl6Il?jZsBf3O7_l^6`WoiE^Qb-V4a[/OiaTW,b
	5Ybks;G7NW*WFbRa!qMC>WH$7MX!5K,;8L]!C/Lk#+\GdIDM:Y3#Rc^tVqjI:N[rrB;G_LMDje*Hp>
	r[<9<8be)@!+X'-5P4o$?gRUXa8SZ>_r(>'r$VLEVB%k3/,bP+HiF(_"8I]P!/&6TjJ@=B5P?=LIK'
	;rn&!fPrrDgMX8Y]"mGIpDA&lA\r@n.IY7U^6K>g(9V1-9Gp*4s5rrCO:_V4_`!;J@Nr^jTdhu<[da
	1tLL0`4hGrr@W@O8bAorm3'fMWP$2n,<^`rr=I"rO)Y*lppP0riR>u<W7I)n3`6@pd=$Or"W`84RdQ
	U]IDgS)u)p-nXkcuf"<Nmr=;Qk08DE@/cHH35eM[h;a]-<Dfj5j3,^CNm\,[+eod#<g)6+Kd%dN8"T
	JJ<IK'</&:_.'rJ:FXrrCTenERc>^\ApIr2&lU./s:Pj2YO'W.#pl9eYJKemJ8G"8spgiJ)hkDu)99
	fk:<b&bk6;rr=f3n"'mU2hHJsph*:i=2V3HGZV[E%afaYrK#nj"aGAbn?7RgOf7O]HFBOGS"StGFrF
	A9gU0]Om7R!:[]o_2:qaKRS'8FQRRcYAY$_SbU4>JP)u^=YrrA:sI!bknYoDUkri-J7f7A<TrK2i2r
	r<1DrK2SHmga'1D`fcErrD)?m.Km8l3IsV8YPI=e@md7?`;dP)MqM88ChXjH)/W'E7.8McP:,ZdJ5E
	YPC)cr*6\?^.=1d`rr?Le^lSFn*YGU>$iUG-q^biug;!,pDoM_Vfp_1F=Z&F#^*`XRC#HPj>X`G*r(
	><nboao3%!??B9?$#Hl!?U$r&]1O4QsHD(iHIIA;4_Sf7$h#HS9F=Q<+1JhtT$Hp:^J+KOa#Va7%ZE
	`4Dk3V#4$8iV;a.^=)"XQL!SG"iFj/c\Pb1KNj;&<:N2)BCP>rhn)mL9DE.Eml(-#rrCnMIuY?3H2B
	mP^\/iLYl4rXck_ocSWASU"FOA#F^Gi-G"Bl4X*^Mlhoh\j8FT@'G>X2JDL=b//'eh&:A&4UB=%TcS
	!9@+PPp:7/`M0``nhU&kD[&(WS;3;)"Dd%Uj/BHHHi(LD)H_H?IS<7>p!%R18Jr=Rf<@`]!o8+b`4\
	G\W_=aAO][pBleb_k`YrG+?-6nMSp%a6iIT1rrA4Iq[!3%fT#Fqrr>j0$Z#:=p-&A:L[?nt!!J5[!.
	pI1mmGP&h=1aD<;<0a4T'KO-%[uN>b2APr&+"S7ejHj2"&9'd]L.gWF'o0qDA#N0"_Fc,%Di^Z@D@g
	Vu2d_fLPqZDi_[0IJ@#QXoAA*Lj4,3nUJANpaBd.]M59XlTQ9X7_S;,_nI8A0*=)/X.jBY'_o)5lIp
	+'UEkh;I:72:CH,?qB]P@eTd(RZjeWdJQ.s'd\q0X9rr<8frn%>H;?$WJQM`A_FmVuk57[\nBo?-o!
	,%?0M.V`!/bOT1hcS]^1"BPV;\5N2M-=hPoN<gcCK@^fHpt0`k=HbdD0,]N<W4tm[Qj-Sim680p;cs
	eq`i?(C3EeL^orYWY*n6U&L>\:X'OpIQdGM[iO=c>T%H=TS`[KA/)Lg2U>AFg\Lh@+O(QF)rr?)<pa
	9_A=^h2Erl#tc\*Ytg-*R$O`/f\bFIkFuZN2ZM^PQ89T'*t?'""TG&\qh_ZLQ4qY=GLFJg!%=p+*(?
	m.W3G`FQ[8YI(]e/O'ce&%*g[MSKbbGQ&)brrA9jkTBM?h[0;_oapnp?d/!:)\);SiNL58paHujiGX
	Ug%m1<k2o?7,bs)m7=St2L#JsXLN:[h7/Nd,(ef.=T1k-,%qNd_^p97iY6Z74Xrr?_e4,]>_d3a;A!
	7Mb^*I7Yb.)4+nm-24trrD=-nOgQe:\Zd`r_eBPJ(^oN<rW0L]A[=>&)bdar_WdpkPkO:)?#E,kg)J
	)TDV4:KYRH+f?tQQKq`g!7+(ogiLM&_nF),04/HZf(PhoQTkX4h7Z!i&RRO#5I[-\lqGs3t]oJMWBp
	L[Np,[Yp@rDOAQ(/E?>=0AbU+WhgJ-?Wa5Tf(#rr<53rrA:dIbar'p0;`IrA*TEhu<\m7XnrepfB\c
	5Pu/cp:g%aS`TWnp5Am92"(QllJ`)U*'Y-d''^96(,r_o-+mq2pm9sjUZ&g*/f>qF\@?GXlZ6u8;%g
	ALpas8YV/u@nrrB@bWrE(`QUS+D1W<_,,C\:;n8"B,?OCKC=8&i95D5Z8repY>Hn^R?A@]<9-MUSji
	gikNe$RkC@[?$B<:MobMpEDg7nBtqg=I7?]j]*YH#M6Xb,G#W:XQ$'[f6=M3D]E,PP2ck!/0+b-cZ/
	dfXJf1YFD\B&b.\b(4I0)h-:/Q:PSlL&oO;q`YrHSDJiaH:@P1"4&sk>#$YbN>smV15JF[R>qNgq$N
	C)Pn+\+4m<X7kTD0hdm-X=Q<Rj=?4s,$5`2iBWima.7jQZ""kMhssiLNVBeX]=Ce%?L!gj">.'TpDi
	hJW[(8*/"q!$8IrXUSiF2P'\;<U7!k!'chS'N&!5;+20!;+20"r'^Pb_;p#oi1.RVGG"^Jm(5dc)7e
	Au$8qh`G)-(tTmkKjJ&12oJ)Hj3pNN8+([Sb(r#*&srX(O_!-X.t!24kk<RLgH0`M.)o7?kP;+25F#
	N_TU(>&O_7Jh-*!8.t75P4WCfD4HV_$Y=ITmsm_5@PShZMgiMpnt*)hGKc`$3'u3(P'/,iVrnbn+,V
	t/H5^X525/c?aP)CB(M]0$'Y;tJ)IcMnqo*TQi>'dWW)srXVS[sX8WBerr=KQrJ!Q'\ERAsA_*oZQg
	j,&0E!0tq^;CD#B'Oc1ADCRYP8M&;s9MhB$pT>Hn`/$08ZlLUMlX]-c*Jc&Jh4A>bV,@eu@S'(\gd!
	do&oB28=c^*n\6\DLA)$DtkoN`o6epplGC\p%qfJip%Gc`kV9rB>TJ;I=:gDQ)FDlnB9h3`r?$nrr<
	dk_]gXtp<2I!&'VKIg\gNt553BnrrCa@r#DR11,&#$rr<27pm^9V1JI[qN'CpX'DQ(tc@F9X/)DV0U
	J3t,INh6.LG'^>C#CWZleWu<,F)fGOh<J_2!C!7Df]dpC7ZUDQ*'hNiO?^cLH;MpF^adW;Xri))7kt
	W(H+<%N\5]DX5%rK4-b3-R:kMP%hNO-[d=F0^7jPG@W+;<]LZn107#@$@<hTP:\Z#N+6h>U!!_K`!6
	Q1o@umh\%K?F1=7OGJDX6g+rXHpJ!0f9g`ue[B)ufnAYN(msh:Fdg3IconRfK1?.R<u_rrCug+7Mbg
	#6+\>7(s/rh\U_UkS>'im?d=G_cKoG#M1N#L<]]OG]u]5iq<9_Gf!qZ6$76mR?,8aHVeW:_n,JsVTj
	=%iSA!D0`M-E([P`1<;]SkKR[`TKqG_b_q?mT%hsCBnU(soO2EbHEMg_7h[2Nep4&,%*I*GZ,:o:5M
	DQ[0Zoc7:[qgsUnk3h#cg9B"RpgATrl;GG6GN"ibqHoE0DlNnp?U1T!\KVR2ZEcb-cT'n(.&21Zdn7
	/Y,cR%RgUY3-(`uMcVO'ng;T&RX=YE8G46f`>?Q59@u$e:k"ZFeCTI*q^WYaEqV1p.naD53.XXDK-c
	H#b#2V83i=CbD%IhE!HmsNeW7TlFnV2m1iZ/Nrd2l7V\^L-i=c0;D..]W**uh8eYK_"\,G([4lC[Q=
	?e@R*?]CeoMtUu^EMl('AgHT/7Zt>YL85$!mN69%*4""i<EU(O=T[>DD/:B(L\.IJC<`p,^_QdRJ&0
	ptnr<*i?hSjH!"H^96iPN!rCki6c2RbKF+;=k^'T;Bn,,*D!7_VW8l\gbj6?m/-i=l;rr=Jjpt>ZIA
	jc)1rr?-Hm+l%4WF+girr<7^J'(;G2LjDAr($beearYs=8FCH<qtRH!2>?$+@"21rXSZ%!0c(6RQp/
	i+TDGl\+(6K;h*`P^\KXGg1UE1RW&.(T+3CBbPi"FrrA88rL,t;efatme[P&a^JfX?d(fB3O4n7GcC
	/\M<1aXNV>gMtjWFFM!W?\/72=#I?f`s@!!W)r!0k1rgA_0H4Eq\B!*'QI])Mb2MZ3Z*J+t\+r2&lU
	fDbiUj1rG+W.#c<e35hj(\s^g^/+MH8,T(lp*fq@Yoh".qRCtufBaf44oYMu!^GcXJ$DNBM#KC6!7f
	!W(;F9..;o)kjoImb;?Qhcli"CFr'b1S=='+JUNgC)jGI'97ZLTINJ^:IOgkg[N#>c$'pY-;Vu(L#4
	;Ug]F)<a82V0ZR4h\cH,g]<ia<ZXVAW4!:`@Pi27jMom+u"*b82\e%m!mdIqe.)7A,cN6F8l6_83R@
	[!83J33<'!/oD;)1mGIg[1]IG'hY>k*!,'(:-iX0G5O@!/LYqTF%+%`K!!OYC2&oQ6/=+&U5Jq.e;E
	5?M[^^795I>:M_`Fc/L/tan\%#Q$g<Bf>1O[ATGQ#AX!/!ajjW!(rJ*cq/,l[l0L]*\*QgeMUr7E+@
	bnO#[i"c5ahsaj"q+Bi;ci3uVa&W->dk6PclU,%?^&J'9\,QGmY(#1+!;9Z??i;bD[C$O)rr@cPBFj
	`8rr@WsJ''1S@B]PP3a_lX[As1!YKK0*,$4]:MtS(h!4!iGrrD<L>-HGub$2V^q1)=2'S%U+M?#'!M
	?#'!M?*QBrr@\35NN=2[QiC;H2dlqX8!W@`)$:MNW/u-RJi.pT<o^>ZDY_]rr>Og!8HQ-54IIsnbXY
	\<rJ5p?/lrH^cie6YQ"S.0D:0ZHoYW5l?^a>rr<<X`30Dn9!nI1QDVi85MPZ)*G_P-H-Q5u9?H=SpS
	f0^4oW7s!:Xjg_(XFcp9XNkqcS/6p6,3Kj6mP,./s:#lh`o`?6es3KXAu?<rW/Qlf#%+IN%&@[eEF[
	YFtarO,Rta.t8jpH$<m01Oe<>[=k9J,i5Xqb1k_u^W6rM)N#rEJ1D#GhBUH2+5ssGpp\0XCLNn2>=6
	qg8$1Z@<(CMqBU0GqSu$WSAlT.SB59?Lbf[P-aaU+rCW?ASBRb\Nnb_6'`d`P[podcg28@.<Kt]YD>
	C5B>!Xie7F2OGrO*igaG[F=uoQ[O]gRV*b_c4./`^q(,L>cX1,Y94P&-MiY2>p1errBIAm7XTt"f7j
	3^U2n=m7U>13&anPGe`9'`(@+i9G)n^9.%"):!sbfBpnrjbDQ<"AD[[f@nH/cKfh*JblT6#d(CU^m2
	*Y9/\Cgii6l]V2VUjQTjndU`*+ZQ87QQj.-'*t,\X\Rr5JZZTC?V\m,e+&rm;ekIqU?^g/m:cNc2W=
	Hqa$Z`>p2?HKTrD)e#OXHLHFX]2'#P2YrEpPK@q^XBNW9@s'/\VF^s*c]G\WrC^2!B,P`gm$$nhh>I
	?Q:]CFQmSAJq`F#kt^d!e/[dqbCHm/H^'>o$1Og@PjiGXV1$J2'&mj<0H&[2*X^'F.5MYW5ODYM;Mp
	QS2GS,WJ@7Xd50KR[gqg'chEea/UuB?$!_f)@2-[GD$Fr[mn.ip.hb_U4MS:BuUQ+aE;;)&67D$o]W
	-T"h[og\^[tn5&rr&,&utO8CGPrrC!Kf7NWZLc7L,^J>^AEm%5-2=D">?46;4L\tdpH)=d1W:gk3o4
	TeNh^lnf[%18p87[J:igE"Rrr?HApbrH:+7'I6<W"NKWk8H2;LDa>B8D!T2iAke$1#;=n<TW=pleJC
	LOsnBi/LN,eZLb)>3G7oBAsdd$Z`3k8#]VC>c,W9L1DMgq`-sS2Y>Dm5+Z/38JG#jA-__Nrr<9^rli
	)&rLn`!R9h',7tWY1X^B"2ZWG)k$[d95Yg_MDhqe&P9@:CLi/\on7KeVi#=7meSiG8g2TV>*KJ$k2i
	\lNui?S=.C&\/:'_/C)'-HqJdXPqK%!Yqd+8C%Zn@#[mkMh!/l1IE;^Pi!lYMNtSXj+#<Xo4#S9cI?
	cHpQ`k!"\jW8^o$7D^.&P:Sh;_/2\ruYP#iKYd2e1Y;FL!cIYqBFW4PC%7<q+[ta=jrl4@B\%K&[[(
	&VXlIP5*Opd1nj,t:ROlMQB2J#+qJ*hsi!!](pb24-8D68'[p1*m>ic!LJ?%2)1<7F)Pc/?3PMVeg/
	2&hAu\9L+ZVG6'b"F--H\lH_fNW/tkf'sQ5FIaI#(>8tRVWkP?g/NDtS5``@HT-<;f%OiASq)97J&+
	N;i9>_#IaPp9pVa8goCcepT0.DW%=@,2J[Ku_^,>\DnN4[8$Fb]d0B0S][!rrqpd[X>PhMXr`i#m$2
	g<t>TAg;M>gP^?rn.(/d4[+[L(sP8rr@X%Ia*<erM[KhVLPmqK/?:XlMF$>-cJ:YHuSk7G7)X(RR_m
	W%-q)@NcfWT9=oRE@;E#Ql$?-XD!mTkA8Q,$)HE:`6Z[;VVt;e(&,7r]<rUg^IieUG>&`ut9WrYWi=
	FW<jQfmi*!`m\^=I`b$OnMi(3R?T:=]PaTg,kg3KcVkfDZ*Brr<28rKP(TRU-*Hr$VA)G\:$fnNVrG
	`r?#M^+B'EqU8dGQ/edk_u529;q8!,r@^mnF:C7lRS>`Y4r_plI1G+JVSBXI][e]R2*77JV[0[5gM>
	*hDXZns>H9gdqB\QE=#^A5Pe[,4g\t+FqeQ33f^[m,rDYuklht!;q4[br5N(6[J`!onm7m+tp8.:Tm
	4n-<_&E=R`U./*ehnNVkT1B+L7tC+o'$&fd!R>X2HQ?+X*ZsM>NcXS8Cn6[B"2qV,\^F[P)PlW2/`@
	h+-3&`:1*cVDr>j+8c'6M#5sk#;u8BK=7O#>n:s9\oPI7?=pKt5+fFQ#`4F!K]MIOcVR!SY@XH`?)f
	9m?8J^9o1tM*bju5PT:;:G6pc=Vs#OMohrrCtq^`=Bf<VXJjh.,K3`ZKqb#ILZGC47u.?.PL=C4?lo
	Bqfi)a&phCD.+5^2EGF#[iP.l]t"pmgVW1[cKK&b5N34"ft[NI&*%m5&=s"(!9<b<rrBCOr#3'6"87
	'9rrDOIj7\K0<IA6F(:!?fit'$lN&k$qofiY*0%WhLF[(VP1snF"A#&<*<jNaGCE6197#o:PinPK//
	`q80k<p&%d<Bomh=]Uuq>S)nIoQ&;7:6-b'Mng!'Mo&+`W#oC"+S-U5A;57-JsHjA:KNpZ`^Fhd<":
	XMdA4/muKRIj%TkDJ&/i`nBJ_$/[[!K?$6Kde$[p4D1<OLQ9)L/p!!_G[@(>8e6^#Srke9tbs1.V/N
	!AfQ/D9N^0cct!+M,J(t[fE]DOc0P=%0HC=5k+)b8mT@i`Y"\s(%tDD!5hVpj,5n@BsBrrCMDr"MNt
	$+]ppJ&+fB&F!O.^-ANRo\]F3orF\up]JOm"4r9cif=9<Np=JU2Wk"e)s^d2_n+*`rKI2D:t#8-U$>
	\M>E:P]o\E,$D+<:UG4?+@):>Mb!5_#Lr$$X"[[`p(Q?6e9Ljs&qWI.!?D"<]>;D+I/L+P>bT&/@?7
	rYT)a*BVbp=:WS_lQ"bNMa*ZI9)\?TCf8knlP]\rm9O@5Ai..8&q5CIORuEMgd;VB^oAuYGM#89tQQ
	'RA$nTmt?''i9_"%^VBcld562%+2\!odai8&;NfVVc5W7BrCUelY(+rFrWqQ])J_RATDTAOi%Mml)-
	S>Q`9FY29B&I\RoOQmo`"oI?P2rK]M#7!HK%Je>A7uf(T#r$h?CL#Z^+fWah0DUjfHouE0EN/5O_D9
	pc#DM3<&u1IX&Ippqs)r)Y`VBq`oCT;01^"Lu/ed]fSdSf7@jlm2EIOrr@fI(E/m9UMHpKQMr)u#.<
	IXHV'c/?OpmT,IPX_pUZ6I'U"DsMZ#G>Mu)'-MC>QVr`t$3kHFY.+,YP_YM$P(rrBG[_9WSIGa%.=m
	'@JAhCnBdO`)PkZ/WNL>3a#(pm1'ZdO=4L;Uk[bCH?ha.(.Okei.LUlJ=Y78%HCDdqiXq(-c7-!8DG
	PVu.5*p4;_bm1\so>.(X*:6019U$M\"etT[fn<]3K)65p5Rb*/hA#<I8=j*aWRY8+m2peoj<qk<C[A
	N1lp6Ti5Wp*Q.&H;a8NINj9[pT%P*W$KKem:!!#K6WBKAIgB-gZoa1W:0>g8;SH#GLD]0DJ,?CKcD+
	BY)ct4r!9cO,)IY]U!!;90WOR_nl<oOeeT1oL?U+Rdmha;'jCK=%BrjBBA=^`a0Yb!/&+:!mBLY]^^
	44F7FFsid>nuk'26j^-;$uVr0Y=8O=tt4CbAEkrp9>lt1/k7GZm-9&e6A6N7%%rrA+HrgEcd@=R!/q
	t@r+P(!R`e!c>NXZQo6nY<p7j#?IMQEN3]DrJd?ohA'4gIbahHOVH1=m`>n+\D>2d^7!)\FZSX_Tk)
	5B`A'q?Om)9_4=c^fBp?3/cE@>Zf,SqG.[bSKQm-;]1mbBfc0"0g\Xe+m$`Bo4R)UC,lZ;Rc%\Zhm=
	/R%ZJY$9i4mqqp3QL*q_n@7e@\;Qpb1RoKBt]>iVd!"f33UsM01mA(Rf!Neuj+c1Ifh=^:LkcSnUC+
	V:aMB\PaAg7-8.Km(#'h]BsN$pj:d,I\M]M0L*N0ieRGrT88!j4F"44!)M4Srm.2FJ)m)H4oYMe+2W
	O(@FOQ<8F[Mo)CbPDpl!'Omt`@iYC8@`c*$@NT!:/c?3fsM`<<cCm.[eQ)a)*n31b10Z[D2@2qR`)i
	S>P.%etN?nGG(6Et3o!l'a_9&ur%>`MQd(AK9,JI#B8L!m&Ns.lIVLXfBZ&jlLhqqDGt$i.:e_rrBm
	pTCPmp@3>@Y^-;Psl1a.RH[kr2ec,Upg\1+9!3tSB-iTK^.9Gmar"W`@#g)SZrX,jg%tad'pjqt1a+
	"FCpb/E;gIK^Er#MGTIp7h8MoOA_)nihOrO'+)\!"l22Zd3c^/d\6S':bd?&/=jS,N^EnF->_;;qNT
	N?02:J+7HsT,$>[c`D@A=Ocb$AYNja/@mCH$F91JQ)lkMU-#3iGKJi9Upt3!1i7"=QhTA>S6[aQH*g
	V]AtK#&G\cmCr@Rl<Xcu[O@L(rNr"n8i;$Zu6rrC]4i.(]157Xalgje7PT=%IMrr?M(gK3;lm7ZH2$
	L8`lcor$,qYmaupfGB-elmO-XN.De,K0QrMAn(j6oC2>%E?'je;\FZ=rVZR_n#mJXT&:/kNo=DIbT@
	Xcc,A+CW/IfepJ(&HsY4mD')[G:4ZtdW9Y?a>!InO*u.:'Q'S/fANZ/]BJA/][gf_g\<587Lm@ndJ&
	EG$Z[_op+3*dI+Zp#0!6=DOF+T=/]!p,a1maR7r'gqg2u`m*SpYGU!5e3?J,EcjCqnnn^[P5V!.Vga
	Hi`b=a8Q)6<T=UD<dtIh@AA'3:t,>NXQ[7GcDu#fkc_*WH"SaeM$u(*')=/DIds60QRQ9u^[VQlm,.
	gC7u-WHrr<=#!WN/iqYd`"!.n8O!5U15!WN-&Y4)\8?N><Qiie;).bX`"nV3%`%7<t^L5hqk[lRO7N
	M=.F'qLju/%dZ(1em-pc25JDj]j**]pCCaIVg[OQ1'3pcM]:!lD51l=TSM0hsb\?r2&`>hu/Ag!^H?
	SGXfHLrrDgO_u<M%i@k'\*u[B9oqtc=n5.I+2cJYLr"LgXVt$tX9B.\Z0B.c)c%!aE5D&NSY6t&;_S
	-`71j^(P(ZAXM_R?dThWhBum'9u&ku$8A/;pqsVK>MOWF)QQn4jMH42P@o:+t:i9Dt:V($"0`r(,2A
	^DQaT`Y&!<`B%n)V!?C`ppTVImc)@U1mWJC"f">^"H)&HMVgUBXee"gEJeYu7nY_F5_#B'r#A6(,*1
	DQrX*<.F&:7@`j#5dqaa-\m1nR.*"J9KW-Ib,r\'+3FAdr:+#_m5G+7Kn8M":SJ*d+U>1"KdA@?htS
	,36d!/"oKCZ"o$5PQT2L-?ILK2h_l`#mYg?b#kaX2R3XAb=jjjGC;E!/-f)8%>W]Fg$NPmQ:TJYKOJ
	*+5HdEI.-`@r"WH8#mp*>rX,j(Hlf`kMrXg;(47\'-c)o\`KTLL/b!A5U$C?dTqZeWf11m*nF!+WZD
	`gqpAY+'BY'anb;T5XXm]:-Z)M!AH&qk9bPhdBi;WfP-$R;BM4Qd'C\pYM8beRFHrofLTA`Q]GSA'q
	(\$:HUKh0i3m)4:)"C9YH7d:pY-Hs\Y.R3"=fg#qC>+/p22%(p`nG)t:,8]1pm%tq[aT^`FpIF5'N%
	t`r$['2ih,d>^L85]&\^I/!9s7:D0pd1):e`e,hr%]rrB=ai$\MkIOS@c-i=]hrWpX8bPhjPiX^Y?+
	S^NXUW7ik-MT6hptJ<f/c6W^G^iqU>DpMQ^)ObsRf0Y'8%4Z'r&4[]XhIh)\spq@M-Yo7&tAk,/+E$
	,#uT[]!0&$Apj_gP`h+")ps6$d.p1<h4Ct7#H7ZWY^'_19-'bPi$)0MX`-9>_8Yik3N&5Be&"!%J)`
	bmcjk#tjCNaF\pP-F9?ddi2r6'T+gjcUcGZWoQ^b=GD_g5ID8,0:HbE%7)'/&\4E<L_Sn/QX5mt!>Z
	6<>_?WHb2Rf:'^?DNM0D\pqUSh[2HXdsHlJ)Ct\m$]R+=M>`/k9<!C;:7`Q]0B#X=`5kU)?@QGZ,N?
	.qC1Thr;V(5!*p]+QHkT2W-Df^M8M+B(Irf]062pr$6pG*5L7ds4T@nk9+1!W=m:TGgY+)NYrY+g7L
	\u(`=R!DXLjU#uIgPEPhcoCb/[haA@e8kG1n*T]2%MYs[YNj:=u[g_GE-A:!$o<fDtl6niK*==qb[2
	HrM]]5Ib(,-otM)d4Ls%<\F@5=i9pp)BRVMZ4@u2\IN-md406P634K`J\pgV(d*!?L-(^rK@=J]7I@
	N82e#)(OWnU:+f%GGa!</2GU5Hl"k'-e7]`.tr?g&U*FPdE)!;-ouV-h5Dr"7]_$5;@Tpa1LXBrM$Y
	IQ@1Kibs[b/apP0)14A=%X:cKd^4F"0>(#]pd\;me=,i.<jXcnZ1r3M-\YXIBeCO]nfsV'!(bH2.?F
	B?gVLYo;\.R,ch;JNcbr$]Hns)c^*Ir9i^3F$_KoOPX6PaoiLML;RTpbH>3cU*K%B3O&ksq+#4n+^@
	T<.E9)Jhl!/Nj(B)_l-4?nh_pd039rrA,2eE$i=)*Qa<p9IsgXZl5=i\3UM^]'2`j*1J=IKTTMit_M
	!rrBkp5AqVMJ&+X)Ao03pR.+1-]LVJK6Ie2.ink!]iK"]<>%Xn;7<@E<]6d2/f=TI2/BeoI3kQ')q2
	q]Tpu9&[chN.ap2Bs2UVll_rr@^"JH#WErI7.`n4jMH42P@o:+t:i9Dt:V($"0`r(,2A^DQaT`Y&!<
	`B%n)V!?C`ppTVImc)@U1mWJC"f">^"H)&HMVgUBV*AO0Eqf1?Q[e=N+?oCkMCTf6aa=!pDuTed>lD
	55!:75\^\VNhC]+r3i/-tmEW6"ASc+=ORP^H>^'<i,9,+>.*7;m/lY.Vb7c:>BWF^0_.`u^ORf(k;Y
	Q"U\fY;u%[Jp6o1\$h*R.2Qk4n3=(qX;F"(u4o(;t/(fi=?0#Bf\,rc)%83=kMQfb.!]KW`go(QODq
	nBB`d9^Tme=m+nCba<.`Q_6;Oa_gWo^Hsr`H)XqmYK=&r<CNc#0)RcthD0L2I\!Qf3%+]Un]3V_LG3
	@'&ML3p\S7MsOogpL4j^:<qZi1<,q]rrC8c*o7dN>g_St@@%i;Eo$GCCn6@YIn*ItbU!MD#hA$6+8c
	Arc'O+$eDZHola3mG"[T\+%$abm_ssqFLVd_%o7NrrDh2Dtk\-m.KmE<RlT,IN\D]_lN9BimcE3IB-
	4`Ln>%u[IESWX/sB[/mJ3O`a0aJ_k.Jm2nWtSppq>3]s:1jVhP-N_,A&+L#2t3!8sfj'tt^dAFZS:?
	QAtfn[F(^"ZO>gle_n[INI'LnR%%of<;hWTLYtOXSH^MEM-\)Sg7EML.N<OhcTG\#aR15p)j&U?i1P
	3_r'rUmgT,!n3;JQ4o@S?]AUG]g@'do<d[!h>mE[Cm5ucUN>#+&dPWUl6ol=4^?<HR9U[8fZn>iPA6
	p)"4I8>AUUeZ+KPu<^jli;MHi/EmB;186&.0h[J-m^!J3Sj^pcOV@r"GFrmdpGY6N*6arr@[13r]2r
	7_eB<rrD[Eg5<Xm^Yl0m!:WM9LAq8C<T!RJTCB(60_jPa5Pup*pf`1#+7P$K=q7turrDgt?gt4Ihu0
	DM[chSCZG5@'f_plt\b!SCY'f^20Ub5aPTTBbhhM.2n4GA/?[qRK^+f?>ilCsM^\Cg$gA_0BR:ob6L
	boY;<PS%.^;9c;rJ9lZJ$jdb@paYjm9&q/ZYd@Ip!Xi6Sj(>]?>iP%/,hi<bLcBql@-TI72:V#Q@JC
	.?hm,,mE>M0A4KW!!7TMW?ftGh!!Gjm!0jX8_]SSWFKbWulW*qXrrBJ4m+nCbfDbiW5K7'`T>[<IeU
	/I4r+5A?c\&Vi'53\tQhn.MD0'o8G1W#qGO2b^';J_\XEOomg?a/fi7I=Hrr<8Br!E=`5A?aB?aRk.
	rr?d%MdA*hILZ(lgVt.EL3:fJGWNl:eo#?,0.dsbqX24$]XNTXm?scZ?Sc`#>2#M,(eHgF[aq"t5^u
	=3&c;[gT8Od$r-RqF`jS+cILZ(;i4g!$"3%ih<I_A<1ZKJcqnp#<Nb+5Qa4g0f7dAkd73[3PkDdq=J
	&ZEeQbm)AqulfDnS@'4N!;CCn;$"!NW'gjJ]&(9*;[-r4@c@FDYEK(AS6+m]Uqr7X$>H3Z<GK\UsgT
	O]Dhl<c$qVN!4Pc%)bp2jrnG2q-cI1]MZ3\:f>Q!h)W/MlXUA/!(PDW5iGT%fRKP\FQ/S8U_jZ=bB5
	sq.GH3ra>=VD'</s<1g<K<hatQu:BW4]l]BoNCJb6/D)it"!-t`F<5/4H`rj?+R.fHu_O+1Pef_`R9
	YWqKBn>GtTn;iNNcQ@CUiCEen?ePE1nK!@VVJA6%r$Pha]OUI]n*RPe@l92e@))5kesgU=\*kn"iL4
	-1]Tr1*B.%srXda0TfEHaOhsadppao;/1]IFX\GlP\P'enOIt;][$[btL#NHoZ0B))R4D""p`N/rt-
	h0p_`_VXV(&n8k]HuU/0$<?]n@+4WF?^9!H;2>Ef"NL#gt$dgZeTe7CY5>nO8?u%`c(W%5Pu*<p1=7
	(Jtm);*;GBNh\>k_iD7KY"o(7l!I/8:ItFi*2/=.l#heN)pP:Z`%X>V$](4%?lZuU"Xn\g4>,@bC*V
	Y577+Za[_ft)ZXYpQ6#jMmL?Lk\6l#8ieIQN%qhg3n1IM;$.+7/n%,0TKMipOLSh.cRh2Y_jn7a&eX
	)=S-4FD`6#f[B[VV0F@R\FHEWNN%g$92/Ue_g6\kZQna=DR$*B]oK/kR/@*^,OqQ&g&7_Z(%?/#mC&
	qQT8[+t4F#HGWG5>ehb,;mXkqiJhCJ-:M`!)Q2_jPX/Xb/%>N5$jAX0B>gDrp`RsUi!rjB-%pbSP\"
	(-pK>PA!BgVV'S9\3Hlm,<8ZrQU:>Pt:6oIPnj1@s)mGb@qnne02)24RXXqnpHk?UbDKj&,[%Fp-J]
	YJnA]ML"F/E&*gk_ppoBI3AeJer,h^l/V^=r#?B4ji4-;dp4r>\.h*T:IM.tChE/i$57Z=M>\]=<@/
	_P(Hq/7SBt%-so@&;=MXB05DQUZ;Rm)@Nq=$o57u'81r#5?)n41=RrrD!lpd+E(_&j)537CA;;p1p1
	(W0EpL32,:&hi(!X.)g=.uU9&gTDfipGm97e7bSe^ao4mrr@\^^Z?El"Ma<trYp@PL]+&"qO+P3chJ
	t;r"F:j5O_W:J0#9s"67^a4t?>3U\I4:%u:-<gN\@f)HN!%C0-jiJ`+;!*Xd`nT%@+U[>r8dfAZtqo
	X>F)ZmE_aCl.^U/Q<XIU>F"mq>pM,J&.m%nraNCTCue[&cVk(I/_C@red!91]IFX])Mb^%X]T&!.nO
	)Idqp.mf@f^pl"Z8=RgmWmgsjf\a]V!MnD"-XWL9DdrkZj)LOd>UtWa'=u;:^pX](G&+&YX[ul-bf(
	t*D^[E=r&)M&D,c)j=ejok".&[7GpqPbUDtuPWfq\Pk@LrEAIh?Jh2uX6orrA62rMG)2l)+I\eOf8i
	^Hhf!i2M4q6XPO3n5Q$<rr<RY06mBSVo16BRZGADL<8rAb=D&WLHIMsfkOPZidVMaTDM7GI;20A/#,
	;A/[(?KmX1LGJ%kAY8H/\+/O/0\^'+H9Jm/'qpkA3i^crM1>ObK`pkA5]rZp?8r\)[kI2_uY^4-Q)*
	Z-qTZl1a5'3^2K(iI"NO.GH=3dnq=g!2e)P?Z^^m*c(/nqnis5V)c/rrCukht!,KgL's#Nro=]lCmu
	s?g?$Gbn'3Prr<8Nr!r\6rr?ePMr1oqMLT?$MZ*n5r\&%*5-_']=$Z8AKJa2\8!ca8Y(P\8TsD>\AR
	!jJRbpAbl:/9hb;I23@3\CmPa#_5frK>^JGX-]#SI(:."hJU5O:o1a8W4`Lpd*d?RgNCJ$QM6q\"A$
	56uaMY7#TY=n04Wn:sNbFF?*e3rP>(SZHT=CE=tW]N$6/[T[`0PS-?'Y>&dNgU>^ghD]r@44i#*%p&
	X2"Vag)&+Ti&!.pa?bhaZEOah:6g4/%9Lif,W1<W)\Z/X(@GSY"dBV<qj)#2]`\aa=MX_u9HA:f'04
	=@2oEF(5uf+I9D`O;P:cSsT8gW3=iB)R_(i9VNkr$VH2INJD<rM2Yj08R>*ppKV'_"o.(XZU[_%i'>
	$4V-OH[tXItI31r1r)EuXrl(g\:LCfaXXt@-;JEE2ZI;_%A%^CZXgH/fdm;H4V(_Tm(]4n)p.YJdJt
	.(07UM.$2RVL>MI$kCmW@=gHu8Y(EFYkjpHm>AQ<V-!7s/t(/@>p/`VpE0N/`:t%u;cLRn]@3;ObQB
	YD2L'NE5WAq60<!r#*oAFO]Ip(B(r=)m("2hUqUUp3+q:FZX_[AMMoa2"-BlKrs)q#El3=)7(,Wq9C
	h_7+ddPcVAIPGIgFS4VN$FpNQQ9raUH9UHc4hO+6)_+16<RIqdd]BGu)IJ)MQZdJQ#_cN39Se*>LJ#
	4NF`/PVjmHoO!ARsR0gX[i,PR`<%B23+.9X5Z9H<P5Qa[!aiJ4W_N>')qsihET\s`4rWSr"@K:DO]Z
	\1@%?uJ&WL!`IAs%SJq06MW[d?pksP-p`X7$i2i62(Z,\o?O#fI<dmcL=l*m02UfS;QtDe*NPApepb
	e];5lI07GN%G9rrBD2`/bR\f)@,fVPA"0BO2G*HmPZf48:io9.?1l_XGE,"1QlEB<6?iq`a:)ArfU9
	]P-.:e:_`M^#=rOc=aL[l310t<CBZ^MA6^g<E2nM<DeHM:]dZ"!fV-`2(D&67Q7W\oX<L-QX,rV&#+
	q3&.8F;-1CU\^\jpLp?2GUZK%tb!9oh=YP"Tmjs0T7rr@[\rWN5PrrBFP`a@G0`1OF2`NKO4^DT.DF
	5m^*_`Alm4<8jGkgqaOQBmMC@s<DPhHWCHBWSLE0:BACV.iOo12ZC.]CeF<Q2^j#'#3NB?a//\OW?+
	T!)HeKI\p2k^Tme=m+nCba<.`Q_6;Oa_gWo^Hsr`H)XqmYK=&r<CNc#0)RcthD0L2I\!Qf3%+]Un]3
	V_LG3@'&ML3t'<=`./=9TC98-4YsTE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!
	TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:
	!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!T
	E:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!
	!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE
	:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!
	TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:
	!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!T
	E:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!
	!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!$q5=5mK$]"`^jZOeJF>@6g!BA.ZL
	I>%O4qkFG5.Bt;j?Ph%fQPVos^?&r[ilAjr+(gnHrAEK)872*&goAg0Lf2g;f+i,DGJH4lR7p\N;*]
	rG)7\reUOrHq3sUn>!l[hDY/*j51%<2"5CNO6o.Iq#:?53Zj!%1T0Y4,p.$V]L@7HBi^X^.AS&!\rS
	9[O7uMrIU.3mrX79V!!J/RDga71iZHofiU3I'1Sq_*i%GH8;u!D&A9FH*U=B/Yp^>([D"%tAa<'Uc\
	Lh<7Kd<'-k1OAH!&7:'9D5[iUd&Yp!$5GD9)YSM1&0YckDLr?\sh2g'^F+<UNh)8ZPfB2n:u^6f$hM
	8%+3_F'7XKd=%C[1[4B#YIWN-9c]u)7Xm\2tbGWZjJc;L\nI`h>&Y&c\*<-#u4T<l\r8VJj!/QY"i/
	HRcGj#),&a/kgrrD4$?fe+Q=0RI*II$f]rr>sSpk[u0#gNAL7ui)h*e.q>rc,;p`((p=7W8,cF8l5r
	oD;Pf!:u2Ro$X7n@1Ml*fD,IHV8)O4a8?O=rf8'!!9--?eURMWB`A'gN^)H\ht20Vrr<Yop8e2nk8R
	diV*uHB*Td%!ncSh`J)V]6p`h`r*]a6#`-M<]rrDl7dJj1Y*.PdB^Zb46rZfbV=8r9G2S[F-MEQVSb
	O8g!#Psbd!5qALn4%?m4ELN&M"CLDrrDYMU])Gsrr@X,J'm;Kr(!C5YQ"TmD1@k:'RL+0QeoKu&+qO
	S!/QY"i/HRcGj#),&a/kgrrD4$8,Pbprr<16rrAh75PU:([9rq6384B4/Li1B&FV9cIukc;>Q4[8*.
	PdB^Zb46rZfbV=8r9G2NRWhj8K>/rr>QLJ+4S0C;9af[Jj?/;=#I_?[D_P+@"AbrZX?%!.m"VdGpks
	8"\M=rrAR++7Tr`r"5FtNu\0"i]R4jJ,J>Br3WDtfL*<cp&74+WGh]&EW6"AB)_k+a$9?[5IFku!'&
	[siZjNZ,<,QB3WB)tH2XcC!;XXdq.W\rY_RLPlhl;5!)h_LLu\I?c2Rc6NdpR?IqlatEO:567j%4iD
	u)S;rr@lHqc3Xro8TsEd\;e2%eBMKq#UJk^[VoVr"5FtNu\0"i]R4jJ,J>?rr@k85N%LXoQ]R!!"nD
	fX8`1_)dh^'739;djnGtL"8tlBiZjNZ,<,QB3WB)tH2XcC!;XXd]R2(+!.r^M_(35Wl?4(1J\Q'JK(
	*N$Vj*WmVo0$7>PL?-h"Mjl\$C\b?I:kBNMtXS,]HuP]Dhl</hWX[E8*P%mVD`dW2&!8]Y>!J"9#\#
	m70t&ln%g(-MknadkqMHD`%D_::c&O:VO0FNFd_,cL0BI\%&l<-WqUa#p)*:ATW,p=)7_h5@M>%.Q?
	airr<2qnNDo5q`Xj^eZJ`d[t<dLpbCeXYImg'DoGO9b?Wl>WH]cTp)%n0bLp2!mh0k+lbbn=NF\G/[
	HLM&P&Ku/rr@XUJ&,SYB-6mtO2C9k=OAa<4qrB\pi592fD[T()=]nuDU\AZ8VTNJGN4_nG_YKH2VZ2
	8%7SC!4-'t"Xc:qemOp+B4B8<Co3^_QlF>-(Ts!^ml*gT#m_JdFY64R]qc!L=?aDAO#-[nkI!YQXn6
	4!*-C[aP&q#2fT*\ii#d3C/6diB57b:VkA_e'Dp3e"-qJY08KK`(`5E0UV.u4$BkMlsM!"sOKp3cl?
	Jo0g3rZ(FIM0jTCpp9[oHTN6L=n-XY/G=:rT*9>];V(;1d<mSd$)<R@2Pk29Y%u8GJ)L2g%GBG!rZU
	eBn\aC**I->u=,Jkr*.16GO,CXoGh9l89mu"3(jOfR3k'uo;6O<3WjUuoiXL)!rr?*Lm[7'TXtQt*R
	?^_6*@dgQ[<XrC.p`/T_#6=qrhMUT!;mfmrr<1DnD9i7Au#69kdM?VXN"NJi;WfE&`UJdWn^<dG&#k
	LpdM8u;DENBAQ\C=RKeN.1Mq2M1q;H5&]ae]S,SHgrrD%@rmcMrj(nS"W3&49HctpY!$FMU\,IR2rr
	@X,J'm;Kr(!C5YQ"TmD'/9[a8?O=rf8'!!9--?eURMWC](Q<UY%rH^@hIjJ#RAa6ui5,"D7Z6UW5Uo
	O$C$Zrr>%45N3oKp`h`r*]a6#`-M<]rrDl7fD0,X8$IboII$f]rr>sSpk[u0#gNAL7ui)h*e.q>rc,
	;p`((p=7W8,cF8l5roD;Pf!:u2Ro$X7n@1Ml*fD,IHV8)O4a8?O=rf8'!!9--?eURMWB`A'gN^)H\h
	t20Vrr<Yop8e2nk8RdiV*uHB*Td%!ncSh`J)V]6p`h`r*]a6#`-M<]rrDl7dJj1Y*.PdB^Zb46rZfb
	V=8r9G2S[F-MEQVSbO8g!#Psbd!5qALn4%?m4ELN&M"CLDrrDYMU])Gsrr@X,J'm;Kr(!C5YQ"TmD1
	@k:'RL+0QeoKu&+qOS!/QY"i/HRcGj#),&a/kgrrD4$8,Pbprr<16rrAh75PU:([9rq6384B4/Li1B
	&FV9cIukc;>Q4[8*.PdB^Zb46rZfbV=8r9G2NRWhj8K>/rr>QLJ+4S0C;9af[Jj?/;=#I_?[D_P+@"
	AbrZX?%!.m"VdGpks8"\M=rrAR++7Tr`r"5FtNu\0"i]R4jJ,J>Br3WDtfL*<cp&74+WGh]&EW6"AB
	)_k+a$9?[5IFku!'&[siZjNZ,<,QB3WB)tH2XcC!;XXdq.W\rY_RLPlhl;5!)h_LLu\I?c2Rc6NdpR
	?IqlatEO:567j%4iDu)S;rr@lHqc3Xro8TsEd\;e2%eBMKq#UK**sTL<YFk;XYE-8cY)2Yop=/jVH*
	1lqgKJ=&+,bM>0>d[/<P,l`g$H)*+6&9HK68bLqGQ'Kb>,IV]&3&qGNEW4E[bJ-ME.Am-A#c2@[8?D
	,*jYl4E<q9'!E7R%$%-a.EKRfrZcR^`W#o@q>UGHd!j`an4t';7+6T,HpkaEO75WajqZGH!,(bWg6M
	ZPi!K%hkUn"II+K!,X*cbRr1NFmW-CMccVJ>o%/T[SiYuQ;_J,8GjaSZWC]&__!*Etdo/H@nrr@YTr
	lAHTVsL\J5MDaIIQc,n)>JR;G)msL!:9gG:PcU%Q_nQ5")faWVS0T*/"'ubf7"UPL=YMQ_>Z'l?gRd
	m'j8EIcs'UsP/ghserBTWJ&,+!i9"s<?QV/_&pt_uK(Y+Mi&AH@Bs':nO,PuR5*>BMicI^t.CC`GrJ
	FnY-Le^rgA5B`OLG/h&13,kDtPaqBV04Un?%FBV^XO+CN"ZPIr^#[rr?ncfb='``.,-am3hC1i;TJ?
	`H)9>r,;*1_jX)Qn#`HO]"$4:+!pf/UJl_ph</MK7FZ)pcL)6^YKn4^rXL@V!.m.D=0l"6rn2HMcNf
	fN9fM!Km4YQo2k(M&.#1^K4q1k5f-Do)Z@/>0?RB(J9sT"UNBbTb>1WA=&aJ)1^Z$8<;qL]u@e+q?=
	Osm\qlNdteMR`6)I'907o@!dHct`uR9cVu]"4>%VNIF?h>0sMPmI&HI[4@'#Psbd!5qALn4%?m4ELN
	&M"CLDrrDYMU])Gsrr@X,J'm;Kr(!C5YQ"TmD1@k:'`E\HbO8g!#Psbd!5qALn4%?m4ELN&M"CLDrr
	DYMU])Gsrr@X,J'm;Kr(!C5YQ"TmD1@k:'RL+0QeoKu&+qOS!/QY"i/HRcGj#),&a/kgrrD4$8,Pbp
	rr<16rrAh75PU:([9rq6384B4/Li1B&FV9cIukc;>Q4[8*.PdB^Zb46rZfbV=8r9G2NRWhj8K>/rr>
	QLJ+4S0C;9af[Jj?/;=#I_?[D_P+@"Ai0DINUrWpn.Z,E9C6t)p7ND.*nrrDFZ$pgG9K-\qD&WR])1
	&7W67#j/#h9e5IAUFd`!.phm_*.euBoPm.622o+?[N=QLPb[ac*itsl257*iBJ;sdgi@RGU(5Cn;d:
	Q;oeX61i%dE!,B9i)N%k<5Ks--&+]DmQD+<6'Nb*OrrBkmrrCukrrBKGlk?LGJ&36XnQ*'p7fLYOgt
	LKI^BhP!CR9@E\)E;gIC)pGn=Ra)OhTEE*HP_)$\)gaB&[Z#^bS$]48^sKIsM!tD>oS\Z3TcHn144n
	p_Da@g(3n)nSDMZn5"o#2YYc]!ZPJ[paa;VYe_Zoi/\i@Z-RD:KAt,[98HLB`TEW?o%%S.Da_:hHp=
	Xq>-7c[V^QJ`m^Drbq<uZ@Vs'k4J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J
	-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^
	!J-m^!J3Ol8i44@,;OKc-S,WJn^8KsD"5_eQqa5aG][VBKr!@sWi175,;7,f!GcTh?esA*eCNjF\k=
	E1l]!]#WL>peM`S/@cX=rt;d]Y=\+7dD%orVT>Ra/%p0+dE8qVR)drD*@m>1YXF<pk>5;chNB9<#,&
	/Q5Q^\p813DtOLkk.A:=\<9LCMi"$>S_`,fqE+]WK;O-3]h@ABr"Q<si7qDXrYGI!^))#A_%np@8C(
	g/?1A.iZ1tH\h-g[_/8"nM9^u2:r&^j&5$H#,!!o.'['6[W[EH>VQf5[hl[CMW(4kEt%-b5^a,)oUX
	Qb0SnG\J\Ts"&oDd0r.:"$E'<H^fHS*Ts@HWX:9<MbgAFKWb`jbeItB)ObDlaS$3rl2^WhsE/qHi-m
	)i=G;"nE0VfgADLJW-Fe:\<Sn3"aCPFRV%(chDk%2f`'.BFS9tA><#dR2/R*f)6>Y8.ok*-=hjXKn1
	XbLr:#);'ohDD0Df.%QM\W;2TY`eLHYld+%t%(*?ORclLqYM2"CJ/3erQ/Q>\BE^:<YCKk-?#n=;Hq
	rUBfLJ)H^OYU@>lpa8#eS+-FXi'2m:m4rT!bGK"1-MZKYRn26#rZV2De9'GBif.\Ga^[u0d'VPl3Y-
	j"knR8mn@kNl_]m@)9rVLWIYCfYXX=#&'(T+Q\,<u;Jc(ja`$$5-0Dum*m8*`^JKG2Jq:j<s!"ag4`
	4tqbrrBGkrWITprrD5#?e12O51Y5-roO,c?_;KHnm27q&;5MN^[uRH!4>&j"FMNq!9\8jr'D"m')qs
	ZbPp#k!;I/qQi@&V]mj3B;=/#ocgG0%jn\XYIjO"B#Y45Srr>PBqc!Lpi((Xkrc[p``$$5-0Dum*m8
	*`^JKG2Jq:jNoUI?6TJ'@oRra&s(FpISDrr<U`I`0"nErQ-I5Q1e5-3!u.Db'^l&c34@!7B!heGfOD
	&b).e!1gfQ=u9+DBDg*D?fgDFpL&IshsgtBlq@?Y7kaa<rrCtI_I*:coRFe&+0dKt*5Cl:rr@Tl$%M
	d*fCbn-*nGhbroO,c?_;KHnm27q&;5MN^[uRH!4>&j"FMNq!9\8jr'D"m')qsZbPp#k!;I/qQi@&V]
	mj3B;=/#ocgG0%jn\XYIjO"B#Y45Srr>PBqc!Lpi((Xkrc[p``$$5-0Dum*m8*`^JKG2Jq:jNoUI?6
	TJ'@oRra&s(FpISDrr<U`I`0"nErQ-I5Q1e5-3!u.Db'^l&c34@!7B!heGfOD&b).e!1gfQ=u9+DBD
	g*D?fgDFpL&IshsgtBlq@?Y7kaa<rrCtI_I*:coRFe&+0dKt*5Cl:rr@Tl$%Md*fCbn-*nGhbroO,c
	?_;KHnm27q&;5MN^[uRH!4>&j"FMNq!9\8jr'D"m')qsZbPp#k!;I/qQi@&V]mj3B;=/#ocgG0%jn\
	XYIjO"B#Y45Srr>PBqc!Lpi((Xkrc[p``$$5-0Dum*m8*`^JKG2Jq:jNoUI?6TJ'@oRra&s(FpISDr
	r<U`I`0"nErQ-I5Q1e5-3!u.DdNeLeXu>EVo528piB@'8*kBq8SR&sF_`DdSf`Z9)#QI.i%8_CL(mZ
	(qB*Y()cY<L1OH3/3,%\qr'B;6#O(FCIB1;J,J1/RImj^GdncG+kgF2Al/ha8"8l05/:8c=RID`d-]
	5VNr*o.SM*;mV8ao3HqF?Ej)rf[/j%7hoMrfgViq':T'RBCrers>')FgQ<f,AP3V;5;>\lIkSRsAjl
	2_Um"S&Cm7P>dgc?6[u`4YF4;lJ<E0A^L*cr?b6G_g:^TZe#%;WP+#)]3jcJc'pSnWMJ?,eiJMsq)<
	KG6i4Ip!(NUU3Ih#7_;P=ng/mu9nL*^Pi8"Igch;qgPr&e08Z?J`2Xj"Vj0+$"QU9`Q?5_AX;&`hk_
	?jjpH1;9[2n)]/qG"\nik6DM*W@OViVrm:qWW\/j*eKrjoJhjrrDO_htSE4m>LuE"YR?L`*WoE4Y,L
	C_#5o`P>0ZC4T%kOd*oWCDlmPIJ"h0C_T($m>k.goM!\-bo;qRG;5*5u9+@MMr(5l3Y:TV?%K?E[@f
	F?XL\qhgp=f9fq_KhSp6FTT'l0.>rrC!p&8C?&c@PK"_7G'8M*,QrCN8I^'qVJ+BpsPL,<d'Z\qXu[
	Hr7(\IqXPpG=VZ5>JGob%D3#:GJG7/pf6h$_YR>c^)hYcnE-"p56gm]7"sUK1bTC'[ZT6WeeZFRb<3
	L<&Lj1:l?eHTl\:l!qW?r2H)Gqg;j0Y^r"l8u+3Bk#J)JZ1fquYUL*)8E[I;.#'mPNc?YIs%$fKnCG
	R$YmYF4SL)D8c@`2huhbY!UaH's&hGMhR-_qKUY+WmsBr>`T>:]CEG*smGmgXl+n7:GRrr6Oe<jlQ=
	4@"0K[nH_YO9E+u^0De]J!8pAa?iG6@J&EKPYqQ%q^[4hs!.c3uJ,.jNoqOqsepkpCjo/RnT6:J1?2
	jm9KRUkSoQ's3[6OWnHmSdmkANlg64s)-rrCHirm^rJp_!"^rrAV'Ip+[+m:Z@CmU,);q=e9H-/\4u
	8*inK!(S^>;uZjU8&AX4G4^:&+WmsBr>`T>:]CEG*smGmgXl+n73:$0bl6`'?=0=J#P)1#!"ag4`4t
	qbrrBGkrWITprrD5#8,P[cq\&o/dEDO=rrDg+n<a.TS\9MV1f<XQr6Oe<jlQ=4@"0K[nH_YO9E+u^0
	De]J!8pAa?iG6@J&EKPYqQ%q^[4hs!.c3uJ,.jNoqOqsepkpCjo/RnT6:J1?2jm9KRUkSoQ's3[6OW
	nHmSdmkANlg64s)-rrCHirm^rJp_!"^rrAV'Ip+[+m:Z@CmU,);q=e9H-/\4u8*inK!(S^>;uZjU8&
	AX4G4^:&+WmsBr>`T>:]CEG*smGmgXl+n73:$0bl6`'?=0=J#P)1#!"ag4`4tqbrrBGkrWITprrD5#
	8,P[cq\&o/dEDO=rrDg+n<a.TS\9MV1f<XQr6Oe<jlQ=4@"0K[nH_YO9E+u^0De]J!8pAa?iG6@J&E
	KPYqQ%q^[4hs!.c3uJ,.jNoqOqsepkpCjo/RnT6:J1?2jm9KRUkSoQ's3[6OWnHmSdmkANlg64s)-r
	rCHirm^rJp_!"^rrAV'Ip+[+m:Z@CmU,);q=e9H-/\4u8*inK!(S^>;uZjU8&AX4G4aI;i6\[[XMl<
	;p6trYUR7g4A<m--bo02RLu([diTq"'.hH#ERMM#TcS]dX^TBOFp9Xa2pFl+.r;3]_cfb#Drr@[F^M
	$u.^)PWcDu1XSC!hEDkVT>c0BMt1j"1JmiKqKpRqPi$-)ZI)Ofdpj$1Vo1Wj0dVqPDeo>2hH/g;,Eq
	db<GPr_5LNiL^_W0>r2"KR@."lQ-i3=,&S:m17-A)t=]5H)']:(:C#Ea_.R:3kglX6Z7CNC,Ql*8T/
	leGmlVIo1&5nM!9fs!,WYR2?*[7lHf5Q(PO`mKt95@'Pl["LTRqe+*\l2nBZX"BXcH,bXph*!r.Lc5
	7@5ga-t2i_C!l^)<+`EHjqC_QL/gqkWUNEmB82'[d\a2D#.)1gJO9Gd7^V>qJ5!'Y(?L%BjN7Y2MJ%
	'QU]@"8$;(05E)tm>o1KV<gB`N)K)&(XW#5^dsOSoV"g+mdc)3OF%iq1#*#DDQF8iMG?20K`g<Rf:r
	8R-(=PX17=N@._$[s8T)(,<'Kc$RnAg,E,$7Kdn2'#EK6?^Bj#*"A/[BVb5gZnZ2b``0J:?)]%heZh
	`L<rnB<4H/p@m#12UB@Jl*j^IKsWcmmb3P8m""Ifi0sZGn3F23+8uTpU$9<+j#T]sqtiHi/FB;3?hf
	h^l8P&Y1P-".Bm2MR0*,1uA#jjkg=fCbrr?qO>*jqj+*Am3m@B#hmWC$ARfr_Lr&+KS#(Z]pf%O(Wp
	rE*3rLu1*ED$2);=N.jnCtg+<4IYtIj[_9F?^[M6+Z#fOaPE"j(pJ<#L;hPc-Q'nUZhPMLU<U*5gV@
	$4%%A:4Z^VRd54Q=`nO281jpTB[Yi7&de(42as\h5rB!f]Jf?cj)`V96['bW:+Gh:2;5[[)XZ#g!X0
	U?dFfrN0-/\4u8*inK!(S^>;uZjU8&AX4G4^:&+WmsBr>`T>:]CEG*smGmgXl+n75&F@k'qFO!&$"O
	]*%j]rr@jA5@S!r3IfbTrr<*a')qt'\"ipG#lTU0kiMgEC4H-epe1VecJH=<)CY<crb(sYo()_UYWn
	<>pk0mc-3!t?Qi3o`!:V5l0E2#6H9^C#O4]fuNaMLXrrBiqKYRHPlh]#'O)$uBIrbPh0/(Y`"8OSL!
	/Ns+@UJslJ(gOp!!5=srrDZ"U])DBrJ?$fjo5<qJ,BTI9E,";hS602./("HBD4(Mo)/Bh5E^B.pbXA
	l0md,XYl1JLC$TQdM:U8;nNI[p>/N?*bECl1*s-0)gr-:<8ITgoN?\:Y14AHcEW*P"i7?f>fCitKY.
	=']p1X!ASbl];)aLd@eFfF>koLSOn5%'k4&36hH"GC9%[ska1nPj[@r/H!U+ZuNMVlAhnj]8)*XTK)
	RN$2;Atju[C%$O!D_L\Z_#FBHM;XuVH*+5XQJ1KT=Y9%nkDeGl$/oqFYg!l5A;Y&r<fU:X<+ss.5L5
	5cJ,]M#/:YK1]M8D+"PNaT]KNIa>/$[`m,@JE:slolqa1'X%("[.iRtB*hb*[+Vq@eD\a_&b>H@S-b
	Ah/*gNAJZ]L1Y2FT0ueX'aI#pc=?4$,b_/K"hoq$i>3s+n4TsL\raolbqDh"o.DZl#@):1>h+^p208
	SHopAHCFGFbDftRt_n&X#5N+#+Fg\W@`*O,VhRQ:MDoN]dbhpKaFJc'*D'&#Lrr@TGJc=ETGF"\WV6
	6Mih-45g?X#gA@squP=&tZRQVf=-f2f@71W+3LE=9fD1IEBU1ea'%mZ%`[YJu(e+=HOoWIE9Fn4N0&
	UL!C!o4f<tpg']]568DgE:Pj65Q!!:>(7$,61-(_8LC&"Itl/)X1^i8L@_:l/hX"_dGoHLR'&?;>>K
	A-!C[]#!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!
	2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!"8nS%i4'SI=246*+5;r
	obDC+J:Q3m`M'UM3NjcNKLAX2C@r<0@+tH;:CO991pfQL3&O1Gj]XRkH6_io"n,*mGp'T9V96IhPrr
	@eZp_S8'0d8V*dQSgf>.p8kJDs+cp;YqNL/$(N7]us9n@PNC=8Wikr_g<(F8l6nERfR2bG*T#rr<1Z
	rrA:VI_gO-FWUk'oe4e[[QhZ:i*Z=O+7$1#'NYhL'N%+!'N%+!'N%+!'N%+!'N%+!'N%+!'N%+!'N%
	+!'N%+!'N%+!'N%+!'N%+:"8c-`[Q<%,\bes3qPCK(Bpu6@08s(PULu4<*Sl_L_nQdeh:kItQ,6=8/
	<RZd<nd@M#FbYm)-[%?B:mmnr_:#uKDtqW+n8q>!)Ph-^W%2'BPfD&q#UFtJ&.k**h.BNGlH'=+Lnm
	`FY+F':"Lr'fj$$ZXBO5pc\1\8/5"((/mU<GHZciXQ:86Jnf7#-FKb<nYOgcR!/!UfjRtfPJ,;*[rr
	D_/r&V%R*NZ:@!"rWlr?VG@72;0n'N%+!'N%+!'N%+!'N%+!'N%+!'N%+!'N%+!'N%+!'N%+!'N%+!
	'N%+!IV=5IA@)e%`4te70AF*6eY-3*>Ar3@a5.qn2Fs>jVr9]OnP5!+fqXf7>&-/VNRG%2Q8XCY&jn
	E"anf@OSU^-15P[bRmHacPB!_#_rr>mo8u`sQJ&NMS!WGN1rNh!iS/Qg?\qg1t6WK<'-e)t6rr?UN5
	18r'B7e<*TD">U^UB.!7<^qZVTUIh!#+&'rQ]nLRf;*Wi6BQ^n56CdZp4Ksp7e^i^VcD]rr>YVIr<b
	57<*iT72,`!72,`!72,`!72,`!72,e#r-uQ.H7#&[rrBk[r\%Vcg*O_iLAiNI&(\*j?gh+^F8SMTr&
	H@Y>qk`BC\kH"rH#W8]mlFBJ#BLJ*6J3\."_6irr?QD^n:R1?4O11$EgBN"9/?7r/`#aZ2Xe.OBu3u
	J&+$l0LKi"/CA23!4JfDX#h0ZEli$1rr<2:B5@7NJPQkGf=0@uD&W>dIFQU;h<Xp!YN;8Q%2o0GP](
	qdrrBC_plk^XWZUqMYNf`(WU\0]!fAD)!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!
	2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?
	!!2>?!"8nM#i3rXcns.PUTDm#oX8`0s>o'r2p`rr=V$$E!rrBC(pc\WWWICIF^\el)r_g<(F8l6nER
	fR2bG*T#rr<1ZrrA:VI_gO-FWUk'oe4e[[QhZ:i*Z=O+7$1#'NYhL'N%+!'N%+!'N%+!'N%+!'N%+!
	'N%+!'N%+!'N%+!'N%+!'N%+!'N%+!'N%+:+o=u`agZ`GJ+c8o/,oV7#HubS_cQ^trmP6FD;V]BrK.
	VJrrDnHlh162e^Hm"HEYC#lS&5H$3(!hf_qZH!:88arrCTYnERd8G/)@]rXB26!0c(6V>gP^egLIte
	[P&5^X./0X8GP:^\!`k72/d1'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:
	!(&?J]!!RHD!0gl?hS8c"58\nC&(IZP;SP9m!8t#0nr++6fDa$-it)-_qNY#D3<&u95FM]PMX1.[rr
	@[13r]2r7_eB<rrD[Eg5<Y$gA]mBi6BQ^n56CdZp4Ksp7e^i^VcD]rr>YVIr<b57<*iT72,`!72,`!
	72,`!72,`!72,dt)?0[A14RFh^-7&!n*h_)!*9thX8Ki8rB5Ygk"ke@(WXl!*W?3A!:&S5FaocYF\q
	iTpn-Vtrr>Ie!;JB`r_^B!\,O^'i_TQPJ(_!>WLEfh^YmM3q*t+uhtoS:!/Wr:U&P+)])JRB$D/<O5
	U`@aJ-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^
	!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J-m^!J3V/&rX3ZE!%D1O\c2Zr\E
	^j*A^P:Lrr@X>J'(SP@))S"O+Z?dQg+1trrBlPrrD.2T=7&`QQ90-!)0sUE?F[@YPCcqlkf[%B2S/F
	rr>sq5.b>&2?!dZ!2P2F]+e+2E<&j)'ED!!'ED!!'ED!!'ED!!'ED!!'ED!!'ED!!'ED!!'ED!!'ED
	!!'ED!!'ER28[+G5FGO5Y8!+\IV^]'mPrI9b`J$[Jg2?*Y'h>9M<!8.qYYQ"U$*ku(B%:(eKQ`Bt6r
	j)P(i6\+l4ce<(rlno%rEFa]X8N9=r:n%bd%C+sO4mt?c!l2$>CR-`r<I*f^VlJ^rr>VU'N%;2!C[]
	!!C[]!!C[]!!C[]!!C[]!!C[]!!C[]!!C[]!!C[]!!C[]!!C[]!!FMCIn5hjM7L/>Hrr?Z;nV@,E;#
	O#$74[pnrX6"$>=J<Urr<1qrNc*U@dXVLHscBeHn!Gpj\[;WQFHB_?.(hE"f7_58=E]>Zdu=f8Qf0o
	QH)_4^N=_%h&`9[8,Q$O5_#"]Ir8W_B'3Or.+eFO+9$uk;-39,?e^qF)7eAu$8qh`G)-(tTmkKkeQ;
	Ndq1%X"&+/)..'>62.&)5!.&)5!.&)5!.&)5!.&)5V"$b`+:\dBpa3XW'rWN6$lJh;UJ!a5cVm$"<a
	o;>hK)#0A!+WdZTD`#$%^5I2Y,WQGrr<`1O<<\Yrr<7^rrC2#^,Gukg$ei1rrCR[q_d!u1LJ<ar#.B
	k!%?_!g]%7d^[W]O!)u2Lf3d%P@8l3QW!*l4:]X!!:]X!!:]X!!:]X!!:]X!!:]X!!:]X!!:]X!!:]
	X!!:]X!!:]X!!:]X!!:]X!!:]X*X:e;c0#pc#@#:,IY!Sm;K^)m6H5Aj8P56b`5nAg:DO5^\2m?unC
	de)kEK0mp;'GP*0[A[TF;gSY"&nnju<u7n,a_cMcPl=pIq"sSgp7;!-nWI+4r*A>%kVPm*..F-iN4L
	Bk&glH3R<7atMs>&O8JPgfXu/kK<n[2;T-\rC_gWM:q>;]$Wl>oO?WBQl`8`!g?F2"jVh`*d$BpBB8
	i*S34Xn@L;lMX$HmX@&%SMs[G\TuVSiR>#G^M(%WD]2A(%G!j&<_6rUImE,#q$XQMpVFinZV=9n/('
	]ZWd.!ig5A$YAMH/`gru4al5H]hF6P#\C3Q#(9N('-9=Y:D\E`3MXV'ZrX(U]4))q`foI3?i;bA(:P
	J208P]5r,9$!TU:<2]k%.Y]@H$tYQ1ujuI\VPbGD@T`5?u3?GhT`M2,]/IN1.2TS1)[YDf2uEA[AtY
	q8P),>l(OoeSr'B&tZb9<9n!CV1,g"=qp&GlDV[/<k9B`TCDGJJH#WA.=>D#!5T1uJ,-dQrZ5eC+9$
	sIMkBbfn8J=,2mrEn7=$'G$+NA%I,k5,n@F,IM8fJp&N>SskO&`X!!qQ`!6H=nTCDGJJH#WA.=>D#!
	5T1uJ,-dQrZ5eC+9$sIMkBbfn8J=,2mrEn73D%+\3p7Cj8T,K\psX6J&G(@TDAA9rrBnqJ+?+tBDam
	@i'7/I?Pbrr6f?l$DeT.NLRNSqrrA`ciog:HHlN(cc0]rtd7=+$D@lgJT/ciNr%=WA!$WNT'6pGSIc
	/!1NZ\1]qjIHa%lF%lrr>BP`R"Gnpc&3QS(^*ck+;\S!9d>U\c2Y]*sV`Fo6Xi!FA`&<&=\>;kKZ<l
	!"5_)!6Brn7,BBm!2$bSr$.!s!$m$UJ&BMp"9/AJV=AX,!!GIprrD3TO8+!u^jl1p^+OonLV^b'hUg
	_W'S"%Ji=GbUO8f3sl2LbS+o_NS2i<+JmL0$p#iYd`aWJ'cnFKG+rrD[?HsH[O_%20Jq7WR&*bk*cr
	e3"`TD0T!DuTer[J4B'+7TZI6iMJnrrDQ"J,G+P`(f6`q>5dD!5^^Fnji+\r&iHd5Q(pr(I.CVi8=N
	PB`A'fRX>A?!23'FkPba7)ufo_m=#r#8,P\k&H;a&3<'!V/t`.D+s6=gGc1Oii4ncA+8h8uRK!6t2#
	%U]!(*$kchn@L2u`lIg-=QYT)nrlkYh2drr@Wm#6+\pHXDML;?$V-RtO#hc9M=/$`F")aG9[]hC8I)
	T=?QP,DZ:!,_"m*_p(@IrrCEBnT4^1"?m:p!9X!9pj&dQJ,0kn/q;f7_8#p)fAW87J&E\m&,GgXrrB
	q#rrDU5rr<WiMLXgW$i^24iVro"+1\$5o1so:!;%^f>lOf?%tfB-]qbQJC%*5DKeJ@Vp`]-Frr>!cp
	h*#;nHl]mrd<c+!:[RLr.oj@:#_f@qh"hJ_Dm&98+($f4O`4Qr<cmJ5O_%uhu7P-rr@hCHjBZOThFD
	.rWmljrrC=2IMpO'r'G94rrAZNrrDsLTDnm8+7U"hVuD/'^[R7*r/po2rrBl?I!)649`G*EPQ'3@4O
	@s<)bhEn*uB&?:J\IMiO65FTsp4XdUNT/%AhnZZuZG2[k'J)&XE@rQCVbTp`rr=V$$E!rrBC(pc\WW
	WICIG=oSI*!<3%_c2F?Nm!lbL!7D6)ofr3s=8\lsp'^m#Z`*X^rrB$IT3on>Xr`l>1!FU$;cI_Ggh%
	UjPNJ%)7_MDne>2c$:kH<+]=t38%U!,8.kSs7<G^s[E*,e&<u#EG9%5<>SYL@kk*'L2Y@XG"J$-a);
	-jji'N%:!'N%:!'N%:!'NaiArr<98J&,=g!,`nR-eI`Gn5&#@m(;d8_qkdjO,Z=+7H:!O=DJugHk#*
	rm^u$H&3OTu)p#4q;k`KC[]pi38(41/*PBeRmtKloI-I3Zq>1*kLm`bNY@$p.r!iZ+L*PX^rr=f3Wh
	h-ieZA]K!8r?-oXKCKbn^4chsh@5r"\PsMr0*#nAK\srrD1NO8+QurX/>u!(H@lhtUYE&:a9r:Y="j
	^OQ.llHdW3rgu#Kq1F189Y^'uYPKo$#6+\@&b(GQ!1=`ii[/%-/(a_9^B8uEM"j:9!6gED`dchArrC
	u,<dn*\o_G5rbT$O*AcDa^]mnFVn2L=`O+\VQaO1"f&Mj@d_-Xn?^%`QH!";B7&,p*Qp+u^:hu<ZYq
	Qob&J#CO+ra=XR'/07uli)h"J\U]mHm&Fhk!kF,M3n2Kp&>"\n%diU@Qk?Qo-6c1TD*g7!;IYdT9[=
	m5%q.?&,7;Dm="NZp>Z%%4?`5tp5JN"S`8O`HABHMM*;fgehjQ=kWTZeI36@qQ(>@IDDZhPfP.p+8H
	_s_Z<Su]bs(Od4*@aZqT5WNe(k"$7218#U5Aq!U5As@&)(gu9tU+OrrB>JnR):r:d'9B`YuVFkOtAE
	!0_=!T`5#YLjW;(!7VNdYOR@MRN"oMIR&BcJ+.,Ir1:sr0E2#aYs85i^P>hgK=1]+?gq`)r1:sr0E2
	#aYs85i^P>hgK=-tOi_/D5!2Q7p.&+$JU5C?!U5C?!U:_TAV=Dlg4r=4BJ$`k,^B\(6Vtdm_hnY;2h
	Dt)-r:ZH.n6#IH_I!hd6a,]tP??\\4e:q?g7FpP1mXJ)c"h?^QtM-4G=2@Jhsh@5r"\PsMr0*#nAK\
	srrD1NXu,6%[;A#*!5ej:T/9XFK7Cg5^[P=.qCd:%rrBqKn:U`@R2S<L-=?NufDQN#"+T9cpd+o[b`
	,u7TD*g7!;IYdT9[=m5%q.k#6+[ZR=F.u?h@\&%K?E_,N/n-!&?B\`([r8=0MHRIKofP_\)BjrrAH*
	4cKC@]D)=*_#CG5Xrlp"7=U[`r'\a.!!R]K!2B5GDu;=3#XA-IU])HKrr@YaJ'iW42uXYTKHL-5dHk
	NEhnT-qok3B*rr>i`/,[5ui[/%-/(a_9^B8uEM"j:9!6gEEnImSR($kjWhgrQ3`-`^-!9Qb3@mBD[r
	rDOQX$8+iqL$[tjph=j&Mj@d_-Xn?^%`QH!";B7&,p*Qrr@kCJ)IM;oNqG)rr@cui<TA_1,O=qrr@9
	3rr@WK=nu;ee)lPf!&/?dM3n2Kp&>"\n%diU@Qk?Qo-6d'7*GT1"a^1KUA*Sar%T9!5P^G:f['H0J,
	BiBccY5GT/9XFK7Cg5^[P=.qCd:%rrBqKn:U`@R2S<L-=?NufDQN#"+T9cpd+o[b`*[`J)1#%!8r?-
	ITI'Pq4bXJ)u_$mrr@YaJ'iW42uXYTKHL-5dJj1Y1B.?j?GG^;p`'55$qJ/Fra]^91]Hk#rr</tZgt
	VUV[&$*7H+7H#j>I,MEFtCB`8k<c\M/Y]jkF>(PoI\/Jgb#oUS/N]$rT3?WYaT[aXm)3l]l6/h\l]/
	g7X2L,gQO<(1C@k8"!s#7ph7_-su0qgA<.nB^IYq`/Fn3iD>Zn4U\Y>5eI$N!+4U=aX`SY*QQN,5@d
	&[\%+!i1C6fpY)L*i;:]uHWdbWX`MFlhifs`2i"96aNrS8rX*B:H%+JUT@lH9\*Z'C(ZHNk4S\?6^p
	`k!4p^q)/^t4A[Ca'GFn#9$n?7EsYH5qTep<&DK6M`Ym50p[V"Zf$2o?B,3aAkV[,&)pT79ZErnP9H
	c-F)n;6Tl(5Q(u`U9EQ7^UGlk1NTbt'Pm^8&,uVrrMZ`rrr<O90E!=#rOYoq'ug8C'Mng!'Mng!'Mn
	g!'Mng!'Mo%mBD`akrr=I!q"apiA&#gOrENY=YO`+)o_&4aK:+sc&76MDm!&4<rrB*X_:ANn<RjIpJ
	)Ys@"8eel!/"drC_)8mZi:$l(\)F[^,"(5FfB,%TC$pah\8@@L,@-Vp;&:5ILUZ,d\;J1F^Geq[ju^
	4)D00r7ie[mX>4"k>e@VD5LH,$4O`4Qr<cmJ5O_%uhu7P0poXPrJgPuhWqcSorltnj?i$pS'NaWYIf
	BDc?5rCRD38CtQ84a]=KH*Q264<5\\\ho;N'XgMc!N4d3")4+!5J<=e95.IMT($@IUdp;PL(CN96k.
	#Ob7,noo"RXfS)\F8%Ki*bk*cre3"`TD0T!DuTer["$!<4p1fbd&$8Rrr<0c%K?Fjp:h%"YB0[d2[F
	oZS:CMS:]CEW4AYa/]Mnh15B(!)7h>SirQP9ALRNSqrrA`ciog:HHlN(cc0ZVBo1so:!;%^f>lOf?%
	tfB-]s#=7./s:'9u8"Dk9'^(L"$&%j?rnjD\W3OceK?9&]=VKP!="PiT?a5rrD7\pppD)Jfb3s!:tP
	-r&iHd5Q(pr(I.CVi8=NPC[fW,5N3>qL]$tgrrD#"rrDj+rr@kE`BWtg"oeRUE;oq!O5/(VH)JH-q@
	pXrJ)H*u^\ls9rr<Qdp^dB)6C5[;r"/W^rrAPBr%k(.pk7EGrr>6&rrDh"5Q4&8i[41kr;FH]i>b)X
	,PO"n*bk*cre3"`TD0T!DuTer["$!<4p1fbd&$8Rrr<0c%K?Fjp:h%"U])Dq#_10jJ,U6[rrA/lpkc
	X^rr>9&?hd,%r^d"3rr@hCHjBZOThFD.rWmljrrC=2+7SktJH#WA.=>D#!5T1uJ,-d]_`B4G!/O@d+
	7nY;rr@c%rrD+IrZZ7prrCC#(]G#arrA3HF$JXGT)nrlkYh2drr@Wm#6+\pHUmure)3Ih$==T6n3c-
	krblTAcAFjG'6&a)q8`L8iH5)"q%3Q+Lmu@JoCiFg!/,=k!9B3rchMd`^jl1p^+OonLV^b'hU2?'%l
	F%lrr>BP`R"Gnpc&3QS(dcrU6#)&g`c[t5&pT&pg$,`6pKZXnPB)]_11D`5PZPu1]AG0n/qX`08lIt
	+n0FM!&q97_p(@IrrCEBnT4^1"?m:p!9X!i%-XJc+ZB[Vc^]La(Jk&2OUq5D]Mnh15B(!)7h>SirQP
	9ALRNSqrrA`ciog:HHlN(cc0ZVBo1so:!;%^f>lOf?%tfB-]s#=7./s:'9u8"Dk9'^(L"$&%j?rnjD
	\W3OceK?9&]=VKP!=9"TD0hlm-UaYCNqsgTEbV+lJ<>cR3F`dm#Yma`jFgepR-kL?%\L$nlNU$/,#D
	+$h4:#D1"#,9>]:>[fo[e:=S^mnE-]i,BC%nl(0,X8\_g"*FlRfQ%82>IkoMTT8`8`LFY[h:DoU/W`
	eo'<M>;ET6XA77MTHtfdoNsZu*KOga@uir@'D%@<1^?48[,uXbWq-RoG)Udu3*b6<_((XT&:&n3[1A
	":th]j:HS>&_%lBTbOp4c29!gVg^K#)j]>F#l)F9I1d!hHn"%g0"9epM0Am\/NW0)qI6[h2/./:N@s
	I\G($9$a^;8ZZet/lnE8ggem93`,]W`GnbpWV(><)iGdHU;rPJVmRLZ_^G3U_nOQ&D>;2X6'Sk/7M-
	IlJIOaf"C:CVCCJt5S8,n/N]VOXQ@_88gP(bOp,_7(nUMH?%?8m$sMigd#JK!G/96/iAGS^&'eY$#?
	tD+5@i<9!,mRqZn>`?c?r=(t,=@7$dNdY&pK^>blE/+^+8_S7@GD(jX9qSrO8=84rJIoU8UD&R7M`n
	iZ'VdHgOEJ#"`LO;%'$^S2`d>X0&)T429;-g8h((Y6Tdp1/iVsVD!5gSq0iM,OB)SJ&c559d(XXcl0
	#>oQ:BX":HY3YV?QAXcI\;*f,?Z^=bp%R5.S_Hf&&+f9^,a(_ES=JZ'GpJ^@a7SPe:YP_!i/0MhXs;
	3T7]mZ#=[O^VeW2R;ok;GsR*)[LQDH&g'WFp+do*:TPpVZl:S72"&U;0q%D7HIXQe?-36O%pe!6q1V
	c#!Dn?h8aKh@GAV-1d8)H3O>[d$YM,a(_EP"nbm8N`//F^t8hc_AfUImTc^KbRBL"Vag!"Vag!"Vag
	!"Vag!"Vag!"Vag!"Vag!"Vag!"Vag!"Vag!"Vag!+2t/U'Ee>12ti"+!3uP#rr>S@X47.Li/qC;PR
	lD"rm%:sp\q#cI<fK''Ee>12ti"+!3uP#rr>S@X47.Li/qC;PRlD"rm%:sp\q#cI=E-trrDUNcG/^[
	R/[0O?"<a&,Q@b+/l2KI@_BJU!)Y/:l`ikm=3[>0;+20!;+20!;+20"r"B#0_:[WO4tD"IrNa1N*Da
	I8%)*m0j%ZfWR3AiJe3"o4^CkdW`mXX0;ttuaD!l2J>rME5$a1b!B)=^=/Da(Aq_h!+?cp^m1FMQ7r
	r>Oen[nf$%6oo'q4FkaJ>0K3B,$[^Be+-%!!!Q"J,]M'AGr<Rkhj*5J)R<qn,EADoRFb6IaUIQDr2M
	KnC.1,rrAJ`rr?^>._WIn<VQLn_"I\mU&H_F!:\4)[#b/)pVu\"2#]Z<!9S`kph!=U8,eMFj*1J@Ii
	eUio06UL!C\'crr=PGrrCu'rr>\grr<l8!;L/%g.2.%qr;o")Lih.!:rEFr%f_f,Q@a5rUIN"!"D/R
	J,,_?p4/luDZ9^%IK'<:4b'<,IuF=,r%f_f,Q@a5rUIN"!"D/RJ,,_3rY^pnOoGEVIe_b!!/@,d^\l
	F0q`n"K[suQ7rrDg8^XCUrT7?VoCVg!%n2L7XhnkfmNP$k&56pM:r+PlAFXE%+N=StWriDF;3kh3Zp
	CF0:f!]dS$\_VpAnZS&PS0#7'49*T'NQu:dW2aumpHJNU8.jJ.%gX!.%h(^rMI?jgV7Ddq][*srrD]
	ofB`?CX8SW>Bs7=jn(J<OaG7`arBU&Prr<mNl(PJt=6'VZQi@$iK`;%om!dC_!;:1ArrD?=piTs-4(
	%0irr<7VrrC1-Ia\5rp1k?A!:&>6F^O>o=]PGH^0g_/!2>?$0FB5&J-m^!J3IKA[Hqh>:Y=:m\'m1W
	9<C]^e:2(+O&e;jT4;dsh<jn&hnm,CgY,f`g=rEeh-F;^,]MMm_]4k71l32lZb!8gOPfsl-g`/Y!(Q
	qW]Dhj?5EC<iT<Is=U9oVL7+JJbII6k3r\+9OnB@N3O8U$l`p`g^r]U8]k'iBdAl%,Nrf-g8GQ&M1*
	rc635@<dY7;;/Hnuoh-#I!d-&+P/L!/>%_UjqUc^,LQ#Vt'6U!&O7s__Q\h5P/mO)o(mkq"OdgRJQp
	`BF60]n+g&Brr</QqHA[L^]+;O14IY9oP`V+^[T_Ip\t5]qENr,5A;592t)a`phBYQrrC:AJ$]@nH[
	#Cgn,EB=lhrD&r*TI(iL)oE+8RqbNSjMFr-SGDbl&XQbb)8'r>YLNn,,$A4oYNEI_XS<MESTN<VQLn
	_"I\mU&H_F!:\4)[#b/)pVu\"2#]Z<!9S`kph!=U8,eMFj*1J@IieUio06UL!C\'crr=PGrrCu'rr>
	\grr<l8!;L/%g.2.%qr;o")Lih.!:rEFr%f_f,Q@a5rUIN"!"D/RJ,,_?p4/luDZ9^%IK'<:4b'<,I
	uF=,r%f_f,Q@a5rUIN"!"D/RJ,,_3rY^pnOoGEVIe_b!!/@,d^\lF0q`n"K[suQ7rrDg8^XCUr`W#r
	;)3acVrrAgCptbrML7cN$r6Nl6rlr3b<NHj=h#%9LeST/?'U.<W:[k^20Yn/OTorQUQ;%ZqN[WpgP"
	?p1&ZY;LOQ+%/&rJiar`/^m!5S:,QD+:&=&udg='$/=[e&3Z>#-`Ph5/V!gYCLfgWImhDfGp'*3d`t
	Z*\R>,-6VF]Q,2W;_.g"^MH.0-]dV@qfd9P;=LdV-h'dG*\u4tFS;rdrZbS1Q?jXlY6V@bf!dgUplV
	IY`Su:pD(Yrm9r(@/FlC#2mGbS+ZqXlEI?X[2RLf<2YPni:nO*9^EUilI")F7t?8hR-nJ-2+GMl!1G
	-r++`;0\+F_r2!iL^cL$72O0`"*'37ne]VeolQ50>=jD[!rYOWGQ:L-C^mf.`QdNqeu8n#N]6@DI;m
	Fk?n!4fDXDFre:5H=7I5:gR%gU\_$ff2?*Z"L]7@JIah?^rr<O90E!=#rOYoq'ug8C'Mng!'Mng!'M
	ng!'Mng!'Mo%mBD`akrr=I!q"apiA&#gOrENY=YO`+)o_&4aK:+sc&76MDm!&4<rrB*X_:ANn<RjIp
	J)Ys@"8[WL!.lPIaf>.9!<17O`F&JEIM>lM21@[f!5T=5jOJX-rr?[8iii;^57/q7)S`I8,Q:7sMuL
	M#rrAn>r`8&Dq'pI#q[K1sOT;,5/*`1_$7MX!$7MX!$7MX!$7MX!$7MX!$7MX!$7MX!$7MX!$7MX!$
	7MX!$:%-)JjBNIk6)C<+Kn6VY8mD@'ES'lq\K1b=4c(#8&=YQ)QR/eG0oKf$1Ya)3rPpKN!QOJ45ro
	4S2Jf_Ca4R&eg>"?QL1HO^O)<XL?9T/lMa;)+G'n&&VHSb7j*Ds(k0,=lhpqb_r%g0rr<r9)E*</>L
	RZRmt]e3d^>L@FZ2A<M_[hl(;D"PBl75rH*lC1pIQmm=T,tqdBuN,Im&%M_%\R0nK(Uu1pGL[`Yk?\
	P^-uiX&`K4nW]]5/NQn32+kPAW5]RM:2l-b[5gHlnE5`\@p6r09$XR`'\p"\9hAZfC364sQs,Z:Eh,
	g!:8KD]ai]i\#rLnq;uENk[6>h[nJh1TnY<2J>pmIT5Oa8<Ym4m$.""$+n7o+Zi>>jFJk]G-A;tc>;
	F6l/&KUjKX4k:cF003RVQkBbme'jXpJ\Y4G8@a(\X)N(-NcAp<c-YU44P8Jf.+R7b4<a\>tH><"bae
	Pe[i=kUC#2ZZCKFB2tj-u8_pi4j&q[+VIc-)EV3S,nT_(ah_s^uW@::eZsa`D)#]i@.p3#i;-ngl'N
	%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!Ihn[G:_3@ahqB%Ka8>?(
	+L81Lrr@X>J'(SP@))S"O+Z?dQg+2)TC>Yfq)mQg)udnTn,4B7Y>bH$Jjk13:d8@&q`9djhti](p&&
	HprrC.+3r]2bVITW+WHF9fb`D`k\Ng%Mo)A^g7&#16`=u0V2L9pC'Mng!'Mng!'Mng!'Mng!'Mng!'
	Mng!'Mng!'Mng!'Mng!'Mng!'Mng!'Mo$jIa_ZpD;V]BrK.VJrrDnHlh162ec*lZ[+G5FGO5Y8!+\I
	V^]'mPrI9b`FO8`JX7?AhbPqQp6@\(i5A>WE22V>5okjUfYOij=oA]cMK0k(Kp-38@q_a61!;14,3j
	8/rXK):#&mm<j,lge2'po.=;*Y:!;*Y:!;*Y:!;*Y:!;*Y:!;*Y:!;*Y:!;*Y:!;*Y:!;*Y:!;*Y;6
	)LoTBT<k,Anc&Ug$!m)e<kQnIkJa%nS&=,)4:A*aXHs_A<Tf#mBJf/p+5@Akm!&I0%CP(2=ks/:A;4
	a&eLr.hdaMjs?%-qr!5Vq?!9G%>\$,b!cc.(*6hMq-Hu]/d')]QF!$]#RgqVdlcG/jGYPY[kr<r=nY
	MqIT[kIM4F0GKUC]<]3rr>CaW2lr%nE'6@!7HrNgU._m>[S7C70"$!70"$!70"$!70"$!70%c@J&0@
	$nq\r[TCtAE$3("U`Sg%]!&1GQ!)Hts3KsG>"nD3`a+&Y)qRF0Y?fi)/<'CQd-i"lLW%[oiBDe4%O8
	f4Hi4N(i!355@7=N-Uj3RW81]C*Ma8Z/5E*b$o!7c/[U;(-;qX];'jHI["linR.>gMML1]IH<V`XnY
	YhB$Vkn"1MU;!T%J>.oL!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!3`GQ@_[
	`jHo_/!4;R<EMb3H0chnoSe4&&#Q6-^^"<(4L)+>=T+HK+(Bd?ub'QYVn7s@anWqMRSguu>`Q`O>p9
	>)iRZIJ8D*MmXi/n2DCJ\f>PM-G1"?Icl\i+_>AAj7oK'e4I`-%%M[:R0J..)K`r8eZ37?eLZCQDl[
	L/]Q;`ZO@U1PA5>9<=D4#[FHahPb@\NN8gZO/*du1pF+EX(#Ep6'N%+!'N%+!'N%+!'N%+!'N%+!'N
	%+!'N%+!'N%+!'N%+!'N%+!'N%+!'N%+!'N%+;`M`VJ"9)(Tp4iSIZ2XY#!(\ZAeGfO,O^I[D&(iQ7
	cD0=lrh]I>H"[$h"9)(Tp4iSIZ2XY#!(\ZAeGfO,O^I[D&(iQ7cD0=lrh]I>Ii7GL!:i1r^[,[%rrD
	=iA,>dArrA06:]CE(]YFIH;(/(&Ysf@.c(:S*72,`!72,`!72,`!72,`!72,`!72,`!72,`!72,`!7
	2,`!72,`!72,`!72,d^+10YtRs46)rr?RsikPJcHMr>P21MsYm5=nD-JePbrrC^`poj\tW#i]\isf9
	N2OCHAJGukS!8u4rq)sem?iJ;ZJ,NT$%]fO5C]*tBi6\+l4ce<(rlno%rEFa]X8N9=._iogbPqQ65S
	R'aAcY=7:]X!!:]X!!:]X!!:]X!!:]X!!:]X!!:]X!!:]X!!:]X!!:]X!!:]XpoJ+-N(q*kVVli-rs
	ZgihN!)WVd^I9[EYPnmlrr=I_rOm^Iep]=Q!9tZ*<C>f-pnRYX5KL"B[kIM4F0GKUC]<]3rr>CaW2o
	]QYO0O4%,C1K!!O;@!4tVu!78Jq.dF)43IJU6U^-V\72/f?"Vag!"Vag!"Vag!"Vag!"Vag!++^'RF
	!pm[$fgFKNrK(\J+[f+3krlg^XLg6%V5S>PX0\ErrB=]i(s?T0*bSSKi_7bJc>_,r^[Rb$iUF"rr=C
	Hj8T,V3%l"rlFH[e?a/)UoD\dn9`G*V<Up(hrL=[]^\(k0.'M9<rk.0Mq'>MaqZ2KOQS\GAN;in=WQ
	tMDlo'@i6ir5oYGsco.&)S!.&)S!.&)S!.&)S!.&)S!.&)S!.&)S!.&)S!.&)S!.&)S!.&)S!.&)S!
	.&)S!.&)S!.&)S!.&)S!.&)S!.&)S!.&)S!.&)S!.&)S!.&)S!.&)S!.&)S!.&)S!.&)S!r[g@mTHE
	`M^U,ruO8%Q.6"OB#rr<1ZrrA:VI_gO-FWUk'oe4e[b<OpX+7a]lZo@rEpYYg5AR;;7!!J2Z!0j.*_
	120$*s]RR0@T7^cThF0Ok+[T!+S^Crr>s_+4lo&r/#HDq\A5m!;_O?rr?>^.&+Flo`C"!TE:!!TE:!
	!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TE:!!TFVV4VSD3H^M#k/+s.R"!;-HGlhk1lrL
	JFPl!h.#R_NNMVNE$R07gkRA<pA(@u;\0n.rb/8L06]UhHHifpPi?8`1$/pr-</%Ai@)+?usBpbXAt
	:Lj*brrBB-TDnmlhnuJo!(#?=!'QtL1c"XP5Aj9N7`J)WQM0Y<;:I6Nm9.q726DqYmtJ"&>XoiZ1fi
	&i(,=,Zr3<ZZ./s9q1&cjVQ!`NDjo5=VTF**AZN-_W-ig!!-ig!!-ig!!-ig!!-ig!!-ig!!-ig!!-
	ig!!-ig!!-ig!!-igHr^\B=Or1aAfp&>#u=noo7!2t@C?_Wh]fDbgSF8l6)@"-tIp1ll0J+X?%WhJt
	'r)*C=+66L1gR%gU\_$ff2?*Z"L]7@JIahBq7b@@qrr<7@FoMGnNITcXrrD7i[2!garZ&XZqGIFmG+
	sjEMunkbTE:!!TE:!!TE:!!TE:!!TF\iapc4Q;;$HL]rl9M>5Phn&*FIqD?g6nV!!b9/arnD^J(X5Z
	-iX0J(PAdd_Q0\l_#FDQrr=;Lo`b?q"AJgqP?%/Q!<&E(MSJghr$\c$CA`AW!.lPIaf>.9!<17O`F&
	JEIM>lM21JqO8,SNq(]Am%rr>][r2mtgnl4e%p)?6p+ot+H=4JBH'N%:!'N%:!'N%:!'N%:!'N%:!'
	N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:
	!'N%:!'N%:!'N%:!'N%:!'N%:!Ihn[G:_3@ahqB%Ka8>?(+L81Lrr@X>J'(SP@))S"O+Z?dQg+2)TC
	>Yfq)mQg)udnTn,4B7Y>bH$Jjk13:d8@&q`9djhti](p&&HprrC.+3r]2bVITW+WHF9fb`D`k\Ng%M
	o)A^g7&#16`=u0V2L9pC'Mng!'Mng!'Mng!HpddArrBl*5@ZAA-hmNhTD33*N1]U=J)P6o_I*<C$N'
	fSkJ^dLJ&4MO!!jD=,9QE@J&sJ82iRb:ZG3][iA0o[r.b4OZ[Ua/V>gN.hmRrnrrDE#&V%_h+7Ma<q
	E/j!!/U7D<W<'jNM`HuWf(Z(9nE1c7=HG1`((p=7W8,cF8l5roD;Pf!:u2FrZX?%!.m"VdGpks8"\M
	=rrAR+5"YbS/ALZjr]kqgd9h^%nI`h>&Y&c\*<-#u4T<l\r8VJj!/QY"i/HRcGj#),&a/kgrrD4$7j
	S*7Q='Cprr=0+DWn:B:\]b+rWpdK!(W'!nK*0p^]&5[J&Fi!n4%?m4ELN&M"CLDrrDYMUQU,M0Dl"R
	!0A;3FB@HLr'YQ)!!Hp6!2IS!pl@YI?iL*cg-=RAO8'qYr>n!!!5s0]WrE(p`mMmmjd5rJrrC+NgU\
	p*'E018rr@X,J'm;Kr(!C5YQ"TmD'/9[a8?O=rf8'!!9--?eURMWB]PfVbPqPCJ)gk%h%f^Arr<WNJ
	&*#;kjd!u,L>aYrrC>&O8+OkrWpdK!(W'!nK*0p^]&5[E_lLBrr@SancSURMYomB!/QY"i/HRcGj#)
	,&a/kgrrD4$8,Pbprr<16rrAh75PU:([9rq638-A?r3H>&^gHm<qfbJX,(IO$+7Ma<qE/j!!/U7D<W
	<'jNN[t!C9RCo$hc(FF5bA5bP"s*(W;s"2rY7sj`G?,`&]3r_LI9*1<CR@f!D@NM,2%tkHgT-:[EKo
	^p^K4M[\1on<.JaA/C9U-Jc49ohBmCIAd)F#7UUehA#pMJ)Hoj'`8=K]*)IYIqk#SC]=A:IMmBR$^d
	8\P<n_-P%e8<]O:762g1WSL-,dBC,Tk.6Q::l/F`suX:aB=5[<(D!1/t!:&AK#g0_3/mH*lI>kn!h7
	sN/R;<&*`,h$j`.`*&[cNj4]_\TQ&/t:eV!dK!n/u$^?2l="$dRO]#?><Z/ou6@0iZ1Zof<m2'<P8-
	>\uET12LDoWra-d4<W<'WMSHUNMu*[-_*YjFr+,?+T\<biIhJofn;H<JTsdur1ZA)H..+,Y`&AkCQ?
	UgU)<0Bm$2EO[L>LePlL.C8h;t2uZees(l2Ip<2qD0/Q(FnN?<ZVTDPLucI:9'Vgd?9qI:II.>ZtH:
	h:oT(?!:N",]h_q5pVQ<%#ZBIn[c,XM%tM3hsa5[pc-mcDsS_-?OqMbrLgeVWrCD<ZWDpT[aMf/p2+
	-n:\_KiLI8NW*PRHj%9HO78b%Rgo_WcEFFOGgU?b@67uZ2*kWU]J1`\X36'<_HEqc?Cc!PqN^7#*%P
	>kWAB7RbTk!/Vd-]Bla2.$oBHh#.n]BN_4Q;7s7pY\ie/Os$QP&EG+[CDjfLP,RNpi34=o$gpP[tlX
	ggWtZAf,%f.np?GmLu\I?c2Rc6NdpR?IqlatEOF-70BJPUhj>LpFB@HLr'YQ)!!Hp6!2IS!pl@YI?i
	L*cg-=RAO8'qYr>n!!!5s0]WrE(p`mMmmjd5rJrrC+NgU\p*'E018rr@X,J'm;Kr(!C5YQ"TmD'/9[
	a8?O=rf8'!!9--?eURMWB]PfVbPqPCJ)gk%h%f^Arr<WNJ&*#;kjd!u,L>aYrrC>&O8+OkrWpdK!(W
	'!nK*0p^]&5[E_lLBrr@SancSURMYomB!/QY"i/HRcGj#),&a/kgrrD4$8,Pbprr<16rrAh75PU:([
	9rq638-A?r3H>&^gHm<qfbJX,(IO$+7Ma<qE/j!!/U7D<W<'jNMHIs3<&u11Omg4TDV3Og9:MVS8B7
	0r`Oa/0DpA!];!%P5N3oKp`h`r*]a6#`-M<]rrDl7dJj1Y*.PdB^Zb46rZfbV=8r9G2NCB/!%bnS(]
	H[Kh9fScTCEN6r"5FtNu\0"i]R4jJ,J>?rr@k85N%LXoQ]R!!"nDfX8`1_)b21R!1%!e$i^2L5Ao\g
	`)$/aj8K>/rr>QLJ+4S0C;9af[Id8]\,QF3LAq7*F+2hm(%"0irllOl8beS@7fNHVf"=LeiK*b5IiW
	nUk30N#L+A6moD<=Drr<IT/)f"T*&>OkB9QA#X,YjcTUGNs*+ZHsP$Qdkj9Oq7'N%a/72/Q!72/Q!?
	_)]9=$QLM#OUjW!+rS-L]7?NrCXgn/+]tD$KqEh.)>epJ*ba80`M.<+/r7-j,`u1q4KsnY.qG!pbQu
	pr"NrGm193s6N*j`pl2KEbPhq*li-qg)ZKfL6iR/5^M57`X8Fu*^\"<,p?b9_<u;)T;*Y:!;*Y:!;*
	Y:!;*Y:!;*Z4STC?nLr1XSZkP^G@!!7ZCEHjOZbUUBVfDZ7jrrA9LI!kqoZ/=J8riRmZ=8@PO<=aZ\
	!/^\G&*aQ%#at\m-EH2,!;e`/'n>MZpebD&ebJb9!!H!q!0^FQrrE"f(Q-!#>l6"RfP:Dui/d[Znh9
	k@L]3Vrq-/gX!9C-)rrDCDJ,2P7MC>[.5%#e5M?#'!M?#'!M?#'!M?#'!M?#'!M?#'!M?#'!M?#'!M
	?#'!M?#'!M?#'!M?*'n./6tQ"FNc1kCb1=TfsFcGDJ)#eAe`t[^+F9@C)@6'dF:FfrR+Dq+@p!18Cb
	jZFFZJ,l[jrOSg?5nE7`,-fWFBC?J"ToprOXX\P">-J-5**Lba"P.3Ru3k'n3m:<YdC:)FR3i(Nf0=
	17f]Ik)HWTSO:=.-ot;T)um.d9%)@];do`D_2')Xs_AUtcr$D,pOp+Nl6G)9u`Yc7UiFM5]VrXj;a#
	rMCKK9/SadK7'f"bF1A;X=0g#pJ2bWU5Aq!U5Aq!U5Aq!U5Aq!U5Aq!U5Aq!U5Aq!U5Aq!U5Aq!U5A
	q!U5Aq!U5AsM/O/0d+7a]lZo@rEpYYg5AR;;7!!J2Z!0j.*_120$*s]RR0@T715N&1Vnp/!W2uSg3h
	tfWM?Dmf'"H*3ZPb<KAJ+e",#J]pbe*HeT5Q:_Geogum@narC!)i,)f9m`YM/n+C($5GqqM@W?!*tI
	1U:tI:!fAD!!fAD!!fAD!&)nu9%jUE?!!ME`!5#oD!78JlgAW=4qf;]:K?3oh!5U[FmdEC40A1N`Lt
	_3lr&FWS!;*,h7=RR0ZhOA1/)[&=hgupW^*mcH'##f/]#TkZ$/sbVC0H(Q-\VboB6gRmd,%Q:A1p&*
	F)ik,P"&Q&d;_"4If$m0@K-=_,(@l<!;';U0`M.1IL6#Sk#/r[_t\#dGa]=$'X5)K9+aXaH>V\U7Cm
	VM)8W]@RVjlUcW.='6fDhUMo-BXeSt2$(mS!Q>*NbJKW`b&:2U_:W7e!q]/@.sc;@rt+8e,4p4*)BU
	9X6Drql1\rr=g=J&@C5BE%u..j#UXn%T#*!:qXDJ&F#"n+m1(J)PPmrrA5]XSf8gr'\76rrA^^=8if
	`rrD,.J#B493CSEkJ+2Mpg&D'OMT<^YqsV?cr5qn:!"MEqTDnoTXF+IV!5A@ErrC9>+7Ta6]Dd@8TD
	2]IrrD,pX$8,,nIkUurdo,spd\]k!0QsRStF6g(&]le!5jp`BE%u..j#UXn%T#*!:qX0r&GGaJ,]MC
	Z13VKqs[D]!&Bdg`%U-=q?4ZbiH?=C!0[>_r2tOf9As7S$,qDQ*In&YfD9fC1R(u5a8Z,L7/`bX!9g
	M3@K->Ar"K)1bbZENjA4J/!<.kr`ZP*H_*@k?;?$V-^Pfkj'++[=L"LnS9DZ!c\c2XA084o>-PcX]K
	Q[:pq&`u.l28h(?dg+p3>;+9rrAdunV@,@n5'&a16d:+O[!LY!;\2f(k;"h"TJJn.7a;&r\"3NTM-a
	4(Ld=Dq(M$Zb3/[j^(pYJTU]*_&_I$_jF)NUVt2o;InY@]jA4J/!<.kr`ZP*H_*@k?;?$V+7/`bX!9
	gM3@K->Ar"K)1bbZEO$i%@5JM<_k?&/F[jM.`[/"c>EpfIHHEF8K2?iL+gp&:PTbiKT<1&h6kO[!LY
	!;\2f(k;"h"TJJn.:/"l^\B%/m#BtnX*_Sm:%:U1)2uT]efH4/Kq=d1:?V\#&U5rqn@#;9&hqFe[>?
	/-np/*ZV;Z&&<18d1?t`!9SP$EE331eV7Q"fPg+[HM'g,7MGX9Ie0t!gk`B5EqT;/G::qs)po1/Bgn
	DiJ_`#joO.b";+nB\sThi.J3WO=CcN=sM(,tNSeP4JJ.N-9MZRr,iBo2O5BD"QI!rr@ImEst:GYN^]
	53WB)2A:-90'B!40GaJ,Y[ID4t4E]Z@$>OlgM=#FMZeTdU^ciOK[<&E`qGm4DG45C5-'2]h]O8%u[>
	ZiRSqAnkRU0`4a6?[C?\BL/^(+hkn;hrKn.15c$)G#IEGsg\,1aVHq'4eYc`5kH)uX+-"H9C(WSLld
	D/GkfcG,:0n5rK?mf*8S\$l7#]EP:XB6C<?ep?f(h+#Os'^MONio<>o0p)I!1tCPep$WG]N??k2R5B
	6qH)rl/<n[Jq%Dk+a!G/\6K05Y[N-,seG[*0ONYC_9U>o".)KcabC6Eu4Fm?l1Pnd2uE6<.3q#!VsB
	,ku[d)^6@eB5!qBC.EUKf;,$eZ$($V-:8Ung[W!B\O%i=/f5"l,pae7ZYJ0O4ktu57W'In\1"P1W<P
	$N;aSqCD&"K[I%G>XDV[YF@dgeL.N7qeEjR.Q^Yq?>.CofB%AR$df0=6&B?OghEs_\]DhlI28A(,^U
	=[N'Y7B9=2WiE9__i],>YtDa&Vp)nL=uCf><m+el2O=qaKuiQ"+Y`XmlL"Z^#-_nguG1Hon.Z>KpT[
	Gb7L@HTQ#8_QaiL<jc\bPq5$IeYuDCU84a8<@$Y);H&hBWP\S?j!i8NMFkpsg\nR7-Ure.194<cWDe
	L0>-j-f<Pg4Ld\DJ((K,G=RuChn-JF?jO3!2/qsEl[r#,M7q_)+92K4%4rN1N3GaHA7'OTQ4Vh4h"n
	FOI7%+C$Z9Pj>AF&2R`W7o2<q2H<=i_.9nfb*&n%$/qg`$$5-0Dum*m8*`^JKG2Jq:jLc[YK)$5O8:
	dq-R(uqC&Q>(]OJk69epdqDj&ZTDnlm4qdkqo=(Lo+UJ%'J*?"o!,@#]#l%'m!7'G^D%?%&J(OTSo!
	j1A72>fRrrDQp8*inK!(S^>;uZjU8&AX4G4^:&+WmsBr>`T>:]CEG*smGmgX5D^h>P[rrr@e&<tFod
	U;,&^rZMRGM1=aNrr?e`r!<'jrrC@$O8+AQp*K_=UR1qYrrDO5i@k324*j&s428?+!+56Ab2N>J'Nb
	,=rrBt\+0dKt*5Cl:rr@Tl$%Md*dJj1XKRUkSoQ's3[6OWnHmSdmkANl!LNiJWli%dt>X-Q/MZ3ZBJ
	,"[Ap*K_=UR1qYrrDO5i@k324*j-N&<GJ1rf1@ZVuHb4O+b:GmHF8jmf)DJJ&=K$L\^R>?g'0C!"ag
	4`4tqbrrBGkrWITprrD5#8,P[cq\&o/dEDO=rrDg+n<a.TS\6)u*T,ZP!3c01j`(5"5)Llh"oeS^&<
	GJ1rf1@ZVuHb4O+b:GmHFQMLdF=8?hud4g7SBF!^77s!;![pgI&UMTCr3a%/d7MkL!Ya2uFTOrr=KP
	n;$t)+,p4"qI\4BpW*7V#lTU0kiMgEC4H-epe1VecJH:prr@XsJ&/l!!4,c)';+uYdm%PRL#3e43V_
	XR>$lrq<T+4*+!4/6(\%'_4tO*nde;fhiU7"b\raM38/:N8hlJo1r7GPYSQJK>8a=o?jo'S?!<)A\M
	CY%qMC>,!MC>,!^H2Api3%S#N"=[prlo*9&,r:!Q%"Tlk?n-%ci-dmqg/8BfrY*[rrCP5;Q>Mm+7Vk
	m5_"o%Ir8W_B'3Or.+eFO+9$uk;-39,?e^qF)7eAu$8qh`G)-(tTmkKkeQ;Ndq1%X"&+/)..'>62.&
	)5!.&)5!.&)5!.&)5!.&)5V"$b`+:\dBpa3XW'rWN6$lJh;UJ!a5cVm$"<ao;>hK)#0A!+WdZTD`#$
	%^5I2Y,WQGrr<`1O<;sgr"1aa9ioC8!;:A<.fTM!F7>p=@B8q]rWnql!%+c,rrDpU0,9!%\bK$/Ygr
	\t_&r5>jBqT_&,e+no!]M:!6J01rrC\frrD\I"Vag@<.)JY72,`!72,`!72,`!72,`!72,`!72,`!7
	2,`!72,`!72,`!72,`!72,`'F7?fYdeM_Z7tCL\$r&JH-]>W%UWB/ePV'<2WGN+*cAo(GL>'nL\=:`
	DNF@\"ra#37=6V+1'78[Ya,'^>C>TeL)cmq*J8FXq]bYgNGrK%\f.>Y4A;SF]+jta&EHNSOHWd&/<m
	p-eQqdPr'5#bb9T(^NW_#Z^HmMcY2f="C<U?s>f"95?l)/(GLGY1$?+lgNb:7-Bem4WZ/lAg/VX(Um
	abH]>;\M+=h4YaH-Y4`12bm!F!3SO%rYP?Ritm5.6h(*U`99XM[;5c"I2lrIer?^qI,-S]Yn"n[cCK
	%iD^`]3h*P_[R%%lZOoGEMYDQZqHrofe`k'3A4C_nRF^6J+@(;,9=R,a!O!iR;XX\Kn2]?k7'RjRDb
	7r=/c"D;2[H4g@X?Y5=I/Wq-rm'@)rLj'D1li89FPdYodELGanV*JVofWB=;QTDqIUjt.Bf@U^XnIs
	",/Z1uCK[b-UOr1Mk<BLPi`n'mSdujf;^KH5N2n?S3T0EKlrGa'(WQhO0odTLpSS9qPr1#>p/QTfj*
	hK!&RjXU_>?9=^(M&XS?3W;k\DQ#X#KOi8\&9p5B[^1TfuT)g=#t6.'I=Ze*mJ!:V_s/l!?<rUg6%D
	i`NQ`'^=oW4ri1;0N^2lrkpNs#fiDmQ[KUOV/F%0>Bqk1dWiHT:gl)G>^dTW1BiT0MSdu&SLX7]7\r
	,ap6++,Un[6)aZ.Bk-BI=`<YlF$Y>YgfTiV\ZUFo`7CI,h5*r<jXRWj^Uj!_;`[hb?.72=6Y'N%:!'
	N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!'N%:!Ihn[G:_3@ahqB%Ka8>?(+L81Lrr@X
	>J'(SP@))S"O+Z?dQg+2)TC>Yfq)mQg)udnTn,4B7Y>bH$Jjk13:d8@&q`9djhti](p&&HprrC.+3r
	]2bVITW+WHF9fb`D`k\Ng%Mo)A^g7&#16`=u0V2L9pC'Mng!'Mng!'Mo&)'E8%;OnJ_SJo^kkh;3YF
	?aB'K&[hSJJ&12oJ)Hj3pNN8+([Sb@`,0ZqrZ$B:qGRLnBDm\%jO&Hi&,RU.#6+\P*Mn0O?S?lHhst
	HqZ\SLAmfS((NmbY8YO*m1r^?Q`rJPVZqMRoD5L$t(CRP2&fY\[.!3%hBMC>Z!o>6A5TE:!!TE:!!T
	E:!!TE:!!TE:!!TEo(k3+J+SA<&(4NMMkC),`HR74e"#lr?mp<LK8B.^-70$@a+G-Js2^ps8Ilif3l
	^1nHVqT"D,Y#P/2RFG[23O$M0h'B3SU9@4s4o\4WOrT&.qYbV-\Rf;-W-s]V]nC-A3jfF1eX%rhB[c
	ZFC'UYeN5h%*;5ch&_Ukl5G.:8CUK0&p#`_9)q*/=`f<2T3<RE#(qV)="(8kiZ;7\sY&g3RY_fmG$^
	6-DC0[(WOcJ\tE)<uQ3%HF6cFdW20VqRa=bl!s2.pa,Cq<IOlI"T\M1^'T85Ap^XE_B'oQ-h/S'4_i
	,.K'u2(<T)&4nILWAZ++>/>AG.kR:lO"#e,S,Rbm<KD\DBi4P,n&AsYCS[f6=;IN<YPi>7%B,OiV0T
	7sY%"T1LR+,BLG$hus'H3L$GB_i3kUg#.BT;PgrW?``C`kH!44I6j_1m^."9li/>^[M:(!!\;DH>VR
	,j82.;K&YTte?iT92dEZ;AT4`ZZ"m\_4qk@%Yq%==\TH9emFL8T=Vf^qaE+ZOd_F/W^B:SbkKD:3r)
	.b::YN[C.',Z^U5Aq!U5Aq!U5Aq!U5Aq!U5Aq!U5Aq!U5Aq!U5Aq!U5Aq!U5Aq!U5Aq$o<8-#kPkN1
	_#:rrm+-V>rrD=+WE8;[IWbYj_-I!?jVT)KYPjp9`ZP.HodZnfEW6"QIl%E+("`0@rr<7@FoMGnNIT
	cXrrD7i[2"0'[JdXc_4.!Fi1jZRBRfjpm6t;\Ito\Drfhs4h5I'*irGg2-ig!!-ig!!-ig!!-ig!!-
	j/rprXNK=!0fcsI/a2Ohr%<0XtL#]q1VoHHN*u]bb+H^09;b!48]Eb!7f'HlMgi<Wp6;I5Ogt[!W><
	6_%T&oeU2lH!+uJpYPhNe$7kfg^E.m_M4a?R^-DVtZ\%^Kri;ZF(&JGIf:3HQ!$n.)rr?F\rrCL0Ik
	,N2r09;"rJ&Yu!(_W;72>JcbQS\X5Qqj!5Qqj!5Qqj!5Qqj!5Qqj!5Qqj!5Qqj!5Qqj!5Qqj!5Qqj'
	[!WYa!V%Pt^:6#'"DH4ASS`?\>2P3["ab.tBIP&4>5J7!A!q4nB?c3)Z&7jF\6keD]Tejuq6>1g/cu
	Vc(QH@1_VqH6Sum>1NB2$>S>=SRPI+a5mnQSH.CPAQ(CQ&=i[J;TPUbZI'rB)GN>P91-N'VQm#optG
	)Tn#Usr=YQhXeSa2NNF4DU_e'>`6dlW)JI#()2N/WPsj`ps#B>1I7cF)Rsjd7NIob-K8J1cBMrgtl;
	j>0[!qr$;&EiST:%!:]a#rr<HN2EEFnqGm0MUj$"fXZ>uq4_FI60K2%Pd<WBu,=cMTL<^D`XeA/BIq
	S6'gVD^QkCu`oiODXZiZ1KJS&G:[]S%W0YM@'!Ou8<ER<773fq`2adVYdn@9cNL2<FIohTtg'IkUSJ
	`tIC%<%rP<H<Dj-DH'TaKhQA.c7]u7+(c+CP]5-Kmm7\XWcHC6cBn01"7U\_G7Qf:2j1%VMh6pi(8V
	Ec#3.RqV'N/l3CYdB<*nqS#f[?OVsPrJ;+5qQIIW/tpj5<s?BKN+Gah4PFo;tN5o'*YX4]dg@<@'cd
	:TetN_#PWlE\@I$c=0idB^iLp%cr(A,Ze>i'.fHFfP?gnK$M<0;`BKrXnO+-J,mabf*2nB6;R]Db,d
	5=WQUn?AP/6_/4"Va6B-0m:>!@ST+O/;^op@iDc7g.&O$'WjQDa\8&$c-S$fL2c&-r2p"&8hoF!I%&
	5n]WTJFT30t@n<b]G`8N1up`):QT"asWTq'>qfb@CA$nXo/&qal#j8IU%RO2][IYldkm?DhM=a"@R;
	*h+s"rZE[\h;+hYIc*;BCZkXtiEsP%$:g"YpiGK/,"TVXY,C5!I`9iI:sqEWet!Qk&XAp$lDl0!RBP
	nEMZ#%1j$%NZ$96hA0#b3"cU)dDEgGG$3F\ZBqXVW\f1;[p0jYN)2(%F;bd#f"p4Z[l0i<tb7E&]3b
	,h_k.EfAlr0r2Q5HfR`'3G26_/8Z@!#_R2&cI(UJ==7P$ZCOic$rkQ=/5cq&[JV='9rLsnEVb,GC'8
	h93r/(KJ^I-I6[Wf8,iRYr0Q2g-K"<Rleh=;ec,X=>C6AM`b>APKR[>.!2([Brr@Z*hu5E=ekHj.`,
	)LS!(>p5r&W%$!1hu]da\9sLdOi7LXZ8'_dn8m^WCoEnnnC,#l_O;!'j7crr<53^\h])pdb#Gq>tF3
	!;J.ZrrD(:rFF;Gr'niDoM/?b!5knQq;(B8/Pl.p1r&7&5Q!E0rrAPdQe[';hsc]mht.'%rrDOmHiF
	)cB`A'cIpW-TTI-lB!.rt_r\Ip49b`)qCodR97--Z23m7O'S_h-0eGfN)6VIE6e,KEcA:OEiaaM5#D
	>sSArk8=35YYVc!!TjHr+;#b8+l?I!c%`8pas2Z!95s8AC3pF7`rL<:/h/m_lUWKh<Y"k:\]T"^Z^)
	1r&.(F!1WnQgj^[.n;lnmoE<_E!:X3>rrC&Prr@_%?N1"u-EmFLK%o2^1LJ^-'S"&;X8`/fjZiZ(bP
	qR5hS7Lgrr@jB9E'^qrrBrIJ,-k$IE1nqrr<?(^&J't9jdo#"h28EArl^Wp$__YCB";//\V/aj#-dG
	d7=+(b.mRD;uZj8XM=SelhrD2pk1K=k^>\n2FmcIS,AW.IjX(BO6b]q"P*MPn6:8>!6/^P!/,i.rrA
	]=YQ"TSgY_ud?e.pcJ&H0(rr>IK5Q!RcrrAVH^XCX3!/O!8reJu&!5i>sq7k%"a7=*I!!rS;rr>;Y?
	iL*0\%hiQO8)6<n+m*#rrDgG^&J)m2>q(58,Pj!^[t9"rrBs<^\Q^Or@Lh?KJ^I-I6[Wf8,iRYr0Q2
	g-K"<Rleh=;ec,X=>C6AM`b>APKR[>.!2([Brr@Z*hu5E=ekHj.`,)LS!(>p5r&W%$!1hu]da\9sLd
	Oi7LXZ8'_dn8m^WCoEnnnC,#l_O;!'j7crr<53^\h])pdb#Gq>tF3!;J.ZrrD(:rFF;Gr'niDoM/?b
	!5knQq;(B8/Pl.p1r&7&5Q!E0rrAPdQe[(NchnIm$*F4-D%G>I)5<9#U\KOfZGeRUElPu6:\e<U$Hc
	0==b!%bSc8ZmMZ3[@TRO_,p2qG^^\'8/laQloK%p;*b#^fFJ,:iZYPsr3>2hd)O^I[D&(iQ7cD0=lr
	h]I>IRT:94E`@qNH"Se)2Q4?]pCZBZhhX4eb3a*Z#f!hjlUQ@Q*4bG0@qm;AV.bW0PYL'eSr$G2mdS
	dFVP6[Uo*.AP['GkDJ<;Jk'"<7]+e+2Giqn#72,`!72,`!72,e#7/m8'jF)O9SA4fBTDBAj]3iKnIr
	8W_GopDg-SPGSkPg240%]V4?'N*Z+.rOs_#E?n!+FafpsSp14oLhQ/A*4eHb2qCK0BC+hWi]YeSZu%
	L%Hlb8R\2@7uh9=:?@TUQ'[&/<W<'9^[^Lc#sL!A!5`YWrrD+0rLElfJjfV=atNbp@%[<RT7c%tLhY
	E9/RP[>4Cc=fn@39YaCnP5(Cs"F)8(Ag\Z-A(9hDOgb0EU<[G@>.p&(-kiD(I0MT"L\F]o:hLojt!@
	%ekO>,8/XVXZ/$4O#6bII4`J!0lC9=8k>^!21dZhtTq35Q$4*r%%dI*e2P#ipZdloq24MYNj8fkl1X
	=f8BS.U43^R!/DJbr5n:'/U@?riXoV6k]pP8!!k%R!:s9qoX4ZsJ)Oc0oDXE8(OtC&XT&:k'd)qKr-
	A;B6;NNSn=/!Yq$Om;.Ob;sLt@Oa!2=rRrr@fmTDZgsr@Lh?KNN0h*`r@A_?tejea*/cJ!Ajc=8k>^
	!21dZhtTq35Q$4*r%%dI*e2P#ipZdloq24MYNj8f5N4Q[^Z_<-rrD#tVuH`PHN*t<;uRpU)ubVXrrD
	P?TDnmKHN*t<?fa6G(&n8p5Nk]/GQ&8%ci3tg;?$V'rrC*3oHa4Drr<A=BE%snX89,rO8+]ZYPKX9r
	rDh6WW)tBT"i_'rr@jDLAq7Ija[1NVuHbA?GFq?q+^khKn&./q@\0]rr@`/Zi:$H<.Dd"n`TiW4tcj
	8_J`TW!9>X/XJhon,@2o"M>TU;*,9up-a30M5N38`^Z]rMrr<<RrrDXlYOo7%<3<kQr'e8_6YZ&i!6
	2K(&6MA<iE^VP#[A-R***L/.*gu0o(;3_9E#Y*!6)/<-/T;an;6Zgrr=Q"qO=4R?8Z52mc53a]&+N3
	9t`Th4BG66q7@@`#k3[S=k4n5n\NY2\"g,[cfBR,TCAcX/Uu/#pl#.PKMRGSq,p5c.K9C+?h@"*,6%
	Z%'B3Bu<`erQ75+Fq=T8Bt&RbV=n?TP'!%IU?QF6_m&<@"p!(38XrY!ZZ!9L-L47RgZ0?%.FKYJ4=/
	j:0N6%TA+*I-:@kF9;Z,Dm=HMo/_faXj_]R&M'&`iS`%bc7\ThqS).C]0iSBs7=jn(J<OaG7`arBU&
	Prr<mNq!KWl.f<^R"]i>AQ3lJX?CY"Fe#KDtmZa3-4<_l-m#kD\C%Q0/m'p,N..FW,D)sZ!\@%9d$+
	Es"BtA28C.0Gl3HK7g7b`*#Y.)mVbPqQp6@\(i5A>WE22V>5okjUfYOij=oA]cMK0k(Kp-38@q_a61
	!;14,3j8/rYD91V8US;FP^Qq:72;0n'N%+!'N%+!'N%+!'N%+!'N%+!'N%+!'N%+!'N%+!'N%+!'N%
	+!'N%+!IWbYj_-I!?jVT)KYPjp9`ZP.Hod]nSYKjoX/"ca7"8;Ef!4,i'_uB_8I\g$TN^)Nak(*I3,
	.dd/^YmA^^[P+(qm8Td$hg<ui\nQ\0DI>EYP])Mrp:6r!(-X_X/`AmjmrEOdZ>R*[1lJC?kcI,!#/:
	!!#/:!!#/:!!#/:!!.G-%_9APBLbFg]p,i0YrrCTgi9L=B0WP-Q:LElWPQ"D_nalb#It9i\\@`hhjq
	V0$4pV'7q&ho$&,7=qQ)WX>b$P],ZI?"[ia:CQ`Gr8N[[.dBXFoKH_KI>6.+ptAFD\Y!D.N)-q]Gh<
	#l_O;!'j7crr<53^\h]U&,7tor_^B!\,O^'i_TQPJ(_!>WLEcq-LkQB8X85>V3++XYV]>`?03btWhS
	81FOgYjK6M(co'^YjbicknH+mpNbarl*%iJO$FB2`eMOi6u.\G<Ao37OTjH$%?r0r2Q5HfR`'3G26_
	/8Z@!#_R2&cI(UJ==7P$ZCOic$rkQ=/Z&u&[JV='9rLsnEVb,GC'8h94'LS+Up+$+&Dn:%?^Yjk5PE
	-pE.Mdr$2(4r;ed*r"e/h!:cLBi?-[dkR"<i!8t<[rrA#0oohfdnJ`tX!7<f&rr<P7rrD5+YOo4eiX
	jQ<!29&b!:\Y`rbq@7EVu;U_EY5RckBL\!5WO@rr<q3rXo*Urd^HPrX3Xops":k1f=8Q&[JV='9rLs
	nEVb,GC'8h92kg5%57Q":]CD(OoGFDrr=A>+3D"i,Pq05!B#B)(>f&knX;]$+4n9k$*4(+i3rC[!0#
	P&P=6S`)_1jfd5b#&!"Q=7!9\R0oX-pC&CURYU%J?bnC\o_Dt77Tr0r2Q5HfR`'3G26_/8Z@!#_R2&
	cI(UJ==7P$ZCOic$rkQ;?$V.ZEO3?PlCaQlS&6]HN*t<;uRpL0DZbdrr<LjrrD3]!%%@]ag_0mqY0p
	h21PN>hZ!TGRQoaQf>$MUX8`1X[eKe%N7[`d73D%=.fTLr3D]YT%^Q*7kBF-%[6NX^df0<@o`"p\fc
	U33nm?D7Rt&:>YCFn4=8r9:D=@K))5I0CrHnNoR_Sh0Dh%Q,Ip"U*rr<Y:YPf-!rrDQS0E-0Arr>\j
	rZM_(qB&N5!"G(j!9X:]-2/M'\,7KIp\b+MJ,C)=rrDSX5N*^9^ZZ!)rrCucp\t5PfCb=r+7U:"rrC
	G,:]CD)ZMspfGH^YH5N37&rrAbbrrDQA+9$3L?ZH"5J&4FRJ'\j1rrBlPn,EA*U](l(HiAPa^]"UZJ
	,%9<=Ys"U!"lN?r=bFq!:];-rc`\g!)$8i+Up+$+&Dn:%?^Yjk5PE-pE.Mdr$2(4r;ed*r"e/h!:cL
	Bi?-[dkR"<i!8t<[rrA#0oohfdnJ`tX!7<f&rr<P7rrD5+YOo4eiXjQ<!29&b!:\Y`rbq@7EVup&?O
	Hc[l`qd>-c;PslLIIXO`\nTlhA]J,*n5=D05#_Y):G_pK:MRPf8%Oi6U%cp6+s1OdS<D+,"I+?k/sl
	9hs/,N\$.O9f<d:4?sSk]sgIIIDU1JfCVd+H.^F\Z^S+_E*64KKTrk,XZH6f8'WS;$P$`b3MS"pEGI
	qV$fO!B:.eX$cQ.k"GN>M+(g+t"G"o&+\R/ZG7U;gNbg1tB!:W^D!VghB?!$$pM!k1bI1%=8n;h8I2
	M9tBALq"8bGCHhHG!Am8<4J=$pa99HY\kcImu7*%qn-@dOb#$%-[P*JYHl"@^4@gM^U,-/Prc8X>[M
	l`tFd\RTW`8H),&@7VNn"[cjp>F.OT$pk#S^k1PH9;M/kX(=bN)-M4u&2'iS@QRd(=:j!\c2!&69ns
	k=\aXOfHAd485aX'!I3S13p[&IB,SQW"oo""<[\'#VB'N&0clie)#5Qqj!5Qqj!5Qqj!5Qqj!5Qqj!
	5Qqj!5Qqj!5Qqj!5Qqj!5Qqj!5Qqj!5Qqj!5Qqj!5Tf(#rr<53rrA:dIbar'p0;`IrA*TE`.,TI^Z?
	jcY[@@"8&=Zm9D&)JrrCucrrDVTceG)kbDrY'!2a$;\<$D1=8\lsp'^m#Z`*X^rrB$IT3\`$)ZKd=r
	rCJ4rr?>^.&+5%.&)S!.&)S!.&)S!rZZjMnijhX:1*n1ci"7F?*E6G^UGlk4HH]D':8^doD\eWrKh<
	pNNUE2_iN.D!(pXKY*]&!-iQtmqZQp!frY)mrrCP9:9W&[r9=4]JjfV=atNbp@%[<RT7c%tLhYE9/R
	4IpqS15UMC>8$72/Q!72/Q!72/Q!72/Q!72/Q!72/Q'Ljmf[nnm9k+8q<4MZ3\QJa<".0\-0K5IB&?
	Rs46)rr?RsikPJcHMr>P20@4!?E<W!qTJm=K0k(Kp-38@q_a61!;14,3j8/rYOgcR!/!UfjRtfPJ,;
	*[rrD_/r&V%R*NZ:@!"rWlr?VG@72;0n'N%+!'N%+!'N%+!'N%+!'N%+!'N%+!'N%+!'N%+!'N%+!'
	N%+!'N%+!IWbYj_-I!?jVT)KYPjp9`ZP.Hod]nSYKjoX/"ca7"8;Ef!4,i'_uB_8I\g$TN^)Nak(*I
	3,.dd/^YmA^^[P+(qm8Td$hg<ui\nQ\0DI>EYP])Mrp:6r!(-X_X/`AmjmrEOdZ>R*[1lJC?kcI,!#
	/:!!#/:!!#/:!!#/:!!.G-%_9APBLbFg]p,i0YrrCTgi9L=B0WP-Q:LElWPQ"D_nalb#It9i\\@`hh
	jqV0$4pV'7q&hoL5Q2*0rrA:%Hu8l`ZetPArrB&@p1pksB"sXMpbZX_;8)M/rm-)R:]@;Bfri)hR_k
	uC02N!(U7_RF.%gX!.%gX!.%gX!.%gX!.%gX!.%gX!.%gX!.%gX!.%gX!.%gX!.%gX!.%gX!.%gX!.
	%gX!.%gX!.%gX!.%gX!.%gX!.%gX!.%gX!.%gX!.%gX!.%gX!.%gX!.%gX!.%h+AIfBD"m<E\Ln@/<
	1]Ct%/2+7$'DS@N54sPo-8=@r>A+9B3^+RhU&u%,PFIdHl9u24fGAi4-+aDj>RXa7b^C`;@K\u8q0A
	*>b08V!4hnu$"rMY/Nl<YXHSn*En2aKY>oF#MK<K^KUN%UHogg01aA8("em(4<P,BoP?TKi359D202
	49bU^Hm&BjoNa@^pd@;0r'.[cJ)]i^37ZurpndJX2V*k9E/:)QG_=u#UZ&h5+rcRuCQJ6Wp$&0<ijS
	Dp^QQ1qKq'Ce'VF2n#Q&U??d?^i&6Ji=(#U1gQf(Acrr?^#N.*\6[%H)'iAZNDHo%j<?6Rg-[FDoNp
	g:q)$P&Zr2o:W#nc&T-G`B(W<?Di1><+;n90I11;XmSi[da!qCmI<54`SS'[[ONf'N%:A$7MX!$7N*
	Irr?f[g<\\9lrW[d`;]fXrr?_n*U0.#n2H*hV&&;Xf(/To`S0RcRXI96h?D84GV8nkir*Q,/:)2pA'
	2h4cD@JaVs(Q-QD\>5YTLn5r#R<Ibl^f;M>IO*0t+V_nOJ6p)>c[Do3&D&'[$]3nJba.:Z;<R%U?Y6
	pP>0)O2B3X6PPONaOW-sA''&r0WXT5paDd%\)WPE-r95InON;CnZASM[f.ej[aG!Xi8\i1iUA54?Ok
	*0ItPB_*Q"mtgg&RtiO(7dqA<Uq<:NGWXm6O&>:':LfqIu/fe<&@nUKqEqb);LrL80@D08(!r\/^dn
	G`KA'&q=?E7uXsF*%&Y(&4fg-7TLri9q"VlWu*lRunbYUY\_Mp2$na/m'FQ?2F!)rr?)<pa%hRW;(T
	9$).5"kutL,g0^cES+%p$>?;;t_&ffLo0V!p@\,MXGV2nBq>kYU,-0JE^)-V*-GKK[Y(+<[(t!^EiG
	T0M1W+B5l+S2-Ne*u#@mJN&rr?,/U1bHf[[![l8(73U[PjH@./rRB\dIJ8mCr#H'N%:A$7MX!$7MX!
	$7MX!$7MX!$7MX!$7MX!4O<%PL2X_?n9a08K65r,g-.+`C#cr:l2)^sS*dfUL%S_$f5*P.o39PQO)0
	8UIUW%2YMZPRA$>UiYOXgU!.ql_ah#7RA,cN4%K3+e&DZMjC#0NQI!r)D:&%^:LrX(Vn>kP\Tm,M2#
	E:oQOX8G#H5l1R"mT/#`uHPf%h%\=d@u&YATUau'R_(err>;K=?k`m08WjSKR_pSrr<Zo#HZb9>$cS
	YrKt67UNfa2+Be@Z'6mTuh[_h`-Bi3a3f.#;,GY%G=IWdA1<#sUgZ81V+8R_Dpr%X*T<q,,?eI6qrr
	Bocg,n7VqJ#pnpd='N42mX1g-"8sC2lQ%=mKB5ee/95So"SKRK_QIiGT93__a/TBR7)bZnk&?,jG<6
	?a((='GL1hrr@Y/Hj\671].aQ/W8mEA#;Q^0B&2QUC=jppdsKRX$J?+KmZs0@^N^k,J&p+4U8pPfYs
	QZZGt;b/K/7i\[JqHU=88gp[W)qa7KK%=t$,L!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!
	2>?!!2>?!!2>?!!3aNE!;J0:`4[,KBD`C#p=ImgS""(-`*Wf<IMup^cKXKKCHiOk]cZ5$T5A3K:B["
	#0hL@o^1E"oCO8-)S,"4ng<t)HeSE@O9fg_g:t.,"XDBG)VnBaX]UgWh905dKRX:O)X-oA!\$ic",a
	rGEFcIl8h;&YLYOf%!!/$=3!8t)1&,im5B:s^phm5h0PJj*"YJHhG9B':tr'Jh:N>(=W`JYZS]cPG2
	20-d%C0gr9HYKGERXUa,0&7np?6[n&p$FIk/I+c7Iu&4tV\^d4/(pfs=YN(+qYnfji6K(YBGuB=:YW
	qKNQoTnMEG8(c[['!dB)%j'$m4u3S-GGG^mYU.1uO=V4OIP:Vs?Z,5e^RoIB\.P.ur*qe,m7g&#X]j
	8KAPqceG#rMMamB_p8oKeI=cIi`ho>`2.#GOX5&;6HPO*stSYb9V9*2d1K490g4[)<'$A;5NKF`:he
	3@J4EHW^Y&C97QMHrd]L&I22@'m&0_`r!*,-4q)[Gj1jsLj1R7h*X;-\ZpN^oRbf\0GXl$TnB\'.43
	(M3:HdThr*Q1dif@!bn%!,m[a_\K[1*oO!):u35*2ooRaJ0"bQ<YMTE:!!TE:!!TE:!!TE:!$R.6f.
	4<a4W_O_n?hiI\4TQi!'?5(bip!4<HZc-+UNe?<J&*W^!)6\0G@p%7D[]n6ID5('VY&:.t1`]p_TF^
	53rXP.eM5,;WrWuTa?OH'2`&03+59#%^pa\U\VF]lsbo9`upm6=i:m:$9'H1&'Y9KC"G/Dj-Df+q]5
	P_-Wmf*:b(VfqVX'u#."X3i@FH6r[,eh$3fmEFAO';&I_TAr)]$oQr+,Mk3m)P(!.pcq60jEI;>3fP
	KH>\f%h*4komFm&EFJRFK[aFb$'Pi"p\)?mU90BJs$u[uO4E3e(8CC-^Z7ni0N\gp1h2854UGF]Pp$
	ALk(tn?3D0E\l":+c_rrBm4?6%I:5PQRD`#VVG$JTgGp:g<si]SHn9"no.C%0$uLP-t$\gkg]>JdtI
	>N'9@rSGEjE_M>g4P/b?r"=YU<P89gJ)Hpu!4*KW%<BFprr<s^Hf=m/-hrg<.^.R.4sbSGe?Aiopu=
	uXR8lu)G]R6^/a%iTApgl4oLgTr#mqgR&[#9DjX.EP!fAD*!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!
	2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?!!2>?
	!!2>?!!2>?!!2>?!!2>?!"6,sJ-pR&inE^&\&,Ri(9)Y0l,!+tHigVp8Ifjr3D,'-\_s`Fc'$YFSh\
	t/%XOcrJ/t%,5Q?pQA*S$p#?5h<N]`mi+U"(2trrC0]p8S"Ur\f5F59)e"q`aq,n9*oHrZHG@n>jSR
	[+[a$1cpO?)D@%3-)uW&D0Njg+h!61[%1CPj_S2dpQ4'C[MkEbTDLBFkAU848,`gMq_%mK_+T4q>PK
	T+c\?):nW/F_^2Jau)#P^4/3Y;+3ki73b*m4G4hU9"4rM,+@=<45]'MAE(9-E9G76AJh56[Dl.XUca
	R&SXr#^F`!.U-FNNMM1)qHj\&GUHMeFX7_BR5B0XeP-M/bRtcXD&TMT/p7[C3j3a@k8G-I\C=o%!NJ
	2QErquDfH[i$_sFZIcYqarr@\5^Yl/b">i1^%GZ>JnFsr)+&%A2Z!WO*#1@m5Xs=<ip?K-D2:CRTc]
	5EtGHtL;kD6cFX(i8Q6@s")J`_]9kP!I+!/#&Oi1^/NZL4WjlMghjHm52jkJF_M=Z#R\r#2l&r'Q@g
	H&iYG+S[a8H$/-.eRV3RRbtoeHpH.\=qlBf/nRaer%IU/_>aLn574S?e%R5X0)1@ohb\nmMJF:Tp`m
	_k&%mKc)K_!"D1"^JC"(*I]rf/OZtdh9o-/[`I@V1-mI8<,m=2\3][u!FoJQXK&RKt':d=/NrK]\;e
	9Jn2!1o`'nJ16b'a+GhrrC_^rr<KuN'I.&fCMR&5"L/SIdcU3kM:^f/cPgh=.et]&,I+B!+h5h2'+I
	O!9^7Mr'bo2!!PXf!24o9=T8B=;<&2dH?K/6;+DlrQ9TTdg[jjKrf2A-rr<:!rrBl7r'R8SVeI'Am/
	,^6ad'_YrY>2kp<?doRQ!ZK@I_*i4Ct3B7a/2/p5KjH9TbuiG^RSCr(?p`rr?hQg/I^]n[n]erMBKL
	pugZJMUc9u_WSmaWI69_[[j1=X?7lhD*BHl$[>$4Q:+lOdekbmkk][jDjg"*kE4Z<[*9suf'aj4Zu%
	`ueb'5L7uG>\Zamf^Q"!4G<_I41V4H0seYJ=n2VT.^^WBiY^U%#>&^UF`;>XC/Q<(a/^LZ5Z>"43i,
	R/0.HrSIq4qRJnf$7D1ACP)Y-cAFBr#52CLurK257,6e/RbFS!0:tTk&$3jBL>un5'em#&'XnM!(%4
	k2S8qp#HrU"rXYXpjo(tP2(jgWa5YF!`g-%3^m`N<Y\P<g4r!=FgYLc^Qc'Y`ON0PKj55[?V7^g4IS
	=tB([t*KB7Fm3Q](P(%n-)/pa'#>)fP49p+Y(q2=]GpUt5/[g,o"dd3Z-Lr&(3Pl*IS0:PCk&Urtp0
	WT!5+>(R2^a8RL9VN*0t0?'M2dr]pW-KescO5Tme@`$T#J*G+[WDuN1a(N$<r_'Gs^aPq7^]KBATE:
	!!TE:!!TE:!!TE:!!TE:!!TE:!!TE;m"chKI5rWt6+rr<37p^O%s;tql=>?lX-J$]-@X&%Zu4^&4rr
	[[n2]793"J)OqiP;H-dD*rR_ReO_QYGN(YqX"'uM!na_priN-0Bc/gEKc;TDSN5:+@!f2=OHek&*j"
	gJZn<aNeae$HB%WZX_>;bNR!rmkk`#]F"N]SV<XLdlqh#&qMq1n"P1'52c.D7CNg36bmI.--$iq7&!
	,Te5A%YPC#9VR!IRf8^VVX[)Hns5^*rJ(LbJB07U$a@MHcW!;YqHUDldVrcNHJdH4I%dp5c/m)FK!_
	Et?B"kq2o8"^(d)JcYkq^[P*Ibtm?nJZnIUB91c8COc!6M)l-%%K?E\r[19TMCg%I\)@]t[.`$-GiO
	_Z51dj//`!%VX_d'Q4a'%,Bt?KbU0)mUJ$hfE&C^UcC&97Bg8&%(rL/+FnOp_7%<3u7`34\0I\H:]_
	:RC_&kIdXSdu4]c/Sa'$sDRS0pfo:(%BJdEO&:-`s\ZW>\ZSuFIuOdrh&N/&$Gg6rr<9nrrBl9HlJf
	rV!FU%p`]/kjp3Qs)ZKeuILk(8CJssLBJ\!7!"/=#n.(R3pBr6^E?f0^0t2m*f^`:\cYNO\&RKt':d
	=/NrK]\;e9Jn2!1oa22ngI)[u(#-W'6F)cOOai(tE)0Q;'0R3_#g;l4LB:a_a)PSu$@BEfC7H'&1X4
	+7A9NiI@C=.iPIO+3Pb<qX++Q@"1h!nJ16b'a+GhrrC_^rr<KuN'I.&dJj1Y?@Tdf5NlJQQ9XlgGf0
	O]St1?fPYoO5jcA6rG5V6A5Gc-iMY$fSJc>^:rrDDjrr@eK`ZP-Nkl1X=Y<UsD+7q5cb9-Lo4CS6ic
	VD6D8grbUo#L1t]7,1\+4B'E7="n5"[N(fTmuc<rrBr6it)-8FFV51TC>ejqA9/3AWQaH*\dTokGM\
	3,ntAeq.'/K?,&Si&*\$3,/!pUJtRV?^\]R3iMc:%rr>2C5N43>paQOI$i^44a8R!<(k;/+YND"*3?
	e=*qnK;kT6:J3\,QF??@Tdf5NlJQQ9XlgGf0O]St-tn($GK0"9+#S!81l^!"DGW5PaQqo1;@jOT&A\
	hq)em]*%n6rr@kY5N&I^oIp3e+8BS5@K->R:651-oDT)Jrr>Cc!:6uj!/@8g+8kcsq4saF8:N1>n*@
	IGh1>MVrrBu=TC>ejqA9/3AWQaH*\dTokGLiJ7="n5"[N(fTmuc<rrBr6it)-8Fo9Zb7jL<b5BleTo
	BsEnQN$sE/'mu?#Q5&1!4'ZE)NP_bo@'K6,/!pUJtRV?^\]R3iMc:%rr>2Crb3dUOrqjh]DCpjpL&J
	DJ+49:r"T>5L&V/+A,cN<7uT\.l-]M2&RKt':d=/NrK]\;e9Jn2!1oa21mCkZ&*8l.rHA,9YWnu!pk
	n\B$A&3W6N7&PZ2XfYUW+DRo]Z;TLp'&$W#tXbrlZDYC-5r)!7+ETRS#!hL[rLRrk!W-fH8Q!r'bo2
	!!PXf!24o9=T8B=;<&2dH?>>M!5[8/n5L8LOu1QNA]Pb:d:S<q5Dors].!e``;]fNk(L*PmSPMj8%F
	(nh*+I1BkX9)+3Pb<qX++Q@"+DjfAH("+8@7.mDGZ)pcIN^m1\J@^P;T;TtC)&i*AE5phfO"rYT9`X
	*[!V6h"ZAOZ/59/T+29>K>c>mh.H9&6[5?)6E4s0?lQSHf3NB7JgNmd(6'fOml$;@/0-Z0&h)3)XkQ
	#$p7mqBUX7kjuDdOT+ZWb8)_]"`5k'Um1!i1e*L+)7!kKn)HZS2!<3$%nG`K@;SFORVc`H_`/j[AQ\
	qmD*;D#;>CAtJg$dn.^Ls]s6h(^QP:i'ZIu%8j\"4B)DOE>4@aqOX(Ob;fEr*bXD63F!$#3dAV$_6r
	(IYh\o'?VQRJSoB!5UP-CiA%Ri,?Y3g+2**_EDDJ^C.aUkj>AET2pq(,/*MPrNt,glTQ$XB;W^b2:%
	;q>N*m=>ts>i&8:oI3cBf?G!++1*H/g+%u>ZLYP+^c9CS#$Qb\*+?5**(n8lDE*;FOCe%j[:=uV._)
	<"j^*A^15/7WrPON.bpa`DlYG:gh0X(o,L?##hZX*&]gC=ef@SaG7ohp.kl'j(AD\+h3FBBt!mq!Ir
	1lZs*.j82:2Eo(R1-.+?Pg"YG_`GKqhAtJ0bnID+a_*4jV%hrb78M/5eim/"s]#B]3F2$g>n9s`0Is
	8(CENGXDX![Ie]mh_#JD]%dp9spr5@a.$Vo2BaUZ4S!ILg\*Q724iHmu([d^ACS)FoP"`L[jp,/3QU
	MtG)dG+(QI`>UA6VoL^;P2"8Qh*5b(.K9AQ:B(=1<;\nT6`4\qTBuI8]?!tSli&C/4n_$Bjd%bnBqb
	#dMEDiO.nIh38bRQJh*dDc6qD^8A,Q'!V17E`J+-?sfhYS\[J66g-N$cloIEK\0_k7u?A3ChHb_R@E
	CfC:UG%Hf*N+]9csXIR'3j/bZ6'SB$Qo:ol*f&ZKg.LR>p!.pY765qV!:!(ntJhO>-3e8T6@J1(rmf
	.]8@JX8>Gorj_\qoX_eC1BZn^lrGDB3r?m*5=.et]&,I+B!+h5h2'+IO!9^7Mr'bo2!!PXf!24o9=T
	8B=;<&2dH?K/6;+DlrQ9TTdg[jjKrg*Qai[`@M.L5n[rrB@FrYgh7J+M-arZ]#T!.pknd(fH/J)R?r
	L]7?;3rWhAUQQ_B+1qC:q=e9H97QIHkPQ%sre:@Pfjk$^%7c@Aq<?<,!"iOe_,*A[?i?9TnC2^#rrA
	X]Il*BeaUdKoh>MNpqli;]^\E]XrX+5V!(-\cm'6QjL82a1r:K4Q!/RgCi2@ai0E0-:phDp"rrCA?^
	R@bCjG3<Hmf'hIIFoXiSbN%&BE%r87D#t!g'p.;A()cm$:TGSn<_(6?/%8'o3dVWpl24S1Q6/M!(sS
	h4La*'q(;JNrrBl/rr?q4gTjB;^M0n*&&oYOnAVO#l8jF4brp0`#(/5Umi`%(QYG@g#$>PF)84O9,$
	utK>1L"9:L&Ta\T=^^f9_OW_U(S3eF;3s6S6R-bd#pWgVFiR4S-eV32)'T_auE-aNGQ#7]t/qCepZ\
	p/f%jpa8l)g&"HXG+*?c&(s2-Q];^Kehl"=n.)k!GUD8(b:#5$L`S%Td/4?Jmoa..g8Bb._ahDeCe5
	WW=@ZRaIET+t&"fdB)HZTMrr<8]J&*3h:]!ET>k!71j73-L_KU<=m.9_%?\?9]"uM<_c/E#h*u0/bI
	-4,RXKA=^.IK;#nCLpPO&W^@)@"Xf7H5s\cbn>[WEJIl0XJ+_Hi=>brr<8%>52`8nE7copaF1@F?^K
	\3_2,$5M;[f^8#sriVDpdOu]Z&pndL%#-a:l["PK_U#@'qgTI/o2j.OgGPYt,1onshj26<bnFqRJ5G
	@jF_HJ"EiL^L&B1^SE%h<i*5h#*WN=S>%oSZ8A1p%iidd/00b>$FWgF+5PZ*CZj)f&Z&@tkiK1f^Vl
	<E=+"\)(KRrFs_dK5QPpY&F^rU4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<
	S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U
	4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S
	!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4
	<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!
	U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<
	S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U
	4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S
	!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4
	<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4<S!U4>K.f`
	ASCII85End
End

// JPEG: width= 354, height= 198
Picture ebas_jpg_LAC
	ASCII85Begin
	s4IA0!"_al8O`[\!WW42!+Z'0s6K^t7!3!TGlRjF"98E%*WQ3?mJm__A8bpg!+`kF!!!'"gAlm,&.8
	jR$k!UT$kO3c%1a6o'G(fi)]ok4(Ddl0*Z#_5)B'D5*[;sY,pOHa0/GC;00hcf5X7S"5X7S"5X7S"!
	>,hQ&JG`k&eYon&JPfk)AEr&'H/;:)B9Y6-86Yc*Zc@I0Inb'-RUMs2)R'A2)RWa5<qJ!5X7S"5X7S
	"5l\V"&I8BV!Fc-3+ohZV!<Wo7s24o1!!*'%!<E3%zz!!!-*"p4o-#6=i*!s&B%zz!!!!"!sAZ:!!*
	0(!<WT4"U#&7#64`(!<<0'&Hi7M+Ya0e;3<&#OqSO<EIfl3dSupfE[)@9@Y,?aZ/MEUP6^V66R4KgZ
	GPUB6rk*9!<<-&"9JT+"9SW(z!!*[?![46>'/:+c;/q/l_(n?>i?J<U!"8r1!!3`7&HG#qhkD:r+s;
	H)ac())PYomll%u='h#<tP/^J"_08nst:LqpEX%MWKaSG`-BJkA[Z9DdPGI4C6j*\-j.)r0tL9u#b[
	de@tNZ[p+1HoQsaiQ?)P;J>qoF,<p^Tra_:6P.uD_ls<;Nu!?Rquo8[KaG_lQ16jY5;1`O",KN4BG"
	>XWkJnW/-<D+sI(4+<i!2+s8'R![8a2+p&r2+sI(4+<i!2+s8'R![8a2+p&r2+sI(4+<i!2WT$%$PH
	ci3Bg'F;hJhA/b14cHBlf7Pd8G7?==glUaBq,Wr`JI(3LE#/lJ<LDZE3iA<ID@Rj%l(/U=!qW42dE;
	#mXKlZ5W;GichY)gKVd@4Eg6%^-W`%rr?O,#1D3e96fj`'P(SPl/t7\G<U,hei`'j.cJ7N=n*T7WZj
	!R+sJ-R+p&r2+sI(4+<i!2+s8'R![8a2+p&r2+sI(4+<i!2+s8'R![8a2+p&r2+tk^p*&0W[%[Jdb3
	;N[`:+43Y(;e?Q8M30s3?oL><_5ir]7')%QS8-[<-DG.d(\.8^A@7ZAo-%Ea-i^Z.qTA1A%]*[Pin@
	)BO>_U4%gTUODTJF)YSV-HWH,OMC(\(,)g5G!,Fj^$e!4i?J/#ZiK(,r![97&#`+"eL^8feLkl=mJ;
	B!eLk(;;#`+"eL^8feLkl=mJ;B!eLk(;;#`+"eL^8feZ^b$WUK`e<m<'L.3PH:+GH:&AR-cK$\<Ga-
	'C.c5g9;A,a`BS.b%g_YEVmG,hCNG"qC:XMOm=)RUQX5J`]MAtS%/ddgj?HiN,In:ZhU!lIsT1Mq/,
	H?Irp,9QL"Uu)UUf.!'-BNg$.fE5$W'cYI+4P'MOfbh]2r[0%W0qEK0B9=WsHJRK9d\KZd_lqq')"b
	AUE)qkKM3X5h+OFn#ib1\H_ibH9Y5AF<]Eal"t;OmM=Uou8Ps;C;]-jlDFl*CHOC/9+64NK,?P]uH%
	F'dTs6<Yq'JI*>&6mrY!0IA(>O0r6%^\PBPuQOh"d]R+LuJ<&RbNZRNb*eLQHk5^T0BqZJ3*/#oh*r
	KBu1/`TZ]h(`_%UX,H:F6Yla+aFrP<)L(j@!!"&J5$U&.oKT&J,Nd!>,kT(,`Q[2o"VkTOc@a[S^&p
	29/"%B.H9G]_!-g6mMb(1]r"g7:2#"@e.rA*JE9"Xm+h]+DiA*/&-,rQJrlb):>c60oaW`=9DgnL@=
	k&6"Gk1hi5-\i^"5r!uuIp&[#O13)NsS1bcl4k'LTpK2\Rc!MFLs:jYX&PE,ETOqr=u49Iqq@sM^5M
	XJp`f(oU+g.L%lJ%G=lKH61O9?0.P'T\+F-W;!gl:1=o%1^b8g;f-HHMV6i"kuGK1h.TY1Jp8e:]Ua
	B,3Nr.<mXEX1UKRa9A\^Mer#WCU+Gd!mMPeuJ!U*7Pt8CDr!gk/'>lgb=ti-Q(-$#DNfgtkg4JQ(A:
	A^qmai[tF;p-[-/Mn4Nfic86cgOFDHq"]SW/'+0/%V5Z?L25U+KdR[ubDF.Hs-=MLo_*iOEHH10gAi
	\?Wh=ng`*UZj#1,MthVpB#+Z*7'@c8A(p'[-]i'C+Lsm.)4i@kEKVh!RP56b6-a[2/Fp:0Ai[D'3:;
	,3>O:"Bj)AOfGoD<?**^\hXVQjP`Ygc`\]oT*LC`GCSWJ3;-D$9JTR8=lM?J4K;qN,Q)VU6pgBdE_]
	c>TO!dr0#3<<+*[*6b4[,X-a6q"m&'4a35@;-UT[iY3$LrTFbb9j%Bh7iUN9:,"pHEHP@D@;[@Z<<S
	8NtJY8#<gh13D-n#onI;Rp<.,_GZu7Z])G"'eRUkIM;PRCAF,e6B-k+_Lob6Wj)J=4b$j7cO[jI3=M
	Pj&?9l4(!'/#H<.-6qS>Rjb=5t.;5.-<QcXW@:1#kp\93_uN$HiI3nlMNg1kL$.r4r4_?MK/p96)Yd
	j^ar8a]d0#3.,&_<3EF53rH>a!$&B@IZ0/N':lORP8ed'A"#TTe:$763DKKoMYa:J<dD\oHo4B<bZ:
	s:MjtSApC5^WNKLlMVQ6GH66[Nr+p&r2+sI(4+;,S#Nkbfi=H3FepFDWT48pe")<uR-L[5%U\;'5#i
	:!gPB]_Y[-hj,fO0koN!I^6*%ku0h;9M(_Oho@WG5VK8Sn=YHXQLG]B5A.<C^kD&7sIb*p-a'ea.&Q
	p>YCC&72+d2e66?rF/\er7Z*aeXEH)>Li[e2nNE\q>+&$W[;>1_/VUedh4$X_JlWN04>.O9)%O``Z&
	Y?CSK03?kqjp1<rW.AqX,Fi/9+lr>FLsNdU[SJ%DRiS=#"<'33s':QFMfr:1"*1'0IrLfggBq]5ZSs
	NajZ0a^7IVm<-I'#`o8kelR!B'LD2E1>Fs@N0;&n7t#l.7U&:`2)n-%a&EM4;.R)Hb2i*J06J^%\Ed
	hia9J:2Y5i]\kboLPY8Z*PXDuI4KQ15X4B?`+DaqoRotAV^Q`E-,.u^#G8GI\Z/S!6[[Pu0@=fJh%[
	0F&i$RfBud6S]o"%\A-Br@q?m@N/Si]OW>[oUKANkJt'lGiN)llA<"fj*@f>!VDCR9L@V'm&/D.).[
	]geW32R,UUiZ9-kX2?DRg)0".lr%.iS(Ru4[Lpb&Rf=)O?\=Q45nKZ_g<9Y,-2<8"e[dt5u(7<<1LN
	AT#_]6_4!V"f+ia1/VCVeX*NeRl,UNF3`>9pSOL"^^^;!"^\i:A!K-%!PY`5^TdeaQfJ26WGM5oPR:
	8q[,])Y$W(4%c1+S%gJk=&epldg5q/\*U-0=["_bEpF6kjL_r5OFH4<&,mc*^*bGJep+f"=YD@"ie`
	Y?-+25->O>7s`r?#\Fb"9f\&U.n\W5H+)Gl`jA.h%`62GL#rr?uHrr=XcEmJ_O]q(I%!H',nXu3Ps7
	qi"*nLE6oOTrPR&I#gD2fq`/#H=GU*HuJCnYPX;23/8Wk?!a-[_MXh_WL:?f%nq:&iM]d2*((I$?':
	B3b^fRB(JnW[J?;H`GQ1VbuObCoH:[%RuBM=$*V%P[r'C.P"R3cm+8W/'b3+V(EP3B`8qkPN5Q"iZ;
	7$g2o#I`_"W\4<R%EHi/T]$DCf9R(g>U'V&um3e9)5.Wit@l%i:GCiT]?\>[*BgH[ro`b6con3gDP#
	rdb9O_OJ%7!"VTip5sMd'c]MtFmKR+!F(@q7e4*fHWEOd%1^65&6J(q%IP"Kou6L.9W*8s3a@)\lb%
	;9P,je)g1qa3FBUc/)RHl,98D<87i3l6hM%M$7Su>`AW5[2nJ'2aKCA5t"%d9BW^lbd(#S7(5,J5)P
	FP.-j+^]*@Msi&J'q/A9DbDI8O<#&mY)[CSuhpM_C\":-pFL+d%KL)5!n%073eX:1m4L@2;E@#B+du
	];&,Hs,5SDqpoA4mOft2#boY[`!XhdVeMB%%&Ml8!SfX2"nrYgcFNIS)3=BLqhbr.+(u.!O31%Zg-#
	fQ?gZcpBPkA'u'08!jj#H'j&J9'M6pq/H>mCpLmVgB3$`:Z*V9L`Pmq99`8o140'LY2S6kOHAgME^U
	m&n6b&eJ@fimMq>6YQ+G8,iSP]JKNqTB<[uOTohi!o^YIMdUs<d`RstBH/EkY:@;q[t`Jj4(oNM$r%
	.?7jD1c(IUOo-\enK(`deO(L"SlL!=UOCV?=9;u-`SC/9U5WMu\shpSlfJsRRr(`[\6\q8g=mFoV'k
	=Ad%`hQ/*ffW"o/I.WWKM90rdWRXKSZWnuR#!Q'E%VI#CS_\LZ%f?;BjBdZpdGpgrY$<7MV];.rr=P
	!i^dQfd*Q"$Ci:MhL^F9p>7#>4A_blFfNY&QCPW/+73"=3WT8R9-@fqYY%$PKL(PpAPgV<,3okI0cu
	`*^_q<aTTZTmTl`4W`6?O;##/:Z5m8Hj_7EFL?EgF_rqB7[`e,uq-cI+V&V'6?.3"lE9dk?bE9Jp?9
	9&gc^$7edI-9E@R(=s/H$YQn=ULDNr==E!bjAXG,5ar-i2GtO$Rc/MoF>`H*!4Qjd%UJ@G+<i!2,*.
	4ub:?^J+1Ff+NcuM[$(=:^>YfjP7bG_,XQrMSf>9\.JU<OJQ:FRkX56L>H-'!hQ6(5BU#N;qf9=\:D
	mZPi87\-Yo)#W#Iimc'`30lDH9'O4)t:7=U+5;@2/:,[&J=LVKosP^j4XWh^/oZd2r6`^bS;+f;gRV
	U<)Kp5JCV^6.>XC5QR4]V1=WK@7*4G91((;E[DU?l>P10QZPPq)e+GmtZPPq)eG@<LE4WLKdRuZi/`
	bd+Yk,>cY>uHXZFc.U]:*F'cI9EZGPMQKhUs8l"5#Hq?m;Ap[7+BQ9j-XNY!7^*1!%IHClCEBn/Tk:
	6!fj8cT?Pf")[)Fju0enJk--1HL<bf+qE0l7l:h6\Fl-Wc&^+QZr$:\)"KTa.n5<$l&hJ!IcW;)Z6g
	nK![86q$_1l7dSA^4.R#N2Ij`1Jd3&1rO34nEhl-!fn;k#9*H-m\%d(9I8Tn?E<8A5AQ.e(p!"3*GI
	Nc[@poIia,pO@=;/$k]G^Gm&&dLG_F9U-PGaAr*ne:'EF7(V,enW5aWbCe_da3VlQCBB6Y]_?!mOh/
	J/="p-)+.>+KpnWjGdcKSDiBl%CZb&9FA*;\eST%m%b\C/,*5G2-#^BgLC[5s=^*!DmQS=o)d/62Ca
	-Qj;t"`;)'1$^S5#c]nhrDRZD!Bb]XYN?4/a1E<I]P@].JiI^O&<i0KRqAcoJ6\1p<lVEHNpU(d(:]
	aZ5r"_]SSPFPt?0mI<-^bi$S4pJ\K<lj[>`rq$g_Z\c['hCf%lRdO\8NRa\3IHR&9oIb?8<pNCO.##
	F)bhkh1)eBath.!d3gH`'T0fEV5A7fNdb[!!T_DC[b7ddP\-P?'QrXk-VR@MQ';6!Ykj^BOpNLM=ZJ
	0=(Qr]IZKhFh?o1a$OUXDW6>)saI+qPpYKGaBLtL6F=>=UYaZShoi?bS;]+Q*S?d/>1'inNDLrD2e&
	L"e1t??aZgY6'gOnX<RN^B5;Etrj48eF,Z8@OS)C&YtW(*1m]i-[)uVK4GACrZU>7+keO?uPuhmR`-
	a!9D/pDabV=&G1#6(2lsSYJH9FDA[VmOK\`(`umPm&Y>Xg;N2(9s)>11H4Cd?#'\AKb/gY4i=WOIu!
	0YTm&eN.mj.5m\dQ%LXm00<^f='^Dpk)&re96h$??\7:<Hu:.ZaQ'I1k[OY=Cc`Wseg,+q.u$N@Ska
	M"%F([7/29sllWE9`P$)*J[#s[K%3H$kmP@^G>Y,lEJgoLj]:3-=>KUaI>r\</r$Ea`kh+Q7%Vm;!X
	/)(#D5X(>G[fimnb?c@Zbs4r+'Df(VJ?RXLJU$,m>I9VpG\>M`F?-=%C0O=/U._d8ZXb!l@I/!K4B%
	D'6'+>AH)W^1N-KZ_F6=@XO`s?ZjSP(PM9YeTn;:B>5nRQLeWnCHcZlBGIS;V'2WG>nKe,7c>scV1C
	M)PUSR]%Jd!"IXcN="L%KUj>^:31/J)5kpe>NpT^_[dmK=2JK0PL'a]W*CQLWa8h?Q*)&c`Bs\;k%/
	S*i=NWQ*XQS:X[<rT-t)OglBR29ih)\)P7*#`]qm0,;uPpkkO.1<J<V],PC<P!"kEVD@,t?k)MMd\G
	<EVs@&^4*?c!#d5g*&4p^/915S,]MR'lq\DtfAVlSV)/H*=LGlHbdDD[<=kq:Lmh^th`_$112j)6hH
	)lZRlu?^:L'dc^espB_PR7m@GQV=p@R%C.d?iis93]$P]q)eOp<YumG],3Uj<!W8j0<dd?6OK8b"3p
	i@Ch0hAVmglQOQW4>F[1'/'6\p_^7IW;dj`kE6&mtG`]J$f35Z5\m.]#F,;XG9^:9k,%[%[,=Jeef\
	Cr%[0=!W2a)m_)e!M$,aSF80+Y6e0hSrSeui$u23Wb)0K6HMF7&JJTuF+ej!;Z9!l+W)@Z_c/Oc,Mp
	`lgH,kI<CDN8@8j82]Ur4PYaCZCFF7jt=<I&*6+GH=+kB[$T4T)`d#@hd[YgqS63"8Mqijm3eEh0W1
	Bl,9NuJ%cOec"gu6MGoJ*8_t0MPPkn0'Yu'rgLRPjFhCB>S&$>j3#ki1?`A8kO5MCSgiHo[i4'=0X\
	V";Q4Fq]ZIO)\uXp(V6o&8=&!)*=lZ#^:/bL[[4!/3hi8T?9CPj4CnY!919!0]YS4MtncNY<HbXVtL
	NO"X[(at($:`SF\d_K):)O7;5s4.rL,-Xkg7IY*G?Q?6JHkM@2LLNF:#[E\Gs*jJ01&usq!%lJ(\`[
	`k\E9AhJJpS^p)FVeD=V^2+aQdJLSR'_JeU1Oa(7n#d27_H\#]kCteYr?ZeQs*i9fs]jon:n>YC,A(
	P;kWihTuE0<O*h-Wu.X#8&2G.F-O1hadB+E\bDKoUSnJNN1D>?B^FteKLDhZGRHW?1(-$0*0R[0Ba[
	:dUit?.T<UZAHt5!OjhmaBU.C1f)AiRb3!6[3'r=;5S2kQQn.mfN..7>5ob?,rV#LEmVr1\=P[uV6!
	ZcW0m5fq2QIPL)-*'EO=Q=hu+3?$an?M\\XX%`4rbhO32`A/>3W,K[5hAMCOL^D2k$SH(KK!-!Is@D
	8ck-IOo%6aXGcMZaU=0utAH34=1a/X\C??hPi>g,'ZJ3JZ(Ei_X)od`GN%uEL3-/s9V6WhZ17*B!0B
	+n&3H$e2m%[3a/1cf2m+11aAI@H&Pi:tP53Bo(\sD2o5"[5[r9\U/_=%TVT5*,gX_=Ip"4=B%6('ib
	JokN\Zat0Al+A7B]<f_edUOrbAHf1))fqIh[UX%Qr4#t;X>rHD!3q!DTp=0(C?MJEo`rLD25.,d!)O
	1k=h[(c?fY\I&7#+CUPaR8ZFZ(b_R-7oQ)2*0D.0kk]*fPprXhSXcX6H0>3k@kA<.C;9Pr3KFRfO-U
	7[Bd/](=,aP_;0b3I$nB;"i6$ca.G0.mEZqa5&F'R\IJ++_VoYOT(#$TuIb3,YW$3eF6)ne/CPK.Fb
	M^1hW@8K't!m[P,!#W`p3Du<8+)q`C#(io=8MsP837QJ3WL/1ot7k2t3$jK3bD)W,;nlHFHjXokQZs
	sK"Q;HV=SqVCbpC$s@fD-f_>"Spj6&`rm8"\#pq^pilbA2OL`/H9)N6l;]^fC+B@fHFsiN=c"5<Yd\
	[lgBSFdl05j_BT+S-[g:mP9''jq0H<NZoN+%B87O>6+jLe4.eTmY1$>&J58g1c_D8'kn@)nq*heiG3
	X.>nkSE12EV8eFWgG&J7"B?=L&QG&Z,"fHCrBg.C/\GETS4,%<!q-;O6B2NO?fpL>324-h>6\])iOF
	,`aRUoQWNpR8_`Qtm*FB_8pr5I"5nQOq`*\=*HD8l_@E05R`u/.IB(]^[$n$l!^D0).s(>3-D8A1VQ
	M&&rqD*d8Xi=t\jUf,OXDLlTDA5tQ.8(@k()%&OfMe?XY@HFAN=@?6#W*ssK\9j[G)`CWI=(h44]JI
	rL@Lkl=mJ;B!eLk(;;#`+"eL^T4(jgC)TQWI&jTSR?0b3ZAQ@jJU4r]>kpH"8NO>DdIPVu*T1ks=!m
	?(];2o>C@<'%Nk2ic@A!r(S6TQ0o\Ja]MlgBuIF]c''&9EuD'%o^-Uq4V#H1[^Le9hE,Lr#iUW6XC0
	f`;"M1i>ih$1\L!4F%r@6&VNK,0E.Z">77PXJ'Nk6uc2+mYLl,me%R/dgPa;qg5X7!!!V\q5&fM.<^
	c%@+Mt9<!\i`-CaL51FR1%CGZ.*M*%_=H6c%_-D%g-%'Qt49F#n'%I-J>DgGn=_QA+H"3G]++BOFlo
	_=e,kMJnYUF9Wi/R2O)q,rrAtGh)cX"Bm057>A<iEP%aQs^f6uWU<E)HAm7n?NjE_Bh:l2t\YRe)(b
	5:Hh-Iio1X2G&%HBQr4DXc;bg4f+?6+1rf!Nk%IYs$m#!MlU`0kgBF`@SeURMsH"GMJ,HG5unZMb)B
	rr@&Qrr>.X&8BNlrh$Uu!#g@`?RPjBqjkLBksQ;CLk).1DnM@)M[_#"W?8Tr]o%(lg35)k?MDb%3UJ
	\]5,<Y$]_bZ%\E(ib)p/5miS+k]i8)%p>WWhfJ+b@jj*\-j.)fN`)U[e"CLq8(94hD7EsC+=GtLE+/
	8I-<LNGp^clsY8+s8'R![8a2+p&r2+sI(4+<i!2+s8'R!lNnT>CWV1Z;&k[nMRS]m\s]`5J.cj;K4W
	(_4H66,VWP/eA4-*YJT`p$aiQqib7k+p3?A*2cj'uVhEY+Q3)08SVMJj/@PQY;5%[2D"c;]F[aKP>u
	#gBVkHo%n=dm-^F>87hdrSgo3GWQ-aR*mMY&$gK,\g&igd^3=0gKe6HaOD#4k-V[_KVRAoJQrlrDU%
	o9YLL`_M,/31YVuD^d0rKlE@qHV9+L\W=;3S^TaG,`3L=B`WS?S6bPi''foa0ohOcnJq*bd*nrAJF\
	5C(Aeok@Dc2,ggQN5cb#?0MO*NbCT6N4dsdS+J+ahqJb-#\r'-fcC>U7oICNjZ]5=2Sl8o)=EMH%#8
	C>KX!9.Mb,XGMMelNWq)#PrZP$cI`HID%(hr2#'dn60]\uL13nRFPV3[T'+D;[j)H%9C<J$!i19\&9
	0(QlhR"6<Z0PXVMPpD7Pl#j.lOTAa"U[Uq%gV/01Q7+cFI;BGNdrZq^Q0#SX_Tt%VN?"Yd9[oo\5D.
	aaD*N4.]&&kIC<EaW`D]$F=r]U]3WgnToJ*U/rX;(ILgeWX_[`9I;M(E83SN:isMLOiDG\\R"IXQ53
	S?GiGeBtPNluAq7"]l(>1-$>$no84fYW%b:pW!itiZ(F^FUq*Z[,JZn(K!mZEoqW,G]TQtUL!u(PLe
	hlEVSBL`n<dlD#45A/^hm0jR93CZH"bZr8_K:-(gD:nH:$3cHVU(ks9QML^8f-!0ap26!'\mo%(M_%
	4.U=H5lArfWqk^Z57Dk]6qZTY*d6c7cheHh=i_2#lWqT=."$#@]j=Kc(87pC%d8$%G94V]o[%N=M91
	t^LGQn&44Qb=U\bu?iViq\;EWNEV51pLo&ISL^8feLkl=mJ;B!eLk(;;#`+"eL^8feLkl=mJ;B!eLk
	(;;#`+"eL^8feLklG(hQJFfT6ir)l_.T\J40t-K*4+:EPmjHA^m:p%?Rq&ao:rI4I),sY+6FPQJu0`
	\I3\rMBruPV#?]j\E3F%os;"d;d2=NV-ss[fk$`*h7M7`d-48@m1,D77-q27D;2a?m1,B3cHtfX6r(
	oGf%mshcHtfMD!_^tKLG13h/1o[D!_^sf$;Y,=@>p-*S0&Yf$;Y,9l02,Q%VQlZ/'9O]km'GQ1PW2K
	2AdeAhrdiCUj!rk^.qgb3U:kS!#c_R-*"&C\>$@3`B6E6`"D)MV:%-R4MiDN!XGCmH+4F8t!tg8f;Z
	tAgt?9Xdu06Rb?C8.gV"o/<9%6h<S]eFJcKiLJ#E-G$+1@mG>9pLIu>pBQU="-Y8>(DVaVkBQU,[G)
	&],,'I)V[dDq[G)&\*B4uCg+t$r^lYbPEB4uCa[W[Eu_BO/*m^DN>[W[EuCM.=&X<K$'NpCT=lXsmQ
	VRCZ'9#;cq=RNWbhR7T_8o&'QFK?Z6AWH(oh<S]eFJcKiLJ#E-G$+1@mG>9pLIu>pBQU="-Y8>(DVa
	VkBQUGY#-N2snmQV$>iOt=dQf.j96lcB-"`B:4LLVUQ"\PWG-jY*&TT)6gQ?kKMiaM&rRu+gc-:$`W
	AaLG:Es3cld?]-X3],4m]2M9rkH(3Q\4S`m`G#IQ\4S`m`G#D.eL17['o.aKBhLbampgGKBhLbampW
	&QJBpCSmDr.O1Qd\SmDr.O1Qd\LmhOh95]$"5-@*9T-AQ*5-@*9T->InD9XZCjl$!Fqm(U+jl$!Fqm
	(U*M5@[<[ca!0lJq<SngBcVlJq<SnffEHgsXrK?4X)t]-k[s@c59bl8Qn.,`k!1EOCi0=!^M.&JX7t
	a,SQ-.j)fU9\`N0loO9RiYm:qP^C!LkA*VgYO_12>^b9h6q#1_TD"eSm63`l4M2b;+*LGB4M2b;+*L
	GB&Or)BcBd8Vn9nPiffhgpn9nPiffheldbC3pF3DDmEVF#>'?e5bEVF#>&JIfTBl20L#M$lNPN5Lm#
	M$lNPN5,+/\.^e4M2b;+*LGB4M2b;+*LGB&N$rYQJD'#I9_3R5"+u2I9_3R5"%fegR;>fbJEjkpLO(
	5bJEjkpLO(3'2*4WD9jj?e]6L0jA.E6e]6L0j?u]o\YZbt]H:2sG#+5_]H:2sG#+541q)P4h"'r_>^
	b9h7.Thq>^b9h6q#JXRTjjV_=_gBAGHn^_=_gBAGHfN95\H\cS#ORa5)s?<u<?jn]L;1EAbjVA^(7g
	[+#.$lO%u/NSS#=B`:)rd1KX1s4I
	ASCII85End
End

function ebas_help_docs()
	dowindow/K EETA_doc

	String nb = "EETA_doc"
	NewNotebook/N=$nb/F=1/V=1/K=0/W=(243.75,195.5,762,647.75)
	Notebook $nb defaultTab=36, statusWidth=252
	Notebook $nb showRuler=1, rulerUnits=2, updating={1, 1}
	Notebook $nb newRuler=Normal, justification=0, margins={0,0,468}, spacing={0,0,0}, tabs={}, rulerDefaults={"Arial",10,0,(0,0,0)}
	Notebook $nb ruler=Normal; Notebook $nb  justification=1, fStyle=5
	Notebook $nb text="EBAS Export Tool for ACSM/AMS (EETA) - Documentation\r"
	Notebook $nb fStyle=-1, text="Prepared by: Jay Slowik \r"
	Notebook $nb text="Paul Scherrer Institute, Switzerland\r"
	Notebook $nb text="\r"
	Notebook $nb fStyle=5, text="Overview\r"
	Notebook $nb ruler=Normal, fStyle=-1, text="\r"
	Notebook $nb text="The EETA utility is designed for exporting and uploading of data from the Aerodyne aerosol mass spectrom"
	Notebook $nb text="eter instrument family (Q-ACSM, ToF-ACSM, ToF-AMS, Q-AMS) to the EBAS database. EETA should be operated "
	Notebook $nb text="on fully processed data (some features additionally require the toolkit used for data processing) and is"
	Notebook $nb text=" capable of merging data analyzed within different IGOR experiments. This document provides a brief over"
	Notebook $nb text="view of navigation within the EETA tool and instructions for use.  Further information is available thro"
	Notebook $nb text="ugh the <Help and support> button group at the lower right of the main EETA panel. EETA can be started f"
	Notebook $nb text="rom the EBAS menu by selecting the <EETA (EBAS Export Tool)> entry.\r"
	Notebook $nb text="\r"
	Notebook $nb text="At present, EETA provides full support for the Q-ACSM (requires ACSM_local v1.5.3.2 and higher) and limi"
	Notebook $nb text="ted support for other instruments.\r"
	Notebook $nb text="\r"
	Notebook $nb text="Throughout this document, the syntax <txt> is used to refer to user selection of a button, menu etc. (e."
	Notebook $nb text="g. <Button#5>), while italicized text provides information important only for a subset of the supported "
	Notebook $nb text="instruments (e.g. ", fStyle=2, text="Q-ACSM: fully supported", fStyle=-1, text=").\r"
	Notebook $nb text="\r"
	Notebook $nb ruler=Normal; Notebook $nb  justification=1, fStyle=5, text="Installation and Updating\r"
	Notebook $nb text="\r"
	Notebook $nb ruler=Normal, fStyle=-1
	Notebook $nb text="Installation requires only that the EETA ipf be added to an IGOR experiment and compiled. It is frequent"
	Notebook $nb text="ly useful to install EETA within the IGOR experiment in which the data was analyzed. EETA should be appl"
	Notebook $nb text="ied to final data and/or an analysis toolkit (e.g. ACSM_local, SQUIRREL) configured to provide final dat"
	Notebook $nb text="a as discussed in detail below.\r"
	Notebook $nb text="\r"
	Notebook $nb text="In most cases, upgrading EETA should only requires that the user: (1) close all EETA windows; (2) add ne"
	Notebook $nb text="w EETA ipf to existing experiment; (3) kill old EETA ipf; (4) reopen EETA main panel; (5) open each of t"
	Notebook $nb text="he Background Information panels (step 1) and verify that the entries are correct, as new fields may hav"
	Notebook $nb text="e been added.\r"
	Notebook $nb text="\r"
	Notebook $nb ruler=Normal; Notebook $nb  justification=1, fStyle=5, text="Output File Contents\r"
	Notebook $nb ruler=Normal, fStyle=-1, text="\r"
	Notebook $nb text="Output data consists of two corresponding files at EBAS data levels 0 and 2.  Level 0 contains data for "
	Notebook $nb text="species of interest in native time resolution together with important metadata and is intended for speci"
	Notebook $nb text="alist users, while Level 2 contains only the species of interest in hourly time resolution and is intend"
	Notebook $nb text="ed for general users. These files contain:\r"
	Notebook $nb text="\r"
	Notebook $nb text="(1) an extensive header providing information on instrument operation and users, sampling site, and anal"
	Notebook $nb text="ysis methods (Level 0 and 2);\r"
	Notebook $nb text="(2) data time series for Org, SO4, NO3, NH4, Chl, Org_43, Org_44, Org_60 (Level 0 and 2)\r"
	Notebook $nb text="(3) time series of uncertainties for the above species (Level 0 and 2)\r"
	Notebook $nb text="(4) time series of species-dependent flags denoting measurement quality and special conditions (e.g. nor"
	Notebook $nb text="mal, compromised, missing, or unusual data) according to EBAS specifications (Level 0 and 2);\r"
	Notebook $nb text="(5) time series of important metadata (e.g. collection efficiency, RIE, lens pressure) (Level 0 only)\r"
	Notebook $nb text="(6) flags for metadata as in (4) (Level 0 only)  \r"
	Notebook $nb text="\r"
	Notebook $nb text="Species concentrations are reported in ug/m3, ug S/m3, or ug N/m3 (depending on the species) and are cor"
	Notebook $nb text="rected to STP.\r"
	Notebook $nb ruler=Normal; Notebook $nb  justification=1, fStyle=5, text="\r"
	Notebook $nb text="Instructions for Use\r"
	Notebook $nb ruler=Normal, text="\r"
	Notebook $nb text="Step 0: Data analysis\r"
	Notebook $nb fStyle=-1
	Notebook $nb text="Data must be fully processed before using EETA.  Depending on the instrument, this may include determina"
	Notebook $nb text="tion of collection efficiency, modifications to fragmentation patterns, airbeam and/or flowrate correcti"
	Notebook $nb text="ons, RIE values, ion transmission corrections, etc.\r"
	Notebook $nb text="\r"
	Notebook $nb fStyle=5, text="Step 1: Background information\r"
	Notebook $nb fStyle=-1
	Notebook $nb text="This section allows the recording of various information regarding instrument identification, sampling s"
	Notebook $nb text="ite characteristics, and operation/analysis personnel.  In EETA, this information is divided into Instru"
	Notebook $nb text="ment, Site, and Personnel categories, as controlled by the <Type> popup menu.  When one of these options"
	Notebook $nb text=" is selected, the blue <Edit info> button can be used to access the individual panels.  \r"
	Notebook $nb text="\r"
	Notebook $nb text="IMPORTANT: within these individual panels, it is necessary to press the blue <Update in IGOR> buttons fo"
	Notebook $nb text="r values to be recorded!\r"
	Notebook $nb text="\r"
	Notebook $nb text="Once set, this information is unlikely to significantly change across sequential EBAS submissions.  The "
	Notebook $nb text="<Reference .itx file> box allows this information to be stored in an external itx file and loaded into o"
	Notebook $nb text="ther ACSM experiments where EBAS export is desired (gold <Load from itx> and <Save to itx> buttons).  An"
	Notebook $nb text="alogous buttons appear on the individual Instrument, Site, and Personnel panels.  Note that the operatio"
	Notebook $nb text="n of these gold buttons is tied to the active item in <Type> (main panel) or identity of the active pane"
	Notebook $nb text="l.  That is, if \"Personnel\" is selected under <Type> or the <Save> option is selected in the Personnel p"
	Notebook $nb text="anel, only Personnel data will be updated and the other data will be unchanged from its previous state. "
	Notebook $nb text=" The \"All\" selection under <Type> in the main panel allows all background information to be loaded/saved"
	Notebook $nb text=" at once.\r"
	Notebook $nb text="\r"
	Notebook $nb text="Note that selection of a <Host institute> is possible only after institutes have been defined on the Per"
	Notebook $nb text="sonnel panel (or loaded from a reference file).\r"
	Notebook $nb text="\r"
	Notebook $nb fStyle=1, text="1.1. Site panel:", fStyle=-1
	Notebook $nb text="  All sites must be registered with GAWSIS in order to receive their identifying set of station IDs.  Co"
	Notebook $nb text="ntact instructions are provided.  Once these IDs are received, the station status may be changed to \"Reg"
	Notebook $nb text="istered\" and the IDs entered.  The <Station description> box contains general descriptions of the site l"
	Notebook $nb text="ocation and sampling inlet.\r"
	Notebook $nb text="\r"
	Notebook $nb fStyle=1, text="1.2. Instrument panel:", fStyle=-1
	Notebook $nb text="  The <Instrument type> field indicates the specific instrument model in use. This field controls the op"
	Notebook $nb text="eration of the main panel with respect to full/partial instrument support. For supported instruments, th"
	Notebook $nb text="e <Get ID values from...> button will attempt to initialize values from the instrument data stream. Not "
	Notebook $nb text="all fields can be initialized, and should be checked by the user.\r"
	Notebook $nb text="\r"
	Notebook $nb text="<Additional ID> is a unique identifier representing the specific parameter(s) being measured at the stat"
	Notebook $nb text="ion.  This field should remain unchanged if another ACSM is switched in for identical measurements, but "
	Notebook $nb text="would change if the measurement style changed (e.g. dry vs. wet aerosol). Please choose a short, logical"
	Notebook $nb text=" name without spaces. <Analysis method> is a unique internal code identifying the lab standard operating"
	Notebook $nb text=" procedure used to generate the final dataset (no spaces).\r"
	Notebook $nb text="\r"
	Notebook $nb fStyle=2, text="Q-ACSM: some versions of the ACSM DAQ do not properly store the serial number.\r"
	Notebook $nb fStyle=5, text="\r"
	Notebook $nb fStyle=1, text="1.3. Personnel panel:", fStyle=-1
	Notebook $nb text="  This panel identifies the personnel involved in the generation of the submitted dataset and their affi"
	Notebook $nb text="liations (one per person).  Organizational affiliations and personnel identification are performed on se"
	Notebook $nb text="parate tabs and most fields are self explanatory.  Of note, the <EBAS lab code> on the <Organization> ta"
	Notebook $nb text="b can be obtained from ebas@nilu.no and is needed only for the primary hosting organization.  On the per"
	Notebook $nb text="sonnel tab, note the distinction between <Data originator> (data generation/principal investigator) and "
	Notebook $nb text="<Data submitter> (responsible(s) for specific submission action).\r"
	Notebook $nb fStyle=5, text="\r"
	Notebook $nb text="Step 2: Generate data for export\r"
	Notebook $nb fStyle=1, text="2.1. General.  ", fStyle=-1
	Notebook $nb text="Panel operation is controlled by the <Instrument> and <Method> fields. Note that <Instrument> is provide"
	Notebook $nb text="d here only for reference and must be changed in the Instrument panel (see step 1.2). Depending on the s"
	Notebook $nb text="elected instrument, two options may be possible for <Method>: (1) <Manual> (available for all instrument"
	Notebook $nb text="s) or (2) <Automatic> (Q-ACSM only). <Automatic> means that EETA will attempt to generate the requested "
	Notebook $nb text="data products (step 2.2a), while <Manual> indicates that the user will explicitly provide them by provid"
	Notebook $nb text="ing full paths to waves and/or numeric constant (step 2.2b). Selecting <Manual> opens a sub-panel in whi"
	Notebook $nb text="ch this information can be declared.\r"
	Notebook $nb text="\r"
	Notebook $nb text="IMPORTANT: Using the <Method><Automatic> (step 2.2b) feature or \"Auto\" entries with <Method><Manual> (st"
	Notebook $nb text="ep 2.2a) means that EBAS may draw on the data analysis toolkit for its calculations. This means that the"
	Notebook $nb text=" analysis toolkit must be (1) present and (2) configured such that final data products can be directly c"
	Notebook $nb text="alculated (except as overridden by instructions on the EETA panel).\r"
	Notebook $nb text="\r"
	Notebook $nb fStyle=1, text="2.2a. Data selection: manual.", fStyle=-1
	Notebook $nb text=" This section should be ignored unless <Method><Manual> is selected. Selecting this option opens the eet"
	Notebook $nb text="a_export sub-panel. Three categories of data must be declared: time axis, data/error waves, and metadata"
	Notebook $nb text=" waves. The following types of entries are possible: (1) wave declaration including the full path to the"
	Notebook $nb text=" desired waves, e.g. root:myFolder:Org (2) \"Auto\", which indicates that EETA will attempt an automatic c"
	Notebook $nb text="alculation of this data product; or (3) a numerical constant (metadata only), e.g. 0.5, in which case th"
	Notebook $nb text="is value will be used for all time points. All data and metadata fields are defined in the Appendix.\r"
	Notebook $nb text="\r"
	Notebook $nb text="For any fields in which \"Auto\" is entered, any applicable controls on the main panel apply (see step 2.2"
	Notebook $nb text="b). Invalid uses of \"Auto\" (e.g. an unsupported calculation) will generate an error at step 2.5. Note th"
	Notebook $nb text="at the collection efficiency group on the main panel remains active even if \"Auto\" is not entered; in th"
	Notebook $nb text="is case, only the <CE method> title is used for documentation and the calculation method is taken from t"
	Notebook $nb text="he Manual sub-panel.\r"
	Notebook $nb text="\r"
	Notebook $nb text="IMPORTANT: In Manual mode, the CE wave is NOT used in calculation of the final data products.  The only "
	Notebook $nb text="modifications made by EETA to the declared data and uncertainty waves is conversion to STP (and re-avera"
	Notebook $nb text="ging to hourly time series for Level 2).\r"
	Notebook $nb text="\r"
	Notebook $nb text="All declared waves must be 1-dimensional and have the same number of points. Metadata units apply to the"
	Notebook $nb text=" user inputs and not to the values saved in the final EBAS file.\r"
	Notebook $nb text="\r"
	Notebook $nb text="EBAS files allow for an option inlet relative humidity field. This must be (de)activated on the EETA mai"
	Notebook $nb text="n panel as described in step 2.2b before it can be configured in the Manual sub-panel.\r"
	Notebook $nb text="\r"
	Notebook $nb fStyle=1, text="2.2b. Data selection: automatic.\r"
	Notebook $nb fStyle=-1
	Notebook $nb text="The blue highlighted species list is for reference only and cannot be modified. Note that NO3_30 and NO3"
	Notebook $nb text="_46 are included only in the Level 0 output file. \r"
	Notebook $nb text="\r"
	Notebook $nb text="Four types of metadata can be configured.\r"
	Notebook $nb text="1. <Detection limits>. If measured during the selected time period, they can be input using the <Edit va"
	Notebook $nb text="lues> button.  <Method> identifies the traceable procedure at the reporting lab used to determine these "
	Notebook $nb text="values.\r"
	Notebook $nb text="2. <Inlet pressure (ambient)>. This refers to the *ambient* pressure at the instrument inlet (i.e. on th"
	Notebook $nb text="e ambient side of the critical orifice) and is used for conversion to STP. If measured, the user can dec"
	Notebook $nb text="lare a wave; otherwise an estimated pressure can be given.\r"
	Notebook $nb text="3. <Inlet temperature>. Similar to inlet pressure.\r"
	Notebook $nb text="4. <Inlet RH>. Similar to inlet pressure, except that it is not needed for STP conversion. If unmeasured"
	Notebook $nb text=", it will be excluded from the EBAS file.\r"
	Notebook $nb text="\r"
	Notebook $nb fStyle=1, text="2.3. Select time period.", fStyle=-1
	Notebook $nb text="  Note that manual editing of the time intervals is possible only when one or both of the popup menus ar"
	Notebook $nb text="e set to \"User set\".\r"
	Notebook $nb text="\r"
	Notebook $nb fStyle=1, text="2.4. Collection efficiency.", fStyle=-1
	Notebook $nb text="  EETA can be instructed to read collection efficiency valeus from the batch table or a time-dependent w"
	Notebook $nb text="ave with the same number of points as the main time stamp wave (", fStyle=2
	Notebook $nb text="Q-ACSM: root:ACSM_incoming:acsm_utc_time", fStyle=-1, text="). \r"
	Notebook $nb fStyle=1, text="\r"
	Notebook $nb text="2.5. Preview & set flags.", fStyle=-1
	Notebook $nb text=" The green <Preview & set flags> buttons calculates Level 0 and Level 2 versions of the requested data p"
	Notebook $nb text="roducts and opens the Preview window, discussed in step 3.\r"
	Notebook $nb text="\r"
	Notebook $nb fStyle=2
	Notebook $nb text="Q-ACSM: As in preparing a dataset for PMF analysis, the user is prompted to input the gain, dwell time p"
	Notebook $nb text="er m/z, and m/z to use in determining the electronic noise.\r"
	Notebook $nb text="\r"
	Notebook $nb fStyle=-1
	Notebook $nb text="All data products (including flags and time stamps) are stored in the root:EBAS:output datafolder. \r"
	Notebook $nb text="\r"
	Notebook $nb fStyle=5, text="Step 3: Preview data and set flags\r"
	Notebook $nb fStyle=-1
	Notebook $nb text="The Preview panel then appears, showing time series of data at Level 0 and 2 (with or without uncertaint"
	Notebook $nb text="ies) and Level 0 metadata, as well as automatically generated flags.  Automatic flags identify only pres"
	Notebook $nb text="ent or missing data; others must be set by the user.  Other flags can be selected in the Preview panel b"
	Notebook $nb text="y a combination of the <Active flag> and <Apply to> popup menus together with the and graph marquee.\r"
	Notebook $nb text="\r"
	Notebook $nb text="To apply a new flag to a section of data, the user should: (1) Select the desired flag in <Active flag>."
	Notebook $nb text=" (2) Select the target species using the <Apply to> popup menu.  <Apply to> includes several shortcuts f"
	Notebook $nb text="or setting flags across groups of related (meta)data. Within this menu, \"level\" refers to the data level"
	Notebook $nb text=" currently visible on plot, and a \"group\" is a set of related chemical species (e.g. Org, Org_43, Org_44"
	Notebook $nb text=", Org_60). (3) Left-click and drag a marquee covering the x-range (time) in which the flag should be app"
	Notebook $nb text="lied; (4) Right-click within the marquee to bring up its contextual menu, and select <EBAS: apply active"
	Notebook $nb text=" flag>.  Current flags can be viewed in the top panel or by the <View current flags> button. \r"
	Notebook $nb text="\r"
	Notebook $nb text="NOTE: If the <EBAS: apply active flag> option does not appear in the right-click menu, the most likely c"
	Notebook $nb text="ause is a large number of user procedures adding entries to this menu. The user can delete some of these"
	Notebook $nb text=" procedures and retry or set flags manually using the <View current flags> button.\r"
	Notebook $nb text="\r"
	Notebook $nb fStyle=5, text="Step 4: Finalize\r"
	Notebook $nb fStyle=-1
	Notebook $nb text="<Acknowledgement instructions> to EBAS database users can be stored in the file.  A field is also provid"
	Notebook $nb text="ed for any <Additional comments> relevant to measurement, analysis, or other issues.  \r"
	Notebook $nb text="\r"
	Notebook $nb text="It may be the case that the user desires to combine data analyzed in separate IGOR experiments into a si"
	Notebook $nb text="ngle file for uploading to EBAS. The yellow <Save output as itx> and <Merge itx outputs> accomplish this"
	Notebook $nb text=". <Save output as itx> saves the output data and EBAS file headers to an itx file rather than an EBAS-fo"
	Notebook $nb text="rmatted file. <Merge itx outputs> can then be used to load such an itx into an existing experiment, comb"
	Notebook $nb text="ining it with whatever data is currently stored (in root:EBAS:output). Such a merge accounts for inserti"
	Notebook $nb text="on of missing data points (Level 2) and includes all EBAS flags set by the user, but currently does NOT "
	Notebook $nb text="check that the headers are internally consistent.\r"
	Notebook $nb text="\r"
	Notebook $nb text="IMPORTANT: It is typically desirable to do this with the Preview panel open, as the merged data can then"
	Notebook $nb text=" be viewed and flags set. Clicking the <Preview & set flags> button will restart the data product calcul"
	Notebook $nb text="ation and overwrite the merge!\r"
	Notebook $nb text="\r"
	Notebook $nb text="The green <Write EBAS file> button will commence generation of the final files.  It is recommended to vi"
	Notebook $nb text="ew these files in e.g. MS Excel (can import as delimited text file with no selected delimitors).  \r"
	Notebook $nb text="\r"
	Notebook $nb fStyle=5, text="Step 5: Upload to EBAS\r"
	Notebook $nb fStyle=-1
	Notebook $nb text="The Level 2 version of the most recently created files is stored in the <Last file saved> field. The fil"
	Notebook $nb text="e pair can be automatically uploaded to EBAS using the <Upload to EBAS database> button. (A manual uploa"
	Notebook $nb text="d is possible through the EBAS site <EBAS home and FTP button>. Please remember to upload both Level 0 a"
	Notebook $nb text="nd Level 2 files if uploading manually!) \r"
	Notebook $nb text="\r"
	Notebook $nb ruler=Normal; Notebook $nb  justification=1, fStyle=5, text="Appendix: Data and Metadata Fields\r"
	Notebook $nb ruler=Normal, fStyle=4, text="Data (Level 0 and 2)\r"
	Notebook $nb fStyle=-1, text="Org = Organic mass\r"
	Notebook $nb text="SO4 = Sulfate mass\r"
	Notebook $nb text="NO3 = Nitrate mass\r"
	Notebook $nb text="NH4 = Ammonium mass\r"
	Notebook $nb text="Chl = Chloride mass\r"
	Notebook $nb text="Org_43 = Organic mass at m/z 43\r"
	Notebook $nb text="Org_44 = Organic mass at m/z 44\r"
	Notebook $nb text="Org_60 = Organic mass at m/z 60\r"
	Notebook $nb text="\r"
	Notebook $nb fStyle=4, text="Data (Level 0 only)\r"
	Notebook $nb fStyle=-1, text="NO3_30 = Nitrate mass at m/z 30\r"
	Notebook $nb text="NO3_46 = Nitrate mass at m/z 46\r"
	Notebook $nb text="\r"
	Notebook $nb fStyle=4, text="Metadata (Level 0 only)\r"
	Notebook $nb fStyle=-1, text="CE = Collection efficiency\r"
	Notebook $nb text="airbeam = N2 ions per second detected; units are instrument-dependent\r"
	Notebook $nb text="lensPressure = Pressure at the instrument inlet, vacuum side of critical orifice (i.e. flowrate diagnost"
	Notebook $nb text="ic)\r"
	Notebook $nb text="inletPressure = Pressure at the instrument inlet, ambient side of critical orifice\r"
	Notebook $nb text="inletT = Temperature at the instrument inlet, ambient side of critical orifice\r"
	Notebook $nb text="inletRH = Relative humidity at the instrument inlet, ambient side of critical orifice\r"
	Notebook $nb text="RIE_Org = Relative ionization efficiency for organics\r"
	Notebook $nb text="RIE_SO4 = Relative ionization efficiency for sulfate\r"
	Notebook $nb text="RIE_NO3 = Relative ionization efficiency for nitrate\r"
	Notebook $nb text="RIE_NH4 = Relative ionization efficiency for ammonium\r"
	Notebook $nb text="RIE_Chl = Relative ionization efficiency for chloride"


end